/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ub){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function sb(tb){var r=tb.a;var s=r.buffer;r.grow=qb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=tb.abort;var M=NaN;var N=Infinity;var O=tb.b;var P=tb.c;var Q=tb.d;var R=tb.e;var S=tb.f;var T=tb.g;var U=tb.h;var V=tb.i;var W=tb.j;var X=tb.k;var Y=tb.l;var Z=tb.m;var _=tb.n;var $=tb.o;var aa=tb.p;var ba=tb.q;var ca=tb.r;var da=tb.s;var ea=tb.t;var fa=tb.u;var ga=tb.v;var ha=tb.w;var ia=tb.x;var ja=tb.y;var ka=tb.z;var la=tb.A;var ma=tb.B;var na=tb.C;var oa=tb.D;var pa=tb.E;var qa=tb.F;var ra=tb.G;var sa=tb.H;var ta=tb.I;var ua=tb.J;var va=tb.K;var wa=tb.L;var xa=tb.M;var ya=tb.N;var za=tb.O;var Aa=tb.P;var Ba=tb.Q;var Ca=tb.R;var Da=tb.S;var Ea=tb.T;var Fa=tb.U;var Ga=tb.V;var Ha=tb.W;var Ia=tb.X;var Ja=tb.Y;var Ka=tb.Z;var La=tb._;var Ma=tb.$;var Na=tb.aa;var Oa=tb.ba;var Pa=tb.ca;var Qa=tb.da;var Ra=tb.ea;var Sa=tb.fa;var Ta=tb.ga;var Ua=tb.ha;var Va=tb.ia;var Wa=tb.ja;var Xa=tb.ka;var Ya=tb.la;var Za=tb.ma;var _a=tb.na;var $a=tb.oa;var ab=tb.pa;var bb=tb.qa;var cb=tb.ra;var db=tb.sa;var eb=tb.ta;var fb=tb.ua;var gb=5709392;var hb=0;var ib=0;var jb=0;
// EMSCRIPTEN_START_FUNCS
function Gt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=C(0),_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=C(0),xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=C(0),Ua=0;$=gb-48|0;gb=$;ma=$+40|0;v[ma>>2]=55324;v[ma>>2]=55224;e=gL($+32|0);g=gL($+24|0);d=v[e+4>>2];v[$+16>>2]=v[e>>2];v[$+20>>2]=d;e=v[g+4>>2];v[$+8>>2]=v[g>>2];v[$+12>>2]=e;ka=b;oa=c;c=0;V=gb-128|0;gb=V;K=a;pa=a+24604|0;a=pa;a:{if(!v[a+16>>2]){break a}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){b=V+112|0;WO(b,6290,10346,200,45);a=gb-160|0;gb=a;v[a+88>>2]=0;e=gu(a+88|0);v[22708]=0;c=Q(2,a+120|0,14848)|0;g=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{if((g|0)!=1){v[22708]=0;U(6,a+104|0,1,14490);g=v[22708];v[22708]=0;if((g|0)==1){break h}v[22708]=0;U(3,a+136|0,c|0,a+104|0);g=v[22708];v[22708]=0;if((g|0)==1){break g}v[22708]=0;ha(33,e|0,b|0,1,10899,a+136|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}vb(a+136|0);vb(a+104|0);vb(c);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(a+136|0)}vb(a+104|0)}vb(c)}S(b|0);L()}gb=a+160|0}a=v[K+480208>>2];i:{if(!ka|a&512){break i}ya=K+8204|0;za=K+1074332|0;Aa=K+397452|0;Ba=K+397448|0;Ca=K+393352|0;Da=K+397456|0;ea=K+12|0;qa=K+1298260|0;Ea=K+1074376|0;F=v[K+1074380>>2];while(1){j:{if(F){break j}W=K;b=a|512;k:{if(a&256){break k}F=0;o=gb-48|0;gb=o;J=gb-32|0;gb=J;j=K;d=j;b=d+1074392|0;a=v[b>>2]+1|0;v[b>>2]=a;l:{m:{k=d+1074376|0;n:{if(tk(k)>>>0>a>>>0){break n}s=d+1074312|0;e=d+1074992|0;a=d+1298224|0;p=d+1074424|0;i=d+484344|0;f=d+484360|0;h=d+1074448|0;l=d+480210|0;while(1){Sz(J+24|0,d,k,(v[d+480208>>2]&524288)>>>19|0);o:{p:{q:{r:{if(!(w[d+480208|0]&32)){c=x[h>>1];b=d;s:{if(tc(Sb(f))>>>0>c>>>0){c=x[sc(Sb(f),x[h>>1])>>1];break s}c=65535}u[b+1074446>>1]=c;t:{if(Te(i)>>>0<=(c&65535)>>>0){break t}if(ii(_b(i,x[d+1074446>>1]))){break t}u[d+1074446>>1]=65534}if(x[d+1074446>>1]>=Te(i)>>>0){while(1){u:{v:{w:{x:{if(x[d+1074446>>1]!=65535){b=x[h>>1];if(tc(Sb(f))>>>0>b>>>0){break x}}g=x[Sb(f)+28>>1];if(g){break v}b=x[h>>1];if(tc(Sb(f))>>>0<b>>>0){break w}c=x[h>>1];if(!c){break w}while(1){g=c;c=c-1|0;if(!c){break w}if(x[sc(Sb(f),c)>>1]!=65535){continue}break}break v}c=x[h>>1]+1|0;u[h>>1]=c;break u}g=0}u[d+1074448>>1]=g;v[d+480208>>2]=v[d+480208>>2]&-524289;y:{if(tc(Sb(f))>>>0<=(g&65535)>>>0){break y}while(1){if(x[sc(Sb(f),x[h>>1])>>1]!=65534){break y}b=x[h>>1]+1|0;u[h>>1]=b;if(tc(Sb(f))>>>0>(b&65535)>>>0){continue}break}}b=x[h>>1];if(tc(Sb(f))>>>0<=b>>>0){break r}if(!Oo(Sb(f),x[h>>1])){break r}c=x[h>>1]}b=d;z:{if(tc(Sb(f))>>>0>(c&65535)>>>0){c=x[sc(Sb(f),x[h>>1])>>1];break z}c=65535}u[b+1074446>>1]=c;A:{if(Te(i)>>>0<=(c&65535)>>>0){break A}if(ii(_b(i,x[d+1074446>>1]))){break A}u[d+1074446>>1]=65534}if(x[d+1074446>>1]>=Te(i)>>>0){continue}break}}u[d+1074450>>1]=x[d+1074448>>1]}if(!me(i,x[d+1074446>>1])){break m}if(y[d+1074424>>2]>=y[_b(i,x[d+1074446>>1])+12>>2]){v[p>>2]=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break o}if(!Bu(a,x[h>>1],v[p>>2],Hq(J+16|0,e),w[J+24|0])){break o}b=v[d+480272>>2];if(b){if((b|0)>=1){v[d+480272>>2]=b-1}Jo(a,1);Bu(a,x[h>>1],v[p>>2],Hq(J+16|0,e),w[J+24|0]);break o}if(!(w[l|0]&64)){break r}if(oR(a,h,p,1)){break p}v[d+1074448>>2]=0;v[d+1074424>>2]=0;v[d+1074428>>2]=0;if(w[f+16|0]<(Ri(f)-1|0)){break q}Si(f,0)}Jo(a,1);break m}Si(f,w[f+16|0]+1&255);Jo(a,1)}c=0;while(1){$m((d+B(c,872)|0)+1074992|0,7,d,c&65535,134217728);c=c+1|0;if((c|0)!=256){continue}break}MO(d);v[d+1074416>>2]=v[d+480196>>2];v[d+1074420>>2]=v[d+480204>>2];v[d+1074456>>2]=v[d+480200>>2];u[d+1074450>>1]=x[d+1074448>>1];v[d+1074428>>2]=v[d+1074424>>2];c=a;g=tc(Sb(f));b=x[d+1074448>>1];if(g>>>0>b>>>0){Ra=d,Sa=x[sc(Sb(f),x[d+1074448>>1])>>1],u[Ra+1074446>>1]=Sa;b=x[d+1074448>>1]}Bu(c,b&65535,v[d+1074424>>2],Hq(J+16|0,e),w[J+24|0]);if(!me(i,x[d+1074446>>1])){break m}}Rz(d,k,(v[d+480208>>2]&32)>>>5|0);g=Yc(_b(i,x[d+1074446>>1]),v[d+1074424>>2],0);b=x[d+480188>>1];if(b){n=(d+B(b,872)|0)+1074992|0;c=e;while(1){b=J+16|0;Db(b,s,82);B:{if(!Cb(b)|w[c+805|0]!=1){break B}b=w[g+3|0];if((b|0)!=2&(b|0)!=3){break B}Ra=c,Sa=_g(d,w[c+800|0],u[c+772>>1],v[c+704>>2]),v[Ra+700>>2]=Sa}b=J+16|0;Db(b,s,91);C:{if(!Cb(b)){break C}if(ce(g)){break C}if(!ce(c+788|0)|w[c+791|0]!=19){break C}b=w[c+793|0];if((b&240)!=208|y[d+1074416>>2]>(b&15)>>>0){break C}Ra=c,Sa=_g(d,w[c+788|0],u[c+772>>1],0),v[Ra+700>>2]=Sa}b=J+16|0;Db(b,s,92);D:{if(!Cb(b)){break D}b=J+8|0;Db(b,s,5);if(Cb(b)|v[d+1074416>>2]!=1|w[c+791|0]!=17){break D}v[d+1074420>>2]=B(w[c+793|0],1e4)}b=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c+788|0]=b;t[c+789|0]=b>>>8;t[c+790|0]=b>>>16;t[c+791|0]=b>>>24;b=w[g+4|0]|w[g+5|0]<<8;t[c+792|0]=b;t[c+793|0]=b>>>8;b=v[c+676>>2];v[c+20>>2]=v[c+672>>2];v[c+24>>2]=b;v[c+88>>2]=v[c+88>>2]&-393217;b=J+16|0;Db(b,s,21);if(!Cb(b)){t[c+831|0]=0}v[c+860>>2]=0;t[c+805|0]=0;g=g+6|0;c=c+872|0;if((n|0)!=(c|0)){continue}break}}b=d;g=b+1074412|0;E:{F:{c=b+484344|0;if(cm(c,x[b+1074446>>1])){if(MP(_b(c,x[b+1074446>>1]))){break F}}v[b+1074408>>2]=v[b+480216>>2];b=v[b+480220>>2];break E}Ra=b+1074408|0,Sa=v[_b(c,x[b+1074446>>1])+16>>2],v[Ra>>2]=Sa;b=v[_b(c,x[b+1074446>>1])+20>>2]}v[g>>2]=b;if(!w[J+24|0]){break n}b=v[d+1074416>>2]+1|0;v[d+1074392>>2]=b;if(tk(k)>>>0<=b>>>0){continue}break}}if(!v[d+1074416>>2]){v[d+1074416>>2]=1}b=v[d+480208>>2];a=d;c=a;G:{H:{if(v[a+1074392>>2]){v[d+480208>>2]=b&-4097;if(v[d+480180>>2]&1048580|(w[d+480210|0]&32?0:v[d+480180>>2]==1)){break G}if(y[d+1074392>>2]>=tk(k)>>>0|y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)){break G}a=v[d+480208>>2];break H}a=b&-528385}v[c+480208>>2]=a|4096}A=0;q=gb-16|0;gb=q;u[d+1074444>>1]=65535;a=d+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;G=d+480208|0;R=d+1074376|0;if(x[d+480188>>1]){ca=d+1075809|0;I=d+1298260|0;E=d+1074312|0;da=d+480210|0;while(1){m=d+B(A,872)|0;i=m+1075785|0;f=w[i|0];k=m+1075783|0;b=w[k|0];p=m+1075784|0;c=w[p|0];Y=m+1075782|0;e=w[Y|0];T=m+1075781|0;g=w[T|0];a=v[d+1074392>>2];h=v[d+1074400>>2];l=v[d+1074416>>2];N=m+1075780|0;s=uu(N);X=m+1075843|0;t[X|0]=v[d+480208>>2]>>>12&1|w[X|0]&254;H=(a>>>0)%(h+l>>>0)|0;n=w[N|0];if((n|0)==252){a=w[T|0];h=Gq(N);l=Fo(N);I:{if((a-1&255)>>>0>249){break I}a=v[(d+B(a,160)|0)+906140>>2];if(!a){break I}kb[v[v[a>>2]+44>>2]](a,h,C(C(l>>>0)/C(999)))}n=w[N|0]}J:{if(b&255|z[m+1075852>>2]==C(0)?(n&255)!=251:0){break J}l=v[G>>2]&4096;K:{if(!l){h=w[m+1075862|0];break K}h=w[T|0];t[m+1075862|0]=h}if((h-1&255)>>>0>249){break J}a=(d+B(h,160)|0)+906140|0;if(!v[a>>2]){break J}L:{if(!l){n=x[m+1075860>>1];break L}n=qu(w[Y|0],w[p|0]);u[m+1075860>>1]=n;Z=C(C(qu(w[k|0],w[i|0])>>>0)/C(999));z[m+1075856>>2]=Z;h=v[a>>2];Ra=m+1075852|0,Ta=C(C(Z-C(kb[v[v[h>>2]+48>>2]](h,n)))/C(tk(R)>>>0)),z[Ra>>2]=Ta}h=v[d+1074392>>2];i=tk(R);a=v[a>>2];h=(i|0)==(h+1|0);kb[v[v[a>>2]+(h?44:104)>>2]](a,n,z[(h?m+1075856|0:m+1075852|0)>>2]);n=w[N|0]}l=m+1074992|0;M:{N:{O:{P:{Q:{if(!GP(n&255)){if(w[G+1|0]&16){break P}a=g;break Q}a=gb-16|0;gb=a;u[a+12>>1]=0;v[a+8>>2]=0;cj(a+8|0);b=x[a+12>>1];t[l+792|0]=b;t[l+793|0]=b>>>8;b=v[a+8>>2];t[l+788|0]=b;t[l+789|0]=b>>>8;t[l+790|0]=b>>>16;t[l+791|0]=b>>>24;gb=a+16|0;a=0;e=0;c=0;b=0;f=0;s=0;i=0;p=0;k=0;g=0;n=0;h=0;if(w[G+1|0]&16){break N}}zP(d,l);g=a;break O}if(!g){g=0;break O}v[m+1075752>>2]=0}R:{S:{if((b&255)==33){a=q+8|0;Db(a,E,30);n=f>>>4|0;rA(d,A&65535,n+(f&15)|0,Cb(a));b=33;break S}n=0;T:{if((b-19&255)>>>0>1){break T}U:{if(!(!(v[d+480180>>2]&16777250)|f)){f=w[m+1075825|0];break U}t[m+1075825|0]=f}a=f&240;if((a|0)==208){h=f&15;if(!h){if(v[d+480180>>2]&16777248){i=b;p=c;n=1;break R}a=s;i=b;p=c;k=e;h=f;if(v[d+480180>>2]!=2){break N}break M}V:{if(h>>>0<v[d+1074400>>2]+v[d+1074416>>2]>>>0){break V}a=q+8|0;Db(a,E,14);if(!Cb(a)){break V}if(!g){break M}t[m+1075795|0]=g;break M}i=b;p=c;n=h;break R}if(!(w[G+1|0]&16)|(a|0)!=224|(v[d+1074396>>2]?v[d+480180>>2]&16777250:0)){break T}a=f&15;if(a?0:v[d+480180>>2]&2){break T}v[d+1074396>>2]=a+1}}i=b;p=c}a=s;k=e;h=f}_=i&255;c=v[d+480180>>2]==16&(_|0)==19&(h&240)==208;M=c?0:n;W:{if(!M|w[N|0]!=255|w[Y|0]!=2){break W}b=q+8|0;Db(b,E,74);if(!Cb(b)){break W}t[Y|0]=0}b=v[d+1074392>>2];e=q+8|0;Db(e,E,72);X:{if(Cb(e)){r=0;if(M>>>0>=y[d+1074416>>2]){break X}}e=q+8|0;Db(e,E,88);r=(H|0)==(M|0)|(b|0)==(M|0);if(!(!Cb(e)|!M)){break X}r=(b|0)==(M|0)}b=q+8|0;Db(b,E,44);if(Cb(b)){t[X|0]=w[X|0]&254|(H|0)==(M|0)}ba=h&15;f=c?ba|144:h;b=q+8|0;Db(b,E,66);b=(!M|Cb(b)^-1)&a;Y:{Z:{if(!(v[d+1074392>>2]|(!(w[da|0]&32)|!g))){v[m+1075652>>2]=0;if(r){break Z}if(!Oi(l)){break Y}t[m+1075795|0]=g;if(x[d+480190>>1]<g>>>0){break Y}a=d+B(g,104)|0;v[m+1075680>>2]=x[a+484410>>1];u[m+1075764>>1]=t[a+484417|0];break Y}if(!r){break Y}}h=w[N|0];if(g){t[m+1075795|0]=g}_:{$:{if(!ve(h)){break $}a=q+8|0;Db(a,E,67);if(!Cb(a)){break $}a=u[m+1075762>>1];aa:{if(!g|b){break aa}c=bA(d,h,g);if(!c){break aa}a=t[Ak(d,c)+36|0]}h=(a+h|0)-12>>>0>119?0:h;break _}if(!(v[d+480180>>2]&25165856)|!x[d+480192>>1]){break _}a=h;if(a){a=ve(a)}else{a=1}if(!a){break _}a=g;ba:{if(!a){a=w[m+1075796|0];if(!a){break ba}}if(v[(d+(a<<2)|0)+900380>>2]?x[d+480192>>1]>=a>>>0:0){break _}h=0}g=0}if(!((_|0)!=25|f)){a=q+8|0;Db(a,E,55);a=Cb(a);g=a?0:g;h=a?0:h}c=q+8|0;Db(c,E,65);a=(g|0)!=0;e=!h;c=Cb(c);n=1;ca:{if(v[d+480180>>2]&16777248){break ca}s=q+8|0;Db(s,E,107);if(Cb(s)){break ca}Db(q,E,85);n=0;if(!Cb(q)){break ca}if(Oi(l)){break ca}n=1;s=v[m+1075096>>2];if(!s){break ca}n=Md(s)^1}H=a&e;s=a&c;da:{ea:{fa:{ga:{ha:{ia:{if(!(v[d+480180>>2]&1048580)){break ia}ja:{if((h|0)!=255){break ja}if(!(!((k&255)==1|g)&(_|0)!=13)){a=q+8|0;Db(a,E,55);if(Cb(a)){break ja}}a=v[m+1075648>>2];if(t[a+60|0]&1?a:0){break ja}v[m+1075680>>2]=0;a=m+1075080|0;v[a>>2]=v[a>>2]|2097152;ka:{if(!(v[d+480208>>2]&4096)){break ka}c=q+8|0;Db(c,E,86);if(!Cb(c)){break ka}v[a>>2]=v[a>>2]|4096}g=0;h=0;e=0;a=0;c=0;H=1;if(s){break ea}break da}a=q+8|0;Db(a,E,59);if(!Cb(a)|v[G>>2]&4096){break ia}la:{if(!h){h=w[m+1075789|0]-w[m+1075762|0]|0;break la}if(h>>>0>250){n=0;s=1;h=0;break la}ma:{if(g){break ma}a=q+8|0;Db(a,E,98);if(!Cb(a)){break ma}g=0;break la}n=1;s=1}e=h;b=0;break ha}e=0;c=0;if(!H){break ga}}a=q+8|0;Db(a,E,65);if(!Cb(a)){break fa}h=e;c=1}a=h;e=c;H=1;if(s){break ea}break da}h=e;e=1;H=s}na:{oa:{if(!x[d+480192>>1]){if(x[d+480190>>1]<g>>>0){break na}a=(d+B(g,104)|0)+484380|0;break oa}a=v[m+1075096>>2];if(!a){break na}}pa:{if(u[a+34>>1]<0){break pa}if(v[d+480180>>2]==2){if(!Md(a)){break pa}}v[m+1075680>>2]=x[a+30>>1]}if(!H){break na}To(l,x[a+28>>1],d)}a=h;c=e}e=q+8|0;Db(e,E,71);if(!(!Cb(e)|!g)){t[m+1075831|0]=32}qa:{if(!x[d+480192>>1]){break qa}e=q+8|0;Db(e,E,100);if(!Cb(e)|!g){break qa}if(ve(a&255)){break qa}e=v[G>>2];ra:{if(b){if(e&8){break ra}break qa}if(!(e&4)){break qa}}Nm(l);v[m+1075688>>2]=65536;e=m+1075080|0;v[e>>2]=v[e>>2]|2097152}if(c){c=q+8|0;Db(c,E,11);sa:{if(!Cb(c)&v[d+480180>>2]!=268435456){break sa}c=q+8|0;Db(c,E,87);h=0;if(Cb(c)){h=Oi(l)^1}ta:{if(x[d+480192>>1]){if(x[d+480192>>1]<g>>>0){break sa}if(v[m+1075648>>2]!=v[(d+(g<<2)|0)+900380>>2]|h){break ta}break sa}if((v[m+1075096>>2]!=((d+B(g,104)|0)+484380|0)|h)!=1){break sa}}a=w[m+1075789|0]}ua:{if(!x[d+480192>>1]|!(v[d+480180>>2]&1048588)){break ua}Nm(l);t[m+1075810|0]=0;v[m+1075748>>2]=0;v[m+1075688>>2]=65536;c=m+1075080|0;v[c>>2]=v[c>>2]&-2101249|2097152;e=q+8|0;Db(e,E,86);if(!Cb(e)){break ua}v[c>>2]=v[c>>2]&-2049}g=n?g:0}h=a&255;va:{if(h>>>0<251){break va}c=q+8|0;Db(c,E,50);wa:{if(!Cb(c)|!g){break wa}c=bA(d,w[m+1075791|0],g);if(!c){break wa}c=d+B(c,104)|0;if(u[c+484414>>1]<0){break wa}v[m+1075680>>2]=x[c+484410>>1]}c=q+8|0;Db(c,E,100);if(Ra=Cb(c),Sa=0,Ua=v[G>>2]&4,Ua?Ra:Sa){break va}g=0}xa:{if(!ve(h)){break xa}t[m+1075794|0]=a;t[m+1075791|0]=a;if(!b){CP(d,A&65535,g,h,0)}c=m+1075776|0;a=u[c>>1];if(a){v[m+1075684>>2]=(a&32767)-1;if((a|0)<=-1){a=m+1075080|0;v[a>>2]=v[a>>2]|256}u[c>>1]=0}a=m+1075787|0;c=w[a|0];if(c){t[m+1075830|0]=c-1;t[a|0]=0}a=m+1075788|0;c=w[a|0];if(!c){break xa}t[m+1075829|0]=c-1;t[a|0]=0}ya:{za:{Aa:{Ba:{Ca:{if(g){c=m+1075096|0;e=v[c>>2];Eo(d,l,g,b,1,1);a=v[c>>2];Da:{if(!a|!(w[a+35|0]&2)){break Da}if(!Dd(I)){break Da}Eu(v[I>>2],A&65535,v[c>>2]+68|0)}Ea:{Fa:{if(v[d+480180>>2]==1){if(!b){break Fa}a=q+8|0;Db(a,E,85);if(!Cb(a)){break Fa}break Ea}a=q+8|0;Db(a,E,50);if(!Cb(a)){break Fa}if(!ve(h)){break Ea}}t[m+1075795|0]=0}a=q+8|0;Db(a,E,42);if(Cb(a)){if(!ve(h)|(e|0)==v[c>>2]){break Ba}break Ca}if(!(!(v[d+480180>>2]&16777248)|(e|0)==v[c>>2])){a=0;if(ve(h)){break Aa}}a=q+8|0;Db(a,E,107);Ga:{if(!Cb(a)|(e|0)==v[c>>2]){break Ga}Ha:{if(!b){if(ve(h)){break Ha}}a=m+1075068|0;if(y[a>>2]>=y[l+4>>2]){break Ga}v[a>>2]=0;break Ba}b=0}a=q+8|0;Db(a,E,85);if(!Cb(a)){break Ba}if(!Oi(l)){break Ca}break Ba}if(!h){a=b;break ya}e=0;s=m+1075795|0;Ia:{if(!w[s|0]){break Ia}if(!ve(h)){break Ia}Eo(d,l,w[s|0],b,!(v[m+1075096>>2]?1:v[m+1075648>>2]),!(v[d+480180>>2]&1048580));t[s|0]=0;e=1}a=b;break za}v[l>>2]=0;v[l+4>>2]=0}a=b}e=0;if(!h){break ya}}b=m+1075096|0;c=v[b>>2];Ja:{if(!c|!(w[c+35|0]&2)){break Ja}if(!Dd(I)){break Ja}if(!e){if(DP(v[I>>2],A&65535)){break Ja}}Eu(v[I>>2],A&65535,v[b>>2]+68|0)}b=A&65535;ru(d,l,h,a,!(v[d+480180>>2]&1048580),0,b);if(!(!a|(!(v[d+480180>>2]&1048580)|!g))){c=m+1075080|0;v[c>>2]=v[c>>2]|2097152;Nm(l);t[m+1075810|0]=0;v[m+1075748>>2]=0}if(!(v[m+1075080>>2]&512)){break ya}if(!Dd(I)){break ya}if(h>>>0<=253){if((h|0)!=253){break ya}c=q+8|0;Db(c,E,99);if(Cb(c)){break ya}}c=q+8|0;Db(c,E,110);if(Cb(c)){XA(v[I>>2],b,0,1,0)}uk(v[I>>2],b)}Ka:{La:{switch((k&255)-1|0){case 0:p=p>>>0<64?p:64;v[m+1075680>>2]=p<<2;b=m+1075080|0;v[b>>2]=v[b>>2]|2097152;break Ka;case 1:break La;default:break Ka}}Pm(d,l,p,6)}if(x[d+480192>>1]){kO(d,A&65535)}b=a}a=q+8|0;Db(a,E,77);if(Ra=Cb(a),Sa=0,Ua=v[(d+(A<<5)|0)+480280>>2]&1024,Ua?Ra:Sa){break M}a=v[d+1074392>>2];c=q+8|0;Db(c,E,75);e=a>>>0>=M>>>0;Ma:{Na:{Oa:{Pa:{if(!Cb(c)|!M){break Pa}c=v[d+1074392>>2];if(!c){break Oa}e=1;if((c|0)!=(M|0)){break Pa}e=!w[T|0]&(k&255)!=11}a=k&255;if(!e|a>>>0<3){break Oa}if((a|0)==11){a=q+8|0;zA(a,d,N,M);c=w[Ve(a)|0];Ao(d,l,x[a>>1]);if(c){break Na}k=11;break Oa}c=q+8|0;Db(c,E,62);Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{if(!(!Cb(c)|p)){p=0;k=0;Xa:{switch(a-8|0){case 0:break Wa;case 1:break Xa;default:break Oa}}if(w[G+1|0]&16){break Oa}v[m+1075684>>2]=0;break Oa}c=q+8|0;Db(c,E,41);Ya:{if(Cb(c)){break Ya}if(p){t[m+1075826|0]=p;break Ya}p=w[m+1075826|0]}Za:{switch(a-3|0){case 0:case 1:_a:{$a:{if(p){break $a}c=q+8|0;Db(c,E,41);if(!Cb(c)){break $a}p=w[m+1075826|0];if(p){break _a}p=0;break Oa}t[m+1075826|0]=p}Do(d,l,((a|0)==3?p<<4:p)&255);break Oa;case 2:if((M|0)!=v[d+1074392>>2]){a=q+8|0;Db(a,E,41);k=5;if(Cb(a)){break Oa}}a=q+8|0;Db(a,E,41);Fq(d,l,p,Cb(a));k=5;break Oa;case 3:if((M|0)!=v[d+1074392>>2]){a=q+8|0;Db(a,E,41);k=6;if(Cb(a)){break Oa}}a=q+8|0;Db(a,E,41);Eq(d,l,p,Cb(a));k=6;break Oa;case 11:break Qa;case 12:break Ra;case 10:break Sa;case 9:break Ta;case 7:break Ua;case 6:break Va;case 5:break Wa;case 4:break Za;default:break Oa}}a=q+8|0;Db(a,E,53);if(Cb(a)){t[m+1075815|0]=p&15;k=7;break Oa}Hl(l,p<<4);k=7;break Oa}Hl(l,p);k=8;break Oa}a=q+8|0;Db(a,E,62);qA(d,l,p,Cb(a)^1);k=9;break Oa}a=q+8|0;Db(a,E,62);qA(d,l,p<<4&240,Cb(a)^1);k=10;break Oa}k=12;a=q+8|0;Db(a,E,12);yP(d,A&65535,p<<2&252,Cb(a));break Oa}a=q+8|0;Db(a,E,12);xP(d,A&65535,p<<2&252,Cb(a));k=13;break Oa}k=15;if(!r){break Oa}a=m+1075096|0;if(!v[a>>2]|p>>>0>9){break Oa}ab:{if(!p){g=v[m+1075656>>2];break ab}g=v[Pe(v[a>>2]+68|0,p-1|0)>>2];v[m+1075656>>2]=g}Om(d,l,g);break Oa}k=14;if(p>>>0>1){break Oa}t[X|0]=w[X|0]&251|!p<<2}g=f;bb:{cb:{db:{eb:{switch(_-1|0){case 12:if(!(w[G+1|0]&16)){break Na}a=d+B(A,872)|0;v[a+1075680>>2]=f>>>0<64?f<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Na;case 1:if(!f){g=0;if(v[d+480180>>2]&1){break Ma}}yP(d,A&65535,f,0);break Na;case 2:if(!f){g=0;if(v[d+480180>>2]&1){break Ma}}xP(d,A&65535,f,0);break Na;case 10:if(!f){g=0;if(v[d+480180>>2]==1){break Ma}}Do(d,l,f);break Na;case 3:Ao(d,l,f);break Na;case 5:if(!(!f&v[d+480180>>2]==1)){Do(d,l,f)}Ao(d,l,0);break Na;case 4:Hl(l,f);break Na;case 6:if(!(!f&v[d+480180>>2]==1)){Do(d,l,f)}Hl(l,0);break Na;case 15:if(!(w[G+1|0]&16)){break Na}break bb;case 16:a=q+8|0;Db(a,E,5);if(Cb(a)){if(!(w[G+1|0]&16)){break Na}if(f){break bb}break Na}g=Qm(d,x[d+1074446>>1],v[d+1074424>>2],A&65535,0);fb:{if(!(v[d+480180>>2]&16777250)){break fb}if(g){t[(d+B(A,872)|0)+1075827|0]=g;break fb}g=w[(d+B(A,872)|0)+1075827|0]}v[q+8>>2]=B(g,1e4);qc(q+8|0,B(v[v[d+8>>2]+24>>2],1e4));b=gb-16|0;gb=b;e=v[q+8>>2];v[b+8>>2]=e;a=d;c=v[a+8>>2];gb:{if(e>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){e=v[a+480208>>2];Db(b,a+1074312|0,92);if((Cb(b)|0)==((e&4096)>>>12|0)){break gb}v[b>>2]=B(v[c+24>>2],1e4);c=a+1074420|0;a=b+8|0;Ra=c,Sa=v[(zn(b,a)?b:a)>>2],v[Ra>>2]=Sa;break gb}if(w[a+480209|0]&16){break gb}f=a+1074420|0;e=(e>>>0)/1e4|0;h=B(e&15,1e4);v[f>>2]=v[f>>2]+((e&240)==16?h:0-h|0);e=v[c+20>>2];c=v[c+24>>2];Db(b,a+1074312|0,8);Fp(f,B(e,1e4),Cb(b)?255e4:B(c,1e4))}gb=b+16|0;break Ma;case 9:if(!r|(v[d+480180>>2]==4?b:0)){break Na}LP(d,l,A&65535,R);break Na;case 43:if(!r){break Na}b=nqa(v[(d+B(A,872)|0)+1075068>>2],0,f,0);a=jb;e=a>>>8|0;Om(d,l,Qc((a&255)<<24|b>>>8,e));break Na;case 0:if(v[d+1074392>>2]){break Na}a=d+B(A,872)|0;hb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break hb}a=v[a+1075648>>2];if(a){if(Ij(a)){break hb}}a=q+8|0;Db(a,E,13);if(Cb(a)){break hb}if(v[d+480180>>2]&16777248){break Na}}if(!f){g=0;if(v[d+480180>>2]&5){break Ma}t[(d+B(A,872)|0)+1075797|0]=1;break Ma}a=d+B(A,872)|0;t[a+1075798|0]=f;t[a+1075797|0]=1;break Na;case 14:if(v[d+480180>>2]&1048580){f=f&240?f:w[(d+B(A,872)|0)+1075799|0]&240|f;if(!(f&15)){f=w[(d+B(A,872)|0)+1075799|0]&15|f}g=f|256}else{g=f}a=q+8|0;Db(a,E,23);if(Cb(a)){b=d;c=A&65535;if(g){t[(d+B(A,872)|0)+1075799|0]=g;a=g}else{a=w[(d+B(A,872)|0)+1075799|0]}pA(b,c,a&255,(k&255)==15?p+1|0:0);break Ma}ib:{if(g){t[(d+B(A,872)|0)+1075799|0]=g;break ib}g=w[(d+B(A,872)|0)+1075799|0]}pA(d,A&65535,g,(k&255)==15?p+1|0:0);break Ma;case 17:if(!(w[G+1|0]&16)){break Na}a=q+8|0;Db(a,E,22);jb:{kb:{if(Cb(a)){if(!f){f=0;break kb}if(w[G|0]&4){break kb}a=f&240?f-16|0:f;f=a-((a&15)!=0)|0;t[(d+B(A,872)|0)+1075832|0]=f;break kb}a=q+8|0;Db(a,E,71);if(!Cb(a)){break jb}}a=(d+B(A,872)|0)+1075831|0;t[a|0]=w[a|0]|128}a=d+B(A,872)|0;t[a+1075797|0]=18;if(!f){g=0;break Ma}t[a+1075832|0]=f;break Na;case 22:if(!(w[G+1|0]&16)){break Na}g=f<<!(v[d+480180>>2]&59593760);if(g>>>0<=128){v[d+1074456>>2]=g<<1;break Ma}if(v[d+480180>>2]&16777250){break Ma}v[d+1074456>>2]=256;break Ma;case 23:a=q+8|0;Db(a,E,9);if(Cb(a)){wP(d,f,(d+B(A,872)|0)+1075809|0);break Na}wP(d,f,ca);break Na;case 8:if(!(w[G+1|0]&16)){break Na}Pm(d,l,f,8);break Na;case 28:qA(d,l,f,1);break Na;case 7:OP(l,f);break Na;case 25:PP(d,l,f);break Na;case 18:a=d;i=a+1074376|0;e=A&65535;h=B(e,872);g=(i+h|0)+616|0;b=f;c=b&15;lb:{mb:{switch(b>>>4|0){case 0:if(!x[a+480188>>1]){break lb}c=(b&1)<<14;b=0;while(1){e=(a+B(b,872)|0)+1075080|0;v[e>>2]=(c|v[e>>2]&-16385)^16384;b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break};break lb;case 1:if(!(v[a+480180>>2]&1048580?1:c)){break lb}oP(a,g,c);break lb;case 2:if(!(v[a+480180>>2]&1048580?1:c)){break lb}nP(a,g,c);break lb;case 3:a=(a+h|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((c|0)!=0)<<20;break lb;case 4:t[(a+h|0)+1075814|0]=b&7;break lb;case 5:if(!(w[a+480209|0]&16)){break lb}if(v[a+480180>>2]&69206025){b=a+B(e,872)|0;g=b+1075764|0;u[g>>1]=c<<28>>24;c=b+1075692|0;if(!v[c>>2]){break lb}if(!ce(b+1075780|0)){break lb}b=a;a=a+B(e,872)|0;Ra=c,Sa=_g(b,w[a+1075789|0],u[g>>1],v[a+1075696>>2]),v[Ra>>2]=Sa;break lb}h=v[a+480180>>2];g=ce((a+B(e,872)|0)+1075780|0);if((h|0)==16){if(!g){break lb}b=a+B(e,872)|0;g=v[b+1075096>>2];if(!g){break lb}t[g+37|0]=c;u[b+1075764>>1]=c;b=b+1075692|0;if(!v[b>>2]){break lb}g=a;a=a+B(e,872)|0;Ra=b,Sa=_g(g,w[a+1075789|0],c,v[a+1075696>>2]),v[Ra>>2]=Sa;break lb}if(!g){break lb}c=a+B(e,872)|0;b=(b<<4^-128)<<24>>24;u[c+1075764>>1]=b;e=c+1075692|0;if(!v[e>>2]){break lb}Ra=e,Sa=_g(a,w[c+1075789|0],b,v[c+1075696>>2]),v[Ra>>2]=Sa;break lb;case 6:if(!(w[a+480209|0]&16)){break lb}su(a,i,g,c);break lb;case 7:t[(a+h|0)+1075817|0]=b&7;break lb;case 8:if(!(w[a+480209|0]&16)){break lb}Pm(a,g,c,4);break lb;case 9:pA(a,e,c,0);break lb;case 10:if(!(v[a+480180>>2]&1048580?1:c)){break lb}Fq(a,g,c,0);break lb;case 11:if(!(v[a+480180>>2]&1048580?1:c)){break lb}Eq(a,g,c,0);break lb;case 12:rA(a,e,c,0);break lb;case 15:break mb;default:break lb}}if(v[a+480180>>2]==1){t[(a+B(e,872)|0)+1075838|0]=c;if(!(w[a+480209|0]&16)){break lb}zP(a,g);break lb}t[(a+B(e,872)|0)+1075836|0]=c}break Na;case 19:b=q+8|0;Db(b,E,78);a=d;c=A&65535;g=f;nb:{if(!Cb(b)){break nb}g=f;if(f){break nb}g=w[(d+B(A,872)|0)+1075798|0]}vP(a,c,g);break Ma;case 24:a=q+8|0;Db(a,E,55);if(Cb(a)){if(v[d+1074392>>2]!=(f|0)){break Na}a=v[(d+B(A,872)|0)+1075648>>2];if(t[a+60|0]&1?a:0){break cb}if(!(!(w[Y|0]?1:w[T|0])|f)){a=(d+B(A,872)|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break cb}a=d+B(A,872)|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break cb}if(w[G+1|0]&16){break cb}break Na;case 27:a=(f&240)-16>>>4|0;if(a>>>0>9){break Na}if(!(1<<a&880)){if(!a){break db}if((a|0)!=1){break Na}uP(d,l,f&15);break Na}a=q+8|0;Db(a,E,58);if(Cb(a)){break Na}vP(d,A&65535,f);break Na;case 34:case 35:if(!(w[G+1|0]&16)&(i&255)!=36){break Na}a=A&65535;JP(d,a,R,(i&255)==36);b=nu(d,a);if(!b){break Na}kb[v[v[b>>2]+80>>2]](b,x[l+774>>1]>>>2^8192,a);break Na;case 20:if(!(w[G+1|0]&16)|f>>>0>64){break Na}a=d+B(A,872)|0;v[a+1075740>>2]=f;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Na;case 21:c=d;b=l;a=f;ob:{if(a){t[b+816|0]=a;break ob}a=w[b+816|0]}h=a&255;e=b;i=a&240;g=a&15;pb:{qb:{if(!(!i|(g|0)!=15)){if(!(w[c+480209|0]&16)){break pb}a=h>>>4|0;break qb}s=v[c+480208>>2]&4096;if(!(!g|(i|0)!=240)){if(!s){break pb}a=0-g|0;break qb}if(s){break pb}if(g){a=0-g|0;if(!(v[c+480180>>2]&25690144)|!i){break qb}break pb}if((a&255)>>>0<16){break pb}a=h>>>4|0}Ra=e,Sa=Lb(a+v[b+748>>2]|0,0,64),v[Ra+748>>2]=Sa}break Na;case 26:NP(l,f);break Na;case 29:if(!(w[G+1|0]&16)){break Na}a=d+B(A,872)|0;v[a+1075716>>2]=f;b=q+8|0;Db(b,E,60);if(Ra=0,Sa=Cb(b),Ua=w[a+1075722|0]&4,Ua?Ra:Sa){break Na}a=d+B(A,872)|0;v[a+1075732>>2]=f;v[a+1075724>>2]=f;break Na;case 11:yA(d,R,A&65535);break Na;case 13:a=xA(d,R,A&65535,f);if((a|0)==-1){break Na}v[d+1074436>>2]=a;if(!(w[d+480208|0]&32)){break Na}u[d+1074444>>1]=x[d+1074448>>1];break Na;case 37:case 38:case 39:case 40:a=l;b=i&255;e=(b|0)==38|(b|0)==40;b=d;if(w[b+480209|0]&16){c=w[a+848|0];h=g&240;if(h){c=h|c&15;t[a+848|0]=c}g=g&15;if(g){c=g|c&-16;t[a+848|0]=c}t[a+849|0]=(c&240)>>>4}g=(i&254)==40;rb:{sb:{if(v[b+480180>>2]==32768){c=w[a+848|0];if(w[b+480209|0]&16|(c&240)==16){break sb}break rb}if(w[b+480209|0]&16){break rb}c=w[a+849|0]-1|0;t[a+849|0]=c;if(c&255){break rb}c=w[a+848|0]}t[a+849|0]=(c&240)>>>4;c=c&15;c=e?c:0-c|0;tb:{if(Kj(a)){v[a+852>>2]=v[a+852>>2]+B(c,v[v[v[a+656>>2]+44>>2]+36>>2]);break tb}Ra=a,Sa=_g(b,mu(b,v[a+700>>2],u[a+772>>1],v[a+704>>2])+c|0,u[a+772>>1],v[a+704>>2]),v[Ra+700>>2]=Sa}if(!g){break rb}v[a>>2]=0;v[a+4>>2]=0}break Na;case 41:vA(l,f);break Na;case 42:break eb;default:break Ma}}if(v[d+1074392>>2]|ba>>>0>1|f>>>0>47){break Na}a=(f&240)==16;g=a?0:A;b=(a?x[d+480188>>1]-1|0:A)&65535;if((g&65535)>>>0>b>>>0){break Na}a=((ba|0)==1)<<26;while(1){c=g&65535;e=(d+(c<<5)|0)+480280|0;v[e>>2]=a|v[e>>2]&-67108865;c=(d+B(c,872)|0)+1075080|0;v[c>>2]=a|v[c>>2]&-67108865;g=g+1|0;if(b>>>0>=(g&65535)>>>0){continue}break}break Na}tP(d,l,f&15);break Na}Co(d,l);break Na}RP(d,R,f)}g=f}a=q+8|0;Db(a,E,78);if(!(!Cb(a)|!g)){a=g&255;t[l+840|0]=a;t[l+812|0]=a;t[l+811|0]=a;t[l+809|0]=a;t[l+807|0]=a;t[l+806|0]=a;t[l+826|0]=a>>>4;t[l+827|0]=a<<2&60}a=w[T|0];if(!a){break M}t[m+1075796|0]=a}A=A+1|0;if(A>>>0<x[d+480188>>1]){continue}break}}ub:{if(!(w[G+1|0]&16)){break ub}if(!IP(d,R,1)){break ub}v[G>>2]=v[G>>2]|524288}gb=q+16|0;a=1;break l}a=0}gb=J+32|0;vb:{if(!a|!v[j+1074420>>2]){break vb}a=HO(j,j+1074376|0);v[j+1074380>>2]=a;v[j+1074404>>2]=a;b=Fd(x[j+480188>>1],1,31);A=j+1074332|0;wb:{if(w[A+34|0]){a=v[j+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}s=((B(v[j+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+38416|0]|0;break wb}s=v[j+480228>>2]}u[j+480212>>1]=0;H=j+1298260|0;n=j+1074312|0;J=j+480210|0;M=j+480209|0;m=0;while(1){k=j+B(m,872)|0;p=k+1075080|0;xb:{if(!(v[p>>2]&4096)|(v[k+1075016>>2]|(v[k+1075012>>2]|v[k+1075688>>2]))){break xb}a=o+16|0;Db(a,n,64);if(Cb(a)){break xb}v[k+1075068>>2]=0;a=k+1075084|0;v[a>>2]=0;v[a+4>>2]=0}b=x[j+480188>>1];a=v[p>>2];yb:{if(v[k+1075068>>2]|b>>>0>m>>>0?a&1024:1){if(b>>>0>m>>>0){rO(j,m&65535)}u[k+1075834>>1]=0;break yb}f=0;N=k+1075712|0;v[N>>2]=0;q=k+1075672|0;v[q>>2]=0;E=k+1075e3|0;c=E;v[c>>2]=0;v[c+4>>2]=0;v[k+1075092>>2]=0;v[o+44>>2]=1065353216;u[o+42>>1]=0;R=k+1075648|0;G=v[R>>2];v[o+36>>2]=0;F=0;r=k+1075692|0;F=v[r>>2]?v[k+1075068>>2]!=0:F;c=k+1074992|0;zb:{Ab:{Bb:{if(b>>>0<=m>>>0){break Bb}if(w[(j+(m<<5)|0)+480288|0]){break Ab}if(!G){break Bb}f=w[G+34|0]!=0}if((f|F)!=1){break zb}}v[o+8>>2]=v[k+1075680>>2];v[o+32>>2]=v[k+1075744>>2];e=o+16|0;Db(e,n,28);a=c;b=o+8|0;e=Cb(e)?o+32|0:b;g=gb-16|0;gb=g;d=g+8|0;f=j+1074312|0;Db(d,f,28);Cb:{if(Cb(d)){v[e>>2]=v[e>>2]+u[a+776>>1];Yd(e,0,64);break Cb}d=g+8|0;Db(d,f,1);f=Cb(d);d=u[a+776>>1];if(f){v[e>>2]=d+v[e>>2];Yd(e,0,256);break Cb}v[a+688>>2]=d+v[a+688>>2];Yd(a+688|0,0,256);v[e>>2]=v[a+688>>2];u[a+776>>1]=0}gb=g+16|0;e=gb-16|0;gb=e;g=e+8|0;d=j+1074312|0;Db(g,d,28);Db:{Eb:{if(!Cb(g)){Db(e,d,1);if(!Cb(e)){break Eb}}v[a+684>>2]=v[a+692>>2]+u[a+778>>1];Yd(a+684|0,0,256);break Db}v[a+692>>2]=v[a+692>>2]+u[a+778>>1];Yd(a+692|0,0,256);u[a+778>>1]=0;v[a+684>>2]=v[a+692>>2]}gb=e+16|0;a=b;h=gb-16|0;gb=h;e=j;Fb:{if(!(w[c+90|0]&4)|(v[e+480208>>2]&2101248)==2101248){break Fb}g=c;Gb:{if(v[a>>2]<=0){d=h+8|0;Db(d,e+1074312|0,21);if(!Cb(d)){break Gb}}f=5;if(!(v[e+480180>>2]&5)){d=h+8|0;Db(d,e+1074312|0,21);f=Cb(d)?5:6}i=Qz(e,w[g+825|0],w[g+820|0]);Hb:{if((w[g+825|0]&3)!=1){break Hb}d=h+8|0;Db(d,e+1074312|0,89);if(!Cb(d)){break Hb}i=w[g+819|0];l=w[g+820|0];d=l<<2&124;d=(!(w[g+90|0]&2)|w[e+480209|0]&16?i:w[g+823|0]+i|0)&32?d^127:d;i=l&32?0-d|0:d}d=a;if(v[e+480180>>2]!=131072){a=v[a>>2]+((B(w[g+827|0],i)|0)/(1<<f)|0)|0}else{a=v[a>>2];a=((B(w[g+827|0],B(a,64-i|0))|0)/-8192|0)+a|0}v[d>>2]=a}if(!(v[e+480180>>2]&16777248)|w[e+480208|0]&4?w[e+480209|0]&16:0){break Fb}a=h+8|0;Db(a,e+1074312|0,21);a=Cb(a);d=g;e=w[g+826|0];g=w[g+820|0];t[d+820|0]=(a?e<<2:g)+(a?g:e)}gb=h+16|0;d=m&65535;l=d;e=b;I=gb-16|0;gb=I;g=I+8|0;a=j;f=a+1074312|0;Db(g,f,71);Ib:{if(Cb(g)){g=(a+B(l,872)|0)+1075831|0;i=t[g|0];if((i|0)>-1){break Ib}if(!(w[a+480209|0]&16|w[(a+B(l,872)|0)+1075797|0]!=18)){f=i&-33;t[g|0]=f;Jb:{Kb:{if((f|0)!=-64){f=i&223;if((f|0)!=128){break Kb}i=w[(a+B(l,872)|0)+1075832|0]>>>4|-64;break Jb}i=w[(a+B(l,872)|0)+1075832|0]&15|-128;break Jb}i=f-1|0}t[g|0]=i;g=(a+B(l,872)|0)+1075080|0;v[g>>2]=v[g>>2]|2097152}if((i&224)!=128){break Ib}v[e>>2]=0;break Ib}if(w[(a+B(l,872)|0)+1075797|0]!=18){break Ib}g=I+8|0;Db(g,f,22);Lb:{if(Cb(g)){h=a+B(l,872)|0;g=h+1075831|0;f=w[g|0];i=f<<24>>24;if(!((i|0)>-1|!v[h+1075068>>2])){Mb:{Nb:{if((f|0)!=192){if((f|0)!=128){break Nb}i=w[(a+B(l,872)|0)+1075832|0]>>>4|-64;break Mb}i=w[(a+B(l,872)|0)+1075832|0]&15|-128;break Mb}i=i-1|0}t[g|0]=i}if((i&192)!=128){break Lb}v[e>>2]=0;break Lb}g=w[(a+B(l,872)|0)+1075832|0];f=g>>>4|0;h=f+(g&15)|0;if(!(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){h=h+2|0;f=f+1|0}g=(a+B(l,872)|0)+1075831|0;i=w[g|0];if(!(v[a+480180>>2]&4)){aa=f;f=(i&255)>>>0<h>>>0?i:0;if(aa>>>0<=(f&255)>>>0){v[e>>2]=0}t[g|0]=f+1;break Lb}Ob:{if(w[a+480209|0]&16){i=i&255?i-1|0:0;break Ob}t[g|0]=i+1}if(((i&255)>>>0)%(h>>>0)>>>0<f>>>0){break Lb}v[e>>2]=0}g=(a+B(l,872)|0)+1075080|0;v[g>>2]=v[g>>2]|2097152}g=a+B(l,872)|0;Pb:{if(w[g+1075797|0]!=18){break Pb}h=g+1075648|0;g=v[h>>2];if(!g|!w[g+34|0]|w[g+15|0]&2){break Pb}g=a+B(l,872)|0;if(v[g+1075080>>2]&134218752){break Pb}f=g+1075791|0;if(!ve(w[f|0])){break Pb}h=v[h>>2];g=v[(a+B(w[h+34|0],160)|0)+906140>>2];if(!g){break Pb}i=kb[v[v[g>>2]+100>>2]](g,w[f|0],l)|0;e=v[e>>2];if(!(!i|e)){kb[v[v[g>>2]+92>>2]](g,h,w[f|0]+255|0,0,l);break Pb}if(i|!e){break Pb}kb[v[v[g>>2]+92>>2]](g,h,w[f|0],x[(a+B(l,872)|0)+1075680>>1],l)}gb=I+16|0;Yd(b,0,256);v[o+8>>2]=v[o+8>>2]<<6;Qb:{if(G){b=o+16|0;Db(b,n,31);if(Cb(b)){bu(j,c)}I=o+8|0;f=I;e=gb-16|0;gb=e;b=c;Rb:{if(!Pz(j,b,0)){break Rb}g=v[b+656>>2];h=e+8|0;a=a+1074312|0;Db(h,a,31);Sb:{if(Cb(h)){h=v[b+724>>2];if(h){break Sb}break Rb}h=v[b+724>>2]}l=e+8|0;Db(l,a,31);i=g+48|0;T=h-Cb(l)|0;h=Uq(i,T,256,64);l=w[g+65|0];Tb:{if((l|0)==255){break Tb}b=u[b+728>>1];if((b|0)==-1){break Tb}l=w[Mb(i,l)+2|0];g=x[Mb(i,w[g+65|0])>>1];i=e+8|0;Db(i,a,94);a=l<<2;g=(g|0)==(T|0)?a:h;if(Cb(i)){h=b+(g-a<<1)|0;break Tb}if(!l){h=0;break Tb}h=(B(b,g)|0)/(a|0)|0}Ra=f,Sa=(B(v[f>>2],Lb(h,0,512))|0)/256|0,v[Ra>>2]=Sa}gb=e+16|0;qO(c,I);e=gb-16|0;gb=e;b=j;a=c;Ub:{if(!Pz(b,a,1)){break Ub}g=v[a+656>>2];f=e+8|0;b=b+1074312|0;Db(f,b,31);Vb:{if(Cb(f)){h=v[a+732>>2];if(h){break Vb}break Ub}h=v[a+732>>2]}f=e+8|0;Db(f,b,31);b=a;g=Uq(g+68|0,h-Cb(f)|0,64,64)-32|0;a=v[a+684>>2];Ra=b,Sa=Lb(((B(g,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),v[Ra+684>>2]=Sa}gb=e+16|0;a=c;b=v[a+656>>2];e=t[b+26|0];Wb:{if(!e){break Wb}g=w[a+797|0];if(!g){break Wb}Ra=a,Sa=Lb(v[a+684>>2]+((B(e,g+(w[b+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ra+684>>2]=Sa}break Qb}if(!(w[p+1|0]&16)){break Qb}v[k+1075688>>2]=0;v[o+8>>2]=0}Xb:{if(w[k+1075843|0]&4){v[o+8>>2]=0;break Xb}a=v[o+8>>2];if(!a){break Xb}if(w[p+3|0]&8){v[q>>2]=0;break Xb}if(w[A+33|0]){b=B(v[o+32>>2],v[k+1075740>>2]);a=a<<8;Ra=q,Sa=Ac(oqa(nqa(b,b>>31,a,a>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;break Xb}b=B(v[o+32>>2],v[k+1075740>>2]);a=B(a,v[j+1074456>>2]);Ra=q,Sa=Ac(oqa(nqa(b,b>>31,a,a>>31),jb,1048576,0),jb),v[Ra>>2]=Sa}v[N>>2]=v[o+8>>2];Yb:{Zb:{if(v[j+480180>>2]==2|v[r>>2]>=v[j+480260>>2]){break Zb}if(rk(j)){break Zb}v[r>>2]=v[j+480260>>2];break Yb}if(v[r>>2]<v[j+480264>>2]){break Yb}a=o+16|0;Db(a,n,113);if(!Cb(a)){break Yb}v[r>>2]=v[j+480264>>2]}a=o+16|0;Db(a,n,73);if(Cb(a)){Lb(v[r>>2],1,31999)}a=v[r>>2];v[o+36>>2]=a;_b:{if((v[p>>2]&1572864)!=1572864){break _b}if(w[J|0]&32){if(!uu(k+1075780|0)|w[M|0]&16){break _b}a=v[o+36>>2]}b=k+1075704|0;$b:{if(v[b>>2]==(a|0)){a=v[k+1075708>>2];break $b}v[b>>2]=a;e=a;a=k+1075764|0;b=k+1075696|0;a=_g(j,mu(j,e,u[a>>1],v[b>>2]),u[a>>1],v[b>>2]);v[k+1075708>>2]=a}v[o+36>>2]=a}f=gb-16|0;gb=f;e=j;l=e+B(d,872)|0;a=v[l+1075648>>2];ac:{if(!a){break ac}b=w[a+34|0];if(!b|w[a+15|0]&2|(!v[(e+B(b,160)|0)+906140>>2]|v[(e+B(d,872)|0)+1075080>>2]&134218752)){break ac}b=e+B(d,872)|0;T=b+1075783|0;I=w[T|0];g=0;h=b+1075791|0;if(ve(w[h|0])){g=w[ic(a+108|0,w[h|0]-1|0)|0]}h=b+1075780|0;bc:{cc:{if((I|0)==1){i=0;dc:{ec:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:i=w[(e+B(d,872)|0)+1075798|0]>>>4|0;break dc;case 1:break ec;default:break dc}}i=w[(e+B(d,872)|0)+1075798|0]&15}a=e+B(d,872)|0;t[a+1075793|0]=g;if(w[a+1075792|0]==(g+i|0)){break bc}if(!(w[e+480209|0]&16)){break cc}if(!ce(h)){break cc}break bc}i=0;if(w[h|0]|!w[(e+B(d,872)|0)+1075792|0]){break bc}}a=e+B(d,872)|0;Mm(e,d,w[a+1075793|0]+i|0,x[a+1075680>>1])}b=(e+B(d,872)|0)+1075792|0;a=w[b|0];fc:{if(!a){if(!(w[e+480209|0]&16)|(I|0)!=1){break fc}if(ce(h)){break fc}a=g;if(!ve(a)){break fc}}Mm(e,d,(a&255)+255|0,0)}t[b|0]=w[T|0]==1?w[(e+B(d,872)|0)+1075793|0]+i|0:0}gc:{if(w[l+1075797|0]!=1){break gc}if(Kj(l+1074992|0)){g=0;hc:{ic:{jc:{switch(y[e+1074392>>2]%3|0){case 1:g=w[(e+B(d,872)|0)+1075798|0]>>>4|0;break ic;case 0:break ic;case 2:break jc;default:break hc}}g=w[(e+B(d,872)|0)+1075798|0]&15}u[o+42>>1]=g}a=(e+B(d,872)|0)+1075843|0;t[a|0]=w[a|0]|48;break gc}if(!(!(w[e+480209|0]&16)|v[e+480180>>2]!=1048576)){a=e+B(d,872)|0;b=_g(e,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[o+36>>2]=b;v[a+1075692>>2]=b}a=f+8|0;g=e+1074312|0;Db(a,g,13);if(Cb(a)){g=w[(e+B(d,872)|0)+1075798|0];if(!g){break gc}b=65536;kc:{switch(((y[e+1074392>>2]%(v[e+1074400>>2]+v[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:g=g<<4;case 0:b=v[((g&240)<<2)+43584>>2];break;default:break kc}}d=rk(e);a=v[o+36>>2];g=a;a=a>>31;e=o;if(d){b=nqa(g,a,b,b>>31)+32768|0;a=jb;a=oqa(b,b>>>0<32768?a+1|0:a,65536,0)}else{d=(b|0)/2|0;h=d;i=d>>31;d=a<<16|g>>>16;g=g<<16;a=g+h|0;i=d+i|0;a=oqa(a,a>>>0<g>>>0?i+1|0:i,b,b>>31)}b=jb;Ra=e,Sa=Ac(a,b),v[Ra+36>>2]=Sa;break gc}a=f+8|0;Db(a,g,51);if(Cb(a)){if(w[e+480209|0]&16){break gc}lc:{mc:{a=v[e+1074416>>2];a=a-(y[e+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break mc}if((a|0)==16){break gc}i=0;nc:{switch((a|0)%3|0){case 0:break gc;case 2:break mc;case 1:break nc;default:break lc}}i=w[(e+B(d,872)|0)+1075798|0]>>>4|0;break lc}i=w[(e+B(d,872)|0)+1075798|0]&15}a=e+B(d,872)|0;b=a+1075764|0;a=a+1075696|0;g=mu(e,v[o+36>>2],u[b>>1],v[a>>2])+i|0;b=_g(e,g,u[b>>1],v[a>>2]);v[o+36>>2]=b;if(g>>>0<109){break gc}v[f+8>>2]=b;Ra=f,Sa=_g(e,109,0,v[a>>2]),v[Ra+4>>2]=Sa;Ra=o,Sa=v[Mc(f+8|0,f+4|0)>>2],v[Ra+36>>2]=Sa;break gc}a=v[e+1074392>>2];if(v[e+480180>>2]!=1){i=w[(e+B(d,872)|0)+1075789|0]}else{b=e+B(d,872)|0;i=mu(e,v[o+36>>2],u[b+1075764>>1],v[b+1075696>>2])}oc:{pc:{switch((((v[e+480180>>2]&67633152?a+2|0:a)>>>0)%3|0)-1|0){case 0:i=(w[(e+B(d,872)|0)+1075798|0]>>>4|0)+i|0;break oc;case 1:break pc;default:break oc}}i=(w[(e+B(d,872)|0)+1075798|0]&15)+i|0}if(!(v[e+480180>>2]&67633408|w[(e+B(d,872)|0)+1075789|0]!=(i&255))){a=f+8|0;Db(a,g,82);if(!Cb(a)){break gc}}l=o;b=e;I=b;if(w[b+480210|0]&32){h=i&255;if((h|0)==85){v[o+36>>2]=2147483647;break gc}i=h>>>0>85?i-37|0:i}a=e+B(d,872)|0;Ra=l,Sa=_g(I,i&255,u[a+1075764>>1],v[a+1075696>>2]),v[Ra+36>>2]=Sa;if(v[e+480180>>2]&71860480){v[a+1075692>>2]=v[o+36>>2];break gc}a=f+8|0;Db(a,g,82);if(!Cb(a)){break gc}t[(e+B(d,872)|0)+1075792|0]=i}gb=f+16|0;if(!(!(w[J|0]&33)|v[o+36>>2]==2147483647)){qc:{if(v[j+480180>>2]==2){a=452;b=3424;break qc}b=B(x[k+1075764>>1]>>>4&15,24);a=x[b+39318>>1]>>>1|0;a=a>>>0>452?a:452;b=x[b+39296>>1]<<1}Yd(o+36|0,a,b);Yd(r,a,b)}Uz(j,c);a=v[p>>2]}rc:{if(!(a&256)|w[M|0]&64){break rc}a=o+16|0;Db(a,n,37);if(!Cb(a)){break rc}v[k+1075676>>2]=128}l=m&65535;rO(j,l);sc:{if(!F){break sc}a=pO(j,c,o+36|0);if((a|0)<0|!(w[p+1|0]&2)){break sc}if(!Dd(H)){break sc}Pq(v[H>>2],l,a>>>2&255,1)}tc:{if(w[k+1075782|0]!=8){break tc}uc:{vc:{a=w[k+1075783|0];switch(a-5|0){case 1:break tc;case 0:case 2:break uc;default:break vc}}if((a|0)!=26){break tc}}if(v[j+480180>>2]==4){if(w[M|0]&16){break tc}a=k+1075811|0;t[a|0]=w[a|0]+w[k+1075815|0];break tc}if(!(v[j+480180>>2]&16777248)){break tc}Hl(c,w[k+1075784|0]);oO(j,l,o+36|0,o+44|0)}oO(j,l,o+36|0,o+44|0);wc:{if(!F){break wc}v[o+32>>2]=0;b=j;e=o+36|0;r=gb-16|0;gb=r;a=c;i=v[a+104>>2];xc:{if(!i|!w[i+40|0]){break xc}I=Kj(a);d=rk(b);f=r+8|0;Db(f,b+1074312|0,21);g=d?44608:43584;h=d?43584:44608;if(!(I|!Cb(f)|v[b+480180>>2]==1048576)){if(!w[i+41|0]){break xc}f=w[a+818|0];v[r+4>>2]=v[a+756>>2]+w[i+39|0];bk(r+4|0,w[i+40|0]<<8);F=v[r+4>>2];v[a+756>>2]=F;F=(F|0)/256|0;v[r+4>>2]=F;t[a+818|0]=w[a+818|0]+w[i+41|0];yc:{zc:{switch(w[i+38|0]-1|0){case 3:b=mO(Bo(b))+-64|0;F=v[r+4>>2];break yc;case 2:b=64-(f+1>>>1|0)|0;break yc;case 1:b=(f+1>>>1|0)+-64|0;break yc;case 0:b=(f>>>1^-1)&64;break yc;default:break zc}}b=t[f+39888|0]}bk(e,8388607);f=v[e>>2]<<8;v[e>>2]=f;F=B(b,F);b=(F|0)/64|0;a=b>>31;i=a^a+b;b=i>>>2|0;a=e;Ac:{if((F|0)<=-64){b=v[(b<<2)+g>>2];g=Ac(oqa(nqa(b,b>>31,f,f>>31),jb,65536,0),jb);b=v[e>>2];f=g-b|0;g=f;h=i&3;if(!h){break Ac}g=v[(h<<2)+(d?43520:43456)>>2];d=Ac(oqa(nqa(g,g>>31,b,b>>31),jb,65536,0),jb)+f|0;b=v[e>>2];g=d-b|0;break Ac}b=v[h+(b<<2)>>2];g=Ac(oqa(nqa(b,b>>31,f,f>>31),jb,65536,0),jb);b=v[e>>2];f=g-b|0;g=f;h=i&3;if(!h){break Ac}g=v[(h<<2)+(d?43456:43520)>>2];d=Ac(oqa(nqa(g,g>>31,b,b>>31),jb,65536,0),jb)+f|0;b=v[e>>2];g=d-b|0}v[a>>2]=(b+g|0)/256;v[o+32>>2]=g&255;break xc}Bc:{if(!(w[i+39|0]|v[b+480180>>2]&16777248)){v[a+756>>2]=w[i+40|0]<<8;break Bc}Cc:{Dc:{if(v[b+480180>>2]&16777248){F=w[i+39|0]<<1;f=v[a+756>>2];d=a+756|0;break Dc}if(w[a+89|0]&8){break Cc}f=((w[i+40|0]<<8&65280)>>>0)/w[i+39|0]|0;F=v[a+756>>2];d=a+756|0}v[d>>2]=f+F}bk(a+756|0,w[i+40|0]<<8)}d=w[a+818|0]+w[i+41|0]|0;t[a+818|0]=d;d=d<<24>>24;Ec:{Fc:{switch(w[i+38|0]-1|0){case 3:t[a+818|0]=d+1;f=t[(d&63)+39824|0];break Ec;case 2:f=(64-(d>>>1|0)&127)+-64|0;break Ec;case 1:f=((d>>>1|0)- -64&127)+-64|0;break Ec;case 0:f=(d|0)>-1?-64:64;break Ec;default:break Fc}}d=w[a+818|0];f=0-t[d+39888|0]|0;if(v[b+480180>>2]!=1048576){break Ec}f=(64-t[(d+-64&255)+39888|0]|0)/2<<16>>16}d=f;F=B(d,v[a+756>>2]);f=(F|0)/256|0;if(I){z[o+44>>2]=z[o+44>>2]+C(C(C(C(w[i+40|0])*C(.05000000074505806))*C(d|0))*C(.000244140625));t[a+851|0]=w[a+851|0]|32;break xc}if(v[b+480180>>2]!=4){Gc:{if((F|0)<=-256){f=0-f|0;b=0-F>>>16|0;a=(b<<2)+g|0;break Gc}g=h;b=(F|0)/65536|0;a=g+(b<<2)|0}d=v[e>>2];a=v[a>>2];a=((B(v[((b<<2)+g|0)+4>>2]-a|0,(f|0)/4&63)|0)/64|0)+a|0;a=Ac(oqa(nqa(d,d>>31,a,a>>31),jb,256,0),jb);v[e>>2]=a;v[o+32>>2]=a&255;v[e>>2]=v[e>>2]/256;break xc}v[e>>2]=v[e>>2]+((F|0)/16384|0)}gb=r+16|0;if(v[o+36>>2]<=v[j+480260>>2]){a=o+16|0;Db(a,n,81);if(Cb(a)){v[k+1075068>>2]=0}v[o+36>>2]=v[j+480260>>2]}Hc:{if(!Kj(c)){break Hc}a=k+1075843|0;b=w[a|0];if(!(v[j+1074392>>2]|!(b&16)?b&32:1)){break Hc}IS(c,z[o+44>>2],u[o+42>>1],j);b=a;a=w[a|0];t[b|0]=(a&32?-33:-17)&a}a=o+16|0;Tz(a,j,c,v[o+36>>2],v[o+32>>2]);b=wb(a);g=nqa(v[a>>2],v[a+4>>2],v[j+480240>>2],0);e=jb;d=oqa(g,e,65536,0);f=jb;g=g+65535|0;e=g>>>0<65535?e+1|0:e;e=!e&g>>>0<131071;g=e?1:d;v[a>>2]=g;d=a;a=e?0:f;v[d+4>>2]=a;v[E>>2]=g;v[E+4>>2]=a;if((v[p>>2]&134219264)!=512){break wc}if(!Dd(H)){break wc}a=o+8|0;Db(a,n,99);if(!(!(Cb(a)|!(w[p+1|0]&16))&v[j+480180>>2]!=2)){Ic:{if(w[p+1|0]&8?v[j+480180>>2]==2:0){break Ic}a=nqa(v[b>>2],0,261625,0)+66904|0;b=jb;b=Qc(qqa(a,a>>>0<66904?b+1|0:b,133808,0),jb);e=v[p>>2];a=1;Jc:{if(e&2048){break Jc}a=0;if(!(e&4096)){break Jc}a=!v[k+1075688>>2]}e=o+8|0;Db(e,n,110);if(Ra=Cb(e),Sa=0,Ua=a,Ua?Ra:Sa){break Ic}e=v[H>>2];g=o+8|0;Db(g,n,95);XA(e,l,b,a,Cb(g))}b=v[H>>2];a=nqa(B(v[k+1075744>>2],B(v[k+1075740>>2],v[N>>2])),0,63,0)+33554432|0;e=jb;e=a>>>0<33554432?e+1|0:e;Pq(b,l,Qc((e&67108863)<<6|a>>>26,e>>>26|0)&255,0);a=k+1075676|0;d=a;e=v[a>>2];a=0;b=v[H>>2];g=Nl(b,l);Kc:{if((g|0)==255){break Kc}if(vk(b)){break Kc}a=ic(YA(b+314|0,g),10);b=v[b>>2];g=Fu(g)|192;a=w[a|0]&-49;a=(e|0)<171?a|16:a;a=((e|0)>84?a|32:a)&255;Yh(b,g,a);a=(a>>>5&1)+(a<<27>>31)|0}v[d>>2]=(a<<7)+128}Lc:{a=v[R>>2];if(!a|(w[a+60|0]&7)!=1){break Lc}a=a+48|0;if(cd(a)){break Lc}b=v[nO(c,0)>>2];a=vo(a);if(b>>>0<x[a>>1]|w[a+2|0]){break Lc}Qi(v[H>>2],l,1);a=o+8|0;Db(a,n,109);a=Cb(a);b=v[p>>2];v[p>>2]=(a?b:b&-4609)|4096;v[k+1075688>>2]=0;break wc}a=o+8|0;Db(a,n,99);if(!Cb(a)|!(w[p+1|0]&16)|v[k+1075688>>2]){break wc}Qi(v[H>>2],l,1);v[p>>2]=v[p>>2]&-513}Mc:{if(!G){break Mc}a=o+16|0;Db(a,n,31);if(Cb(a)){break Mc}bu(j,c)}b=v[p>>2];a=b&-65537;h=k+1075012|0;i=k+1075016|0;v[p>>2]=v[h>>2]|(v[i>>2]|v[q>>2])?(a|b<<7&65536)^65536:a;e=k+1075664|0;a=e;v[a>>2]=0;v[a+4>>2]=0;g=k+1075834|0;b=w[g|0];a=b-4|0;t[g|0]=a>>>0>b>>>0?0:a;d=k+1075835|0;b=w[d|0];a=b-4|0;t[d|0]=a>>>0>b>>>0?0:a;Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{a=k+1075096|0;b=v[a>>2];Tc:{if(!b){break Tc}if(!Md(b)|!v[k+1075068>>2]){break Tc}if(Oi(c)){break Sc}}f=k+1075008|0;v[f>>2]=0;break Rc}f=k+1075008|0;a=v[v[a>>2]+20>>2];v[f>>2]=a;if(a){break Qc}}if(!sk(c)|w[p+1|0]&24){break Pc}}F=v[q>>2];l=v[k+1075676>>2];a=(B(F,256-l|0)|0)/16384|0;b=a>>>0<127?a:127;a=t[g|0];if((a|0)<=-1){t[g|0]=b;r=b}else{r=a}a=b>>>1|0;if((r&255)>>>0<a>>>0){t[g|0]=a}a=(B(l,F)|0)/16384|0;b=a>>>0<127?a:127;a=b>>>1|0;l=a;g=t[d|0];if((g|0)<=-1){t[d|0]=b}else{b=g}if((b&255)>>>0<l>>>0){break Oc}break Nc}if(w[g|0]>=129){t[g|0]=0}a=0;if(w[d|0]<129){break Nc}}t[d|0]=a}Uc:{Vc:{if(v[f>>2]){F=128;if(y[j+24624>>2]>=2){F=Lb(v[k+1075676>>2],0,256)}v[o+16>>2]=F;b=B(s,v[q>>2])>>>(w[A+34|0]?7:8)|0;g=k+1075668|0;a=g;Wc:{Xc:{Yc:{switch(w[A+32|0]){case 0:if(!(w[j+24616|0]&16)){break Xc}case 1:if((F|0)<=127){v[e>>2]=b>>>1;b=(B(b,F)|0)/256|0;break Wc}v[e>>2]=(B(b,256-F|0)|0)/256;b=b>>>1|0;break Wc;case 3:break Yc;default:break Xc}}bk(o+16|0,255);f=e;d=v[o+16>>2];if((d|0)<1){h=65536}else{h=x[(0-d<<1)+46144>>1]}v[f>>2]=B(h,b)>>>16;b=B(b,x[(d<<1)+45632>>1])>>>16|0;break Wc}v[e>>2]=(B(b,256-F|0)|0)/256;b=(B(b,F)|0)/256|0}v[a>>2]=b;f=k+1075786|0;b=f;Zc:{_c:{a=v[R>>2];if(!a){break _c}if(!up(w[a+14|0])){break _c}a=w[v[R>>2]+14|0];break Zc}if(up(w[j+480268|0])){a=w[j+480268|0];break Zc}a=w[j+24648|0];a=w[J|0]&128?v[j+24668>>2]?-1:a:a}t[b|0]=a;d=v[p>>2];b=v[E>>2];h=v[E+4>>2];if(!(d&131072|((b|0)!=0|(h|0)!=1)|(v[k+1075748>>2]|(a&255)==255))){t[f|0]=0}a=1<<v[A+28>>2];v[e>>2]=v[e>>2]/(a|0);a=v[g>>2]/(a|0)|0;v[g>>2]=a;if(!(!(d&256)|v[j+24624>>2]!=2)){v[g>>2]=0-a}if(d&128){v[E>>2]=0-b;v[E+4>>2]=0-(((b|0)!=0)+h|0)}d=j;h=0;l=gb-16|0;gb=l;e=c;v[c+28>>2]=0;v[c+32>>2]=0;f=c;$c:{ad:{g=v[c+88>>2];if(!(g&65536)){a=v[e+676>>2];c=v[e+672>>2];break ad}c=v[e+20>>2];i=v[e+672>>2];bd:{if((c|0)!=(i|0)){a=v[e+24>>2];b=v[e+676>>2];break bd}a=v[e+24>>2];b=v[e+676>>2];if((a|0)==(b|0)){break ad}}g=d+24604|0;b=(a|0)<(b|0)|(c|0)<(i|0);cd:{if(b){c=LS(g);break cd}c=KS(g)}Db(l,d+1074312|0,4);if(!(!Cb(l)|!(v[d+480180>>2]&4))){a=v[d+24620>>2];a=nqa(a,a>>31,5,0)+500|0;i=jb;c=Ac(oqa(a,a>>>0<500?i+1|0:i,1e3,0),jb)}g=v[e+656>>2];dd:{if(!g){a=c;break dd}a=c;if(!b){break dd}b=x[g+12>>1];if(b){a=(B(b,v[d+24620>>2])>>>0)/1e5|0}h=(b|0)!=0}i=a?a:1;g=v[e+676>>2];a=v[e+24>>2];F=g-a<<12;b=v[e+672>>2];r=v[e+20>>2];q=b-r<<12;if(!(w[e+90|0]&32|(!(b|g)|(!(a|r)|h)))){v[l+12>>2]=v[d+1074380>>2];Yd(l+12|0,c,2048);g=v[e+676>>2];i=v[l+12>>2];b=v[e+672>>2]}d=(F|0)/(i|0)|0;v[e+32>>2]=d;h=(q|0)/(i|0)|0;v[e+28>>2]=h;a=((B(d,i)|0)/-4096|0)+g|0;v[e+24>>2]=a;c=((B(h,i)|0)/-4096|0)+b|0;v[e+20>>2]=c;if(d|h){v[e+100>>2]=i;b=v[e+88>>2];break $c}v[e+24>>2]=g;v[e+20>>2]=b;a=g;c=b;b=v[e+88>>2]&-65537;break $c}v[e+24>>2]=a;v[e+20>>2]=c;b=g&-65537}v[f+88>>2]=b&-2097153;v[e+40>>2]=a<<12;v[e+36>>2]=c<<12;gb=l+16|0;if(!(w[p+1|0]&2)){break Vc}break Uc}v[h>>2]=0;v[i>>2]=0;v[k+1075068>>2]=0;if(v[k+1075088>>2]){break Vc}if(!v[k+1075084>>2]){break Uc}}a=x[j+480212>>1];u[j+480212>>1]=a+1;u[(j+(a<<1)|0)+1074478>>1]=m}v[k+1075660>>2]=v[p>>2]}m=m+1|0;if((m|0)!=256){continue}break}F=1;if(y[j+24608>>2]>x[j+480212>>1]){break vb}a=j+1074478|0;g=a;b=a+(v[j+24608>>2]<<1)|0;c=a+(x[j+480212>>1]<<1)|0;d=gb-16|0;gb=d;v[d+8>>2]=j;f=d+8|0;h=f;e=b-a|0;if((e|0)>=3){i=e>>1;e=(i-2|0)/2|0;while(1){Mz(a,h,i,a+(e<<1)|0);s=(e|0)>0;e=e-1|0;if(s){continue}break}}if((b|0)!=(c|0)){e=b-g>>1;a=b;while(1){if(uq(f,x[a>>1],x[g>>1])){Nz(a,g);Mz(g,f,e,g)}a=a+2|0;if((c|0)!=(a|0)){continue}break}}a=b-g|0;if((a|0)>=3){a=a>>>1|0;while(1){b=b-2|0;Nz(g,b);c=a-1|0;Mz(g,f,c,g);e=(a|0)>2;a=c;if(e){continue}break}}gb=d+16|0}gb=o+48|0;if(F){a=v[K+480208>>2];break j}b=v[K+480208>>2]|512;if(w[K+1298380|0]){break k}a=0;b=v[K+24620>>2]/10|0;c=Ac(b,b>>31);ed:{if(!c){break ed}e=c>>>0<1048576?c:1048576;v[j+1074380>>2]=e;d=x[j+480212>>1];if(!d){break ed}g=j+1074376|0;while(1){b=g+B(x[(g+(a<<1)|0)+102>>1],872)|0;f=b+1288|0;v[f>>2]=0;v[f+4>>2]=0;v[b+716>>2]=e;f=v[b+640>>2]<<12;v[b+656>>2]=f;h=v[b+636>>2]<<12;v[b+652>>2]=h;v[b+704>>2]=v[b+704>>2]|65536;v[b+644>>2]=(0-h|0)/(e|0);v[b+648>>2]=(0-f|0)/(e|0);a=a+1|0;if((d|0)!=(a|0)){continue}break}}a=v[K+480208>>2];b=a|256;if(c){break k}b=a|512}a=b;v[W+480208>>2]=a}if(a&512){Ra=K+1074392|0,Sa=tk(Ea),v[Ra>>2]=Sa;break i}v[V+112>>2]=512;a=v[K+1074380>>2];v[V+108>>2]=3;v[V+120>>2]=ka;v[V+116>>2]=a;v[V+104>>2]=V+112;a=v[V+108>>2];v[V+48>>2]=v[V+104>>2];v[V+52>>2]=a;g=QX(V+48|0);if(v[K+24632>>2]){a=K;b=ma;h=0;d=gb-48|0;gb=d;c=g;i=c<<2;while(1){v[d+32>>2]=0;e=(a+(h<<11)|0)+16396|0;f=e;e=(e+i|0)-e>>2;if((e|0)>=1){while(1){v[f>>2]=v[d+32>>2];f=f+4|0;j=(e|0)>1;e=e-1|0;if(j){continue}break}}h=h+1|0;if((h|0)!=4){continue}break}h=0;while(1){v[(d+32|0)+(h<<2)>>2]=(a+(h<<11)|0)+16396;h=h+1|0;if((h|0)!=4){continue}break}a=mg(d+16|0,d+32|0,v[a+24632>>2],c);c=v[v[b>>2]+8>>2];v[d+8>>2]=v[a+8>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;kb[c|0](b,d);gb=d+48|0}if(w[$+12|0]){a=0;while(1){v[(V+112|0)+(a<<2)>>2]=((a<<11)+K|0)+16396;a=a+1|0;if((a|0)!=4){continue}break}b=v[$+8>>2];a=mg(V+88|0,V+112|0,v[K+24632>>2],g);c=v[v[b>>2]+8>>2];v[V+40>>2]=v[a+8>>2];e=v[a+4>>2];v[V+32>>2]=v[a>>2];v[V+36>>2]=e;kb[c|0](b,V+32|0)}r=K;fa=0;c=gb-112|0;gb=c;l=g;if(g){q=r+12|0;E=r+24592|0;A=r+24588|0;Uo(q,l,E,A);if(y[r+24624>>2]>=3){Uo(r+8204|0,l,r+24600|0,r+24596|0)}u[c+30>>1]=0;a=c+8|0;na=r+1074312|0;Db(a,na,33);a=Cb(a);if(x[r+480212>>1]){Fa=a?2:1;Ga=r+24648|0;Ha=r+24596|0;Ia=r+24600|0;Ja=r+8204|0;n=r+397452|0;o=r+397448|0;H=r+393352|0;W=r+397456|0;ra=r+1074376|0;while(1){s=ra+(fa<<1)|0;a=B(x[s+102>>1],872);k=a+ra|0;N=k;fd:{gd:{if(v[k+632>>2]){break gd}b=a+r|0;if(v[b+1075088>>2]){break gd}if(!v[b+1075084>>2]){break fd}}j=a+r|0;a=w[j+1075786|0]+1|0;if((a&255)>>>0<=5){i=v[(a<<24>>24<<2)+34080>>2]}else{i=0}G=j+1075080|0;d=v[G>>2];hd:{if(!(!(d&16777216)&w[r+24612|0]>>>5)){b=A;e=q;F=d;a=E;if(!(d&8388608)){break hd}}a=H;b=o;e=n;f=l;h=W;if(!w[h+12|0]){Uo(a,f,b,e)}t[h+12|0]=1;F=v[G>>2];b=n;e=H;a=o}f=b;b=F>>>8&y[r+24624>>2]>2;I=b?Ha:f;T=b?Ia:a;h=b?Ja:e;ca=Lm(r,x[s+102>>1],2,1);id:{if((ca-1&255)>>>0>249){break id}b=v[(r+B(ca,160)|0)+906140>>2];if(!b){break id}a=v[b+24>>2];if(!a){break id}I=b+36|0;T=b+40|0;if(!(t[b+28|0]&1)){Uo(a,l,T,I);v[b+28>>2]=v[b+28>>2]|1}h=a}f=k+616|0;if(w[j+1075843|0]&4){MS(f,h,l);a=j+1075084|0;v[T>>2]=v[T>>2]+v[a>>2];v[I>>2]=v[I>>2]+v[j+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break fd}R=0;ga=c+8|0;a=ga;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=f;if(v[a+16>>2]){lF(ga,a);b=v[a+12>>2];s=v[a+8>>2];a=b>>31;e=a;a=s+a|0;b=e+b|0;b=a>>>0<e>>>0?b+1|0:b;a=b^e;v[ga+12>>2]=a>>>0>8191?2:16384/(a+1>>>0)|0}Ka=d>>>12&8|(d>>>5&2|(i|d&1));sa=j+1075795|0;La=j+1075778|0;Ma=j+1075688|0;Na=j+1075024|0;Oa=j+1075020|0;Pa=j+1075668|0;Qa=j+1075664|0;M=j+1075e3|0;X=j+1075088|0;Y=j+1075084|0;ta=j+1075016|0;ua=j+1075012|0;da=j+1075096|0;ba=j+1075076|0;J=j+1075068|0;ia=j+1075072|0;_=j+1075092|0;a=l;while(1){jd:{b=v[_>>2];ja=b?a>>>0>b>>>0?b:a:a;v[c+68>>2]=ja;la=v[ia>>2];b=v[G>>2];p=v[M+4>>2];i=v[M>>2];v[c+56>>2]=i;v[c+60>>2]=p;kd:{ld:{if(!ja|!(i|p)){break ld}m=v[J>>2];if(!m){break ld}e=v[c+8>>2];if(!e){break ld}v[N+632>>2]=e;e=v[f+4>>2];s=e;md:{nd:{j=v[f>>2];F=la&b<<30>>31;aa=e;od:{if((F|0)>(e|0)){if((p|0)<-1|(p|0)<=-1){d=c;v[d+104>>2]=0;e=F;v[d+108>>2]=e<<1;j=Pg(d+104|0,f);b=jb;s=b;v[f>>2]=j;v[f+4>>2]=b;if(!(b>>>0<e+v[J>>2]>>>1>>>0&(b|0)>=(e|0))){b=f;j=0;v[b>>2]=j;s=e;v[b+4>>2]=e}b=i;d=0-(((b|0)!=0)+p|0)|0;k=0-b|0;v[c+56>>2]=k;v[c+60>>2]=d;v[M>>2]=k;v[M+4>>2]=d;b=v[G>>2];pd:{if(b&4){b=b&-129;v[G>>2]=b;break pd}b=b|128;v[G>>2]=b;e=v[J>>2]-1|0;s=e;v[f>>2]=j;v[f+4>>2]=e;v[M>>2]=i;v[M+4>>2]=p}qd:{if(!(b&2)){b=v[J>>2];break qd}b=v[J>>2];if(s>>>0<b>>>0){break md}}d=f;v[d>>2]=0;v[d+4>>2]=b;break ld}if((s|0)>-1){break od}b=0;s=b;v[f>>2]=j;v[f+4>>2]=b;break od}if(m>>>0<=aa>>>0){break nd}}k=i;d=p;break md}if(!(b&2)){break ld}if(b&4){rd:{if(i>>>0<1&(p|0)<=0|(p|0)<0){k=i;d=p;break rd}k=0-i|0;v[c+56>>2]=k;d=0-(((i|0)!=0)+p|0)|0;v[c+60>>2]=d;v[M>>2]=k;v[M+4>>2]=d}v[G>>2]=b|128;b=1-((j|0)!=0)|0;j=0-j|0;i=(m<<1)-(b+aa|0)|0;b=i;s=b;e=f;v[e>>2]=j;v[e+4>>2]=b;if(b>>>0<m>>>0&b>>>0>la>>>0){break md}v[c+104>>2]=Fa;b=m-v[Fb(J,c+104|0)>>2]|0;j=v[e>>2];v[f>>2]=j;s=b;v[e+4>>2]=b;break md}sd:{if((p|0)>-1){k=i;d=p;break sd}k=0-i|0;v[c+56>>2]=k;d=0-(((i|0)!=0)+p|0)|0;v[c+60>>2]=d;v[M>>2]=k;v[M+4>>2]=d}b=c;v[b+104>>2]=0;v[b+108>>2]=F-m;Ub(f,b+104|0);v[G>>2]=v[G>>2]|8192;j=v[f>>2];s=v[f+4>>2]}v[c+48>>2]=j;b=s;v[c+52>>2]=b;p=b;td:{if((b|0)<(F|0)){if((s|0)<0){break ld}if((d|0)>0|(d|0)>=0){break td}break ld}if((s|0)<0){break ld}}if(p>>>0>=y[J>>2]){break ld}v[c+44>>2]=ja;qc(c+68|0,v[c+20>>2]);Ra=c,Sa=Cw(c+56|0,v[c+68>>2]-1|0),v[Ra+32>>2]=Sa;v[c+36>>2]=jb;b=d;i=k;d=b>>31;e=d;k=d;d=i+d|0;b=b+e|0;la=d;d=d>>>0<e>>>0?b+1|0:b;aa=v[ia>>2];m=aa+16|0;b=v[c+36>>2]+v[c+52>>2]|0;va=v[c+48>>2];i=va+v[c+32>>2]|0;b=i>>>0<va>>>0?b+1|0:b;aa=p>>>0<aa>>>0;if(!(!aa&m>>>0>p>>>0)){v[G>>2]=v[G>>2]&-8193}i=k^la;k=d^e;e=b;ud:{vd:{wd:{if(!v[c+12>>2]){d=v[c+60>>2];break wd}b=v[c+16>>2];if(b>>>0<=p>>>0){e=c;d=v[c+60>>2];xd:{if((d|0)<-1|(d|0)<=-1){v[c+96>>2]=j;v[c+100>>2]=s;d=c;v[d+104>>2]=0;v[d+108>>2]=b;Ra=d,Sa=Pg(d+96|0,d+104|0),v[Ra+80>>2]=Sa;v[d+84>>2]=jb;v[d+72>>2]=1;v[d+76>>2]=0;Ra=d,Sa=Pg(d+80|0,d+72|0),v[Ra+88>>2]=Sa;v[d+92>>2]=jb;b=In(d+88|0,i,k);break xd}d=v[ba>>2];v[c+104>>2]=j;v[c+108>>2]=s;b=c;v[b+96>>2]=0;v[b+100>>2]=d;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;b=In(b+88|0,i,k)}v[e+44>>2]=b+1;v[N+632>>2]=v[c+12>>2];break ud}if(!(!(w[G+1|0]&32)|aa|m>>>0<=p>>>0)){v[c+104>>2]=j;v[c+108>>2]=s;b=c;v[b+96>>2]=0;v[b+100>>2]=F+16;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;Ra=b,Sa=In(b+88|0,i,k)+1|0,v[Ra+44>>2]=Sa;Ra=N,Sa=v[b+12>>2]+B(v[ba>>2]-F|0,kj(v[da>>2]))|0,v[Ra+632>>2]=Sa;break ud}d=v[c+60>>2];if(y[c+56>>2]<1&(d|0)<=0|(d|0)<0){break wd}if(ja>>>0<2|b>>>0>e>>>0){break vd}v[c+104>>2]=j;v[c+108>>2]=s;v[c+96>>2]=0;v[c+100>>2]=b;Ra=c,Sa=Pg(c+96|0,c+104|0),v[Ra+80>>2]=Sa;v[c+84>>2]=jb;v[c+72>>2]=1;v[c+76>>2]=0;Ra=c,Sa=Pg(c+80|0,c+72|0),v[Ra+88>>2]=Sa;v[c+92>>2]=jb;Ra=c,Sa=In(c+88|0,i,k)+1|0,v[Ra+44>>2]=Sa;break ud}if((d|0)>-1){break vd}if((e|0)>=(F|0)){break ud}v[c+96>>2]=j;v[c+100>>2]=s;v[c+104>>2]=0;v[c+108>>2]=F;Ra=c,Sa=Pg(c+96|0,c+104|0),v[Ra+80>>2]=Sa;v[c+84>>2]=jb;v[c+72>>2]=1;v[c+76>>2]=0;Ra=c,Sa=Pg(c+80|0,c+72|0),v[Ra+88>>2]=Sa;v[c+92>>2]=jb;Ra=c,Sa=In(c+88|0,i,k)+1|0,v[Ra+44>>2]=Sa;break ud}b=v[J>>2];if((b|0)>(e|0)){break ud}v[c+104>>2]=j;v[c+108>>2]=s;v[c+96>>2]=0;v[c+100>>2]=b;Ra=c,Sa=Pg(c+96|0,c+104|0),v[Ra+80>>2]=Sa;v[c+84>>2]=jb;v[c+72>>2]=1;v[c+76>>2]=0;Ra=c,Sa=Pg(c+80|0,c+72|0),v[Ra+88>>2]=Sa;v[c+92>>2]=jb;Ra=c,Sa=In(c+88|0,i,k)+1|0,v[Ra+44>>2]=Sa}Fp(c+44|0,1,v[c+68>>2]);e=v[c+44>>2];if((e|0)>0){break kd}}v[N+632>>2]=0;v[J>>2]=0;v[f>>2]=0;v[f+4>>2]=0;v[_>>2]=0;MS(f,h,a);v[T>>2]=v[T>>2]+v[Y>>2];v[I>>2]=v[I>>2]+v[X>>2];v[X>>2]=0;v[Y>>2]=0;v[G>>2]=v[G>>2]&-129;d=x[c+30>>1];break jd}yd:{zd:{d=x[c+30>>1];if(d>>>0<y[r+24608>>2]){R=4;if(v[_>>2]){break zd}R=0;if(v[ta>>2]|v[ua>>2]){break zd}}Ra=c,Sa=nqa(v[M>>2],v[M+4>>2],e,e>>31),v[Ra+104>>2]=Sa;v[c+108>>2]=jb;Ub(f,c+104|0);R=0;v[X>>2]=0;v[Y>>2]=0;b=(e<<3)+h|0;break yd}b=(e<<3)+h|0;i=b-8|0;v[Y>>2]=0-v[i>>2];j=b-4|0;v[X>>2]=0-v[j>>2];kb[v[((R|Ka)<<2)+33696>>2]](f,Ga,h,e);v[Y>>2]=v[Y>>2]+v[i>>2];v[X>>2]=v[X>>2]+v[j>>2];R=1}h=b;b=v[_>>2];Ad:{if(!b){break Ad}if(b>>>0<=e>>>0){v[_>>2]=0;v[ua>>2]=v[Qa>>2];v[ta>>2]=v[Pa>>2];v[Oa>>2]=0;v[Na>>2]=0;if(v[Ma>>2]|!(w[G+1|0]&16)){break Ad}v[J>>2]=0;v[N+632>>2]=0;break Ad}v[_>>2]=b-e}m=0;b=0;i=v[f+4>>2];b=i>>>0>=y[ba>>2]?(w[G|0]&2)>>>1|0:b;s=i;i=v[J>>2];m=s>>>0<i>>>0|(!i|w[G|0]&2)?m:!x[La>>1];a=a-e|0;e=c+104|0;Db(e,na,85);Bd:{Cd:{Dd:{Ed:{if(!Cb(e)){break Ed}e=w[sa|0];if(!e|e>>>0>x[r+480190>>1]){break Ed}e=r+B(w[sa|0],104)|0;i=e+484380|0;j=v[da>>2];if((i|0)==(j|0)|(b|m)!=1){break Dd}v[da>>2]=i;v[N+632>>2]=v[e+484400>>2];b=x[e+484414>>1];v[G>>2]=b|v[G>>2]&-768;i=b<<30>>31;b=v[e+484388>>2];v[J>>2]=i&b;e=v[e+484384>>2];v[ia>>2]=e;v[ba>>2]=b;v[f+4>>2]=e;lF(ga,f);if(!v[N+632>>2]){break jd}if((a|0)>0){continue}break jd}if(b){break Cd}break Bd}if(!b|(i|0)!=(j|0)){break Bd}}b=c+104|0;Db(b,na,83);if(!Cb(b)|v[ia>>2]){break Bd}v[f>>2]=v[f>>2];v[f+4>>2]=0;b=v[v[da>>2]+8>>2];v[J>>2]=b;v[ba>>2]=b}if((a|0)>0){continue}}break}v[N+632>>2]=v[c+8>>2];u[c+30>>1]=d+R;if(!R|!ca|ca>>>0>250){break fd}a=v[(r+B(ca,160)|0)+906140>>2];if(!a){break fd}kb[v[v[a>>2]+148>>2]](a)}fa=fa+1|0;if(fa>>>0<x[r+480212>>1]){continue}break}}Ra=r,Sa=x[Ke(r+480214|0,c+30|0)>>1],u[Ra+480214>>1]=Sa}gb=c+112|0;if(Dd(qa)){a=ea;F=g;b=(B(v[K+480232>>2],v[K+480236>>2])>>>0)/48|0;n=gb-16|0;gb=n;E=v[qa>>2];Fd:{if(!w[E+530|0]){break Fd}e=nqa(b,0,6169,0);c=jb;b=c>>>16|0;W=Qc((c&65535)<<16|e>>>16,b);if(!F){break Fd}while(1){c=v[E>>2];h=v[c>>2];b=v[c+4>>2];if((h|0)<=(b|0)){i=c+14|0;j=c+12|0;while(1){v[c+8>>2]=v[c+12>>2];b=c;h=j;s=i;p=0;m=0;f=0;e=gb-16|0;gb=e;while(1){l=b+B(f,44)|0;Gd:{if(!w[l+56|0]){u[e+12>>1]=0;u[e+14>>1]=0;break Gd}k=v[l+32>>2];d=x[k+3840>>1];if(d&3){k=(x[l+36>>1]>>>7&7)>>>(w[k+3844|0]^1)>>>(d&1)<<x[l+38>>1];d=d&4?0-k|0:k}else{d=0}k=e;o=v[l+52>>2];Hd:{if(o){A=x[o+32>>1];q=x[l+48>>1];o=kg(v[l+16>>2],v[l+40>>2],d<<16>>16,0,u[l+46>>1]);H=v[l+40>>2];r=v[l+20>>2];if(!A){if(!q){d=d<<16>>16;o=kg(r,H,d,o,0);o=kg(v[l+24>>2],v[l+40>>2],d,o,0);d=kg(v[l+28>>2],v[l+40>>2],d,o,0);break Hd}d=d<<16>>16;H=kg(r,H,d,0,0);H=kg(v[l+24>>2],v[l+40>>2],d,H,0);d=kg(v[l+28>>2],v[l+40>>2],d,H,0)+o|0;break Hd}if(!q){d=d<<16>>16;o=kg(r,H,d,o,0);H=kg(v[l+24>>2],v[l+40>>2],d,0,0);d=kg(v[l+28>>2],v[l+40>>2],d,H,0)+o|0;break Hd}d=d<<16>>16;H=kg(r,H,d,0,0);d=(kg(v[l+24>>2],v[l+40>>2],d,H,0)+o|0)+kg(v[l+28>>2],v[l+40>>2],d,0,0)|0;break Hd}q=x[l+48>>1];d=d<<16>>16;o=kg(v[l+16>>2],v[l+40>>2],d,0,u[l+46>>1]);H=v[l+40>>2];r=v[l+20>>2];if(!q){d=kg(r,H,d,o,0);break Hd}d=kg(r,H,d,0,0)+o|0}u[k+14>>1]=w[l+57|0]?d:0;u[e+12>>1]=w[l+58|0]?d:0}p=u[e+12>>1]+p|0;m=u[e+14>>1]+m|0;f=f+1|0;if((f|0)!=18){continue}break}d=(m|0)<32767?m:32767;u[h>>1]=(d|0)>-32768?d:-32768;d=(p|0)<32767?p:32767;u[s>>1]=(d|0)>-32768?d:-32768;u[b+3832>>1]=x[b+3832>>1]+1;d=(x[b+3834>>1]+1>>>0)%13440|0;u[b+3834>>1]=d;d=d>>>0<6720?d:13440-d|0;u[b+3836>>1]=d>>>8;if(!w[b+3843|0]){u[b+3836>>1]=d>>>10}d=x[b+3838>>1]+1|0;u[b+3838>>1]=d;if((d&65535)>>>0>=1024){u[b+3838>>1]=0;u[b+3840>>1]=x[b+3840>>1]+1&7}gb=e+16|0;h=v[c>>2];b=v[c+4>>2]-h|0;v[c+4>>2]=b;if((b|0)>=(h|0)){continue}break}}e=h-b|0;u[n+14>>1]=(B(u[c+12>>1],b)+B(e,u[c+8>>1])|0)/(h|0);u[n+12>>1]=(B(u[c+14>>1],b)+B(e,u[c+10>>1])|0)/(h|0);v[c+4>>2]=b+49716;v[a>>2]=v[a>>2]+B(W,u[n+14>>1]);v[a+4>>2]=v[a+4>>2]+B(W,u[n+12>>1]);a=a+8|0;F=F-1|0;if(F){continue}break}}gb=n+16|0}c=ea;a=Ca;p=Ba;l=Aa;d=g;f=Da;b=w[f+12|0];if(v[f+16>>2]?1:b){if(!b){Uo(a,d,p,l)}h=v[f>>2];i=v[f+80>>2];b=B(h,i)>>>4|0;b=b>>>0<32767?b:32767;u[f+98>>1]=b;u[f+96>>1]=b;j=v[f+49948>>2];b=B(j,h)>>>4|0;b=b>>>0<65536?b:65536;e=b+127>>>3|0;u[f+49946>>1]=e;b=b+255>>>4|0;u[f+49944>>1]=b;u[f+49942>>1]=b;u[f+49940>>1]=e;b=c;e=a;i=(i|0)>(j|0)?i:j;h=36-h>>>1|0;h=h>>>0>8?h:8;i=16-(B((i|0)<32768?i:32768,(h|0)<16?16-h|0:0)>>15)|0;n=0;h=d;if(d){while(1){j=n<<3;s=j+b|0;v[s>>2]=v[s>>2]+B(i,v[e+j>>2]>>4);j=j|4;s=j+b|0;v[s>>2]=v[s>>2]+B(i,v[e+j>>2]>>4);n=n+1|0;if((h|0)!=(n|0)){continue}break}}j=f+68|0;i=0;b=f;k=v[b+40>>2];n=v[b+36>>2];if(d){s=u[b+84>>1];while(1){h=(i<<3)+e|0;F=v[h>>2]>>12;n=(B(s,F-n|0)>>15)+F|0;v[h>>2]=n;o=h;h=v[h+4>>2]>>12;k=(B(s,h-k|0)>>15)+h|0;v[o+4>>2]=k;i=i+1|0;if((d|0)!=(i|0)){continue}break}}v[b+40>>2]=k;v[b+36>>2]=n;Id:{if(!d){e=v[j>>2];break Id}F=f+49892|0;b=d;i=j;o=v[j>>2]-1|0;h=x[j+22>>1];s=u[j+26>>1];q=u[j+18>>1];m=v[j+4>>2];n=x[j+20>>1];k=u[j+24>>1];E=u[j+16>>1];H=j+32928|0;while(1){r=Lb(v[e>>2],-32768,32767);W=Lb(v[e+4>>2],-32768,32767);n=Lb((n<<16>>16)-r|0,-32768,32767);h=Lb((h<<16>>16)-W|0,-32768,32767);n=Uc(Lb((B(n,E)|0)/65536<<1,-32768,32767)+r|0);h=Uc(Lb((B(h,q)|0)/65536<<1,-32768,32767)+W|0);W=H+(m<<2)|0;r=u[W+2>>1];A=u[W>>1];W=Uc(((B(A,k)|0)/-65536|0)+n|0);m=m+1&127;G=H+(m<<2)|0;J=Uc(((B(s,r)|0)/-65536|0)+h|0);u[G+2>>1]=J;u[G>>1]=W;o=o+1&8191;G=i+(o<<2)|0;Ra=G,Sa=Uc(A+((B(k,W)|0)/65536|0)|0),u[Ra+160>>1]=Sa;Ra=G,Sa=Uc(r+((B(s,J)|0)/65536|0)|0),u[Ra+162>>1]=Sa;e=e+8|0;b=b-1|0;if(b){continue}break}u[i+22>>1]=h;u[i+20>>1]=n;v[i+4>>2]=m;k=v[f+76>>2];G=f+33508|0;b=a;n=d;while(1){h=k&4095;m=G+(h<<2)|0;e=b;h=4096-h|0;E=k-v[f+49892>>2]&4095;i=4096-E|0;h=h>>>0<i>>>0?h:i;h=h>>>0<n>>>0?h:n;s=h>>>0<64?h:64;o=s;k=0;H=gb-32|0;gb=H;i=j;h=v[j>>2];while(1){v[H+(k<<2)>>2]=h+(v[(i+(k<<4)|0)+32>>2]^-1);k=k+1|0;if((k|0)!=7){continue}break}h=u[i+28>>1]/8|0;if(o){W=h<<16>>16;while(1){h=0;R=0;k=0;while(1){r=H+(k<<2)|0;q=v[r>>2]+1&8191;v[r>>2]=q;q=i+(q<<2)|0;A=u[q+160>>1];r=i+(k<<4)|0;q=u[q+162>>1];R=(B(A,u[r+44>>1])+R|0)+B(q,u[r+46>>1])|0;h=(B(A,u[r+40>>1])+h|0)+B(q,u[r+42>>1])|0;k=k+1|0;if((k|0)!=4){continue}break}I=0;k=4;A=Uc((h|0)/32768|0);J=Uc((R|0)/32768|0);h=0;while(1){r=H+(k<<2)|0;q=v[r>>2]+1&8191;v[r>>2]=q;N=h;h=i+(q<<2)|0;q=u[h+160>>1];r=i+(k<<4)|0;M=u[h+162>>1];h=(N+B(q,u[r+44>>1])|0)+B(M,u[r+46>>1])|0;I=(B(q,u[r+40>>1])+I|0)+B(M,u[r+42>>1])|0;k=k+1|0;if((k|0)!=7){continue}break}k=Uc(A+((I|0)/32768|0)|0);u[m>>1]=k;v[e>>2]=B(k,W);h=Uc(J+((h|0)/32768|0)|0);u[m+2>>1]=h;v[e+4>>2]=B(h,W);e=e+8|0;m=m+4|0;o=o-1|0;if(o){continue}break}}gb=H+32|0;m=G+(E<<2)|0;i=b;h=F;k=v[h+4>>2];o=k&2047;e=s;if(e){H=h+8256|0;r=h- -64|0;W=h+24640|0;q=h+16448|0;while(1){J=u[(H+((k+754&2047)<<2)|0)+2>>1];M=u[H+((k+1206&2047)<<2)>>1];A=u[(r+((k+1602&2047)<<2)|0)+2>>1];R=u[r+((k+1750&2047)<<2)>>1];I=W+((k+22&2047)<<2)|0;E=u[I+2>>1];I=u[I>>1];T=W+((k+502&2047)<<2)|0;N=u[T+2>>1];X=u[m>>1];Y=u[m+2>>1];T=u[T>>1];_=Lb(u[h+32>>1]-T|0,-32768,32767);ba=u[h+24>>1];ca=Lb(u[h+34>>1]-N|0,-32768,32767);da=u[h+26>>1];ia=Lb(u[h+36>>1]-I|0,-32768,32767);fa=u[h+28>>1];ga=Lb(u[h+38>>1]-E|0,-32768,32767);ja=u[h+30>>1];Ra=h,Sa=Uc(Lb((B(_,ba)|0)/65536<<1,-32768,32767)+T|0),u[Ra+32>>1]=Sa;Ra=h,Sa=Uc(Lb((B(ca,da)|0)/65536<<1,-32768,32767)+N|0),u[Ra+34>>1]=Sa;Ra=h,Sa=Uc(Lb((B(ia,fa)|0)/65536<<1,-32768,32767)+I|0),u[Ra+36>>1]=Sa;Ra=h,Sa=Uc(Lb((B(ga,ja)|0)/65536<<1,-32768,32767)+E|0),u[Ra+38>>1]=Sa;E=Lb((B(u[h+32>>1],u[h+16>>1])|0)/32768|0,-32768,32767);N=Lb((B(u[h+38>>1],u[h+22>>1])|0)/32768|0,-32768,32767);I=Lb(E+((X|0)/4<<16>>16)|0,-32768,32767);N=Lb(N+((Y|0)/4<<16>>16)|0,-32768,32767);T=Lb(I+((B(R,u[h+8>>1])|0)/-65536|0)|0,-32768,32767);E=o<<2;X=E+r|0;Y=Lb(N+((B(A,u[h+10>>1])|0)/-65536|0)|0,-32768,32767);u[X+2>>1]=Y;u[X>>1]=T;R=Lb(R+((B(T,u[h+8>>1])|0)/65536|0)|0,-32768,32767);T=q+E|0;A=Lb(A+((B(Y,u[h+10>>1])|0)/65536|0)|0,-32768,32767);u[T+2>>1]=A;u[T>>1]=R;R=Lb(I+R|0,-32768,32767);I=Lb(A+N|0,-32768,32767);A=q+((k+426&2047)<<2)|0;N=u[A+2>>1];T=u[A>>1];k=q+((k+682&2047)<<2)|0;X=u[k+2>>1];Y=u[k>>1];k=Lb((B(X,u[h+42>>1])+B(Y,u[h+40>>1])|0)/32768|0,-32768,32767);A=Lb((B(N,u[h+46>>1])+B(T,u[h+44>>1])|0)/32768|0,-32768,32767);Y=Lb(Lb(R+Y|0,-32768,32767)-k|0,-32768,32767);X=Lb(Lb(I+X|0,-32768,32767)-A|0,-32768,32767);R=Lb(Lb(R+T|0,-32768,32767)-k|0,-32768,32767);I=Lb(Lb(I+N|0,-32768,32767)-A|0,-32768,32767);k=Lb(k+((B(M,u[h+8>>1])|0)/-65536|0)|0,-32768,32767);N=u[h+8>>1];T=u[h+10>>1];_=E+H|0;A=Lb(A+((B(J,u[h+10>>1])|0)/-65536|0)|0,-32768,32767);u[_+2>>1]=A;u[_>>1]=k;aa=M;M=(B(k,N)|0)/65536|0;k=Lb(aa+M|0,-32768,32767);E=E+W|0;A=(B(A,T)|0)/65536|0;J=Lb(A+J|0,-32768,32767);u[E+2>>1]=J;u[E>>1]=k;k=Lb(k+Y|0,-32768,32767);Ra=i,Sa=(v[i>>2]+B(k,u[h+48>>1])|0)+B(Lb(J+X|0,-32768,32767),u[h+50>>1])|0,v[Ra>>2]=Sa;k=Lb(Lb(M,-32768,32767)+R|0,-32768,32767);E=u[h+52>>1];A=Lb(A,-32768,32767);Ra=i,Sa=(v[i+4>>2]+B(k,E)|0)+B(Lb(A+I|0,-32768,32767),u[h+54>>1])|0,v[Ra+4>>2]=Sa;i=i+8|0;m=m+4|0;k=o+1|0;o=k&2047;e=e-1|0;if(e){continue}break}}v[h+4>>2]=o;k=s+v[f+76>>2]&4095;v[f+76>>2]=k;e=s+v[f+68>>2]&8191;v[f+68>>2]=e;b=(s<<3)+b|0;n=n-s|0;if(n){continue}break}}v[f+68>>2]=e&8191;e=a;i=c;h=0;F=0;j=f;n=v[f+56>>2];k=v[f+52>>2];b=d;if(b){a=v[j+60>>2];c=v[j+64>>2];while(1){h=v[e>>2];F=v[e+4>>2];c=c-F|0;c=(((c|0)/1024|0)-c|0)+n|0;v[i+4>>2]=c+v[i+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+k|0;v[i>>2]=a+v[i>>2];n=c+((c|0)/-512|0)|0;k=a+((a|0)/-512|0)|0;i=i+8|0;e=e+8|0;c=F;a=h;b=b-1|0;if(b){continue}break}}v[j+64>>2]=F;v[j+60>>2]=h;v[j+56>>2]=n;v[j+52>>2]=k;a=v[f+20>>2];Jd:{if(w[f+12|0]){break Jd}a=v[f+16>>2];if(a>>>0>d>>>0){a=a-d|0;break Jd}QL(f,p,l);a=0}t[f+12|0]=0;v[f+16>>2]=a}if(v[K+946300>>2]){n=0;p=0;e=g<<2;f=K;m=x[f+480214>>1]!=0;a=f+1074332|0;Z=z[a>>2];wa=z[a+4>>2];while(1){h=(f+B(n,160)|0)+906300|0;a=v[h>>2];Kd:{if(!a|!v[a+24>>2]){break Kd}if(!ni(a+44|0)){break Kd}a=v[h>>2];if(!(kb[v[v[a>>2]+112>>2]](a)|0)){kb[v[v[a>>2]+108>>2]](a,1);kb[v[v[a>>2]+120>>2]](a)}c=a+44|0;b=Nd(c,0);c=Nd(c,1);Ld:{if(t[a+28|0]&1){mB(v[a+24>>2],b,c,d,Z);break Ld}i=a+40|0;if(v[a+36>>2]?1:v[i>>2]){Uo(v[a+24>>2],d,i,a+36|0);mB(v[a+24>>2],b,c,d,Z);break Ld}Qb(b,0,e);Qb(c,0,e)}v[a+28>>2]=v[a+28>>2]&-2;if(Bw(h)){break Kd}m=!(w[a+28|0]&4)|m}n=n+1|0;if((n|0)!=250){continue}break}k=f+12|0;h=f+12300|0;i=f+14348|0;mB(k,h,i,d,Z);a=f+1074476|0;r=w[a|0];t[a|0]=0;a=h;b=i;while(1){j=(f+B(p,160)|0)+906300|0;c=v[j>>2];Md:{if(!c|!v[c+24>>2]){break Md}if(!ni(c+44|0)){break Md}l=v[j>>2];Nd:{if(Bw(j)){break Nd}c=v[j>>2];if(kb[v[v[c>>2]+144>>2]](c)|w[v[j>>2]+28|0]&2){break Nd}n=0;if(!p){break Md}while(1){if((Vk((f+B(n,160)|0)+906300|0)|0)==(p|0)){break Nd}n=n+1|0;if((n|0)!=(p|0)){continue}break}break Md}c=l+44|0;F=Nd(c,0);H=Nd(c,1);s=v[j>>2];o=(a|0)==(F|0);a=o?h:a;c=a;b=o?i:b;e=b;Od:{if(!(w[j+28|0]|w[j+29|0]<<8|(w[j+30|0]<<16|w[j+31|0]<<24))){break Od}c=a;n=Vk(j);e=b;if(n>>>0>249){break Od}e=b;if(n>>>0<=p>>>0){break Od}n=v[(f+B(n,160)|0)+906300>>2];e=b;if(!n){break Od}if(!(w[s+28|0]&4)){kb[v[v[n>>2]+148>>2]](n)}n=n+44|0;e=b;if(!ni(n)){break Od}c=Nd(n,0);e=Nd(n,1)}Pd:{if(!Bw(j)){break Pd}Qd:{if(o){break Qd}n=0;if(!d){break Qd}while(1){o=n<<2;W=o+F|0;q=a+o|0;z[W>>2]=z[q>>2]+z[W>>2];W=o+H|0;o=b+o|0;z[W>>2]=z[o>>2]+z[W>>2];v[q>>2]=0;v[o>>2]=0;n=n+1|0;if((d|0)!=(n|0)){continue}break}}b=e;a=c;if(!(m&1)){break Pd}a=v[j>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}a=c;n=Vk(j);if(n>>>0>249|n>>>0<=p>>>0){break Pd}while(1){b=n&255;a=(f+B(b,160)|0)+906300|0;n=Vk(a);a=v[a>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}if(b>>>0<n>>>0&n>>>0<=249){continue}break}b=e;a=c}Rd:{Sd:{if(!((w[j+24|0]&2)>>>1|0)){if(!jF(j)|!(w[s+28|0]&4)){break Sd}}n=0;if(!d){break Rd}while(1){j=n<<2;l=j+c|0;z[l>>2]=z[j+F>>2]+z[l>>2];l=e+j|0;z[l>>2]=z[j+H>>2]+z[l>>2];n=n+1|0;if((d|0)!=(n|0)){continue}break}break Rd}if(r){kb[v[v[l>>2]+128>>2]](l)}kb[v[v[l>>2]+60>>2]](l,c,e,d);v[s+32>>2]=d+v[s+32>>2];if(!jF(j)){break Rd}if((kb[v[v[l>>2]+156>>2]](l)|0)<1|y[s+32>>2]<v[f+24620>>2]<<2>>>0){break Rd}n=0;Td:{if(!d){break Td}while(1){Ud:{j=n<<2;Z=z[j+c>>2];if(Z>=C(1.1920928955078125e-7)|Z<=C(-1.1920928955078125e-7)){break Ud}Z=z[e+j>>2];if(Z>=C(1.1920928955078125e-7)|Z<=C(-1.1920928955078125e-7)){break Ud}n=n+1|0;if((d|0)!=(n|0)){continue}break Td}break}v[s+32>>2]=0;break Rd}v[s+28>>2]=v[s+28>>2]|4}v[s+28>>2]=v[s+28>>2]&-3}p=p+1|0;if((p|0)!=250){continue}break}c=0;if(d){while(1){e=k;Z=C(z[a>>2]*wa);Vd:{if(C(D(Z))<C(2147483648)){f=~~Z;break Vd}f=-2147483648}v[e>>2]=f;e=k;Z=C(z[b>>2]*wa);Wd:{if(C(D(Z))<C(2147483648)){f=~~Z;break Wd}f=-2147483648}v[e+4>>2]=f;k=k+8|0;b=b+4|0;a=a+4|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}}if(v[K+24624>>2]==1){a=ea;f=0;b=g;if(b){while(1){c=a+(f<<3)|0;v[a+(f<<2)>>2]=(v[c+4>>2]+v[c>>2]|0)/2;f=f+1|0;if((b|0)!=(f|0)){continue}break}}}if(w[za+33|0]){c=g;h=gb-16|0;gb=h;Xd:{Yd:{a=K;Zd:{if(!v[a+1074376>>2]){e=a+1074460|0;b=e;v[b>>2]=0;v[b+4>>2]=0;v[a+1074468>>2]=v[a+1074456>>2];break Zd}d=v[a+1074468>>2];b=v[a+1074456>>2];_d:{if((d|0)==(b|0)){f=v[a+1074460>>2];break _d}v[a+1074468>>2]=b;e=a+24604|0;i=a+1074460|0;$d:{if((b|0)>(d|0)){f=LS(e);break $d}f=KS(e)}v[i>>2]=f;v[a+1074464>>2]=f}e=a+1074460|0;if((f|0)>=1){break Yd}}n=0;break Xd}d=(v[a+1074468>>2]<<12)-v[a+1074472>>2]|0;n=(d|0)/(f|0)|0;if(w[a+1074368|0]!=2){break Xd}v[h+12>>2]=50;b=a+1074464|0;v[h+8>>2]=1e4/(v[b>>2]+1|0);i=v[Hf(h+12|0,h+8|0)>>2];f=n>>31;if((i|0)>=(f+n^f)){break Xd}j=v[b>>2];f=v[e>>2];while(1){f=f+j|0;n=(d|0)/(f|0)|0;b=n>>31;if((i|0)<(b^b+n)){continue}break}v[e>>2]=f}ae:{be:{switch(v[a+24624>>2]-1|0){case 0:if((c|0)<1){break ae}b=v[a+1074456>>2];j=b<<12;d=b;s=b>>31;f=a+12|0;b=0;while(1){ce:{if(v[e>>2]>=1){i=v[a+1074472>>2]+n|0;v[a+1074472>>2]=i;k=v[f>>2];Ra=f,Sa=Ac(oqa(nqa(k,k>>31,i,i>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;v[a+1074460>>2]=v[a+1074460>>2]-1;break ce}i=v[f>>2];Ra=f,Sa=Ac(oqa(nqa(i,i>>31,d,s),jb,256,0),jb),v[Ra>>2]=Sa;v[a+1074472>>2]=j}f=f+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break};break ae;case 1:if((c|0)<1){break ae}b=v[a+1074456>>2];s=b<<12;d=b;i=b>>31;f=a+12|0;b=0;while(1){de:{if(v[e>>2]>=1){j=v[a+1074472>>2]+n|0;v[a+1074472>>2]=j;k=v[f>>2];Ra=f,Sa=Ac(oqa(nqa(k,k>>31,j,j>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;j=v[a+1074472>>2];k=j;p=j>>31;j=v[f+4>>2];Ra=f,Sa=Ac(oqa(nqa(k,p,j,j>>31),jb,1048576,0),jb),v[Ra+4>>2]=Sa;v[a+1074460>>2]=v[a+1074460>>2]-1;break de}j=v[f>>2];Ra=f,Sa=Ac(oqa(nqa(j,j>>31,d,i),jb,256,0),jb),v[Ra>>2]=Sa;j=v[f+4>>2];Ra=f,Sa=Ac(oqa(nqa(j,j>>31,d,i),jb,256,0),jb),v[Ra+4>>2]=Sa;v[a+1074472>>2]=s}f=f+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break};break ae;case 3:break be;default:break ae}}if((c|0)<1){break ae}b=v[a+1074456>>2];s=b<<12;d=b;i=b>>31;f=a+12|0;b=a+8204|0;m=0;while(1){ee:{if(v[e>>2]>=1){j=v[a+1074472>>2]+n|0;v[a+1074472>>2]=j;k=v[f>>2];Ra=f,Sa=Ac(oqa(nqa(k,k>>31,j,j>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;j=v[a+1074472>>2];k=j;p=j>>31;j=v[f+4>>2];Ra=f,Sa=Ac(oqa(nqa(k,p,j,j>>31),jb,1048576,0),jb),v[Ra+4>>2]=Sa;j=v[a+1074472>>2];k=j;p=j>>31;j=v[b>>2];Ra=b,Sa=Ac(oqa(nqa(k,p,j,j>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;j=v[a+1074472>>2];k=j;p=j>>31;j=v[b+4>>2];Ra=b,Sa=Ac(oqa(nqa(k,p,j,j>>31),jb,1048576,0),jb),v[Ra+4>>2]=Sa;v[a+1074460>>2]=v[a+1074460>>2]-1;break ee}j=v[f>>2];Ra=f,Sa=Ac(oqa(nqa(j,j>>31,d,i),jb,256,0),jb),v[Ra>>2]=Sa;j=v[f+4>>2];Ra=f,Sa=Ac(oqa(nqa(j,j>>31,d,i),jb,256,0),jb),v[Ra+4>>2]=Sa;j=v[b>>2];Ra=b,Sa=Ac(oqa(nqa(j,j>>31,d,i),jb,256,0),jb),v[Ra>>2]=Sa;j=v[b+4>>2];Ra=b,Sa=Ac(oqa(nqa(j,j>>31,d,i),jb,256,0),jb),v[Ra+4>>2]=Sa;v[a+1074472>>2]=s}b=b+8|0;f=f+8|0;m=m+1|0;if((c|0)!=(m|0)){continue}break}}gb=h+16|0}if(v[pa>>2]!=128){c=K+12|0;e=K+8204|0;a=g;b=v[K+24604>>2];d=v[K+24624>>2];fe:{if((b|0)==128|d>>>0<2){break fe}jO(c,a,b);if(d>>>0<4){break fe}jO(e,a,b)}}if(v[K+24624>>2]==4){a=ea;b=ya;f=g-1|0;if((f|0)>-1){while(1){c=a+(f<<4)|0;e=f<<3;d=e|4;v[c+12>>2]=v[d+b>>2];v[c+8>>2]=v[b+e>>2];v[c+4>>2]=v[a+d>>2];v[c>>2]=v[a+e>>2];c=(f|0)>0;f=f-1|0;if(c){continue}break}}}if(w[$+20|0]){b=v[$+16>>2];a=mg(V+72|0,ea,v[K+24624>>2],g);c=v[v[b>>2]+8>>2];v[V+24>>2]=v[a+8>>2];e=v[a+4>>2];v[V+16>>2]=v[a>>2];v[V+20>>2]=e;kb[c|0](b,V+16|0)}a=mg(V+56|0,ea,v[K+24624>>2],g);b=v[v[oa>>2]+8>>2];v[V+8>>2]=v[a+8>>2];c=v[a+4>>2];v[V>>2]=v[a>>2];v[V+4>>2]=c;kb[b|0](oa,V);F=v[K+1074380>>2]-g|0;v[K+1074380>>2]=F;v[K+1074376>>2]=g+v[K+1074376>>2];xa=g+xa|0;a=v[K+480208>>2];if(a&512){break i}ka=ka-g|0;if(ka){continue}break}}gb=V+128|0;gb=$+48|0;return xa}function Koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-496|0;gb=d;vc(b);g=gb-32|0;gb=g;f=g+24|0;h=d+304|0;Pr(f,h);j=yb(f);f=v[g+28>>2];i=v[g+24>>2];v[g+8>>2]=i;v[g+12>>2]=f;v[g>>2]=i;v[g+4>>2]=f;i=g+16|0;f=b;cc(i,f,g);i=yb(i);if((i|0)==(j|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){UW(h)}a:{b:{c:{if(!f){break c}if(!sX(d+304|0)){break c}if(!Pb(b,Qc(rX(d+304|0),jb))){break c}if(!c){e=1;break c}Hd(a,32);t[d+303|0]=0;j=Kb(d+288|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if(v[d+304>>2]==778924148){v[22708]=0;R(558,a|0,16777216);e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;e=T(195,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(190,b|0,e-4|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;s=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break G}break b}H:{I:{J:{K:{L:{e=w[d+344|0]|w[d+345|0]<<8;M:{if(e>>>0<2185|e>>>0>4095){break M}v[22708]=0;e=T(195,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(190,b|0,e-4|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;s=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}if(s>>>0<256){break M}v[22708]=0;e=T(195,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break M}v[22708]=0;e=Q(190,b|0,s|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if(!e){break M}v[22708]=0;e=T(559,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if(!e){break M}v[22708]=0;R(558,a|0,16777216);e=v[22708];v[22708]=0;if((e|0)==1){break b}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=4096){v[22708]=0;b=Q(2,d+104|0,13592)|0;c=v[22708];v[22708]=0;if((c|0)==1){break F}v[22708]=0;U(560,a|0,1,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);e=0;break d}a=P()|0;O()|0;vb(b);break a}if((w[d+344|0]|w[d+345|0]<<8)>>>0<2194){break M}v[22708]=0;e=Q(2,d+104|0,13121)|0;f=v[22708];v[22708]=0;if((f|0)==1){break L}v[22708]=0;U(560,a|0,4,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break K}vb(e)}if(v[a+480180>>2]!=32){break G}if(((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break H}f=(w[d+344|0]|w[d+345|0]<<8)&4095;e=f<<16;if(v[d+364>>2]!=1414548815){break J}t[d+303|0]=1;break I}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}if(f>>>0<297){break I}e=w[d+364|0]|w[d+365|0]<<8|e}v[a+1074308>>2]=e;break G}if(!((w[d+346|0]|w[d+347|0]<<8)!=2184&(w[d+344|0]|w[d+345|0]<<8)!=2184)){t[d+303|0]=1;v[a+1074308>>2]=18284544;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=535|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[22708]=0;e=zv(d+368|0,255,64);f=v[22708];v[22708]=0;if((f|0)==1){break b}N:{if(e){v[a+1074308>>2]=18219008;v[22708]=0;h=Q(2,d+104|0,12025)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break N}a=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22708]=0;h=Q(2,d+104|0,13943)|0;e=v[22708];v[22708]=0;if((e|0)==1){break E}}Eb(j,h);vb(h);t[d+303|0]=1;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=514|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[a+1074308>>2]=17367040;v[22708]=0;e=Q(2,d+104|0,11917)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);t[d+303|0]=1;break G}a=P()|0;O()|0;break a}if((w[d+344|0]|w[d+345|0]<<8)!=768|(w[d+346|0]|w[d+347|0]<<8)!=768|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|(w[d+336|0]|w[d+337|0]<<8)!=256)){break G}if(w[d+357|0]|w[d+356|0]!=128){break G}v[a+1074308>>2]=18285088;t[d+303|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+348|0]|w[d+349|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+348|0]|w[d+349|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+348|0]|w[d+349|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+348|0]|w[d+349|0]<<8)<<3&32768;v[22708]=0;Cp(d+216|0,3,d+304|4);e=v[22708];v[22708]=0;if((e|0)==1){break D}v[22708]=0;R(324,d+104|0,d+216|0);e=v[22708];v[22708]=0;if((e|0)==1){break D}e=d+104|0;Eb(a+1298268|0,e);vb(e);if(!(!(w[d+350|0]&4)|v[a+1074308>>2]-1>>>0<18285313)){v[a+480216>>2]=w[d+334|0];v[a+480220>>2]=w[d+335|0]}e=w[d+352|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+354|0]){v[a+480196>>2]=w[d+354|0]}t[d+104|0]=31;e=w[d+355|0];v[22708]=0;t[d+216|0]=e;e=qf(d+104|0,d+216|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);t[d+104|0]=w[d+353|0];v[22708]=0;t[d+216|0]=128;e=ac(d+104|0,d+216|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];e=0;while(1){i=(d+304|0)+e|0;g=i- -64|0;O:{if(w[g|0]==255){break O}v[22708]=0;h=(e<<5)+a|0;f=h+480280|0;We(f);l=v[22708];v[22708]=0;if((l|0)==1){break C}E=h+480286|0,F=Fd(w[i+128|0],0,64),u[E>>1]=F;if(t[g|0]<=-1){v[f>>2]=v[f>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break O}if((g|0)!=100){break O}v[f>>2]=v[f>>2]|256}e=e+1|0;if((e|0)!=64){continue}break}v[22708]=0;Q(190,b|0,192)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}P:{if(!(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2187|(w[d+344|0]|w[d+345|0]<<8)>>>0>2189)){e=0;v[22708]=0;f=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break B}if(f){break d}v[22708]=0;f=T(192,b|0)|0;g=v[22708];v[22708]=0;Q:{if((g|0)==1){break Q}if(f>>>0>4e3){break d}g=Sb(a+484360|0);v[22708]=0;f=W(563,g|0,b|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Q}if(!f){break d}break P}a=P()|0;O()|0;break a}e=Sb(a+484360|0);f=w[d+336|0]|w[d+337|0]<<8;v[22708]=0;fa(521,e|0,b|0,f|0,255,254)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}}r=mc(d+272|0);q=mc(d+256|0);n=mc(d+240|0);f=w[d+338|0]|w[d+339|0]<<8;e=0;v[22708]=0;f=W(564,b|0,r|0,f|0)|0;g=v[22708];v[22708]=0;R:{if((g|0)==1){break R}if(!f){break z}f=w[d+340|0]|w[d+341|0]<<8;v[22708]=0;f=W(564,b|0,q|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!f){break z}f=w[d+342|0]|w[d+343|0]<<8;v[22708]=0;f=W(564,b|0,n|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!f){break z}v[d+236>>2]=-1;E=d,F=Vb(r),v[E+104>>2]=F;E=d,F=Zb(r),v[E+216>>2]=F;if(!Gb(d+104|0,d+216|0)){break A}while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}E=d,F=Vb(q),v[E+104>>2]=F;E=d,F=Zb(q),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}}E=d,F=Vb(n),v[E+104>>2]=F;E=d,F=Zb(n),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}}S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if(t[d+350|0]&1){e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22708]=0;v[d+104>>2]=e;e=Fb(d+236|0,d+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break ba}v[d+236>>2]=v[e>>2]}e=0;g=w[d+344|0]|w[d+345|0]<<8;ca:{if((w[d+346|0]|w[d+347|0]<<8)!=532|(g?(g|0)!=532:0)|(w[d+335|0]|w[d+334|0])){break ca}if(w[d+348|0]&192|(w[d+357|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break ca}da:{if(!(w[d+340|0]|w[d+341|0]<<8)|(w[d+338|0]|w[d+339|0]<<8)){break da}if((v[b+8>>2]+(Nb(q)<<2)|0)+2>>>0>y[d+236>>2]){break da}if(w[d+340|0]|w[d+341|0]<<8){g=0;while(1){v[22708]=0;e=T(192,b|0)|0;f=v[22708];v[22708]=0;ea:{if((f|0)!=1){if(!e){break ea}pg(b,((g&65535)<<2)+4|0);break da}a=P()|0;O()|0;break g}g=g+1|0;if((g&65535)>>>0<(w[d+340|0]|w[d+341|0]<<8)>>>0){continue}break}}v[22708]=0;e=Q(2,d+104|0,12177)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}Eb(j,e);vb(e)}e=1;if(w[d+344|0]|w[d+345|0]<<8){break ca}v[22708]=0;f=Q(2,d+104|0,12541)|0;g=v[22708];v[22708]=0;if((g|0)==1){break _}Eb(j,f);vb(f)}fa:{if(w[d+350|0]&2){v[22708]=0;f=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Z}v[22708]=0;g=f<<3;h=Q(191,b|0,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Z}if(!(!h|y[d+236>>2]<g+v[b+8>>2]>>>0)){v[22708]=0;g=a+1298368|0;R(565,g|0,f|0);h=v[22708];v[22708]=0;if((h|0)==1){break Z}E=d,F=Vb(g),v[E+216>>2]=F;E=d,F=Zb(g),v[E+192>>2]=F;if(Gb(d+216|0,d+192|0)){while(1){g=v[d+216>>2];v[22708]=0;R(566,b|0,d+104|0);h=v[22708];v[22708]=0;if((h|0)==1){break Y}v[22708]=0;TE(d+104|0,g);g=v[22708];v[22708]=0;if((g|0)==1){break Y}g=d+216|0;v[g>>2]=v[g>>2]+48;if(Gb(g,d+192|0)){continue}break}}if(!(!f&e)){break fa}if(w[d+350|0]&4){v[22708]=0;e=Q(2,d+104|0,12574)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}v[22708]=0;e=Q(2,d+104|0,12199)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}pg(b,2);break fa}if(!e|(w[d+350|0]|w[d+351|0]<<8)>>>0>1){break fa}v[22708]=0;e=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break aa}if(!e){v[22708]=0;e=Q(2,d+104|0,12177)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}pg(b,2)}ga:{if(!(w[d+350|0]&8?1:w[d+348|0]&128)){break ga}v[22708]=0;e=a+901404|0;f=Q(568,b|0,e|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}if(!f){break ga}v[22708]=0;Ku(e);e=v[22708];v[22708]=0;if((e|0)==1){break h}}if((w[d+344|0]|w[d+345|0]<<8)>>>0<=531){v[22708]=0;Wo(a+901404|0);e=v[22708];v[22708]=0;if((e|0)==1){break h}}v[22708]=0;z=T(215,d+216|0)|0;e=v[22708];v[22708]=0;ha:{ia:{ja:{ka:{la:{ma:{if((e|0)!=1){v[22708]=0;e=Q(555,b|0,11155)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ma}if(e){v[22708]=0;e=T(192,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break la}v[22708]=0;U(288,d+192|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break la}e=d+192|0;f=kc(d+104|0,e);Vc(z,f);xb(f);xb(e)}u[a+480188>>1]=1;v[22708]=0;e=Q(555,b|0,11160)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ma}if(e){v[22708]=0;e=T(192,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ka}v[22708]=0;U(288,d+192|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break ka}e=d+192|0;f=kc(d+104|0,e);xb(e);v[22708]=0;e=T(195,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ja}v[22708]=0;u[d+192>>1]=(e>>>0)/20;e=Pc(28868,d+192|0);g=v[22708];v[22708]=0;if((g|0)==1){break ja}g=x[e>>1];u[a+480188>>1]=g;if(g){e=0;while(1){v[22708]=0;W(571,f|0,((e<<5)+a|0)+480289|0,20)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ja}e=e+1|0;if((g|0)!=(e|0)){continue}break}}xb(f)}if(y[b+8>>2]>y[d+236>>2]){break ia}e=v[d+236>>2]-v[b+8>>2]|0;break ha}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;xb(f);break i}v[22708]=0;e=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break X}}v[22708]=0;U(288,d+104|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break X}e=d+104|0;A=kc(d+192|0,e);xb(e);v[22708]=0;D=Q(572,a|0,A|0)|0;e=v[22708];v[22708]=0;na:{oa:{if((e|0)==1){break oa}if(!(t[d+350|0]&1)|!(w[d+358|0]|w[d+359|0]<<8)){break na}e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22708]=0;e=Q(190,b|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break oa}if(!e){break na}e=w[d+358|0]|w[d+359|0]<<8;v[22708]=0;da(509,a+1298292|0,b|0,e|0,4)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break na}}a=P()|0;O()|0;break j}e=0;u[a+480192>>1]=0;if(w[d+348|0]&4){u[d+104>>1]=w[d+338|0]|w[d+339|0]<<8;v[22708]=0;u[d+32>>1]=255;f=Pc(d+104|0,d+32|0);g=v[22708];v[22708]=0;if((g|0)==1){break W}u[a+480192>>1]=x[f>>1]}pa:{qa:{ra:{sa:{if(x[a+480192>>1]){while(1){f=Mb(r,e);ta:{if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break ta}f=Mb(r,e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22708]=0;f=Q(190,b|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break sa}if(!f){break ta}v[22708]=0;f=Q(191,b|0,554)|0;g=v[22708];v[22708]=0;if((g|0)==1){break sa}if(!f){break ta}v[22708]=0;f=W(376,a|0,e+1&65535,0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}if(!f){break ta}g=w[d+346|0]|w[d+347|0]<<8;v[22708]=0;da(573,a|0,b|0,f|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}t[f+33|0]=w[d+357|0]}e=e+1|0;if(e>>>0<x[a+480192>>1]){continue}break}}v[d+188>>2]=0;if(w[d+340|0]|w[d+341|0]<<8){e=Mb(q,(w[d+340|0]|w[d+341|0]<<8)-1|0);v[d+188>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}u[d+104>>1]=w[d+340|0]|w[d+341|0]<<8;v[22708]=0;u[d+32>>1]=3999;e=Pc(d+104|0,d+32|0);f=v[22708];v[22708]=0;if((f|0)==1){break qa}u[a+480190>>1]=x[e>>1];e=0;if(x[a+480190>>1]){break pa}f=0;h=0;break S}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}l=c&2;k=d+124|0;h=0;f=0;while(1){g=Mb(q,e);ua:{if(!(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break ua}g=Mb(q,e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22708]=0;g=Q(190,b|0,g|0)|0;i=v[22708];v[22708]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((i|0)==1){break Ba}if(!g){break ua}v[22708]=0;g=Q(574,b|0,d+104|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Ba}if(!g){break ua}v[22708]=0;g=e+1|0;o=B(g,104)+a|0;i=o+484380|0;p=Q(575,d+104|0,i|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Aa}v[22708]=0;Cp(d+88|0,3,k);m=v[22708];v[22708]=0;if((m|0)==1){break za}v[22708]=0;R(324,d+32|0,d+88|0);m=v[22708];v[22708]=0;if((m|0)==1){break za}v[22708]=0;Q(301,((g<<5)+a|0)+946304|0,d+32|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break ya}vb(d+32|0);v[22708]=0;p=Q(190,b|0,p|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Aa}if(!p){break ua}f=x[o+484414>>1];if(!(f&512)){break xa}v[22708]=0;f=Q(576,b|0,d+32|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){if(!f){break wa}v[d+16>>2]=v[d+40>>2];v[22708]=0;f=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=f;U(577,i|0,1,d+8|0);f=v[22708];v[22708]=0;if((f|0)!=1){break wa}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+32|0);break j}if(!(f&16384)){f=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;UE(d+32|0,d+104|0,f);f=v[22708];v[22708]=0;if((f|0)==1){break T}Ca:{if(l){g=0;v[22708]=0;W(329,d+32|0,i|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break Ca}break T}g=1;f=w[d+35|0];if(f>>>0>17){break Ca}f=1<<f;Da:{if(!(f&63503)){if(f&198144){break Da}break Ca}if(!w[d+32|0]){break Ca}}f=v[i>>2];v[22708]=0;f=yv(d+32|0,f);g=v[22708];v[22708]=0;if((g|0)==1){break T}g=0;v[22708]=0;Q(318,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break T}}if(w[d+35|0]!=1){break va}h=v[i>>2]!=0|h;break va}v[22708]=0;Q(580,b|0,d+84|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break U}f=v[d+84>>2];if(!(!l|!f)){f=Kb(d+32|0);v[22708]=0;W(413,b|0,f|0,v[d+84>>2])|0;i=v[22708];v[22708]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((i|0)!=1){v[22708]=0;R(581,d+72|0,13514);i=v[22708];v[22708]=0;if((i|0)==1){break Ka}v[d+68>>2]=g;v[22708]=0;U(13,d+56|0,0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ja}v[22708]=0;Y(582,d+88|0,d+72|0,d+68|0,d+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ia}v[22708]=0;U(560,a|0,2,d+88|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ha}vb(d+88|0);vb(d+56|0);Hb(d+72|0);vb(f);break wa}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Fa}a=P()|0;O()|0;break Ga}a=P()|0;O()|0;vb(d+88|0)}vb(d+56|0)}Hb(d+72|0)}vb(f);break j}v[22708]=0;Q(318,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break U}}g=0}f=v[b+8>>2];v[22708]=0;v[d+32>>2]=f;f=Mc(d+188|0,d+32|0);i=v[22708];v[22708]=0;if((i|0)==1){break V}v[d+188>>2]=v[f>>2];f=(g|0)!=0}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}break S}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}u[d+104>>1]=1;e=x[a+480190>>1];v[22708]=0;u[d+32>>1]=e;e=Ke(d+104|0,d+32|0);g=v[22708];v[22708]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((g|0)!=1){u[a+480190>>1]=x[e>>1];Va:{if(!(h&1)|(w[d+344|0]|w[d+345|0]<<8)!=516|(w[d+350|0]|w[d+351|0]<<8|(w[d+346|0]|w[d+347|0]<<8)!=512)){break Va}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&65527)!=21|(w[d+352|0]!=128|w[d+353|0]!=48)){break Va}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8)){break Va}h=d+432|0;g=d+368|0;e=1;while(1){e=(w[g|0]&127)==32&e;g=g+1|0;if((h|0)!=(g|0)){continue}break}h=d+496|0;g=d+432|0;while(1){e=w[g|0]==64&e;g=g+1|0;if((h|0)!=(g|0)){continue}break}g=20;while(1){e=!w[(d+g|0)+308|0]&e;g=g+1|0;if((g|0)!=26){continue}break}if(!e){break Va}v[22708]=0;e=Q(2,d+104|0,7125)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Ma}Eb(j,e);vb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;E=d,F=Nb(n),u[E+104>>1]=F;e=v[a+8>>2];v[22708]=0;e=Pc(d+104|0,e+10|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ua}e=x[e>>1];u[d+84>>1]=e;if((Nb(n)|0)!=(e|0)){v[22708]=0;_(584,d+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ta}e=Nb(n);v[22708]=0;v[d+88>>2]=e;Y(585,d+104|0,d+32|0,d+88|0,d+84|0);e=v[22708];v[22708]=0;if((e|0)==1){break Sa}v[22708]=0;U(560,a|0,2,d+104|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ra}vb(d+104|0);Hb(d+32|0)}if(c&1){break Pa}u[d+84>>1]=0;break Oa}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}if(!x[d+84>>1]){break Oa}e=0;while(1){c=Mb(n,e);Wa:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Wa}c=Mb(n,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Na}if(!c){break Wa}v[22708]=0;c=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break k}v[22708]=0;i=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}if((i-1&65535)>>>0>1023){break Wa}v[22708]=0;g=Q(318,b|0,4)|0;h=v[22708];v[22708]=0;if((h|0)==1){break l}if(!g){break Wa}v[22708]=0;U(288,d+32|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break m}c=d+32|0;l=kc(d+104|0,c);xb(c);g=0;h=x[a+480188>>1];v[22708]=0;c=Q(586,c|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}while(1){Xa:{v[22708]=0;h=Q(191,d+104|0,1)|0;k=v[22708];v[22708]=0;Ya:{Za:{if((k|0)!=1){if(!h){break Xa}v[22708]=0;h=T(374,l|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}k=h<<24>>24;if(k){break Za}g=g+1|0;break Ya}break p}_a:{h=k&127;o=h?h-1|0:0;h=o&65535;if(oc(c)>>>0>h>>>0){break _a}v[22708]=0;t[d+88|0]=0;U(587,c|0,h+1|0,d+88|0);p=v[22708];v[22708]=0;if((p|0)!=1){break _a}break p}if((k|0)<=-1){v[22708]=0;k=T(374,l|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break p}E=lc(c,h),F=k,t[E|0]=F}if(!(!(w[lc(c,h)|0]&15)|h>>>0<x[a+480188>>1])){u[a+480188>>1]=o+1}if(t[lc(c,h)|0]&1){v[22708]=0;Q(318,d+104|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}}if(w[lc(c,h)|0]&2){v[22708]=0;Q(318,d+104|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}}if(w[lc(c,h)|0]&4){v[22708]=0;Q(318,d+104|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}}if(!(w[lc(c,h)|0]&8)){break Ya}v[22708]=0;Q(318,d+104|0,2)|0;h=v[22708];v[22708]=0;if((h|0)==1){break p}}if(g>>>0<i>>>0){continue}}break}g=v[b+8>>2];v[22708]=0;v[d+88>>2]=g;g=Mc(d+188|0,d+88|0);h=v[22708];v[22708]=0;if((h|0)==1){break p}v[d+188>>2]=v[g>>2];gc(c);xb(d+104|0)}e=e+1|0;if(e>>>0<x[d+84>>1]){continue}break}}c=v[d+188>>2];if(!c){break La}v[22708]=0;Q(190,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}if(!(f&1)){break La}while(1){$a:{v[22708]=0;c=Q(191,b|0,4)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}if(!c){break La}v[22708]=0;c=Q(555,b|0,11134)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}ab:{if(!c){v[22708]=0;c=Q(555,b|0,11139)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}if(!c){break ab}}v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){pg(b,8);if(!(c&1616928864)|c&-2139062144){break ab}break La}a=P()|0;O()|0;break j}v[22708]=0;c=T(287,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22708]=0;c=Q(588,a|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}c=c|w[d+303|0];t[d+303|0]=c;if(!(!c|D)){xv(a+1074312|0);t[a+1074368|0]=0}v[22708]=0;Y(589,a|0,b|0,0,d+303|0);c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;o=a+484344|0;R(330,o|0,x[d+84>>1]);c=v[22708];v[22708]=0;if((c|0)==1){break q}e=0;u[d+68>>1]=0;bb:{if(!x[d+84>>1]){break bb}while(1){cb:{db:{c=Mb(n,e&65535);eb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Mb(n,x[d+68>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break eb}if(c){break db}}v[22708]=0;c=W(331,o|0,x[d+68>>1],64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break eb}if(!c){v[22708]=0;_(590,d+32|0);c=v[22708];v[22708]=0;fb:{gb:{hb:{if((c|0)!=1){v[22708]=0;U(591,d+104|0,d+32|0,d+68|0);c=v[22708];v[22708]=0;if((c|0)==1){break hb}v[22708]=0;U(560,a|0,2,d+104|0);c=v[22708];v[22708]=0;if((c|0)==1){break gb}vb(d+104|0);Hb(d+32|0);break bb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break fb}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}c=_b(o,x[d+68>>1]);v[22708]=0;R(592,c|0,z|0);c=v[22708];v[22708]=0;if((c|0)!=1){break cb}}a=P()|0;O()|0;break j}v[22708]=0;c=T(287,b|0)|0;e=v[22708];v[22708]=0;ib:{jb:{if((e|0)!=1){v[22708]=0;p=T(287,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break jb}v[22708]=0;e=Q(318,b|0,4)|0;f=v[22708];v[22708]=0;if((f|0)==1){break jb}if(!e){break cb}v[22708]=0;e=W(331,o|0,x[d+68>>1],p|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break jb}if(e){break ib}break cb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22708]=0;U(288,d+32|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=d+32|0;k=kc(d+104|0,c);xb(c);c=_b(o,x[d+68>>1]);v[22708]=0;R(592,c|0,z|0);c=v[22708];v[22708]=0;kb:{if((c|0)!=1){c=x[a+480188>>1];v[22708]=0;l=Q(586,d+32|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){c=x[a+480188>>1];e=d+72|0;hi(e);v[22708]=0;i=W(593,d+88|0,c|0,e|0)|0;c=v[22708];v[22708]=0;lb:{if((c|0)!=1){E=d,F=Vb(_b(o,x[d+68>>1])),v[E+56>>2]=F;m=0;mb:{if(!p){break mb}while(1){v[22708]=0;c=Q(191,d+104|0,1)|0;e=v[22708];v[22708]=0;nb:{if((e|0)!=1){ob:{if(!c){break mb}v[22708]=0;c=T(374,k|0)|0;e=v[22708];v[22708]=0;pb:{if((e|0)!=1){c=c<<24>>24;if(c){break pb}CX(d+56|0,x[a+480188>>1]);m=m+1|0;break nb}break ob}qb:{e=c&127;h=e?e-1&65535:0;if(oc(l)>>>0>h>>>0){break qb}v[22708]=0;t[d+72|0]=0;e=h+1|0;U(587,l|0,e|0,d+72|0);f=v[22708];v[22708]=0;if((f|0)==1){break ob}f=d+72|0;hi(f);v[22708]=0;U(594,i|0,e|0,f|0);e=v[22708];v[22708]=0;if((e|0)!=1){break qb}break ob}if((c|0)<=-1){v[22708]=0;c=T(374,k|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ob}E=lc(l,h),F=c,t[E|0]=F}e=d+72|0;hi(e);if(h>>>0<x[a+480188>>1]){e=ad(d+56|0,h)}if(w[lc(l,h)|0]&16){E=e,F=w[ad(i,h)|0],t[E|0]=F}if(w[lc(l,h)|0]&32){E=e,F=w[ad(i,h)+1|0],t[E+1|0]=F}if(w[lc(l,h)|0]&64){E=e,F=w[ad(i,h)+2|0],t[E+2|0]=F;E=e,F=w[ad(i,h)+4|0],t[E+4|0]=F}if(t[lc(l,h)|0]<=-1){E=e,F=w[ad(i,h)+3|0],t[E+3|0]=F;E=e,F=w[ad(i,h)+5|0],t[E+5|0]=F}if(t[lc(l,h)|0]&1){v[22708]=0;c=T(374,k|0)|0;f=v[22708];v[22708]=0;C=e;rb:{sb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break sb}f=c;break rb}break ob}f=253;if((c-121&255)>>>0<132){break rb}f=(c&255)==253?0:c}t[C|0]=f;E=ad(i,h),F=f,t[E|0]=F}if(w[lc(l,h)|0]&2){v[22708]=0;c=T(374,k|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ob}t[e+1|0]=c;E=ad(i,h),F=c,t[E+1|0]=F}if(w[lc(l,h)|0]&4){v[22708]=0;g=T(374,k|0)|0;f=v[22708];v[22708]=0;C=e;tb:{ub:{vb:{if((f|0)!=1){if(g>>>0>64){break vb}t[e+4|0]=g;f=1;break ub}break ob}if(!(g<<24>>24>-1|g>>>0>192)){f=2;t[e+2|0]=2;t[e+4|0]=g^128;break tb}if(g>>>0<=74){f=5;t[e+2|0]=5;t[e+4|0]=g-65;break tb}if(g>>>0<=84){f=6;t[e+2|0]=6;t[e+4|0]=g-75;break tb}if(g>>>0<=94){f=3;t[e+2|0]=3;t[e+4|0]=g-85;break tb}if(g>>>0<=104){f=4;t[e+2|0]=4;t[e+4|0]=g-95;break tb}if(g>>>0<=114){f=13;t[e+2|0]=13;t[e+4|0]=g-105;break tb}if(g>>>0<=124){f=12;t[e+2|0]=12;t[e+4|0]=g-115;break tb}f=g+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;f=11;break ub}f=g+53|0;c=f&255;if(c>>>0<=9){t[e+4|0]=f;f=8;t[e+2|0]=8;if(!c|v[a+1074308>>2]-1>>>0>18285139){break tb}f=7;break ub}f=g+33|0;if((f&255)>>>0>=10){f=w[e+2|0];break tb}t[e+4|0]=f;f=15}t[C+2|0]=f}E=ad(i,h),F=f,t[E+2|0]=F;c=w[e+4|0];E=ad(i,h),F=c,t[E+4|0]=F}if(!(w[lc(l,h)|0]&8)){break nb}v[22708]=0;R(403,d+24|0,k|0);c=v[22708];v[22708]=0;if((c|0)!=1){wb:{c=d+24|0;f=qd(c);t[e+3|0]=w[c|0];t[e+5|0]=w[f|0];v[22708]=0;Xu(e,1);c=v[22708];v[22708]=0;if((c|0)==1){break wb}c=w[e+3|0];E=ad(i,h),F=c,t[E+3|0]=F;c=w[e+5|0];E=ad(i,h),F=c,t[E+5|0]=F;break nb}}}}a=P()|0;O()|0;jn(i);break lb}if(m>>>0<p>>>0){continue}break}}jn(i);gc(l);xb(d+104|0);break cb}a=P()|0;O()|0}gc(l);break kb}a=P()|0;O()|0;break kb}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}e=x[d+68>>1]+1|0;u[d+68>>1]=e;if(x[d+84>>1]>(e&65535)>>>0){continue}break}}c=a+1074308|0;xb:{yb:{zb:{if(v[a+1074308>>2]){break zb}if((w[d+344|0]|w[d+345|0]<<8)==2184){v[a+1074308>>2]=18284544;break zb}if(!v[c>>2]){break yb}}if(!gd(j)){break yb}v[22708]=0;e=Q(2,d+32|0,14719)|0;f=v[22708];v[22708]=0;Ab:{Bb:{Cb:{Db:{Eb:{Fb:{if((f|0)!=1){v[22708]=0;R(162,d+88|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break Fb}v[22708]=0;U(3,d+104|0,e|0,d+88|0);f=v[22708];v[22708]=0;if((f|0)==1){break Eb}f=d+104|0;Eb(j,f);vb(f);vb(d+88|0);vb(e);if(v[d+364>>2]==1414548815|((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break Ab}v[22708]=0;c=Q(2,d+104|0,13955)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Cb}v[22708]=0;Q(113,j|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Bb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Db}a=P()|0;O()|0;vb(d+88|0)}vb(e);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if(!gH(c)){break xb}v[22708]=0;c=Q(2,d+104|0,14191)|0;e=v[22708];v[22708]=0;Gb:{if((e|0)!=1){v[22708]=0;Q(113,j|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Gb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if((w[d+344|0]|w[d+345|0]<<8)==8191){c=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)}else{c=(w[d+344|0]|w[d+345|0]<<8)-4176|0}Hb:{switch((w[d+344|0]|w[d+345|0]<<8)>>>12|0){case 0:if(D){v[22708]=0;c=Q(2,d+104|0,5473)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Ib:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+350|0]|w[d+351|0]<<8|(w[d+348|0]|w[d+349|0]<<8)!=9)){break Ib}if(w[d+335|0]|w[d+334|0]|(w[d+338|0]|w[d+339|0]<<8|((w[d+342|0]|w[d+343|0]<<8)+1|0)!=(w[d+336|0]|w[d+337|0]<<8))){break Ib}if(w[d+352|0]!=128|w[d+353|0]!=100|(w[d+354|0]!=1|w[d+356|0]!=128)){break Ib}if(w[d+357|0]|(w[d+358|0]|w[d+359|0]<<8)|(w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24)|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break Ib}v[22708]=0;c=Q(2,d+104|0,7106)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Jb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+335|0]|w[d+334|0])){break Jb}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break Jb}v[a+1074308>>2]=16777381;v[22708]=0;c=Q(2,d+104|0,12106)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);t[d+303|0]=1;break xb}a=P()|0;O()|0;break j}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|v[d+364>>2]!=1229080643)){v[22708]=0;c=Q(2,d+104|0,5525)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);v[22708]=0;Q(410,a+1074312|0,38)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break xb}break r}a=P()|0;O()|0;break j}Kb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|(w[d+357|0]|(w[d+350|0]|w[d+351|0]<<8)>>>0>1)){break Kb}if(!x[a+480190>>1]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&4294)!=4)){break Kb}v[22708]=0;c=Q(70,d+104|0,10812)|0;e=v[22708];v[22708]=0;Lb:{Mb:{if((e|0)!=1){v[22708]=0;e=Q(596,a+484527|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Mb}vb(c);if(!e){break Kb}v[22708]=0;c=Q(2,d+104|0,5551)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Lb}Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}Nb:{if(w[d+344|0]|w[d+345|0]<<8){break Nb}if(!gd(j)){break Nb}v[22708]=0;c=Q(2,d+104|0,6892)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}if((w[d+346|0]|w[d+347|0]<<8)>>>0>767){break xb}if(!gd(j)){break xb}Ob:{Pb:{Qb:{Rb:{Sb:{if((w[d+346|0]|w[d+347|0]<<8)>>>0>=533){v[22708]=0;c=Q(2,d+104|0,12147)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break Sb}a=P()|0;O()|0;break j}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=533){v[22708]=0;R(597,d+32|0,1124);c=v[22708];v[22708]=0;Tb:{if((c|0)!=1){c=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;v[d+88>>2]=c-532;U(598,d+104|0,d+32|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break Tb}c=d+104|0;Eb(j,c);vb(c);Hb(d+32|0);break Sb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j}v[22708]=0;R(411,d+32|0,1423);c=v[22708];v[22708]=0;if((c|0)==1){break Rb}v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22708]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break Qb}v[22708]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break Pb}c=d+104|0;Eb(j,c);vb(c);vb(d+88|0);Hb(d+32|0)}c=a+1298368|0;if(!cd(c)|!(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))){break xb}e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22708]=0;e=uw(e,f);f=v[22708];v[22708]=0;if((f|0)==1){break u}f=Cr(d+104|0);v[f+44>>2]=e;v[22708]=0;R(601,c|0,f|0);c=v[22708];v[22708]=0;if((c|0)!=1){break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Ob}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 1:e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22708]=0;U(602,d+104|0,e|0,f|0);e=v[22708];v[22708]=0;Ub:{Vb:{Wb:{Xb:{if((e|0)!=1){e=d+104|0;Eb(j,e);vb(e);if((c|0)>1915){break Xb}g=v[a+480208>>2];if(!(g&16)){break Wb}v[22708]=0;Q(410,a+1074312|0,7)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}break Vb}a=P()|0;O()|0;break j}if((c|0)>4200){break xb}g=v[a+480208>>2]}if(!(g&16)){v[22708]=0;Q(410,a+1074312|0,7)|0;e=v[22708];v[22708]=0;if((e|0)==1){break r}}if((c|0)>2385){break Ub}}v[22708]=0;Q(410,a+1074312|0,38)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}}v[22708]=0;c=a+1074312|0;Q(410,c|0,102)|0;e=v[22708];v[22708]=0;if((e|0)==1){break r}v[22708]=0;Q(410,c|0,48)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}break xb;case 4:v[22708]=0;R(603,d+32|0,1487);c=v[22708];v[22708]=0;Yb:{Zb:{_b:{if((c|0)!=1){v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22708]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break _b}v[22708]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break Zb}c=d+104|0;Eb(j,c);vb(c);vb(d+88|0);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Yb}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 6:v[22708]=0;c=Q(2,d+104|0,5473)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j;case 7:if(!((w[d+344|0]|w[d+345|0]<<8)!=32767|(w[d+346|0]|w[d+347|0]<<8)!=533)){v[22708]=0;c=Q(2,d+104|0,2138)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}v[22708]=0;R(158,d+32|0,1259);c=v[22708];v[22708]=0;$b:{if((c|0)!=1){v[d+88>>2]=w[d+345|0]&15;v[d+72>>2]=(w[d+344|0]|w[d+345|0]<<8)>>>4&15;c=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;v[d+56>>2]=c&15;ha(159,d+104|0,d+32|0,d+88|0,d+72|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break $b}c=d+104|0;Eb(j,c);vb(c);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j;case 13:break Hb;default:break xb}}v[22708]=0;c=Q(2,d+104|0,3180)|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}Eb(j,c);vb(c)}ac:{if(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2186){break ac}v[22708]=0;c=Q(190,b|0,s|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}if(!c){break ac}c=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;U(604,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}}b=v[a+480180>>2];bc:{if((b|0)==16777216){v[22708]=0;Q(2,d+104|0,11117)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break bc}a=P()|0;O()|0;break j}v[22708]=0;R(411,d+32|0,1423);c=v[22708];v[22708]=0;if((c|0)==1){break y}v[d+72>>2]=w[d+347|0];c=w[d+346|0];v[22708]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break w}}c=d+104|0;Eb(a+1298304|0,c);vb(c);if((b|0)!=16777216){vb(d+88|0);Hb(d+32|0)}cc:{if(v[a+480180>>2]==16777216){v[22708]=0;Q(2,d+104|0,7394)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break cc}break s}v[22708]=0;Q(2,d+104|0,3184)|0;b=v[22708];v[22708]=0;if((b|0)==1){break s}}b=d+104|0;Eb(a+1298316|0,b);vb(b);Eb(a+1298328|0,j);v[a+1298364>>2]=v[a+1074308>>2]?8:5;xb(A);xb(z);e=1}di(n);di(q);di(r);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0;break v}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;gc(c);break n}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}xb(A)}xb(z);break g}a=P()|0;O()|0}di(n);di(q);di(r);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}vb(j)}gb=d+496|0;return e|0}a=P()|0;O()|0}vb(j);S(a|0);L()}function cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;d=gb-1712|0;gb=d;vc(b);a:{if(!Ih(b,d+1704|0)){break a}if(!PV(d+1704|0)){break a}if(!c){f=1;break a}e=w[d+1704|3];t[d+1703|0]=e;v[d+1696>>2]=-1;v[d+1692>>2]=1048576;if(e>>>0>=5){e=sg(b);v[d+1696>>2]=e;if(!Pb(b,e)){break a}v[d+304>>2]=134217727;N=d,V=v[Fb(d+304|0,d+1696|0)>>2]<<5,v[N+1692>>2]=V}C=mc(d+1680|0);e=d+1704|4;h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22708]=0;v[d+304>>2]=h;h=Fb(d+1692|0,d+304|0);g=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}h=v[h>>2];v[22708]=0;R(729,C|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break x}e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22708]=0;e=W(730,b|0,C|0,e|0)|0;h=v[22708];v[22708]=0;y:{if((h|0)==1){break y}if(!e){break t}if(w[d+1703|0]>=5){v[22708]=0;Q(190,b|0,v[d+1696>>2]+12|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break y}}v[22708]=0;R(367,a|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break y}v[22708]=0;Ag(a);e=v[22708];v[22708]=0;if((e|0)==1){break y}v[22708]=0;Ud(d+1648|0,C);h=v[22708];v[22708]=0;e=a;z:{A:{B:{C:{if((h|0)==1){break C}h=Td(d+1640|0);v[22708]=0;g=v[d+1652>>2];v[d+96>>2]=v[d+1648>>2];v[d+100>>2]=g;g=v[h+4>>2];v[d+88>>2]=v[h>>2];v[d+92>>2]=g;l=W(732,d+1656|0,d+96|0,d+88|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break C}v[22708]=0;W(533,l|0,a+1298268|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break B}v[22708]=0;W(533,l|0,a+1298292|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break B}v[22708]=0;h=Q(733,l|0,d+1216|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}if(!h|!w[d+1216|0]|t[d+1216|0]<0){break u}h=d+1225|0;if((w[h|0]|w[h+1|0]<<8)>>>0>255){break u}g=d+1227|0;if((w[g|0]|w[g+1|0]<<8)>>>0>3999){break u}n=d+1216|0;u[a+480188>>1]=w[n|0];j=a+484360|0;n=n|3;cf(Sb(j),w[n|0]|w[n+1|0]<<8);u[a+480192>>1]=w[h|0]|w[h+1|0]<<8;u[a+480190>>1]=w[g|0]|w[g+1|0]<<8;h=d+1229|0;if(w[h|0]){break A}h=6;break z}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}h=w[h|0]}v[e+480196>>2]=h;e=a;h=d+1230|0;if(w[h|0]){h=w[h|0]}else{h=125}v[e+480204>>2]=B(h,1e4);n=d+1231|0;D:{if(t[n+1|0]&1){v[22708]=0;R(558,a|0,32);e=v[22708];v[22708]=0;if((e|0)!=1){break D}break d}if(w[n|0]&2){v[22708]=0;R(558,a|0,2);e=v[22708];v[22708]=0;if((e|0)==1){break d}break D}if(w[n|0]&128){v[22708]=0;R(558,a|0,1);e=v[22708];v[22708]=0;if((e|0)==1){break d}break D}if(w[n|0]&8){v[22708]=0;R(558,a|0,16);e=v[22708];v[22708]=0;if((e|0)==1){break d}break D}v[22708]=0;R(558,a|0,4);e=v[22708];v[22708]=0;if((e|0)==1){break d}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[n|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[n|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[n|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[n+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[n+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[n+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[n+2|0]&8){v[22708]=0;W(409,a+1074312|0,5,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}}E:{e=v[a+480180>>2];F:{if((e|0)!=2){if((e|0)!=32){break F}t[d+304|0]=w[d+1235|0];v[22708]=0;t[d+224|0]=128;e=ac(d+304|0,d+224|0);h=v[22708];v[22708]=0;if((h|0)==1){break w}v[a+480200>>2]=w[e|0]<<1;break F}t[d+304|0]=w[d+1235|0];v[22708]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);h=v[22708];v[22708]=0;if((h|0)==1){break E}v[a+480200>>2]=w[e|0]<<2}J=a+480188|0;g=d+1237|0;h=t[g|0];e=a;if(t[g|0]<=-1){h=h+52|0}else{G=$w(+(h|0)*3.1/20);G:{if(G<4294967296&G>=0){h=~~G>>>0;break G}h=0}h=h+51|0}v[e+480228>>2]=h;v[22708]=0;u[d+304>>1]=64;e=Pc(J,d+304|0);h=v[22708];v[22708]=0;if((h|0)!=1){H:{h=x[e>>1];if(h){while(1){e=v[a+480180>>2];if((e|0)==32){t[d+304|0]=w[(d+f|0)+1238|0];v[22708]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);g=v[22708];v[22708]=0;if((g|0)==1){break H}u[((f<<5)+a|0)+480286>>1]=w[e|0];e=v[a+480180>>2]}I:{if((e|0)==4){break I}e=(d+f|0)+1302|0;if(w[e|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break I}if(w[e|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break I}u[((f<<5)+a|0)+480284>>1]=w[e|0]}f=f+1|0;if((h|0)!=(f|0)){continue}break}}f=0;g=0;while(1){f=w[(d+g|0)+1366|0]!=0|f;g=g+1|0;if((g|0)!=16){continue}break}while(1){f=w[((k<<1)+d|0)+1383|0]!=0|f;k=k+1|0;if((k|0)!=128){continue}break}if(f&1){f=0;while(1){J:{e=(d+f|0)+1366|0;if(w[e|0]){v[22708]=0;_(734,d+224|0);h=v[22708];v[22708]=0;K:{L:{M:{N:{O:{if((h|0)!=1){e=w[e|0];v[22708]=0;v[d+248>>2]=e-1;R(735,d+1192|0,d+248|0);e=v[22708];v[22708]=0;if((e|0)==1){break O}v[22708]=0;U(443,d+304|0,d+224|0,d+1192|0);e=v[22708];v[22708]=0;if((e|0)==1){break N}v[22708]=0;R(444,d+1168|0,((f<<5)+a|0)+901692|0);e=v[22708];v[22708]=0;if((e|0)==1){break M}v[22708]=0;Q(401,d+1168|0,d+304|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break M}vb(d+304|0);vb(d+1192|0);Hb(d+224|0);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;break K}g=P()|0;O()|0;break L}g=P()|0;O()|0;vb(d+304|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22708]=0;e=Q(70,d+304|0,18726)|0;h=v[22708];v[22708]=0;P:{if((h|0)!=1){v[22708]=0;R(444,d+224|0,((f<<5)+a|0)+901692|0);h=v[22708];v[22708]=0;if((h|0)==1){break P}v[22708]=0;Q(401,d+224|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}vb(e);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){e=(d+1216|0)+(f<<1)|0;h=e;Q:{if(w[e+167|0]){v[22708]=0;_(736,d+224|0);g=v[22708];v[22708]=0;R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){h=w[h+167|0];v[22708]=0;v[d+192>>2]=h-1;R(735,d+1192|0,d+192|0);h=v[22708];v[22708]=0;if((h|0)==1){break X}e=w[e+166|0];v[22708]=0;t[d+168|0]=e;R(737,d+1168|0,d+168|0);e=v[22708];v[22708]=0;if((e|0)==1){break W}v[22708]=0;Y(738,d+304|0,d+224|0,d+1192|0,d+1168|0);e=v[22708];v[22708]=0;if((e|0)==1){break V}v[22708]=0;R(444,d+248|0,((f<<5)+a|0)+902204|0);e=v[22708];v[22708]=0;if((e|0)==1){break U}v[22708]=0;Q(401,d+248|0,d+304|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}vb(d+304|0);vb(d+1168|0);vb(d+1192|0);Hb(d+224|0);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;break R}g=P()|0;O()|0;break S}g=P()|0;O()|0;break T}g=P()|0;O()|0;vb(d+304|0)}vb(d+1168|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22708]=0;e=Q(70,d+304|0,18726)|0;h=v[22708];v[22708]=0;Y:{if((h|0)!=1){v[22708]=0;R(444,d+224|0,((f<<5)+a|0)+902204|0);h=v[22708];v[22708]=0;if((h|0)==1){break Y}v[22708]=0;Q(401,d+224|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Y}vb(e);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=128){continue}break}}e=Sb(j);f=d+1216|1;f=w[f|0]|w[f+1|0]<<8;v[22708]=0;fa(521,e|0,l|0,f|0,255,254)|0;e=v[22708];v[22708]=0;Z:{_:{$:{aa:{ba:{ca:{if((e|0)!=1){e=d+1216|0;j=e|5;f=w[j|0]|w[j+1|0]<<8;e=w[e|0];v[22708]=0;U(288,d+304|0,l|0,B(e,f)<<1);e=v[22708];v[22708]=0;if((e|0)==1){break ca}e=d+304|0;H=kc(d+1192|0,e);xb(e);f=w[j|0]|w[j+1|0]<<8;v[22708]=0;U(288,e|0,l|0,f<<1);e=v[22708];v[22708]=0;if((e|0)==1){break ba}e=d+304|0;I=kc(d+1168|0,e);xb(e);e=d+1216|7;e=w[e|0]|w[e+1|0]<<8;v[22708]=0;A=Q(328,d+1152|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break aa}N=d,V=Vb(A),v[N+248>>2]=V;N=d,V=Zb(A),v[N+192>>2]=V;if(Gb(d+248|0,d+192|0)){while(1){e=v[d+248>>2];v[22708]=0;f=T(192,l|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break $}v[22708]=0;U(288,d+224|0,l|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break _}h=e;e=d+304|0;f=d+224|0;Vc(h,kc(e,f));xb(e);xb(f);e=d+248|0;Eh(e);if(Gb(e,d+192|0)){continue}break}}e=v[a+480180>>2];s=1;q=c&1;if(!q){break Z}f=w[j|0]|w[j+1|0]<<8;v[22708]=0;R(330,a+484344|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Z}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}E=a+484344|0;da:{ea:{fa:{ga:{ha:{ia:{if(w[j|0]|w[j+1|0]<<8){r=(e|0)==16?14:(e|0)==32?1:13;while(1){v[22708]=0;e=T(287,I|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break da}v[d+224>>2]=e;ja:{if(!q){break ja}v[22708]=0;e=W(331,E|0,o&65535,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break da}if(!e){break ja}i=0;if(!w[d+1216|0]){break ja}while(1){v[22708]=0;e=T(287,H|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ea}ka:{if(Ie(A)>>>0<=e>>>0){break ka}z=Kg(A,e);vc(z);e=_b(E,o);v[22708]=0;f=Yc(e,0,i&65535);e=v[22708];v[22708]=0;if((e|0)==1){break h}h=0;if(!v[d+224>>2]){break ka}while(1){v[22708]=0;m=T(374,z|0)|0;e=v[22708];v[22708]=0;la:{ma:{if((e|0)!=1){if(!m){break ka}hi(d+304|0);k=0;p=m&15;if(p){break ma}break la}g=P()|0;O()|0;break g}while(1){na:{v[22708]=0;R(739,z|0,d+248|0);e=v[22708];v[22708]=0;if((e|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{e=w[d+248|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(e-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}e=w[d+249|0];Ja:{if(e>>>0<=119){t[d+304|0]=e+r;break Ja}Ka:{switch(e-254|0){case 1:t[d+304|0]=255;break Ja;case 0:t[d+304|0]=254;break Ja;default:break Ka}}t[d+304|0]=253}v[22708]=0;e=Av(d+304|0);g=v[22708];v[22708]=0;if((g|0)==1){break na}s=e&s;break oa}t[d+305|0]=w[d+249|0]+1;break oa}La:{if(w[d+306|0]){break La}e=v[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break La}e=w[d+249|0];if(e&15){break La}t[d+306|0]=11;t[d+308|0]=e>>>4;break oa}g=0;e=w[d+249|0];while(1){if((e|0)==w[g+39104|0]){t[d+308|0]=g;t[d+306|0]=11;break oa}g=g+1|0;if((g|0)!=10){continue}break}}t[d+307|0]=4;t[d+309|0]=w[d+249|0];break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>9|v[a+480180>>2]!=32)){t[d+308|0]=e;t[d+306|0]=8;break oa}t[d+309|0]=e;t[d+307|0]=5;break oa}if(w[d+306|0]){g=w[d+249|0];break pa}e=v[a+480180>>2];D=(e|0)!=32;g=w[d+249|0];if(!(D|(g|0)!=255)){t[d+308|0]=64;t[d+306|0]=2;break oa}Ma:{if(!D){if(g&3){break pa}break Ma}if(g&15|(e|0)!=4){break pa}}t[d+306|0]=2;t[d+308|0]=(g&252)>>>2;break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>64|v[a+480180>>2]==1)){t[d+308|0]=e;t[d+306|0]=1;break oa}t[d+309|0]=e;t[d+307|0]=13;break oa}t[d+307|0]=14;e=w[d+249|0];t[d+309|0]=e;if(v[a+480180>>2]==32){break oa}t[d+309|0]=B((e&240)>>>4|0,10)+(e&15);break oa}e=w[d+249|0];t[d+309|0]=e;if(e>>>0<=31){t[d+307|0]=16;break oa}t[d+307|0]=17;break oa}g=w[d+249|0];if(g>>>0>=16){t[d+308|0]=g>>>4;t[d+306|0]=(e|0)==20?3:5;break oa}t[d+308|0]=g;t[d+306|0]=(e|0)==20?4:6;break oa}e=w[d+249|0];if(e>>>0>=16){t[d+306|0]=10;t[d+308|0]=e>>>4;break oa}t[d+308|0]=e;t[d+306|0]=9;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|16;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|32;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33136|0];break oa}t[d+309|0]=w[d+249|0];e=w[d+307|0];t[d+307|0]=(e|0)==4?6:(e|0)==5?7:11;break oa}e=w[d+249|0];t[d+308|0]=(e>>>0)%10;if(e>>>0<=9){t[d+306|0]=5;break oa}if(e>>>0<=19){t[d+306|0]=6;break oa}if(e>>>0<=29){t[d+306|0]=3;break oa}if(e>>>0>39){break oa}t[d+306|0]=4;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33136|0];break oa}e=w[d+249|0]+33|0;if((e&255)>>>0>9){break oa}t[d+308|0]=e;t[d+306|0]=15;break oa}if(e>>>0>=56){break oa}t[d+309|0]=w[d+249|0];t[d+307|0]=w[w[d+248|0]+33136|0];break oa}t[d+309|0]=g;t[d+307|0]=9}k=k+1|0;if(p>>>0>(k&255)>>>0){continue}break la}break}g=P()|0;O()|0;break g}v[22708]=0;v[d+248>>2]=(m>>>4|0)+h;e=Fb(d+248|0,d+224|0);g=v[22708];v[22708]=0;if((g|0)==1){break ia}e=v[e>>2];if(e>>>0>h>>>0){while(1){g=v[d+304>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=x[d+308>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;f=B(w[d+1216|0],6)+f|0;h=h+1|0;if((e|0)!=(h|0)){continue}break}h=e}if(y[d+224>>2]>h>>>0){continue}break}}i=i+1|0;if(w[d+1216|0]>(i&65535)>>>0){continue}break}}o=o+1|0;if(o>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}}if(!((s^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ha}j=0;break ga}g=P()|0;O()|0;break g}j=!((w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24))&512);e=0;if(v[a+480180>>2]!=4){break fa}}e=x[a+480192>>1]}v[22708]=0;s=Q(740,d+1136|0,e|0)|0;e=v[22708];v[22708]=0;h=1;if((e|0)!=1){Na:{Oa:{Pa:{if(x[a+480192>>1]){g=1;while(1){Qa:{Ra:{Sa:{if(!j){v[22708]=0;f=W(376,a|0,g&65535,0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Sa}if(f){break Ra}}while(1){v[22708]=0;e=T(374,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}if(e){continue}break}if(w[d+1703|0]>=5){while(1){v[22708]=0;e=T(374,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){g=P()|0;O()|0;break i}if(e){continue}break}}v[22708]=0;Q(318,l|0,826)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Qa}}g=P()|0;O()|0;break i}e=Kb(d+224|0);v[22708]=0;W(533,l|0,e|0,-1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break Pa}v[22708]=0;Q(301,f+492|0,e|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break Pa}Ta:{if(w[d+1703|0]<5){break Ta}v[22708]=0;W(533,l|0,e|0,-1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break Pa}v[22708]=0;Q(301,f+524|0,e|0)|0;k=v[22708];v[22708]=0;if((k|0)!=1){break Ta}break Pa}v[22708]=0;k=Q(741,l|0,d+304|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Pa}if(!k){break Oa}k=v[a+480180>>2];v[22708]=0;U(742,d+304|0,f|0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break Pa}if(v[a+480180>>2]==4){f=Mb(s,h-1|0);h=x[d+1106>>1]|x[d+1108>>1]<<16;t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24}vb(e)}g=g+1|0;h=g&65535;if(h>>>0<=x[a+480192>>1]){continue}break}}if(!j){break Na}u[a+480192>>1]=0;break Na}g=P()|0;O()|0;vb(e);break i}vb(e)}e=x[a+480190>>1];v[22708]=0;z=Q(743,d+288|0,e|0)|0;e=v[22708];v[22708]=0;o=1;if((e|0)!=1){o=w[d+1703|0]<=4?!(t[n|0]&1):o;D=c&2;e=0;Ua:{if(!x[a+480190>>1]){break Ua}k=1;h=1;while(1){c=e;m=Kb(d+272|0);v[22708]=0;W(533,l|0,m|0,-1)|0;e=v[22708];v[22708]=0;Va:{Wa:{Xa:{Ya:{Za:{if((e|0)==1){break Za}v[22708]=0;Q(301,((k<<5)+a|0)+946304|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Za}g=B(k,104)+a|0;if(w[d+1703|0]<5){break Ya}v[22708]=0;W(533,l|0,m|0,-1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Za}v[22708]=0;Q(303,g+484423|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Ya}}g=P()|0;O()|0;break Xa}v[22708]=0;e=Q(744,l|0,d+304|0)|0;f=v[22708];v[22708]=0;_a:{$a:{ab:{bb:{cb:{db:{eb:{if((f|0)==1){break eb}if(!e){break db}e=v[a+480180>>2];v[22708]=0;f=g+484380|0;Y(745,d+304|0,f|0,e|0,o|0);e=v[22708];v[22708]=0;if((e|0)==1){break eb}j=0;fb:{if(((w[d+324|0]|w[d+325|0]<<8)&61440)!=28672|w[d+1703|0]<5){break fb}v[22708]=0;j=T(746,l|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break fb}g=P()|0;O()|0;break Xa}if(!D){break Wa}K=w[d+324|0]|w[d+325|0]<<8;q=K&61440;if(!(q|(w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24)))){e=w[d+324|0]|w[d+325|0]<<8;e=Rc(d+224|0,e&1?16:8,e&1024?3:1,0,0);v[22708]=0;W(329,e|0,f|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Wa}g=P()|0;O()|0;break Xa}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);if(!((e|0)>-1|(e+k|0)<1)){e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22708]=0;Q(747,f|0,(B(e+k|0,104)+a|0)+484380|0)|0;f=v[22708];v[22708]=0;e=c;if((f|0)!=1){break Va}g=P()|0;O()|0;break Xa}if((w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24))<1){break Wa}if(t[d+324|0]&1){e=g+484414|0;u[e>>1]=x[e>>1]|1}if(w[d+325|0]&4){e=g+484414|0;u[e>>1]=x[e>>1]|64}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22708]=0;U(288,d+224|0,b|0,e|0);i=v[22708];v[22708]=0;gb:{hb:{M=d;ib:{jb:{if((i|0)!=1){r=d+224|0;i=kc(d+248|0,r);xb(r);r=fd(f);e=(q|0)==16384;if(!e&(q|0)!=8192){break hb}v[22708]=0;p=T(195,d+248|0)|0;F=v[22708];v[22708]=0;if((F|0)==1){break gb}v[d+224>>2]=p;F=v[d+224>>2];p=4/(r>>>0)|0;if(F>>>0>4294967295/(p>>>0)>>>0){break jb}p=B(p,F);break ib}g=P()|0;O()|0;break Xa}p=-1}v[M+224>>2]=p;qc(f,p);if(!e){if((q|0)!=8192){break hb}v[22708]=0;e=T(386,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break $a}if(!e){break bb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(748,i|0,e|0,f|0,r|0);f=v[22708];v[22708]=0;e=c;if((f|0)!=1){break ab}break $a}e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(749,i|0,e|0,f|0,r|0);f=v[22708];v[22708]=0;e=c;if((f|0)==1){break $a}break ab}v[22708]=0;e=T(386,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break $a}if(!e){break bb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(750,i|0,e|0,f|0,r|0);f=v[22708];v[22708]=0;e=c;if((f|0)==1){break $a}break ab}e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(751,i|0,e|0,f|0,r|0);f=v[22708];v[22708]=0;e=c;if((f|0)==1){break $a}break ab}if((K&45056)==12288){e=OV(d+224|0,i,w[d+343|0]|w[d+344|0]<<8,j);f=Wl(z,k-1|0);Vc(f,e);v[f+20>>2]=v[e+20>>2];xb(e);break bb}if((q|0)!=32768){e=1;if((q|0)!=4096){break ab}e=le(d+224|0,i);v[22708]=0;Q(752,d+216|0,i|0)|0;j=v[22708];v[22708]=0;if((j|0)!=1){kb:{if(!w[d+221|0]){break kb}j=x[d+218>>1]<<1;if((j&65535)>>>0>(w[d+343|0]|w[d+344|0]<<8)>>>0){break kb}j=(w[d+343|0]|w[d+344|0]<<8)-j|0;t[d+343|0]=j;t[d+344|0]=j>>>8;v[22708]=0;Q(190,d+248|0,x[d+216>>1])|0;j=v[22708];v[22708]=0;if((j|0)==1){break cb}v[22708]=0;j=T(467,d+248|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break cb}v[22708]=0;U(288,d+168|0,d+248|0,j|0);j=v[22708];v[22708]=0;if((j|0)==1){break cb}j=d+192|0;k=d+168|0;Vc(e,kc(j,k));xb(j);xb(k)}v[22708]=0;e=fa(753,a|0,h&65535,e|0,1,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break cb}lb:{if(!e){v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break cb}c=1;break lb}mb:{if(!(w[d+343|0]|w[d+344|0]<<8)){break mb}e=w[d+343|0]|w[d+344|0]<<8;if(bj(f)>>>0<=e>>>0){break mb}e=w[d+343|0]|w[d+344|0]<<8;j=kj(f);g=g+484400|0;yh(zb(v[g>>2]),zb(v[g>>2])+(w[d+343|0]|w[d+344|0]<<8)|0,bj(f)-(w[d+343|0]|w[d+344|0]<<8)|0);v[f>>2]=v[f>>2]-((e>>>0)/(j>>>0)|0)}e=v[d+312>>2];v[d+164>>2]=e;v[d+68>>2]=e;if(y[f>>2]>(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))>>>0){v[f>>2]=w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24)}}e=c;xb(d+224|0);break ab}break cb}v[22708]=0;e=Q(576,i|0,d+224|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){if(!e){break bb}v[d+80>>2]=v[d+232>>2];v[22708]=0;e=v[d+228>>2];v[d+72>>2]=v[d+224>>2];v[d+76>>2]=e;U(577,f|0,1,d+72|0);e=v[22708];v[22708]=0;if((e|0)!=1){break bb}}g=P()|0;O()|0;break _a}g=P()|0;O()|0;break _a}g=P()|0;O()|0;break Xa}vb(m);e=c;break Ua}g=P()|0;O()|0;xb(d+224|0);break _a}e=c}xb(d+248|0);break Va}g=P()|0;O()|0}xb(d+248|0)}vb(m);break k}e=c}vb(m);h=h+1|0;k=h&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}if(!(!D|!x[a+480190>>1])){f=1;i=1;while(1){c=Wl(z,f-1|0);v[22708]=0;b=T(275,c|0)|0;h=v[22708];v[22708]=0;nb:{ob:{pb:{if((h|0)!=1){if(!b){break nb}h=x[c+22>>1];b=h+i&65535;qb:{rb:{k=(h|0)!=0&(b|0)!=0&b>>>0<=x[a+480190>>1];if(!k){v[22708]=0;T(195,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break rb}break l}g=x[c+20>>1];h=Wl(z,b-1|0);vc(h);b=x[c+20>>1];v[22708]=0;b=Q(191,h|0,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break l}if(!b){break nb}v[d+224>>2]=0;v[d+248>>2]=0;v[22708]=0;U(755,d+304|0,h|0,g|0);b=v[22708];v[22708]=0;sb:{if((b|0)!=1){v[22708]=0;b=Rd(d+304|0);g=v[22708];v[22708]=0;if((g|0)==1){break sb}b=zb(b);g=Vi(v[d+304>>2]);v[22708]=0;b=fa(756,b|0,g|0,d+224|0,d+248|0,0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break sb}v[22708]=0;Q(318,h|0,v[d+224>>2])|0;h=v[22708];v[22708]=0;if((h|0)==1){break sb}zc(d+304|0);break qb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}vc(c);b=0;v[d+224>>2]=0;v[d+248>>2]=0}v[22708]=0;R(757,d+304|0,c|0);h=v[22708];v[22708]=0;tb:{ub:{if((h|0)!=1){v[22708]=0;j=Rd(d+304|0);h=v[22708];v[22708]=0;if((h|0)==1){break tb}g=v[d+304>>2];if(!k){b=zb(j);h=Vi(g);v[22708]=0;b=fa(756,b|0,h|0,d+224|0,d+248|0,0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break pb}v[22708]=0;Q(318,c|0,v[d+224>>2])|0;h=v[22708];v[22708]=0;if((h|0)==1){break pb}h=v[d+224>>2];g=g-h|0;j=h+j|0}if(b){break ub}e=1;break ob}g=P()|0;O()|0;break k}v[22708]=0;f=B(f,104)+a|0;k=f+484380|0;T(386,k|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break pb}o=f+484400|0;r=f+484414|0;f=0;h=v[d+248>>2];while(1){vb:{if(y[k>>2]<=f>>>0|(!g|(h|0)!=1?h:0)){break vb}if(!Md(k)){break vb}v[d+192>>2]=0;v[d+168>>2]=0;h=zb(j);m=Vi(g);v[22708]=0;h=la(758,b|0,h|0,m|0,d+192|0,d+272|0,d+168|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break pb}v[22708]=0;v[d+224>>2]=h;Q(318,c|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break pb}q=v[d+224>>2];bk(d+168|0,Vi(v[k>>2]-f|0));wb:{if(v[d+168>>2]<1){break wb}if(v[d+192>>2]!=(fd(k)|0)){break wb}if(t[r|0]&1){h=mg(d+152|0,v[o>>2]+(B(fd(k),f)<<1)|0,fd(k),v[d+168>>2]);m=mg(d+136|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22708]=0;v[d- -64>>2]=v[h+8>>2];p=v[h+4>>2];v[d+56>>2]=v[h>>2];v[d+60>>2]=p;v[d+48>>2]=v[m+8>>2];h=v[m+4>>2];v[d+40>>2]=v[m>>2];v[d+44>>2]=h;R(759,d+56|0,d+40|0);h=v[22708];v[22708]=0;if((h|0)!=1){break wb}break pb}h=mg(d+120|0,v[o>>2]+B(fd(k),f)|0,fd(k),v[d+168>>2]);m=mg(d+104|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22708]=0;v[d+32>>2]=v[h+8>>2];p=v[h+4>>2];v[d+24>>2]=v[h>>2];v[d+28>>2]=p;v[d+16>>2]=v[m+8>>2];h=v[m+4>>2];v[d+8>>2]=v[m>>2];v[d+12>>2]=h;R(760,d+24|0,d+8|0);h=v[22708];v[22708]=0;if((h|0)==1){break pb}}v[22708]=0;m=v[d+168>>2];h=ly(b);p=v[22708];v[22708]=0;if((p|0)==1){break pb}g=g-q|0;j=j+q|0;v[d+248>>2]=h;f=f+m|0;continue}break}v[22708]=0;my(b);b=v[22708];v[22708]=0;if((b|0)!=1){break ob}break pb}break pb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}zc(d+304|0)}i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}xb:{if(v[a+480180>>2]!=4){break xb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break xb}b=w[Mb(s,f)|0];c=w[Mb(s,f)+1|0];h=w[Mb(s,f)+2|0];g=w[Mb(s,f)+3|0];v[22708]=0;f=f+1|0;ka(763,a|0,f&65535,b|0,c|0,h|0,g|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}g=P()|0;O()|0;break k}yb:{zb:{Ab:{Bb:{if(!(w[n+2|0]&16)){break Bb}v[22708]=0;b=Q(191,l|0,1)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}if(!b){break Bb}f=0;v[22708]=0;b=T(374,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break n}if(!(!(b&1)|!x[J>>1])){while(1){v[22708]=0;b=T(192,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ab}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[22708]=0;b=Q(191,l|0,1)|0;c=v[22708];v[22708]=0;Cb:{if((c|0)!=1){if(!b){break Bb}v[22708]=0;b=T(374,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break zb}if(!b){break Bb}v[22708]=0;c=T(192,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break yb}v[22708]=0;U(288,d+224|0,l|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break yb}c=d+224|0;f=kc(d+304|0,c);xb(c);if(b>>>0>250){break Cb}v[22708]=0;R(605,f|0,(B(b,160)+a|0)+906140|0);b=v[22708];v[22708]=0;if((b|0)!=1){break Cb}g=P()|0;O()|0;xb(d+304|0);break k}g=P()|0;O()|0;break k}xb(d+304|0);continue}}j=a+901404|0;k=a+1074308|0;h=Kb(d+192|0);g=0;c=0;Db:{Eb:{while(1){v[22708]=0;b=Q(191,l|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Db}if(!b){break Eb}v[22708]=0;f=T(192,l|0)|0;b=v[22708];v[22708]=0;Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((b|0)!=1){v[22708]=0;b=T(192,l|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Vb}v[22708]=0;U(288,d+304|0,l|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break Ub}i=d+304|0;b=kc(d+224|0,i);xb(i);if((f|0)<=1397900629){if((f|0)==1229211981){break Sb}if((f|0)!=1229476432){break Gb}v[22708]=0;f=T(374,b|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}v[a+480216>>2]=f;v[22708]=0;b=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}v[a+480220>>2]=b;break Gb}if((f|0)==1397900630){break Tb}if((f|0)!=1414548815){break Gb}v[22708]=0;f=Q(555,b|0,11155)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}if(!f){break Qb}v[22708]=0;f=T(192,b|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;U(288,d+304|0,d+224|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Rb}}g=P()|0;O()|0;break p}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}Wb:{Xb:{Yb:{f=v[a+480180>>2];switch(f-2|0){case 1:break Gb;case 0:break Hb;case 2:break Xb;default:break Yb}}if((f|0)==16){break Wb}if((f|0)!=32){break Gb}v[22708]=0;g=T(287,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;c=T(287,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break Gb}break q}v[d+304>>2]=32;v[22708]=0;f=T(195,d+224|0)|0;i=v[22708];v[22708]=0;Zb:{if((i|0)==1){break Zb}v[22708]=0;v[d+248>>2]=f;f=Fb(d+304|0,d+248|0);i=v[22708];v[22708]=0;if((i|0)==1){break Zb}f=v[f>>2];v[22708]=0;U(764,b|0,h|0,f|0);b=v[22708];v[22708]=0;if((b|0)!=1){break Gb}}g=P()|0;O()|0;break p}v[22708]=0;b=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Fb}v[22708]=0;R(765,d+248|0,1320);f=v[22708];v[22708]=0;_b:{if((f|0)!=1){v[d+168>>2]=b>>>4;v[22708]=0;v[d+272>>2]=b&15;Y(460,d+304|0,d+248|0,d+168|0,d+272|0);b=v[22708];v[22708]=0;if((b|0)==1){break _b}b=d+304|0;Eb(h,b);vb(b);Hb(d+248|0);break Gb}g=P()|0;O()|0;break p}g=P()|0;O()|0;Hb(d+248|0);break p}v[22708]=0;Q(568,b|0,j|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;Ku(j);b=v[22708];v[22708]=0;if((b|0)==1){break q}break Gb}f=d+248|0;i=d+304|0;m=kc(f,i);xb(i);v[22708]=0;f=T(195,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Pb}u[d+304>>1]=f>>>5;f=Te(E);v[22708]=0;u[d+168>>1]=f;f=Pc(d+304|0,d+168|0);i=v[22708];v[22708]=0;if((i|0)==1){break Pb}i=x[f>>1];if(i){f=0;while(1){v[22708]=0;W(766,m|0,d+304|0,32)|0;o=v[22708];v[22708]=0;if((o|0)==1){break Pb}o=_b(E,f);v[22708]=0;Q(767,o|0,d+304|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break Pb}f=f+1|0;if((i|0)!=(f|0)){continue}break}}xb(d+248|0)}v[22708]=0;f=Q(555,b|0,11160)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}if(!f){break Nb}v[22708]=0;f=T(192,b|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;U(288,d+248|0,d+224|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Ob}}g=P()|0;O()|0;break p}g=P()|0;O()|0;xb(d+248|0);break p}f=d+304|0;i=d+248|0;m=kc(f,i);xb(i);v[22708]=0;f=T(195,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Mb}u[d+248>>1]=(f>>>0)/20;f=x[a+480188>>1];v[22708]=0;u[d+168>>1]=f;f=Pc(d+248|0,d+168|0);i=v[22708];v[22708]=0;if((i|0)==1){break Mb}i=x[f>>1];if(i){f=0;while(1){v[22708]=0;W(571,m|0,((f<<5)+a|0)+480289|0,20)|0;o=v[22708];v[22708]=0;if((o|0)==1){break Mb}f=f+1|0;if((i|0)!=(f|0)){continue}break}}xb(d+304|0)}v[22708]=0;Q(588,a|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}v[22708]=0;Y(589,a|0,b|0,1,0);f=v[22708];v[22708]=0;if((f|0)==1){break q}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[22708]=0;U(604,a|0,b|0,g&65535);b=v[22708];v[22708]=0;if((b|0)==1){break q}}if(!v[k>>2]){break Gb}v[22708]=0;b=Q(2,d+248|0,14719)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Lb}v[22708]=0;R(162,d+168|0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break Kb}v[22708]=0;U(3,d+304|0,b|0,d+168|0);f=v[22708];v[22708]=0;if((f|0)==1){break Jb}f=d+304|0;Eb(h,f);vb(f);vb(d+168|0);vb(b);break Gb}g=P()|0;O()|0;xb(d+304|0);break p}g=P()|0;O()|0;break p}g=P()|0;O()|0;break Ib}g=P()|0;O()|0;vb(d+168|0)}vb(b);break p}v[22708]=0;g=T(287,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break q}}xb(d+224|0);continue}break}g=P()|0;O()|0;break p}$b:{ac:{bc:{cc:{dc:{ec:{fc:{if(v[a+480180>>2]!=32){break fc}b=g&65535;if(b>>>0<256){break fc}if(b>>>0<532){break ec}}gc:{if(v[a+480180>>2]!=2){break gc}b=g&65535;if(b>>>0<12544){break gc}if(b>>>0<12820){break ec}}if(v[a+480180>>2]!=2){break dc}b=g&65535;if(b>>>0<4864|b>>>0>4895){break dc}}v[22708]=0;Wo(j);b=v[22708];v[22708]=0;if((b|0)==1){break cc}}if(!(t[n+2|0]&1)){break $b}f=v[a+1074308>>2];if(!f){if(x[a+480192>>1]){f=1;while(1){b=v[(((f&65535)<<2)+a|0)+900380>>2];if(b){v[22708]=0;g=ki(b,2);n=v[22708];v[22708]=0;if((n|0)==1){break bc}n=v[a+480180>>2];v[22708]=0;U(768,g|0,4,n|0);g=v[22708];v[22708]=0;if((g|0)==1){break ac}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[22708]=0;b=a+1074312|0;Q(410,b|0,27)|0;f=v[22708];v[22708]=0;if((f|0)==1){break cc}v[22708]=0;Q(410,b|0,57)|0;b=v[22708];v[22708]=0;if((b|0)==1){break cc}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[22708]=0;Q(410,a+1074312|0,73)|0;b=v[22708];v[22708]=0;if((b|0)==1){break cc}f=v[a+1074308>>2]}if(f>>>0>19267583){break $b}v[22708]=0;Q(410,a+1074312|0,50)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break $b}}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}hc:{ic:{jc:{kc:{lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{if(gd(h)){v[22708]=0;_(769,d+224|0);b=v[22708];v[22708]=0;vc:{if((b|0)!=1){v[22708]=0;U(726,d+304|0,d+224|0,d+1703|0);b=v[22708];v[22708]=0;if((b|0)==1){break vc}break uc}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}v[22708]=0;_(770,d+224|0);b=v[22708];v[22708]=0;if((b|0)==1){break tc}v[22708]=0;Y(771,d+304|0,d+224|0,d+1703|0,h|0);b=v[22708];v[22708]=0;if((b|0)==1){break sc}}b=d+304|0;Eb(h,b);vb(b);b=d+224|0;Hb(b);v[22708]=0;R(725,b|0,1108);b=v[22708];v[22708]=0;if((b|0)==1){break qc}v[22708]=0;U(726,d+304|0,d+224|0,d+1703|0);b=v[22708];v[22708]=0;if((b|0)==1){break pc}b=d+304|0;Eb(a+1298304|0,b);vb(b);Hb(d+224|0);v[22708]=0;b=Q(2,b|0,12195)|0;f=v[22708];v[22708]=0;if((f|0)==1){break oc}Eb(a+1298316|0,b);vb(b);b=v[a+480180>>2];if((b|0)>15){break rc}switch(b-1|0){case 1:break kc;case 3:break lc;case 0:break mc;default:break v}}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}if((b|0)==16){break nc}if((b|0)==32){break jc}if((b|0)!=16777216){break v}v[22708]=0;b=Q(2,d+304|0,7394)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ic}Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,11117)|0;c=v[22708];v[22708]=0;if((c|0)==1){break hc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,7399)|0;c=v[22708];v[22708]=0;wc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,5512)|0;c=v[22708];v[22708]=0;if((c|0)==1){break wc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,9562)|0;c=v[22708];v[22708]=0;xc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,11481)|0;c=v[22708];v[22708]=0;if((c|0)==1){break xc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,7372)|0;c=v[22708];v[22708]=0;yc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,12405)|0;c=v[22708];v[22708]=0;if((c|0)==1){break yc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,7744)|0;c=v[22708];v[22708]=0;zc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,12230)|0;c=v[22708];v[22708]=0;if((c|0)==1){break zc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,3184)|0;f=v[22708];v[22708]=0;Ac:{Bc:{Cc:{Dc:{Ec:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);if(!(c&65535)){break Ac}v[22708]=0;R(411,d+224|0,1423);b=v[22708];v[22708]=0;if((b|0)==1){break Ec}v[d+168>>2]=(c&65280)>>>8;v[22708]=0;v[d+272>>2]=c&255;R(599,d+248|0,d+272|0);b=v[22708];v[22708]=0;if((b|0)==1){break Dc}v[22708]=0;Y(582,d+304|0,d+224|0,d+168|0,d+248|0);b=v[22708];v[22708]=0;if((b|0)==1){break Cc}b=d+304|0;Eb(a+1298340|0,b);vb(b);vb(d+248|0);Hb(d+224|0);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break Bc}g=P()|0;O()|0;vb(d+248|0)}Hb(d+224|0);break o}v[22708]=0;b=Q(2,d+304|0,5688)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break i}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}Eb(a+1298328|0,h);Fc:{if(v[a+1074308>>2]){v[a+1298364>>2]=8;break Fc}if(v[a+480180>>2]==1){v[a+1298364>>2]=2;break Fc}v[a+1298364>>2]=5}f=1;if(e&1){v[22708]=0;b=Q(2,d+304|0,13726)|0;c=v[22708];v[22708]=0;if((c|0)==1){break s}v[22708]=0;U(560,a|0,2,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break r}vb(b)}vb(h);hC(z);ci(s);jd(A);xb(I);xb(H)}xb(l)}gc(C);break a}g=P()|0;O()|0;break o}g=P()|0;O()|0;vb(b);break o}g=P()|0;O()|0}xb(d+224|0)}vb(h);break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0}hC(z);break i}g=P()|0;O()|0}ci(s);break g}g=P()|0;O()|0}jd(A)}xb(I)}xb(H);break c}g=P()|0;O()|0}xb(l)}gc(C);S(g|0);L()}gb=d+1712|0;return f|0}function Ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,ca=0,ea=0,ga=0,ha=0,ia=0,ja=C(0),ka=0,la=0,ma=0,na=C(0);e=gb-480|0;gb=e;vc(b);a:{b:{c:{if(!Ih(b,e+472|0)){break c}if(!UT(e+472|0)){break c}if((PT(b)|0)>-1){break c}if(!c){f=1;break c}Hd(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;kA(e+208|0,32);o=v[e+220>>2];d=a+1074320|0;v[d>>2]=v[e+216>>2];v[d+4>>2]=o;d=v[e+212>>2];v[a+1074312>>2]=v[e+208>>2];v[a+1074316>>2]=d;Rf(a+1074312|0,38);E=dd(e+456|0);H=dd(e+440|0);F=dd(e+424|0);o=dd(e+408|0);pg(b,4);i=a+480190|0;K=c&1;l=a+1298292|0;A=2500;G=!(c&2);d:{e:{f:{g:{h:{i:{while(1){v[22708]=0;c=Q(191,b|0,4)|0;d=v[22708];v[22708]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){t:{if(c){v[22708]=0;h=T(900,b|0)|0;c=v[22708];v[22708]=0;u:{if((c|0)==1){break u}v:{switch(h+21|0){case 20:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){if(x[a+480188>>1]){continue}d=c&65535;if(!d|d>>>0>127){continue}u[a+480188>>1]=c;la=a,ma=Lb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}a=P()|0;O()|0;break a;case 19:v[22708]=0;N=T(426,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break u}if(N>>>0<=1024){continue}break q;case 16:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){if((c&65535)==4){continue}break q}a=P()|0;O()|0;break a;case 15:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;w:{if((d|0)!=1){v[e+208>>2]=c;v[22708]=0;v[e+104>>2]=800;d=Fb(e+208|0,e+104|0);c=v[22708];v[22708]=0;if((c|0)==1){break w}c=a;J=+y[d>>2]*1.24*1e4;x:{if(J<4294967296&J>=0){d=~~J>>>0;break x}d=0}v[c+480204>>2]=d;continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a;case 17:case 18:v[22708]=0;Q(318,b|0,4)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 31:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}aa=1;A=Fd(c,0,1e4);continue;case 32:case 33:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;y:{z:{if((d|0)!=1){aa=1;if(!c){continue}v[22708]=0;c=Q(2,e+208|0,9822)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;U(560,a|0,2,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break y}vb(c);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a;case 14:v[22708]=0;Q(318,b|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break u}p=!x[i>>1]|p;continue;case 11:A:{if(!K){break A}if(!cd(E)){break A}v[22708]=0;R(901,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=E;d=c;if(v[c>>2]){Od(d);HB(v[d>>2],bi(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Uu(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 3:case 4:case 10:if(dh(o)>>>0<=x[i>>1]){continue}B:{if((p|G)&1){break B}if(!fi(a)){break B}j=x[i>>1]+1|0;u[i>>1]=j;d=mc(e+392|0);v[22708]=0;c=T(215,e+208|0)|0;k=v[22708];v[22708]=0;C:{D:{E:{if((k|0)!=1){if((h|0)==-17){break E}if((h|0)!=-11){break D}v[22708]=0;h=T(426,b|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break C}v[22708]=0;U(288,e+368|0,b|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break C}h=e+104|0;k=e+368|0;Vc(c,kc(h,k));xb(h);xb(k);break j}a=P()|0;O()|0;break d}v[22708]=0;R(902,e+104|0,b|0);h=v[22708];v[22708]=0;F:{if((h|0)!=1){h=e+104|0;np(d,h);gc(h);v[22708]=0;Ud(e+360|0,d);h=v[22708];v[22708]=0;if((h|0)==1){break F}h=Td(e+352|0);v[22708]=0;k=v[e+364>>2];v[e+32>>2]=v[e+360>>2];v[e+36>>2]=k;k=v[h+4>>2];v[e+24>>2]=v[h>>2];v[e+28>>2]=k;h=W(507,e+104|0,e+32|0,e+24|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break F}Vc(c,h);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22708]=0;R(903,e+104|0,b|0);h=v[22708];v[22708]=0;G:{if((h|0)!=1){h=e+104|0;np(d,h);gc(h);v[22708]=0;Ud(e+344|0,d);h=v[22708];v[22708]=0;if((h|0)==1){break G}h=Td(e+336|0);v[22708]=0;k=v[e+348>>2];v[e+16>>2]=v[e+344>>2];v[e+20>>2]=k;k=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=k;h=W(507,e+104|0,e+16|0,e+8|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break G}Vc(c,h);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 9:if(!fi(a)){continue}u[i>>1]=x[i>>1]+1;continue;case 8:H:{if(!K){break H}if(!cd(F)){break H}v[22708]=0;R(904,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=F;d=c;if(v[c>>2]){Od(d);sC(v[d>>2],pe(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;ci(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 7:if(cd(o)){v[22708]=0;R(905,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=o;d=c;if(v[c>>2]){Od(d);EB(v[d>>2],FB(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Su(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 6:I:{if(!K){break I}if(!cd(H)){break I}v[22708]=0;R(906,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=H;d=c;if(v[c>>2]){Od(d);GB(v[d>>2],xi(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Ru(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 5:v[22708]=0;R(907,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break t}J:{if(cd(e+208|0)){break J}c=e+208|0;d=v[c>>2];c=oc(c);v[22708]=0;da(908,l|0,d|0,c|0,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break J}a=P()|0;O()|0;gc(e+208|0);break a}gc(e+208|0);continue;case 0:case 1:case 2:break v;default:break q}}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}a=P()|0;O()|0;break a}if(!x[a+480188>>1]|!N){break q}if(cd(o)){break q}if(K){if(cd(E)){break q}if(cd(F)){break q}if(cd(H)){break q}}if(dh(o)>>>0>=256){v[22708]=0;R(909,o|0,255);b=v[22708];v[22708]=0;if((b|0)==1){break b}}la=a,ma=dh(o),u[la+480192>>1]=ma;v[22708]=0;j=a+480192|0;b=Ke(i,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}u[i>>1]=x[b>>1];if(p&1){v[22708]=0;b=Q(2,e+208|0,13556)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(560,a|0,2,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break l}vb(b)}f=x[j>>1];p=1;while(1){d=f&65535;f=0;c=1;b=1;K:{if(!d){break K}while(1){L:{h=Tl(o,c-1|0);d=h;M:{if(w[d|0]?t[d+128|0]<0:1){break M}if((Qu(h)|0)==(p&1)){break M}f=0;d=h;N:{if(!Qu(d)){break N}if(Ib(w[d+6|0]|w[d+7|0]<<8)){break N}if(Ib(w[d+14|0]|w[d+15|0]<<8)>>>0>20){break N}f=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==4}O:{P:{if(f){f=w[h+23|0];d=w[h+140|0];v[22708]=0;d=fa(910,h|0,a|0,(d&2)>>>1|0,(B(c,104)+a|0)+484380|0,A&65535)|0;l=v[22708];v[22708]=0;Q:{R:{S:{if((l|0)!=1){if(!d){break Q}v[22708]=0;d=Q(70,e+208|0,8013)|0;l=v[22708];v[22708]=0;if((l|0)==1){break S}v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break R}vb(d);d=b;if(dh(o)>>>0<=f>>>0){break O}la=h,ma=w[Tl(o,f)+143|0]+w[h+143|0]|0,t[la+143|0]=ma;break P}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=f+1|0;break O}f=0;T:{if(!Qu(h)){break T}if((Ib(w[d+6|0]|w[d+7|0]<<8)|0)!=1){break T}if((Ib(w[d+14|0]|w[d+15|0]<<8)|0)!=2){break T}f=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==10}d=b;if(!f){break O}hc(e+208|0,h,128);if(Ib(w[e+228|0]|w[e+229|0]<<8)>>>0>=x[i>>1]){break P}v[22708]=0;f=Q(895,e+104|0,0)|0;d=v[22708];v[22708]=0;U:{V:{W:{if((d|0)!=1){d=(B(Ib(w[e+228|0]|w[e+229|0]<<8),104)+a|0)+484484|0;if(Ib(w[e+244|0]|w[e+245|0]<<8)>>>0<x[a+480190>>1]){f=(B(Ib(w[e+244|0]|w[e+245|0]<<8),104)+a|0)+484484|0}v[22708]=0;d=da(911,e+208|0,d|0,f|0,(B(c,104)+a|0)+484380|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break W}if(!d){break P}v[22708]=0;d=Q(70,e+368|0,8543)|0;f=v[22708];v[22708]=0;if((f|0)==1){break V}v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break U}vb(d);t[h+139|0]=w[h+139|0]+12;break P}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=b}v[22708]=0;c=d&65535;d=W(376,a|0,b&65535,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break L}if(!d|c>>>0>x[i>>1]){break M}v[22708]=0;Y(912,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22708];v[22708]=0;if((c|0)==1){break L}}b=b+1|0;c=b&65535;f=x[j>>1];if(c>>>0<=f>>>0){continue}break K}break}a=P()|0;O()|0;break a}b=p&1;p=0;if(b){continue}break}k=Ik(e+104|0);j=Ik(e+368|0);b=Nb(F);ba=B(x[a+480188>>1],N);ca=Nv((b>>>0)/(ba>>>0)|0);v[22708]=0;V=a+484344|0;R(330,V|0,ca|0);b=v[22708];v[22708]=0;if((b|0)==1){a=P()|0;O()|0;break m}ea=a+484360|0;bm(Sb(ea));b=x[a+480188>>1];v[22708]=0;r=Q(913,e+392|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){la=e,ma=Vb(H),v[la+96>>2]=ma;la=e,ma=Zb(H),v[la+88>>2]=ma;if(!Gb(e+96|0,e+88|0)){break s}X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{while(1){ea:{q=v[e+96>>2];b=q;fa:{if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==1){break fa}if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==65535){break ea}b=Ib(w[q|0]|w[q+1|0]<<8);if(ze(E)>>>0<=b>>>0){break fa}b=Ib(w[q+2|0]|w[q+3|0]<<8);if(ze(E)>>>0<b>>>0){break fa}if(!Ib(w[q+2|0]|w[q+3|0]<<8)){break fa}if(ze(E)-Ib(w[q+2|0]|w[q+3|0]<<8)>>>0<Ib(w[q|0]|w[q+1|0]<<8)>>>0){break fa}b=v[E>>2];td(e+208|0,b,b+(ze(E)<<5)|0);c=Ib(w[q|0]|w[q+1|0]<<8);b=Ib(w[q+2|0]|w[q+3|0]<<8);d=v[e+208>>2]+(c<<5)|0;b=(b|0)==-1?(v[e+212>>2]-v[e+208>>2]>>5)-c|0:b;v[e+80>>2]=d;v[e+84>>2]=d+(b<<5);ga:{X=Sb(ea);if(cd(X)){break ga}v[22708]=0;R(710,X|0,65534);b=v[22708];v[22708]=0;if((b|0)!=1){break ga}a=P()|0;O()|0;break n}b=v[e+80>>2];ga=v[e+84>>2];if((b|0)==(ga|0)){break fa}while(1){G=b;c=Ib(Ib(w[q+8|0]|w[q+9|0]<<8)+Ib(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;ha:{ia:{ja:{d=b;f=k;c=Xd(f);ka:{if(c){wb(f);while(1){h=c+14|0;if(!Ou(d,h)){f=1;if(!Ou(h,d)){break ka}c=c+4|0}c=v[c>>2];if(c){continue}break}}f=0}if(f){v[22708]=0;c=Q(914,k|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ja}I=x[c>>1];break ia}I=0;if(!K){break ia}c=Ib(w[b+12|0]|w[b+13|0]<<8);v[22708]=0;I=W(544,V|0,c|0,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ja}if((I|0)==65535){break fa}v[22708]=0;c=Q(914,k|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ja}u[c>>1]=I;c=b;if(Ib(w[c+8|0]|w[c+9|0]<<8)>>>0>=ca>>>0){break ha}d=b;if(Ib(w[d+10|0]|w[d+11|0]<<8)>>>0>=N>>>0){break ha}ha=b;h=Ib(w[b+14|0]|w[b+15|0]<<8);la=e,ma=Vb(F),v[la+56>>2]=ma;f=e+56|0;la=e,ma=_o(f,B(Ib(w[c+8|0]|w[c+9|0]<<8),ba)),v[la+208>>2]=ma;la=e,ma=_o(e+208|0,B(Ib(w[d+10|0]|w[d+11|0]<<8),x[a+480188>>1])),v[la+72>>2]=ma;v[e+68>>2]=0;cj(f);ia=b;if(Ib(w[b+12|0]|w[b+13|0]<<8)){Z=0;while(1){c=_b(V,I);v[22708]=0;$=Yc(c,Z,0);c=v[22708];v[22708]=0;la:{ma:{if((c|0)!=1){s=0;p=0;if(x[a+480188>>1]){break ma}break la}a=P()|0;O()|0;break n}while(1){la=e,ma=Zb(F),v[la+208>>2]=ma;c=e+68|0;if(Gb(e+72|0,e+208|0)){c=v[e+72>>2]}la=e,ma=Zb(F),v[la+208>>2]=ma;if(Gb(e+72|0,e+208|0)){Qe(e+72|0)}d=B(s,6);i=c;if(t[c+1|0]<0|t[c+1|0]>84){f=255}else{f=w[i+1|0]+25|0}d=d+$|0;A=0;m=dh(o);l=c;M=w[c+3|0];na:{if(m>>>0<=M>>>0){break na}A=M+1|0;if(t[Tl(o,M)+142|0]&1|f<<24>>24<0){break na}f=on(Ib(w[G+16|0]|w[G+17|0]<<8)+f<<24>>24)}oa:{if(!w[d|0]){break oa}if(!(w[l+3|0]|(w[c|0]|w[i+1|0]!=255))){if(!w[c+2|0]){break oa}}m=w[d+1|0];if(!m){break oa}if(dh(o)>>>0<m>>>0){break oa}if(w[Tl(o,m-1|0)+132|0]!=2){break oa}$o(d)}g=Oj(r,s);pa:{if(p&1){m=v[e+56>>2];t[d|0]=m;t[d+1|0]=m>>>8;t[d+2|0]=m>>>16;t[d+3|0]=m>>>24;m=x[e+60>>1];t[d+4|0]=m;t[d+5|0]=m>>>8;qa:{if(w[d+3|0]){break qa}m=s-1|0;if(w[g+21|0]==w[Oj(r,m)+21|0]){break qa}t[d+3|0]=21;m=w[Oj(r,m)+21|0];t[g+21|0]=m;t[d+5|0]=m}p=0;m=1;ra:{if(w[c|0]==9){break ra}if(w[c|0]==24|w[c|0]==25|!w[c|0]&(w[c+2|0]==249|w[c+2|0]==250)){break ra}m=0}if(!m){break pa}}m=d;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{switch(w[c|0]){case 5:i=w[g+17|0];break ya;case 0:Aa:{if(w[c+2|0]>=201){p=0;Ba:{switch(w[c+2|0]-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[g+16|0]=0;break ta;case 9:t[d+4|0]=1;t[d+2|0]=15;break ta;case 8:if((h&255)>>>0<2){break ta}h=h-1|0;break ua;case 7:if((h&255)==255){h=255;break ta}h=h+1|0;break ua;case 6:t[g+17|0]=f;if(w[g+18|0]!=(A&255)){break ta}t[d|0]=f;t[d+5|0]=255;t[d+3|0]=4;u[g+32>>1]=0;v[g+8>>2]=0;break ta;case 5:t[d+5|0]=242;t[d+3|0]=2;break ta;case 4:t[d+5|0]=242;t[d+3|0]=3;break ta;case 3:t[d+5|0]=244;t[d+3|0]=2;break ta;case 2:t[d+5|0]=244;t[d+3|0]=3;break ta;case 1:t[d+5|0]=248;t[d+3|0]=2;break ta;case 12:break Aa;case 0:break Ba;default:break ta}}t[d+5|0]=248;t[d+3|0]=3;break ta}if(t[i+1|0]<=-1){p=0;if(w[c+2|0]>99){break ta}}if(t[i+1|0]>=0){t[g+17|0]=f;t[d|0]=f;t[g+18|0]=A;t[d+1|0]=A;u[g+32>>1]=0;v[g+8>>2]=0}if(!w[c+2|0]){p=0;break ta}c=w[c+2|0];v[22708]=0;c=gn(+(c>>>0)*.64);f=v[22708];v[22708]=0;if((f|0)==1){break va}t[g+19|0]=c;n=z[g>>2];v[g>>2]=0;p=n!=C(0);break ta}t[d+4|0]=0;t[d+2|0]=14;t[g+16|0]=1;break ta;case 1:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(.0333000011742115);break sa;case 2:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(-.0333000011742115);break sa;case 12:t[e+208|0]=15;f=w[l+3|0];v[22708]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;Ca:{if((i|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22708]=0;t[e+52|0]=c>>>3;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Ca}t[g+24|0]=w[c|0]|f<<4;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 3:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(.0333000011742115);break sa;case 4:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(-.0333000011742115);break sa;case 15:i=f<<24>>24;if(!w[c+2|0]|(i|0)<0){break sa}l=i-w[g+17|0]|0;i=l>>31;i=i^i+(l<<5);v[e+208>>2]=i;t[g+17|0]=f;v[g+8>>2]=0;t[d|0]=f;t[d+3|0]=4;c=ei((i>>>0)/(w[c+2|0]<<1>>>0)|0);t[d+5|0]=c;t[g+27|0]=c;v[22708]=0;f=v[e+208>>2];v[e+52>>2]=B(c,(h&255)-1|0);c=pd(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)!=1){u[g+32>>1]=f-v[c>>2];break sa}a=P()|0;O()|0;break n;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break sa;case 13:t[e+208|0]=15;f=w[l+3|0];v[22708]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;Da:{if((i|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Da}t[g+23|0]=w[c|0]|f<<4;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 23:case 24:case 25:l=j;f=Xd(j);Ea:{if(f){wb(l);while(1){m=f+13|0;if(!Nu(i,m)){l=1;if(!Nu(m,i)){break Ea}f=f+4|0}f=v[f>>2];if(f){continue}break}}l=0}if(l){t[d+3|0]=31;v[22708]=0;c=Q(915,j|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break va}t[d+5|0]=w[c|0];break sa}if(RT(j)>>>0>127){break sa}f=RT(j);i=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;v[e+48>>2]=i;v[e+40>>2]=i;i=W(916,e+40|0,(((f&255)<<5)+a|0)+902204|0,a|0)|0;l=v[22708];v[22708]=0;Fa:{if((l|0)==1){break Fa}if(!i){break sa}t[d+3|0]=31;v[22708]=0;i=Q(915,j|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break Fa}f=f|-128;t[i|0]=f;t[d+5|0]=f;if(w[c|0]!=24&w[c|0]!=25){break sa}ka=1;break sa}a=P()|0;O()|0;break n;case 16:if(!w[c+2|0]){break sa}t[d+3|0]=15;v[e+208>>2]=15;f=w[l+3|0];v[22708]=0;v[e+52>>2]=f+1;f=pd(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)!=1){t[d+5|0]=v[f>>2];u[g+30>>1]=B(w[c+2|0],w[l+3|0]+1|0);break sa}a=P()|0;O()|0;break n;case 9:t[d+3|0]=16;h=w[c+2|0]?w[c+2|0]:4;t[d+5|0]=h;break sa;case 19:if(w[i+1|0]!=4?w[i+1|0]:0){break sa}t[e+47|0]=w[i+1|0]==4?w[l+3|0]:128;t[e+208|0]=w[c+2|0];v[22708]=0;t[e+52|0]=100;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;Ga:{Ha:{if((f|0)!=1){c=w[c|0];v[e+208>>2]=128;v[22708]=0;v[e+52>>2]=256-w[e+47|0];f=pd(e+208|0,e+52|0);l=v[22708];v[22708]=0;if((l|0)==1){break Ha}f=v[f>>2];v[22708]=0;t[e+208|0]=128;l=ac(e+208|0,e+47|0);m=v[22708];v[22708]=0;if((m|0)==1){break Ga}l=w[l|0];f=(B(c,f)|0)/128|0;m=f&255;if((m|0)!=w[g+20|0]){t[g+20|0]=f;t[d+3|0]=21;f=Qc(((B(m,w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[d+5|0]=f}if(w[i+1|0]!=4|(x[a+480188>>1]-1|0)<=(s|0)){break sa}f=s+1|0;i=Oj(r,f);c=B(c,l)>>>7|0;if(w[i+20|0]==(c&255)){break sa}t[i+20|0]=c;c=B(f,6)+$|0;t[c+3|0]=21;f=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[c+5|0]=f;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 17:case 20:t[d+3|0]=0;break sa;case 7:c=w[c+2|0];t[g+25|0]=0;t[g+26|0]=0;t[g+22|0]=c;break sa;case 8:t[g+22|0]=w[g+22|0]+w[c+2|0];break sa;case 14:t[g+25|0]=w[l+3|0];t[g+26|0]=w[c+2|0];break sa;case 18:break xa;case 6:break za;default:break sa}}t[g+18|0]=A;t[g+17|0]=f;t[d+1|0]=A;i=f}t[m|0]=i;if(f<<24>>24>=0){t[g+18|0]=A;t[d+1|0]=A}if(w[c|0]==5){t[d+4|0]=1;t[d+2|0]=11}f=w[g+26|0];if(!(f?1:w[c+2|0]|w[g+22|0])){break wa}if(f){J=(si(+x[g+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(f>>>0)*.25}else{J=0}t[d+3|0]=44;f=w[g+22|0];c=w[c+2|0];v[22708]=0;c=gn(J+ +(c+f|0));f=v[22708];v[22708]=0;if((f|0)!=1){t[d+5|0]=c;break wa}a=P()|0;O()|0;break n}c=w[g+17|0]+w[c+2|0]&255;c=c?c>>>0<120?c:120:1;t[g+17|0]=c;t[d|0]=c;t[d+5|0]=255;t[d+3|0]=4}u[g+32>>1]=0;break sa}a=P()|0;O()|0;break n}t[d+5|0]=h;t[d+3|0]=16}c=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);if(!(!p&w[g+21|0]==(c&255))){t[g+21|0]=c;t[d+5|0]=c;t[d+3|0]=21}if(s&1|t[i+1|0]<1|(x[a+480188>>1]-1|0)<=(s|0)){break sa}if(dh(o)>>>0<=M>>>0){break sa}if(w[Tl(o,M)+132|0]!=1){break sa}f=s+1|0;c=B(f,6)+$|0;i=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=i;t[c+1|0]=i>>>8;t[c+2|0]=i>>>16;t[c+3|0]=i>>>24;i=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=i;t[c+5|0]=i>>>8;t[c+1|0]=w[c+1|0]+1;la=Oj(r,f),ma=w[g+19|0],t[la+19|0]=ma;la=Oj(r,f),na=z[g>>2],z[la>>2]=na;la=Oj(r,f),na=z[g+4>>2],z[la+4>>2]=na;la=Oj(r,f),na=z[g+8>>2],z[la+8>>2]=na;la=Oj(r,f),na=z[g+12>>2],z[la+12>>2]=na;la=Oj(r,f),ma=x[g+30>>1],u[la+30>>1]=ma}Ia:{if(w[d|0]){t[g+16|0]=0;break Ia}p=0;if(w[g+16|0]){break pa}}Ja:{Ka:{La:{Ma:{Na:{Oa:{if(!x[g+30>>1]){break Oa}v[22708]=0;c=h&255;u[e+208>>1]=c;f=Ke(g+30|0,e+208|0);i=v[22708];v[22708]=0;if((i|0)==1){break Na}u[g+30>>1]=x[f>>1]-c;if(w[d+3|0]){break Oa}t[d+3|0]=15;t[d+5|0]=0}n=z[g>>2];if(n==C(0)){break Ja}c=h&255;n=C(C(n*C(c>>>0))+z[g+4>>2]);z[g+4>>2]=n;if(w[d+3|0]){break Ja}Pa:{Qa:{if(c>>>0>=2){f=c-1|0;D=C(f|0);if(!(D<=n)){break Qa}t[e+208|0]=15;v[22708]=0;c=ch(C(n/D));i=v[22708];v[22708]=0;Ra:{if((i|0)==1){break Ra}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Ra}c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(B(c,f)|0);t[d+3|0]=22;c=c<<4;break Ka}a=P()|0;O()|0;break n}if(!(n>=C(1))){break Pa}break La}if(n>=C(1)){break La}if(!(n<=C(1-c|0))){break Pa}t[e+208|0]=15;v[22708]=0;c=ch(C(C(-n)/D));i=v[22708];v[22708]=0;Sa:{if((i|0)==1){break Sa}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Sa}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(B(f,c)|0);t[d+3|0]=22;break Ka}a=P()|0;O()|0;break n}if(!(n<=C(-1))){break Ja}t[e+208|0]=14;v[22708]=0;c=ch(C(-n));f=v[22708];v[22708]=0;if((f|0)==1){break Ma}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ma}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(c>>>0);t[d+3|0]=22;c=c|-16;break Ka}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22708]=0;c=ch(n);f=v[22708];v[22708]=0;Ta:{if((f|0)==1){break Ta}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ta}c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(c>>>0);t[d+3|0]=22;c=c<<4|15;break Ka}a=P()|0;O()|0;break n}t[d+5|0]=c}Ua:{n=z[g+8>>2];if(n==C(0)){break Ua}c=h&255;n=C(C(n*C(c>>>0))+z[g+12>>2]);z[g+12>>2]=n;Va:{if(!w[d+3|0]){Wa:{Xa:{if(c>>>0>=2){f=c-1|0;D=C(f|0);if(!(D<=n)){break Xa}t[e+208|0]=223;v[22708]=0;c=ch(C(n/D));i=v[22708];v[22708]=0;Ya:{if((i|0)==1){break Ya}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Ya}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)|0);t[d+3|0]=2;t[d+5|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(n>=C(1))){break Wa}break Va}if(n>=C(1)){break Va}if(!(n<=C(1-c|0))){break Wa}t[e+208|0]=223;v[22708]=0;c=ch(C(C(-n)/D));i=v[22708];v[22708]=0;Za:{if((i|0)==1){break Za}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Za}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)|0);t[d+3|0]=3;t[d+5|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(n<=C(-1))){break Ua}t[e+208|0]=14;v[22708]=0;c=ch(C(-n));f=v[22708];v[22708]=0;_a:{if((f|0)==1){break _a}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break _a}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(c>>>0);t[d+3|0]=3;t[d+5|0]=c|240;break Ua}a=P()|0;O()|0;break n}if(w[d+2|0]|c>>>0<2){break Ua}ja=C(n*C(.25));f=c-1|0;D=C(f|0);if(ja>=D){t[e+208|0]=9;v[22708]=0;c=ch(C(n/D));i=v[22708];v[22708]=0;$a:{if((i|0)==1){break $a}v[22708]=0;t[e+52|0]=c>>>2;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break $a}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)<<2);t[d+2|0]=12;t[d+4|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(C(1-c|0)>=ja)){break Ua}t[e+208|0]=9;v[22708]=0;c=ch(C(C(-n)/D));i=v[22708];v[22708]=0;ab:{if((i|0)==1){break ab}v[22708]=0;t[e+52|0]=c>>>2;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break ab}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)<<2);t[d+2|0]=13;t[d+4|0]=c;break Ua}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22708]=0;c=ch(n);f=v[22708];v[22708]=0;bb:{if((f|0)==1){break bb}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break bb}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(c>>>0);t[d+3|0]=2;t[d+5|0]=c|240;break Ua}a=P()|0;O()|0;break n}cb:{db:{eb:{fb:{gb:{hb:{ib:{i=w[d+3|0];switch(i|0){case 4:break cb;case 0:break ib;default:break hb}}jb:{c=w[g+23|0];if(!c){c=w[g+24|0];if(c){break jb}if(!x[g+32>>1]){break cb}c=g+32|0;break gb}t[d+3|0]=5;t[d+5|0]=c;if(!x[g+32>>1]){break cb}break fb}t[d+3|0]=8;t[d+5|0]=c;if(x[g+32>>1]){break fb}break cb}if(!x[g+32>>1]){break cb}c=g+32|0;f=c;if(i){break eb}}t[d+3|0]=4;break db}f=g+32|0}c=f;t[d+2|0]=11}f=w[g+27|0];v[22708]=0;u[e+208>>1]=B(f,(h&255)-1|0);f=Pc(c,e+208|0);i=v[22708];v[22708]=0;if((i|0)!=1){u[c>>1]=x[c>>1]-x[f>>1];break cb}a=P()|0;O()|0;break n}u[g+28>>1]=x[g+28>>1]+B(w[g+25|0],h&255)&1023;p=0;if(s&1){break pa}c=w[g+18|0];if(!c){break pa}if(dh(o)>>>0<c>>>0){break pa}if(!(w[Tl(o,c-1|0)+142|0]&4)){break pa}v[e+56>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+60>>1]=w[d+4|0]|w[d+5|0]<<8;if(!w[e+57|0]){p=1;break pa}p=1;if(w[Tl(o,w[g+18|0]-1|0)+132|0]!=1){break pa}t[e+57|0]=w[e+57|0]+1}s=s+1|0;if(s>>>0<x[a+480188>>1]){continue}break}}Z=Z+1|0;if(Ib(w[ia+12|0]|w[ia+13|0]<<8)>>>0>Z>>>0){continue}break}}c=_b(V,I);d=Ib(w[ha+14|0]|w[ha+15|0]<<8);v[22708]=0;d=Be(e+208|0,16,d&255);f=v[22708];v[22708]=0;if((f|0)!=1){d=Fh(Ue(d,0));v[22708]=0;Q(431,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break ia}}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}c=$l(X);la=e,ma=Ib(w[b+4|0]|w[b+5|0]<<8),u[la+208>>1]=ma;v[22708]=0;u[e+56>>1]=1;d=Ke(e+208|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break da}d=x[d>>1];v[22708]=0;da(918,X|0,c|0,d|0,I&65535)|0;c=v[22708];v[22708]=0;if((c|0)==1){break da}c=Ib(w[q+8|0]|w[q+9|0]<<8);c=Ib(Ib(w[G+16|0]|w[G+17|0]<<8)-c&65535);t[G+16|0]=c;t[G+17|0]=c>>>8}b=b+32|0;if((ga|0)!=(b|0)){continue}break}}b=e+96|0;Zo(b);if(Gb(b,e+88|0)){continue}}break}c=0;if(!ka){break r}v[22708]=0;_(436,a+906300|0);b=v[22708];v[22708]=0;if((b|0)==1){break ca}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22708]=0;v[e+208>>2]=0;b=a+906332|0;BD(b,b+16|0,e+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break ba}v[22708]=0;b=Q(70,e+208|0,6713)|0;c=v[22708];v[22708]=0;if((c|0)==1){break aa}v[22708]=0;Ov(a+906348|0,b);c=v[22708];v[22708]=0;if((c|0)==1){break $}vb(b);v[22708]=0;b=Q(70,e+208|0,6706)|0;c=v[22708];v[22708]=0;if((c|0)==1){break _}v[22708]=0;Ir(a+906380|0,b);c=v[22708];v[22708]=0;if((c|0)==1){break Z}vb(b);v[22708]=0;b=Q(70,e+208|0,6698)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Y}v[22708]=0;Ov(a+906508|0,b);d=v[22708];v[22708]=0;c=1;if((d|0)==1){break X}vb(b);break r}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break m}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}c=0}if(x[a+480188>>1]){b=0;while(1){v[22708]=0;eu(a,b&65535);d=v[22708];v[22708]=0;if((d|0)==1){break p}d=(b<<5)+a|0;u[d+480284>>1]=b<<8&256;if(c){t[d+480288|0]=1}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[22708]=0;b=Q(2,e+208|0,9351)|0;c=v[22708];v[22708]=0;kb:{lb:{mb:{nb:{if((c|0)!=1){Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,e+208|0,9559)|0;c=v[22708];v[22708]=0;if((c|0)==1){break nb}Eb(a+1298316|0,b);vb(b);if(aa){break lb}v[22708]=0;b=Q(2,e+208|0,9351)|0;c=v[22708];v[22708]=0;if((c|0)==1){break mb}break kb}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}if(dh(o)>>>0<=128){v[22708]=0;b=Q(2,e+208|0,6455)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break kb}a=P()|0;O()|0;break n}v[22708]=0;b=Q(2,e+208|0,11997)|0;c=v[22708];v[22708]=0;if((c|0)==1){break o}}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;KB(r);IT(j);HT(k);f=1}Su(o);ci(F);Ru(H);Uu(E);break c}a=P()|0;O()|0;break n}a=P()|0;O()|0}KB(r)}IT(j);HT(k);break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}v[22708]=0;h=j&65535;j=W(920,a|0,h|0,c|0)|0;k=v[22708];v[22708]=0;ob:{pb:{qb:{rb:{if((k|0)==1){break rb}if(j){break ob}v[22708]=0;j=fa(921,a|0,h|0,c|0,0,0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break rb}if(j){break ob}v[22708]=0;j=da(922,a|0,h|0,c|0,0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break rb}if(j){break ob}v[22708]=0;c=Q(923,(B(h,104)+a|0)+484380|0,c|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break rb}if(c){break ob}v[22708]=0;c=Q(2,e+104|0,13267)|0;j=v[22708];v[22708]=0;if((j|0)==1){break qb}v[22708]=0;U(560,a|0,2,c|0);j=v[22708];v[22708]=0;if((j|0)==1){break pb}vb(c);break ob}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}sb:{tb:{ub:{j=B(h,104)+a|0;if(w[j+484414|0]&64){if(fi(a)){break ub}}if(dh(o)>>>0<=h>>>0){break tb}if(w[Tl(o,h)+132|0]!=2){break tb}if(!fi(a)){break tb}u[i>>1]=x[i>>1]+1;break tb}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22708]=0;h=j+484380|0;k=B(c&65535,104)+a|0;da(924,h|0,k+484380|0,h|0,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break sb}v[22708]=0;c=Q(70,e+104|0,3377)|0;h=v[22708];v[22708]=0;if((h|0)==1){break i}v[22708]=0;Q(303,k+484423|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break h}vb(c);v[22708]=0;c=Q(70,e+104|0,3280)|0;h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;Q(303,j+484423|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break f}vb(c)}xb(e+208|0);gc(d);p=0;continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c)}xb(e+208|0)}gc(d);break a}gb=e+480|0;return f|0}a=P()|0;O()|0}Su(o);ci(F);Ru(H);Uu(E);S(a|0);L()}function sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0;d=gb-928|0;gb=d;vc(b);a:{if(!iW(b,d+872|0)){break a}if(!kW(d+872|0)){break a}if(!Pb(b,Qc(jW(d+872|0),jb))){break a}if(!c){e=1;break a}Hd(a,8);Ag(a);i=w[d+872|3]-48|0;t[d+871|0]=i;Wc(b,Xb(w[d+880|0]|w[d+881|0]<<8|(w[d+882|0]<<16|w[d+883|0]<<24)));f=d+560|0;Sd(f,b,504);N=kc(d+848|0,f);xb(f);v[22708]=0;R(689,b|0,f|0);f=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((f|0)!=1){if(w[d+843|0]>63){break b}if(Ib(w[d+560|0]|w[d+561|0]<<8)<<16>>16<0){break b}Qb(d+480|0,0,80);o:{if(!Xb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24))){break o}f=Xb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24));v[22708]=0;f=Q(190,b|0,f|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){if(!f){break o}v[22708]=0;R(690,b|0,d+480|0);f=v[22708];v[22708]=0;if((f|0)!=1){break o}}g=P()|0;O()|0;break e}v[22708]=0;U(691,d+472|0,b|0,i&255);f=v[22708];v[22708]=0;if((f|0)!=1){f=d+472|0;V=Ve(f);f=x[f>>1];if((f-1&65535)>>>0>126){break b}u[a+480188>>1]=f;J=dd(d+456|0);p:{if(Xb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24))){f=Xb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24));v[22708]=0;Q(190,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){f=w[d+843|0];v[22708]=0;U(692,b|0,J|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break p}}g=P()|0;O()|0;break f}e=0;if(w[d+843|0]){break c}}f=w[d+843|0];u[a+480192>>1]=f;u[a+480190>>1]=f;e=1;X=1;if((i&255)>>>0>=2){X=t[d+824|0]>-1;f=x[a+480192>>1]}if(f&65535){F=c&2;G=!X;f=d- -64|0;n=f|2;H=f|7;K=f|6;q=f|5;r=f|4;h=d+24|4;p=1;o=1;while(1){v[22708]=0;s=o&65535;f=W(376,a|0,p&65535,s|0)|0;i=v[22708];v[22708]=0;q:{r:{if((i|0)!=1){if(!f){break d}j=v[((e<<2)+a|0)+900380>>2];u[d+28>>1]=0;v[d+24>>2]=0;v[22708]=0;E=T(215,d+144|0)|0;f=v[22708];v[22708]=0;s:{t:{u:{v:{if((f|0)!=1){i=e-1|0;f=Mb(J,i);w:{if(!Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break w}f=Mb(J,i);f=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22708]=0;f=Q(190,b|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break g}if(!f){break w}v[22708]=0;R(693,b|0,d+24|0);f=v[22708];v[22708]=0;if((f|0)==1){break g}f=Xb(w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24));v[22708]=0;U(288,d+432|0,b|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break g}f=d- -64|0;i=d+432|0;Vc(E,kc(f,i));xb(f);xb(i)}i=Ib(w[h|0]|w[h+1|0]<<8);f=Ib(w[h|0]|w[h+1|0]<<8)&15;m=i<<16>>16;if((m|0)>-1){break v}v[22708]=0;or(j,0);i=v[22708];v[22708]=0;ba=1;if((i|0)!=1){break u}break g}g=P()|0;O()|0;break f}if(f>>>0>6){break u}i=w[f+28918|0];if(!f){f=i;break r}u[a+480190>>1]=(x[a+480190>>1]+i|0)-1;f=j+108|0;l=j+236|0;C=i-2|0;g=4;while(1){k=B(g,12);e=(C<<3)+g|0;D=e+28972|0;z=w[e+28924|0]+o|0;e=0;while(1){A=e+k|0;la=vd(l,A),ma=z,u[la>>1]=ma;A=ic(f,A);t[A|0]=w[A|0]+w[D|0];e=e+1|0;if((e|0)!=12){continue}break}k=1;g=g+1|0;if((g|0)!=10){continue}break}f=i;break t}i=1;if((f|0)!=7){f=1;break r}k=0;v[22708]=0;BS(j,-24);i=v[22708];v[22708]=0;f=1;if((i|0)==1){break s}i=1}C=1;break q}break g}g=P()|0;O()|0;break f}k=0;if(G|(m|0)<0){break q}l=j+108|0;g=7;while(1){D=B(g,12);z=B(g,-12)+72|0;e=0;while(1){A=ic(l,e+D|0);t[A|0]=z+w[A|0];e=e+1|0;if((e|0)!=12){continue}break}g=g+1|0;if((g|0)!=10){continue}break}}v[22708]=0;R(696,N|0,d- -64|0);e=v[22708];v[22708]=0;x:{if((e|0)!=1){if(!(!w[r|0]|w[r|0]>16)){t[j+31|0]=w[r|0];C=1}if(!(!w[q|0]|w[q|0]>128)){t[j+30|0]=w[q|0]}e=0;g=0;if(!f){break x}y:{while(1){z:{v[22708]=0;e=B(e+s|0,104)+a|0;R(424,e+484380|0,8);j=v[22708];v[22708]=0;if((j|0)==1){break z}t[d+432|0]=w[K|0];v[22708]=0;t[d+400|0]=64;j=ac(d+432|0,d+400|0);l=v[22708];v[22708]=0;if((l|0)==1){break y}u[e+484410>>1]=w[j|0]<<2;t[e+484416|0]=w[H|0];g=g+1|0;e=g&65535;if(f>>>0>e>>>0){continue}break x}break}break g}break g}break g}A:{if(!F|(m|0)<0){break A}j=Rc(d+432|0,8,1,1,0);D=Ib(w[n|0]|w[n+1|0]<<8);e=d- -64|0;g=Ib(w[e|0]|w[e+1|0]<<8);m=Ib(w[n|0]|w[n+1|0]<<8);v[22708]=0;e=T(195,d+144|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break g}if(Ib(w[h|0]|w[h+1|0]<<8)&16){Zi(j,16);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&32){Ap(j,3);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&64){Cf(j,2)}e=k?(e>>>0)/((-1<<f^-1)>>>0)|0:e;if(!f){break A}m=g+m|0;k=0;l=0;while(1){k=B(k+s|0,104)+a|0;z=k+484380|0;v[z>>2]=e;v[22708]=0;W(329,j|0,z|0,E|0)|0;z=v[22708];v[22708]=0;if((z|0)==1){break g}g=g<<1;m=m<<1;if(D>>>0>=2){v[k+484388>>2]=m;v[k+484384>>2]=g;k=k+484414|0;u[k>>1]=x[k>>1]|2}e=e<<1;l=l+1|0;k=l&65535;if(k>>>0<f>>>0){continue}break}}o=i+o|0;xb(d+144|0);p=p+1|0;e=p&65535;if(e>>>0<=x[a+480192>>1]){continue}break}}f=d+480|4;B:{if(!Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break B}if(!Ib(w[d+488|0]|w[d+489|0]<<8)){break B}f=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22708]=0;f=Q(190,b|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break h}if(!f){break B}la=d,ma=Ib(w[d+488|0]|w[d+489|0]<<8),u[la+144>>1]=ma;f=w[d+843|0];v[22708]=0;u[d+64>>1]=f;f=Pc(d+144|0,d- -64|0);i=v[22708];v[22708]=0;if((i|0)==1){break i}n=x[f>>1];h=Ib(w[d+490|0]|w[d+491|0]<<8);if(!n){break B}f=d+144|0;j=f|5;l=f|3;k=f|1;i=d+72|0;p=d- -64|4;o=h>>>0<19;q=h>>>0<21;r=h>>>0<15;g=0;while(1){v[22708]=0;U(697,b|0,d+144|0,h|0);f=v[22708];v[22708]=0;C:{D:{E:{if((f|0)!=1){g=g+1|0;f=v[((g<<2)+a|0)+900380>>2];if(!w[d+144|0]){break C}s=pr(d- -64|0,0,64);pr(p,w[d+144|0]-1&65535,64);C=w[d+144|0];pr(i,C+(w[k|0]?64/w[k|0]|0:0)|0,0);v[d+428>>2]=3;v[d+424>>2]=s;v[22708]=0;e=v[d+428>>2];v[d>>2]=v[d+424>>2];v[d+4>>2]=e;e=f+48|0;R(698,e|0,d|0);m=v[22708];v[22708]=0;if((m|0)==1){break E}if(w[d+144|0]!=1){break D}la=d,ma=Vb(e),v[la+64>>2]=ma;Gd(d+416|0,d- -64|0);v[22708]=0;R(699,e|0,v[d+416>>2]);e=v[22708];v[22708]=0;if((e|0)!=1){break D}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}v[f>>2]=w[k|0]?w[k|0]<<9:32767;C=1;t[f+60|0]=w[f+60|0]|1}F:{if(o){break F}v[f+4>>2]=w[d+162|0]+1>>>1;if(q){break F}u[f+28>>1]=w[d+164|0]|w[d+165|0]<<8}f=B(x[vd(f+236|0,61)>>1],104)+a|0;t[f+484417|0]=w[l|0]<<4;G:{H:{if(!r){la=f+484384|0,ma=Xb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24)),v[la>>2]=ma;la=f+484388|0,ma=Xb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24))+Xb(w[d+158|0]|w[d+159|0]<<8|(w[d+160|0]<<16|w[d+161|0]<<24))|0,v[la>>2]=ma;break H}if(h>>>0<6){break G}}if(t[j|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}if(w[j|0]&8){e=f+484414|0;u[e>>1]=x[e>>1]|6}if(!(w[j|0]&4)){break G}u[f+484412>>1]=0}if((g|0)!=(n|0)){continue}break}}if(!Xb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24))){break j}if(!Ib(w[d+504|0]|w[d+505|0]<<8)){break j}f=Xb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24));v[22708]=0;f=Q(190,b|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break h}if(!f){break j}la=d,ma=Ib(w[d+504|0]|w[d+505|0]<<8),u[la+144>>1]=ma;f=w[d+843|0];v[22708]=0;u[d+64>>1]=f;f=Pc(d+144|0,d- -64|0);i=v[22708];v[22708]=0;if((i|0)!=1){e=x[f>>1];g=Ib(w[d+506|0]|w[d+507|0]<<8);if(!e){break j}k=0;I:while(1){J:{v[22708]=0;U(700,b|0,d+144|0,g|0);f=v[22708];v[22708]=0;if((f|0)==1){break k}v[22708]=0;$C(d+432|0,2,d+144|0);f=v[22708];v[22708]=0;if((f|0)==1){break l}v[22708]=0;R(324,d- -64|0,d+432|0);f=v[22708];v[22708]=0;if((f|0)==1){break l}k=k+1|0;h=((k<<2)+a|0)+900380|0;f=v[h>>2];v[22708]=0;Q(301,f+492|0,d- -64|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break m}f=d- -64|0;vb(f);i=v[h>>2];v[22708]=0;R(702,f|0,i|0);f=v[22708];v[22708]=0;if((f|0)==1){break n}f=d- -64|0;la=d,ma=nr(f),v[la+432>>2]=ma;la=d,ma=Dh(f),v[la+24>>2]=ma;while(1){v[22708]=0;f=Gb(d+432|0,d+24|0);i=v[22708];v[22708]=0;K:{if((i|0)!=1){if(f){break K}mr(d- -64|0);if((e|0)!=(k|0)){continue I}break j}break J}v[22708]=0;f=Xl(d+432|0);i=v[22708];v[22708]=0;if((i|0)!=1){i=(x[f>>1]<<5)+a|0;j=i+946328|0;f=v[h>>2];n=v[f+520>>2];v[j>>2]=v[f+516>>2];v[j+4>>2]=n;n=v[f+512>>2];j=i+946320|0;v[j>>2]=v[f+508>>2];v[j+4>>2]=n;n=v[f+504>>2];j=i+946312|0;v[j>>2]=v[f+500>>2];v[j+4>>2]=n;j=v[f+496>>2];i=i+946304|0;v[i>>2]=v[f+492>>2];v[i+4>>2]=j;Sj(d+432|0);continue}break}}break}g=P()|0;O()|0;mr(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}f=0;v[22708]=0;Wo(a+901404|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}t[a+901696|0]=w[2040];i=a+901692|0;e=w[2036]|w[2037]<<8|(w[2038]<<16|w[2039]<<24);t[i|0]=e;t[i+1|0]=e>>>8;t[i+2|0]=e>>>16;t[i+3|0]=e>>>24;vc(b);K=a+484360|0;L:{M:{N:{O:{P:{Q:{if(!w[V|0]){break Q}ca=c&1;s=a+484344|0;E=a+1298292|0;z=a+1298268|0;c=d+144|0;ea=c|1;j=c|4;c=d+48|0;i=c|4;F=c|2;fa=c|3;q=d+560|2;R:{while(1){S:{v[22708]=0;Y(705,b|0,d+872|0,d+480|0,d+560|0);c=v[22708];v[22708]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((c|0)==1){break fa}c=Z&255;if(c){v[22708]=0;e=T(417,K|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break fa}if((e|0)==255){break d}}n=Rj(K,c);r=Ik(d+400|0);bm(n);m=w[d+871|0];if(m>>>0>1){break da}if(Ib(w[q|0]|w[q+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break ca}c=d+144|0;gW(c,d+560|0);e=Ib(w[q|0]|w[q+1|0]<<8);v[22708]=0;U(706,n|0,c|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break ba}la=d,ma=Vb(n),v[la+144>>2]=ma;la=d,ma=Zb(n),v[la+64>>2]=ma;if(Gb(d+144|0,d- -64|0)){break ea}break V}g=P()|0;O()|0;break f}while(1){c=d+144|0;e=v[c>>2];u[e>>1]=x[e>>1]+f;of(c);if(Gb(c,d- -64|0)){continue}break}break V}gW(d+144|0,d+560|0);if(!Ib(w[d+156|0]|w[d+157|0]<<8)){break ca}if(Ib(w[d+156|0]|w[d+157|0]<<8)>>>0>64|x[a+480188>>1]>64){break ca}k=Xb(w[d+164|0]|w[d+165|0]<<8|(w[d+166|0]<<16|w[d+167|0]<<24));ga:{if(Ib(w[d+168|0]|w[d+169|0]<<8)){la=d,ma=Ib(w[d+168|0]|w[d+169|0]<<8),u[la+64>>1]=ma;v[22708]=0;u[d+432>>1]=800;c=Pc(d- -64|0,d+432|0);e=v[22708];v[22708]=0;if((e|0)==1){break ga}c=Qc(((x[c>>1]<<5)+50>>>0)/100|0,0)}else{c=32}e=Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22708]=0;h=Q(190,b|0,e|0)|0;e=v[22708];v[22708]=0;ha:{if((e|0)==1){break ha}e=0;ia:{ja:{ka:{la:{ma:{if(h&x[a+480188>>1]!=0){while(1){v[22708]=0;h=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ma}t[d+64|0]=h;v[22708]=0;t[d+432|0]=64;h=ac(d- -64|0,d+432|0);g=v[22708];v[22708]=0;if((g|0)==1){break la}u[((e<<5)+a|0)+480286>>1]=w[h|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}if(!Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break ja}e=Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ha}if(!e){break ja}e=0;if(!x[a+480188>>1]){break ia}while(1){v[22708]=0;h=T(707,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ka}la=((e<<5)+a|0)+480284|0,ma=(Lb(h,-16,16)<<3)+128|0,u[la>>1]=ma;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break ia}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}v[22708]=0;xh(a,1);e=v[22708];v[22708]=0;if((e|0)==1){break ha}}h=dd(d+128|0);e=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break aa}na:{if(!e){break na}e=Ib(w[q|0]|w[q+1|0]<<8);v[22708]=0;e=Q(191,b|0,e<<1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break aa}if(!e){break na}e=Ib(w[q|0]|w[q+1|0]<<8);v[22708]=0;e=W(708,b|0,h|0,e|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break aa}if(!e){break na}la=d,ma=Vb(h),v[la+120>>2]=ma;la=d,ma=Zb(h),v[la+112>>2]=ma;if(Gb(d+120|0,d+112|0)){while(1){e=v[d+120>>2];e=Ib(w[e|0]|w[e+1|0]<<8);oa:{if(Ib(w[d+158|0]|w[d+159|0]<<8)>>>0<e>>>0){break oa}g=Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[22708]=0;Q(190,b|0,g+(e<<2)|0)|0;e=v[22708];v[22708]=0;pa:{qa:{ra:{if((e|0)==1){break ra}v[22708]=0;e=T(426,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}v[22708]=0;e=Q(190,b|0,e|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}if(!e){break oa}v[22708]=0;e=Q(191,b|0,42)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}if(!e){break oa}v[22708]=0;R(709,b|0,d- -64|0);e=v[22708];v[22708]=0;sa:{if((e|0)!=1){if(cd(n)){break sa}v[22708]=0;R(710,n|0,65534);e=v[22708];v[22708]=0;if((e|0)!=1){break sa}}g=P()|0;O()|0;break W}e=Ib(w[d+104|0]|w[d+105|0]<<8);v[22708]=0;v[d+60>>2]=e;e=Q(191,b|0,e|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break qa}if(!e){v[22708]=0;e=T(467,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break qa}qc(d+60|0,e)}qc(d+60|0,65534);g=tc(n);v[22708]=0;R(711,n|0,g+v[d+60>>2]|0);e=v[22708];v[22708]=0;if((e|0)==1){break X}e=0;if(!v[d+60>>2]){break pa}while(1){ta:{v[22708]=0;l=T(416,b|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break ta}l=l<<16>>16;if((l|0)>=0){v[22708]=0;R(710,n|0,f+l&65535);l=v[22708];v[22708]=0;if((l|0)==1){break ta}}e=e+1|0;if(e>>>0<y[d+60>>2]){continue}break pa}break}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}if(w[d+64|0]){v[22708]=0;R(712,d+48|0,d- -64|0);e=v[22708];v[22708]=0;ua:{if((e|0)!=1){v[22708]=0;R(713,d+24|0,d+48|0);e=v[22708];v[22708]=0;if((e|0)!=1){break ua}}g=P()|0;O()|0;break W}v[22708]=0;U(13,d+432|0,2,d+24|0);e=v[22708];v[22708]=0;if((e|0)==1){break Z}v[22708]=0;R(418,n|0,d+432|0);e=v[22708];v[22708]=0;if((e|0)==1){break _}vb(d+432|0);vb(d+24|0)}if(!Xb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24))){break oa}e=Xb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break X}if(!e){break oa}while(1){va:{v[22708]=0;e=Q(714,b|0,d+48|0)|0;l=v[22708];v[22708]=0;wa:{xa:{if((l|0)!=1){if(!e){break oa}e=w[fa|0];v[22708]=0;U(288,d+24|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break xa}e=d+24|0;l=kc(d+432|0,e);xb(e);la=d,ma=Nv(Ib(w[d+48|0]|w[d+49|0]<<8)+g|0),u[la+24>>1]=ma;if((Ib(w[d+48|0]|w[d+49|0]<<8)|0)==65535){break va}e=x[d+24>>1];if(tc(n)>>>0>e>>>0){break wa}xb(d+432|0);break oa}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}ya:{if(w[F|0]==1){e=65535}else{if(w[F|0]!=2){break ya}v[22708]=0;e=T(416,l|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break $}v[22708]=0;l=Q(715,r|0,d+24|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break $}u[l>>1]=e;e=65534}la=sc(n,x[d+24>>1]),ma=e,u[la>>1]=ma}xb(d+432|0);continue}break}xb(d+432|0)}e=d+120|0;Qv(e);if(Gb(e,d+112|0)){continue}break}}k=c>>>(k>>>1&1)|0;Gr(h);break U}Gr(h);break T}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}nv(r);break d}g=P()|0;O()|0;break L}g=P()|0;O()|0;break W}g=P()|0;O()|0;xb(d+432|0);break W}g=P()|0;O()|0;vb(d+432|0);break Y}g=P()|0;O()|0}vb(d+24|0);break W}g=P()|0;O()|0}Gr(h);break L}v[22708]=0;xh(a,1);c=v[22708];v[22708]=0;za:{if((c|0)!=1){e=0;k=32;if(!x[a+480188>>1]){break U}while(1){t[d+144|0]=w[(d+e|0)+826|0];v[22708]=0;t[d+64|0]=64;c=ac(d+144|0,d- -64|0);h=v[22708];v[22708]=0;if((h|0)==1){break za}u[((e<<5)+a|0)+480286>>1]=w[c|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break U}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}e=w[d+823|0];A=w[d+823|0]&64;D=w[d+824|0]&32;G=(w[d+824|0]&31)+1|0;la=a,ma=dW(Ib(w[d+820|0]|w[d+821|0]<<8),A>>>6|0,D>>>5|0,G),v[la+480204>>2]=ma;la=a,ma=Fd(w[d+825|0],1,32),v[la+480196>>2]=ma;if(D){v[a+480216>>2]=G;v[a+480220>>2]=G<<2}Aa:{Ba:{if(w[d+842|0]){t[d+144|0]=w[d+842|0];v[22708]=0;t[d+64|0]=64;c=ac(d+144|0,d- -64|0);h=v[22708];v[22708]=0;if((h|0)==1){break Ba}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=k;v[a+480232>>2]=k;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+823|0]>>>4^-1)&2;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{if(!Xb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24))){break Na}c=Xb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24));v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ma}if(!c){break Na}c=Xb(w[d+528|0]|w[d+529|0]<<8|(w[d+530|0]<<16|w[d+531|0]<<24));v[22708]=0;W(413,b|0,z|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ma}if(w[V|0]<2){break Na}v[22708]=0;U(13,d+144|0,2,z|0);c=v[22708];v[22708]=0;if((c|0)==1){break La}v[22708]=0;R(418,n|0,d+144|0);c=v[22708];v[22708]=0;if((c|0)==1){break Ka}vb(d+144|0)}Oa:{if(Xb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))>>>0<2){break Oa}c=Xb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24));v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ma}if(!c){break Oa}c=Xb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24));v[22708]=0;da(509,E|0,b|0,c-1|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ma}}if(!Xb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24))){break Aa}c=Xb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24));v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ma}if(!c){break Aa}v[22708]=0;c=Q(191,b|0,12)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ma}if(!c){break Aa}v[22708]=0;Q(318,b|0,6)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ma}v[22708]=0;c=T(416,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ma}if((c|0)!=1){break Aa}v[22708]=0;c=T(426,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ia}if(!c){break Aa}v[22708]=0;h=Q(191,b|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Ia}if(h){break Ja}break Aa}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;vb(d+144|0);break L}Dc(d+144|0,E);v[22708]=0;da(509,E|0,b|0,c|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Da}if(!gd(d+144|0)){v[22708]=0;c=W(716,d+432|0,2,13)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ha}v[22708]=0;U(717,d- -64|0,d+144|0,c|0);h=v[22708];v[22708]=0;if((h|0)==1){break Ga}v[22708]=0;U(718,d+8|0,d- -64|0,E|0);h=v[22708];v[22708]=0;if((h|0)==1){break Fa}h=d+8|0;Eb(E,h);vb(h);vb(d- -64|0);vb(c)}vb(d+144|0);break Aa}g=P()|0;O()|0;break L}g=P()|0;O()|0;break Ca}g=P()|0;O()|0;break Ea}g=P()|0;O()|0;vb(d- -64|0)}vb(c);break Ca}g=P()|0;O()|0}vb(d+144|0);break L}g=P()|0;O()|0;break L}Pa:{if(m>>>0<2){break Pa}if(!Xb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24))){break Pa}m=0;if(!x[a+480188>>1]){break Pa}while(1){c=Xb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24));v[22708]=0;c=Q(190,b|0,c+(m<<2)|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break M}Qa:{if(!c){break Qa}v[22708]=0;c=T(426,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break M}v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break M}k=0;l=0;if(!c){break Qa}while(1){Ra:{v[22708]=0;c=Q(191,b|0,8)|0;h=v[22708];v[22708]=0;Sa:{Ta:{Ua:{if((h|0)!=1){if(!c){break Ra}v[22708]=0;R(719,b|0,d+144|0);c=v[22708];v[22708]=0;if((c|0)==1){break Ua}if(!Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))){break Ra}switch((Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))&536870911)-1|0){case 1:break Sa;case 0:break Ta;default:continue}}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}k=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));continue}l=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));continue}break}if(!k|!l){break Qa}v[22708]=0;c=Q(190,b|0,k|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break N}if(!c){break Qa}v[22708]=0;W(571,b|0,((m<<5)+a|0)+480289|0,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break N}}m=m+1|0;if(m>>>0<x[a+480188>>1]){continue}break}}l=Ib(w[d+560|0]|w[d+561|0]<<8);v[22708]=0;c=f+l|0;R(330,s|0,c&65535);h=v[22708];v[22708]=0;if((h|0)==1){break S}if(l){ga=e&16;ia=f&65535;k=0;while(1){Va:{if(!ca){break Va}e=Xb(w[d+888|0]|w[d+889|0]<<8|(w[d+890|0]<<16|w[d+891|0]<<24));v[22708]=0;e=Q(190,b|0,e+(k<<2)|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break R}if(!e){break Va}v[22708]=0;e=T(426,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break R}v[22708]=0;e=Q(190,b|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break R}if(!e){break Va}H=Kb(d+128|0);v[22708]=0;$=T(215,d- -64|0)|0;e=v[22708];v[22708]=0;Wa:{Xa:{if((e|0)!=1){h=w[d+871|0];if(h){break Xa}v[22708]=0;R(720,b|0,d+144|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}u[d+120>>1]=w[d+144|0];p=w[ea|0]+1|0;e=48;break Wa}g=P()|0;O()|0;break O}g=t[d+822|0];v[22708]=0;R(721,b|0,d+48|0);e=v[22708];v[22708]=0;Ya:{Za:{if((e|0)!=1){la=d,ma=Ib(w[d+48|0]|w[d+49|0]<<8),u[la+120>>1]=ma;p=Ib(w[F|0]|w[F+1|0]<<8)+1|0;e=i;if(!Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break Ya}m=v[b+8>>2];e=Xb(w[i|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22708]=0;Q(190,b|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}v[22708]=0;R(722,b|0,d+144|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}e=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}if(!e){break Za}e=Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22708]=0;W(413,b|0,H|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Za}break P}break P}_a:{if(!Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break _a}e=Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}if(!e){break _a}v[22708]=0;e=T(426,b|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}v[22708]=0;e=Q(190,b|0,e|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}if(!e){break _a}v[22708]=0;U(288,d+24|0,b|0,B(x[d+120>>1],p)|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}e=d+432|0;o=d+24|0;Vc($,kc(e,o));xb(e);xb(o)}v[22708]=0;Q(190,b|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}}e=g+(h>>>0<3?48:24)|0}v[22708]=0;g=k+ia|0;m=W(331,s|0,g&65535,p|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}h=e;if(m){aa=_b(s,g);v[22708]=0;Q(428,aa|0,H|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}yg(d+120|0,x[a+480188>>1]);o=0;while(1){v[22708]=0;e=Yc(aa,o,0);g=v[22708];v[22708]=0;$a:{ab:{if((g|0)!=1){m=0;if(x[d+120>>1]){break ab}break $a}break P}while(1){bb:{if(!w[d+871|0]){v[22708]=0;R(723,d+144|0,b|0);g=v[22708];v[22708]=0;if((g|0)!=1){g=d+144|0;I=qd(g);_=Ve(g);g=w[g|0];t[e+1|0]=g>>>3&16|w[I|0]>>>4|g>>>1&32;t[e+3|0]=w[I|0]&15;t[e+5|0]=w[_|0];g=g&63;g=g?g+h|0:0;break bb}break P}v[22708]=0;R(531,d+144|0,b|0);g=v[22708];v[22708]=0;cb:{db:{if((g|0)!=1){g=d+144|0;I=qd(g);_=Ve(g);ja=fj(g);v[22708]=0;M=T(374,$|0)|0;ka=v[22708];v[22708]=0;if((ka|0)==1){break P}t[e+4|0]=M;M=w[g|0];g=M&127;if(!g){break db}g=g+h|0;break cb}break P}g=0;if((M|0)!=128){break cb}t[e|0]=254}t[e+1|0]=w[I|0]&63;t[e+3|0]=w[_|0];t[e+5|0]=w[ja|0]}if(g-1>>>0<=119){t[e|0]=g}v[22708]=0;ha(724,e|0,(A|0)!=0|0,(D|0)!=0|0,G|0,(ga|0)!=0|0);I=v[22708];v[22708]=0;if((I|0)!=1){C=(g|0)>84&X|C;e=e+6|0;m=m+1|0;if(x[d+120>>1]<=(m&65535)>>>0){break $a}continue}break}break P}o=o+1|0;if((p|0)!=(o|0)){continue}break}}xb(d- -64|0);vb(H)}k=k+1|0;if((l|0)!=(k|0)){continue}break}}la=d,ma=nr(r),v[la+64>>2]=ma;la=d,ma=Dh(r),v[la+432>>2]=ma;eb:{fb:{gb:{if(og(d- -64|0,d+432|0)){while(1){e=Xl(d- -64|0);c=e;h=Ve(e);hb:{ib:{jb:{e=x[e>>1];if(!e){e=0;break jb}v[22708]=0;g=Q(472,n|0,e-1&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break gb}e=x[c>>1];if(!g){break jb}v[22708]=0;e=Q(545,n|0,e-1&65535)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break ib}break gb}if(x[h>>1]==((e&65535)+1|0)){break hb}v[22708]=0;e=W(544,s|0,1,0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break gb}if((e|0)==65535){break hb}la=sc(n,x[c>>1]),ma=e,u[la>>1]=ma}c=_b(s,e);h=Fv(x[h>>1]);v[22708]=0;h=Be(d+144|0,12,h);g=v[22708];v[22708]=0;if((g|0)==1){break fb}h=pp(Ue(h,v[_b(s,e)+12>>2]-1|0));v[22708]=0;Q(431,c|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break fb}l=(l&65535)>>>0>e>>>0?l:e+1|0}c=d- -64|0;Sj(c);if(og(c,d+432|0)){continue}break}c=f+l|0}if(!Xb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))){break eb}f=Xb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24));v[22708]=0;f=Q(190,b|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break S}if(!f){break eb}f=c;break T}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}nv(r);break Q}nv(r);Z=Z+1|0;if(w[V|0]>(Z&255)>>>0){continue}break Q}break}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}v[22708]=0;Si(K,0);b=v[22708];v[22708]=0;if((b|0)!=1){if(!(C&1)){m=x[a+480192>>1];if(m){e=1;while(1){b=(((e&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Yb(pv(c));m=x[a+480192>>1]}v[b>>2]=0;e=e+1|0;if((e&65535)>>>0<=(m&65535)>>>0){continue}break}}u[a+480192>>1]=0}kb:{lb:{mb:{nb:{ob:{pb:{qb:{if(ba){v[22708]=0;b=Q(2,d+144|0,13467)|0;c=v[22708];v[22708]=0;if((c|0)==1){break qb}v[22708]=0;U(560,a|0,2,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break pb}vb(b)}g=18726;switch(w[d+871|0]){case 3:break lb;case 2:break mb;case 1:break nb;case 0:break ob;default:break kb}}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(b);break f}g=x[a+480188>>1]>4?14339:14325;break kb}g=14307;break kb}g=14289;break kb}g=14262}v[22708]=0;R(725,d- -64|0,13877);b=v[22708];v[22708]=0;rb:{sb:{tb:{if((b|0)!=1){v[22708]=0;U(726,d+144|0,d- -64|0,d+871|0);b=v[22708];v[22708]=0;if((b|0)==1){break tb}b=d+144|0;Eb(a+1298304|0,b);vb(b);Hb(d- -64|0);v[22708]=0;b=Q(2,b|0,9953)|0;c=v[22708];v[22708]=0;if((c|0)==1){break sb}Eb(a+1298316|0,b);vb(b);v[22708]=0;Q(157,a+1298328|0,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break rb}v[a+1298364>>2]=2;e=1;break c}g=P()|0;O()|0;break f}g=P()|0;O()|0;Hb(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;xb(d- -64|0)}vb(H);break L}g=P()|0;O()|0;break L}g=P()|0;O()|0}nv(r);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;xb(d+144|0)}ci(J)}xb(N);S(g|0);L()}e=0}ci(J)}xb(N)}gb=d+928|0;return e|0}function rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;f=gb-1728|0;gb=f;vc(b);h=gb-32|0;gb=h;e=h+24|0;i=f+1600|0;fV(e,i);g=yb(e);e=v[h+28>>2];l=v[h+24>>2];v[h+8>>2]=l;v[h+12>>2]=e;v[h>>2]=l;v[h+4>>2]=e;l=h+16|0;e=b;cc(l,e,h);l=yb(l);if((l|0)==(g|0)){Rb(e,yb(h+24|0))}gb=h+32|0;e=(g|0)==(l|0);if(!e){eV(i)}a:{if(!e){break a}if(!iV(f+1600|0)){break a}if(!Pb(b,Qc(256,0))){break a}b:{if(!c){break b}Hd(a,1048576);Ag(a);d=gb-16|0;gb=d;e=Tb(d,1339);Dc(f+1344|0,e);vb(e);gb=d+16|0;q=f+1608|0;v[f+160>>2]=w[q+1|0];d=w[q|0];v[22708]=0;v[f+16>>2]=d;R(599,f+88|0,f+16|0);d=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){v[22708]=0;Y(582,f+240|0,f+1344|0,f+160|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}d=f+240|0;Eb(a+1298304|0,d);vb(d);e=f+88|0;vb(e);h=f+1344|0;Hb(h);g=Tb(d,12318);Eb(a+1298316|0,g);vb(g);Je(e,2,f+1610|0);Bc(h,e);v[22708]=0;U(13,d|0,8,h|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}d=f+240|0;Eb(a+1298328|0,d);vb(d);e=f+1344|0;vb(e);v[a+1298364>>2]=8;Fr(e,2,f+1642|0);Bc(d,e);Eb(a+1298268|0,d);vb(d);h=f+1712|0;u[a+480188>>1]=w[h|0]|w[h+1|0]<<8;h=Fd(w[f+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=h;A=f+1722|0;u[a+480192>>1]=w[A|0]|w[A+1|0]<<8;C=f+1724|0;u[a+480190>>1]=w[C|0]|w[C+1|0]<<8;h=Fd(w[f+1717|0],1,32);v[a+480216>>2]=h;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=h<<2;kw(b,e);D=a+484360|0;m=f+1706|0;Tr(Sb(D),e,w[m|0]|w[m+1|0]<<8,65535,65535);e=f+1708|0;cf(Sb(D),w[e|0]|w[e+1|0]<<8);Sd(d,b,Ng(b));I=kc(f+1320|0,d);xb(d);v[22708]=0;d=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break m}v[22708]=0;U(288,f+240|0,b|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}d=f+240|0;G=kc(f+1296|0,d);xb(d);F=x[a+480188>>1];v[22708]=0;E=Q(191,I|0,274)|0;d=v[22708];v[22708]=0;if((d|0)==1){break l}if(E){u[a+480188>>1]=x[a+480188>>1]+8}H=c&1;if(!H){break k}d=f+1710|0;d=w[d|0]|w[d+1|0]<<8;v[22708]=0;R(330,a+484344|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){break k}g=P()|0;O()|0;break e}g=P()|0;O()|0;break n}g=P()|0;O()|0;vb(f+88|0)}Hb(f+1344|0);break c}g=P()|0;O()|0;break d}g=P()|0;O()|0;break e}n=a+484344|0;o=f+1718|0;l=f+1710|0;if(!(w[l|0]|w[l+1|0]<<8)){g=0;break f}g=0;while(1){v[22708]=0;d=T(287,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}v[f+160>>2]=d;v[22708]=0;d=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}v[22708]=0;U(288,f+88|0,b|0,d+1&-2);d=v[22708];v[22708]=0;if((d|0)==1){break h}d=f+88|0;p=kc(f+240|0,d);xb(d);qc(f+160|0,1024);d=v[f+160>>2];p:{if(!d|!H){break p}v[22708]=0;d=W(331,n|0,r&65535,d|0)|0;e=v[22708];v[22708]=0;q:{if((e|0)!=1){if(!d){break p}j=0;if(t[o|0]&1){i=0;while(1){v[22708]=0;d=Q(191,f+240|0,1)|0;e=v[22708];v[22708]=0;r:{if((e|0)!=1){if(!d){break p}v[22708]=0;d=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}s=0;if((d|0)!=255){break r}v[22708]=0;s=T(374,p|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;d=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break r}}break i}break i}s:{if(!(d&127)){break s}e=_b(n,r);v[22708]=0;h=Yc(e,i,j&65535);e=v[22708];v[22708]=0;if((e|0)==1){break i}Uv(f+88|0);if(d&1){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+88|0]=e}if(d&2){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+89|0]=e}if(d&4){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+90|0]=e}if(d&8){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+91|0]=e}if(d&16){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+92|0]=e}if(d&32){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+93|0]=e}if(d&64){v[22708]=0;d=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}t[f+94|0]=d}v[22708]=0;d=Q(790,h|0,f+88|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}v[f+16>>2]=s;v[22708]=0;v[f+64>>2]=v[f+160>>2]+(i^-1);k=Fb(f+16|0,f- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break i}g=d|g;e=0;d=h;J=v[k>>2];if(!J){break s}while(1){d=B(x[a+480188>>1],6)+d|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;k=w[h+4|0]|w[h+5|0]<<8;t[d+4|0]=k;t[d+5|0]=k>>>8;e=e+1|0;if((J|0)!=(e|0)){continue}break}}i=(i+s|0)+1|0;d=v[f+160>>2];if(i>>>0>=d>>>0){while(1){j=j+1|0;i=i-d|0;if(d>>>0<=i>>>0){continue}break}}if(F>>>0>(j&65535)>>>0){continue}break}break p}e=0;if(v[f+160>>2]){break q}break p}break i}while(1){d=_b(n,r);v[22708]=0;h=Tf(d,e);d=v[22708];v[22708]=0;t:{u:{if((d|0)!=1){d=0;if(F){break u}break t}break i}while(1){v:{v[22708]=0;R(791,p|0,f+88|0);i=v[22708];v[22708]=0;if((i|0)==1){break v}v[22708]=0;i=Q(790,h+B(d,6)|0,f+88|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}g=g|i;d=d+1|0;if((F|0)!=(d|0)){continue}break t}break}break i}e=e+1|0;if(e>>>0<y[f+160>>2]){continue}break}}xb(f+240|0);r=r+1|0;if(r>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break f}g=P()|0;O()|0;vb(f+1344|0);break c}g=P()|0;O()|0;xb(f+240|0);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}d=f+1714|0;e=w[d+1|0]<<8;if(!((w[d|0]|e)>>>0<=1|(e|w[d|0])>>>0>4999)){w:{if(g&1){i=0;d=w[d|0]|w[d+1|0]<<8;d=Ac(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break w}i=2;z=2646e3/+(B(B(v[a+480216>>2],v[a+480196>>2]),w[d|0]|w[d+1|0]<<8)>>>0)*1e4;x:{if(z<4294967296&z>=0){d=~~z>>>0;break x}d=0}}t[a+480224|0]=i;v[a+480204>>2]=d}d=x[a+480188>>1];v[22708]=0;t[f+240|0]=0;p=W(792,f+1280|0,d|0,f+240|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){i=a+1298280|0;r=a+1298292|0;k=f+240|3;s=0;y:{z:{A:{B:{C:{while(1){v[22708]=0;d=Q(191,G|0,8)|0;e=v[22708];v[22708]=0;D:{if((e|0)!=1){if(d){break D}if(x[a+480188>>1]){d=0;while(1){e=t[lc(p,d)|0];E:{if((e|0)<=(d|0)|(e|0)>=x[a+480188>>1]){break E}h=((e<<5)+a|0)+480288|0;e=w[h|0];if(!e){break E}g=((d<<5)+a|0)+480288|0;i=w[g|0];if(!i){t[g|0]=e;break E}g=(B(i-1&255,160)+a|0)+906300|0;if((Vk(g)|0)!=255){while(1){g=(B(Vk(g),160)+a|0)+906300|0;if((Vk(g)|0)!=255){continue}break}}e=g+28|0;h=w[h|0]-1&255;h=h>>>0<250?h+128|0:0;t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[f+232>>2]=0;v[f+236>>2]=0;v[f+224>>2]=0;v[f+228>>2]=0;v[f+216>>2]=0;v[f+220>>2]=0;v[f+208>>2]=0;v[f+212>>2]=0;F:{G:{H:{I:{J:{K:{if(E){v[22708]=0;R(793,I|0,f+240|0);d=v[22708];v[22708]=0;L:{if((d|0)!=1){g=0;while(1){d=x[a+480192>>1];v[22708]=0;d=GO(a,d+1&65535);e=v[22708];v[22708]=0;M:{N:{O:{P:{Q:{R:{S:{if((e|0)!=1){e=g<<1;h=e+(f+224|0)|0;u[h>>1]=d;j=e+(f+208|0)|0;e=f+e|0;i=e+242|0;u[j>>1]=w[i|0]|w[i+1|0]<<8;if((d|0)==65535){break N}e=w[e+242|0]|w[e+243|0]<<8;v[22708]=0;d=W(376,a|0,d|0,e+1&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break S}if(!d){break M}v[22708]=0;R(441,f+160|0,1571);e=v[22708];v[22708]=0;if((e|0)==1){break R}v[22708]=0;v[f+16>>2]=g+1;U(795,f+88|0,f+160|0,f+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break Q}v[22708]=0;Q(301,d+492|0,f+88|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break P}vb(f+88|0);Hb(f+160|0);break M}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break O}g=P()|0;O()|0;vb(f+88|0)}Hb(f+160|0);break y}u[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break L}g=P()|0;O()|0;break y}e=w[f+240|0]|w[f+241|0]<<8;d=0;v[22708]=0;r=Q(328,f+16|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break F}if(w[f+240|0]|w[f+241|0]<<8){while(1){v[22708]=0;e=T(287,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break H}v[22708]=0;U(288,f+160|0,b|0,e<<5);e=v[22708];v[22708]=0;if((e|0)==1){break I}e=f+88|0;h=f+160|0;g=kc(e,h);Vc(Kg(r,d),g);xb(e);xb(h);d=d+1|0;if(d>>>0<(w[f+240|0]|w[f+241|0]<<8)>>>0){continue}break}}d=w[l|0]|w[l+1|0]<<8;h=0;v[22708]=0;j=W(796,f+88|0,d|0,33236)|0;d=v[22708];v[22708]=0;if((d|0)==1){break J}if(w[m|0]|w[m+1|0]<<8){while(1){g=f+h|0;T:{if(w[g+258|0]>=(w[f+240|0]|w[f+241|0]<<8)>>>0){break T}if(x[sc(Sb(D),h)>>1]>=(w[l|0]|w[l+1|0]<<8)>>>0){break T}e=x[sc(Sb(D),h)>>1];U:{if(x[sc(j,e)>>1]==65535){d=w[g+258|0];K=sc(j,e),M=d,u[K>>1]=M;break U}if(x[sc(j,e)>>1]==w[g+258|0]){break U}v[22708]=0;d=W(797,n|0,e|0,0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break K}if((d|0)==65535){break U}K=sc(Sb(D),h),M=d,u[K>>1]=M;e=d}v[22708]=0;d=me(n,e);i=v[22708];v[22708]=0;if((i|0)==1){break K}if(!d){break T}E=Kg(r,w[g+258|0]);vc(E);v[22708]=0;d=T(195,E|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break K}if(!v[_b(n,e)+12>>2]){break T}H=d>>>5|0;i=0;while(1){d=_b(n,e);g=x[a+480188>>1];v[22708]=0;d=Yc(d,i,g-8&65535);g=v[22708];v[22708]=0;if((g|0)==1){break K}g=0;while(1){hi(f+160|0);k=x[f+164>>1];t[d+4|0]=k;t[d+5|0]=k>>>8;k=v[f+160>>2];t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;V:{if(i>>>0>=H>>>0){break V}v[22708]=0;Q(798,E|0,f+160|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break K}if(t[f+160|0]>-1){break V}t[d|0]=61;t[d+1|0]=w[(f+224|0)+(g<<1)|0];k=w[f+160|0]&31;t[f+64|0]=k;if(k){zf(f- -64|0,15);t[d+3|0]=20;t[d+5|0]=w[f+64|0]|208}t[d+2|0]=1;t[d+4|0]=w[f+161|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}i=i+1|0;if(i>>>0<y[_b(n,e)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}}Ze(j);jd(r)}if(!(!(w[o|0]&2)|!(w[l|0]|w[l+1|0]<<8))){i=0;d=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);e=(((d&8?x[a+480188>>1]:F)&65535)+((w[q|0]|w[q+1|0]<<8)>>>0>591?s:0)|0)+(d>>>4&1)|0;while(1){d=0;W:{if(!e){break W}while(1){X:{v[22708]=0;h=Q(191,b|0,4)|0;g=v[22708];v[22708]=0;if((g|0)==1){break X}if(!h){break W}h=w[q|0]|w[q+1|0]<<8;v[22708]=0;R(799,h|0,b|0);h=v[22708];v[22708]=0;if((h|0)==1){break X}d=d+1|0;if((e|0)!=(d|0)){continue}break W}break}g=P()|0;O()|0;break y}i=i+1|0;if(i>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}}v[22708]=0;l=Q(328,f+192|0,255)|0;d=v[22708];v[22708]=0;Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){d=f+88|0;r=d|7;D=d|1;F=d|4;s=d|2;k=d|3;h=0;while(1){d=h;v[22708]=0;R(800,b|0,f+160|0);e=v[22708];v[22708]=0;ca:{da:{ea:{fa:{if((e|0)!=1){v[22708]=0;e=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break fa}h=w[q|0]|w[q+1|0]<<8;v[22708]=0;e=(e|0)==32?428:e;e=h>>>0>513?e?e+4|0:e:e;U(288,f+88|0,b|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break ea}h=d+1|0;g=f+240|0;i=f+88|0;j=kc(g,i);j=le(f+16|0,Vc(Kg(l,d),j));xb(g);xb(i);if(d>>>0>=(w[A|0]|w[A+1|0]<<8)>>>0){break ca}v[22708]=0;d=h&65535;g=W(376,a|0,d|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break da}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}if(!g){break ca}v[22708]=0;Je(f+88|0,2,f+160|0);d=v[22708];v[22708]=0;ga:{ha:{ia:{if((d|0)==1){break ia}v[22708]=0;R(324,f+240|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break ia}v[22708]=0;Q(301,g+492|0,f+240|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ha}vb(f+240|0);if(!e){break ca}v[22708]=0;R(801,j|0,f+240|0);d=v[22708];v[22708]=0;if((d|0)==1){break $}n=0;if((w[q|0]|w[q+1|0]<<8)>>>0<513){break ga}v[22708]=0;n=T(287,j|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break ga}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;vb(f+240|0);break Z}i=3;ja:{if((w[q|0]|w[q+1|0]<<8)>>>0<514){break ja}v[22708]=0;i=T(192,j|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break ja}g=P()|0;O()|0;break Z}v[g>>2]=w[f+342|0]|w[f+343|0]<<8;t[g+16|0]=w[((w[f+344|0]|w[f+345|0]<<8)&3)+33238|0];t[g+17|0]=w[(w[f+345|0]&3)+33238|0];t[g+18|0]=w[((w[f+344|0]|w[f+345|0]<<8)>>>12&3)+33242|0];o=0;ka:{la:{ma:{na:{while(1){oa:{if(!(i&1)){break oa}v[22708]=0;R(802,j|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break na}v[22708]=0;e=ki(g,w[o+33246|0]);d=v[22708];v[22708]=0;if((d|0)==1){break ma}d=e;if((o|0)!=3){m=w[e+12|0]&-17}else{m=w[e+12|0]&-17|w[f+88|0]<<4&16}t[d+12|0]=m;t[e+12|0]=w[e+12|0]&254|t[f+88|0]&1;t[e+12|0]=w[e+12|0]&251|w[f+88|0]<<1&4;t[e+12|0]=w[e+12|0]&253|w[f+88|0]>>>1&2;t[f+64|0]=w[D|0];v[22708]=0;t[f+48|0]=16;d=ac(f- -64|0,f+48|0);m=v[22708];v[22708]=0;if((m|0)==1){break la}d=w[d|0];v[22708]=0;R(446,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break la}d=w[s|0];t[e+15|0]=d;t[e+16|0]=d;t[e+13|0]=w[k|0];t[e+14|0]=w[F|0];d=0;if(!Nb(e)){break oa}while(1){m=(f+88|0)+(d<<2)|0;E=w[m+8|0]|w[m+9|0]<<8;K=Mb(e,d),M=E,u[K>>1]=M;m=Fd(w[m+10|0]|w[m+11|0]<<8,0,64);K=Mb(e,d),M=m,t[K+2|0]=M;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}i=i>>>1|0;o=o+1|0;if((o|0)!=4){continue}break}if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}v[22708]=0;hm(g,127,1);d=v[22708];v[22708]=0;if((d|0)==1){break ba}v[22708]=0;gm(g,0,1);d=v[22708];v[22708]=0;if((d|0)==1){break ba}if(!n){break ca}v[22708]=0;R(805,j|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break _}if(!(n&2)){break ka}d=w[s|0]|w[s+1|0]<<8;v[22708]=0;d=BA(a,+(d>>>0));e=v[22708];v[22708]=0;if((e|0)==1){break _}v[22708]=0;hm(g,d,1);d=v[22708];v[22708]=0;if((d|0)==1){break _}d=w[F|0];v[22708]=0;gm(g,d,1);d=v[22708];v[22708]=0;if((d|0)!=1){break ka}break _}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}t[g+25|0]=w[D|0]==1;if(!(n&4)){break ca}t[g+31|0]=w[r|0]+1;t[g+34|0]=w[f+96|0]+1;if(t[f+96|0]<=-1){t[g+30|0]=w[f+103|0]+1}if(w[f+100|0]){d=0;i=g+108|0;while(1){e=d+1|0;v[f+64>>2]=e+t[f+100|0];gV(f- -64|0);j=v[f+64>>2];K=ic(i,d),M=j,t[K|0]=M;d=e;if(d>>>0<128){continue}break}}v[22708]=0;or(g,0);d=v[22708];v[22708]=0;if((d|0)==1){break _}}xb(f+16|0);if((h|0)!=255){continue}break}q=YB(f+88|0);h=f+16|4;n=YB(f+160|0);g=0;pa:{qa:{while(1){v[22708]=0;R(800,b|0,f+240|0);d=v[22708];v[22708]=0;if((d|0)==1){break pa}v[22708]=0;d=T(192,b|0)|0;e=v[22708];v[22708]=0;ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{if((e|0)!=1){v[22708]=0;U(288,f+16|0,b|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break ya}e=f+16|0;i=kc(f- -64|0,e);xb(e);if((w[C|0]|w[C+1|0]<<8)>>>0>g>>>0){v[22708]=0;Je(f+48|0,2,f+240|0);e=v[22708];v[22708]=0;if((e|0)==1){break ra}v[22708]=0;R(324,f+16|0,f+48|0);e=v[22708];v[22708]=0;if((e|0)==1){break ra}v[22708]=0;Q(301,((g<<5)+a|0)+946336|0,f+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break xa}vb(f+16|0)}if(!d|(w[C|0]|w[C+1|0]<<8)>>>0<=g>>>0){break sa}v[22708]=0;d=B(g+1|0,104)+a|0;e=d+484380|0;R(424,e|0,32);j=v[22708];v[22708]=0;if((j|0)==1){break wa}v[22708]=0;R(807,i|0,f+16|0);i=v[22708];v[22708]=0;if((i|0)==1){break va}v[e>>2]=w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24);v[d+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[f+24|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|1;v[e>>2]=v[e>>2]>>>1}if(w[f+25|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=v[e>>2]>>>1}i=2;za:{if(w[f+27|0]!=1){i=6;if(w[f+27|0]!=2){break za}}e=d+484414|0;u[e>>1]=x[e>>1]|i}v[d+484384>>2]=w[f+28|0]|w[f+29|0]<<8|(w[f+30|0]<<16|w[f+31|0]<<24);v[d+484388>>2]=w[f+32|0]|w[f+33|0]<<8|(w[f+34|0]<<16|w[f+35|0]<<24);u[d+484410>>1]=(w[f+36|0]|w[f+37|0]<<8)>>>7;if(w[f+38|0]!=128){break ua}e=d+484414|0;j=x[e>>1]|256;u[e>>1]=j;break ta}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;vb(f+16|0);break qa}g=P()|0;O()|0;break qa}g=P()|0;O()|0;break qa}u[d+484408>>1]=t[f+38|0]+128;j=x[d+484414>>1]}e=d+484414|0;u[e>>1]=j|32;t[d+484416|0]=w[f+39|0];if(w[f+26|0]&2){d=f+48|0;Db(d,n,g);dr(d)}if(w[f+26|0]&5){u[e>>1]=x[e>>1]|16384}if(!(w[f+26|0]&8)){break sa}d=f+48|0;Db(d,q,g);dr(d);d=0;while(1){e=d<<1;Aa:{if(x[e+(f+208|0)>>1]!=(g|0)){break Aa}e=v[((x[e+(f+224|0)>>1]<<2)+a|0)+900380>>2];if(!e){break Aa}t[e+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}xb(f- -64|0);g=g+1|0;if((g|0)==256){break aa}continue}break}g=P()|0;O()|0}xb(f- -64|0);break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break Z}Ba:{if(!(w[A|0]|w[A+1|0]<<8)){break Ba}i=0;Ca:{Da:{while(1){Ea:{d=Kg(l,i);v[22708]=0;d=T(195,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ea}Fa:{if(!d){i=i+1|0;break Fa}d=Kg(l,i);vc(d);v[22708]=0;R(801,d|0,f+240|0);d=v[22708];v[22708]=0;if((d|0)==1){break Da}j=dd(f+16|0);d=w[f+240|0]|w[f+241|0]<<8;v[22708]=0;U(808,b|0,j|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break Ca}i=i+1|0;e=v[((i<<2)+a|0)+900380>>2];if(!(!e|w[e+34|0])){v[e+4>>2]=32;v[22708]=0;or(e,0);d=v[22708];v[22708]=0;if((d|0)==1){break Ca}s=e+108|0;C=e+236|0;d=0;while(1){h=d+f|0;Ga:{if(w[h+242|0]>=(w[f+240|0]|w[f+241|0]<<8)>>>0){break Ga}o=ye(j,w[h+242|0]);h=w[o|0];g=h+1|0;m=d+12|0;K=vd(C,m),M=g,u[K>>1]=M;if(h>>>0>=x[a+480190>>1]){break Ga}h=B(g,104)+a|0;t[h+484418|0]=w[f+338|0]&3;t[h+484419|0]=w[f+339|0];t[h+484420|0]=w[f+340|0];t[h+484421|0]=w[f+341|0];u[h+484412>>1]=w[o+1|0]<<1;t[h+484417|0]=w[o+2|0];h=f- -64|0;g=g-1|0;Db(h,q,g);if(Cb(h)){t[e+14|0]=0}h=f- -64|0;Db(h,n,g);if(!Cb(h)){break Ga}K=ic(s,m),M=61,t[K|0]=M}d=d+1|0;if((d|0)!=96){continue}break}}ms(j)}if((w[A|0]|w[A+1|0]<<8)>>>0>i>>>0){continue}break Ba}break}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;ms(j);break Y}Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(!(c&2)|!x[a+480190>>1])){g=0;while(1){g=g+1|0;d=B(g,104)+a|0;c=d+484416|0;e=t[c|0];h=d+484417|0;i=t[h|0];v[22708]=0;j=d+484380|0;Po(j,(+(e-49|0)+ +(i|0)*-.0078125)/-12);e=v[22708];v[22708]=0;if((e|0)==1){break Ha}t[h|0]=0;t[c|0]=0;c=x[d+484414>>1];Ra:{if(!(c&16384)){c=Rc(f+240|0,c&1?16:8,c&64?3:1,0,11);v[22708]=0;W(329,c|0,j|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break Ra}g=P()|0;O()|0;break Y}v[22708]=0;e=T(192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Qa}v[22708]=0;Q(318,b|0,12)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Qa}c=Kb(f+240|0);v[22708]=0;W(413,b|0,c|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Pa}v[22708]=0;Q(303,d+484423|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break Pa}v[22708]=0;R(581,f- -64|0,13514);d=v[22708];v[22708]=0;if((d|0)==1){break Oa}v[f+12>>2]=g;d=Jk(a);v[22708]=0;U(13,f+48|0,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break Na}v[22708]=0;Y(582,f+16|0,f- -64|0,f+12|0,f+48|0);d=v[22708];v[22708]=0;if((d|0)==1){break Ma}v[22708]=0;U(560,a|0,2,f+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break La}vb(f+16|0);vb(f+48|0);Hb(f- -64|0);vb(c)}if(x[a+480190>>1]>g>>>0){continue}break}}jd(l);gc(p);xb(G);xb(I);break b}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ja}g=P()|0;O()|0;break Ka}g=P()|0;O()|0;vb(f+16|0)}vb(f+48|0)}Hb(f- -64|0)}vb(c);break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Z}g=P()|0;O()|0}xb(f+16|0)}jd(l);break y}g=P()|0;O()|0;Ze(j);break G}g=P()|0;O()|0;break G}g=P()|0;O()|0;break G}g=P()|0;O()|0}jd(r);break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}v[22708]=0;e=T(192,G|0)|0;h=v[22708];v[22708]=0;d=a;Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{if((h|0)!=1){v[22708]=0;h=T(192,G|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break eb}v[22708]=0;U(288,f+240|0,G|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break eb}j=f+240|0;h=kc(f+88|0,j);xb(j);if((e|0)<=844387157){if((e|0)==4674381){break Wa}if((e|0)==5068115){break Va}if(g&1|(e|0)!=726487106){break Ta}t[a+480224|0]=2;v[22708]=0;z=+pa(810,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break Sa}if(!(z>1e-8)){break Ta}z=2646e3/(z*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4;if(!(z<4294967296&z>=0)){break db}e=~~z>>>0;break cb}if((e|0)<=1314144591){if((e|0)==844387158){break Ua}if((e|0)!=1280004692){break Ta}j=0;if(!x[a+480188>>1]){break Ta}while(1){v[22708]=0;d=Q(191,f+88|0,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break B}if(!d){break Ta}d=Kb(f+240|0);v[22708]=0;W(533,h|0,d|0,-1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ab}e=Jb(d);H=Ab(d);v[22708]=0;Xe(f+16|0,3,e,H);e=v[22708];v[22708]=0;if((e|0)==1){break $a}v[22708]=0;R(324,f+160|0,f+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break $a}v[22708]=0;Q(399,((j<<5)+a|0)+480289|0,f+160|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break _a}vb(f+160|0);vb(d);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break Ta}if((e|0)==1397445204){break bb}if((e|0)!=1314144592){break Ta}d=0;if(!(w[l|0]|w[l+1|0]<<8)){break Ta}while(1){v[22708]=0;e=Q(191,f+88|0,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break Ya}if(!e){break Ta}v[22708]=0;e=cm(n,d&65535);j=v[22708];v[22708]=0;if((j|0)==1){break Ya}if(!e){break Ta}e=Kb(f+240|0);v[22708]=0;W(533,h|0,e|0,-1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break Xa}j=_b(n,d);v[22708]=0;Q(428,j|0,e|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break Xa}vb(e);d=d+1|0;if(d>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break Ta}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}e=0}v[d+480204>>2]=e;break Ta}v[22708]=0;d=T(287,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[a+480232>>2]=d>>>9;v[a+480228>>2]=d>>>8;d=0;if(!x[a+480188>>1]){break Ta}while(1){v[22708]=0;e=Q(812,h|0,f+240|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break C}if(e){u[((d<<5)+a|0)+480286>>1]=(w[f+240|0]|w[f+241|0]<<8)>>>10;e=w[k|0];K=lc(p,d),M=e,t[K|0]=M}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break Ta}g=P()|0;O()|0;break Za}g=P()|0;O()|0;break Za}g=P()|0;O()|0;vb(f+160|0)}vb(d);break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;vb(e);break z}v[22708]=0;Q(318,f+88|0,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break A}v[22708]=0;d=T(467,f+88|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;da(509,r|0,h|0,d|0,2)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break Ta}break A}v[22708]=0;Q(813,h|0,f+16|0)|0;d=v[22708];v[22708]=0;fb:{if((d|0)!=1){d=Kb(f+240|0);v[22708]=0;W(533,h|0,d|0,-1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break fb}if(wr(d,9889)){v[22708]=0;U(13,f+160|0,8,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break fb}e=f+160|0;Eb(i,e);vb(e)}vb(d);break Ta}g=P()|0;O()|0;break z}g=P()|0;O()|0;vb(d);break z}v[22708]=0;s=T(192,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break A}}xb(f+88|0);continue}break}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0}xb(f+88|0)}gc(p);break e}g=P()|0;O()|0}xb(G)}xb(I)}S(g|0);L()}d=1}gb=f+1728|0;return d|0}function Cg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,D=0,E=0,F=0;e=gb-2736|0;gb=e;a:{b:{c:{d:{e:{f:{if(ds(c)){qc(b,268435456);D=v[c+8>>2];p=e+2712|0;d=p;v[d>>2]=0;v[d+4>>2]=0;mc(d+8|0);v[e+2708>>2]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{f=e;q:{r:{s:{t:{if(w[a+3|0]-4>>>0<=4){v[22708]=0;d=T(467,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}v[e+2708>>2]=d;break t}d=w[a+3|0];if(d>>>0>17){break t}d=1<<d;u:{if(!(d&63503)){if(d&198144){break u}break t}if(!w[a|0]){break t}}d=v[b>>2];v[22708]=0;d=yv(a,d);i=v[22708];v[22708]=0;if((i|0)==1){break s}v[22708]=0;U(755,e+544|0,c|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break s}d=e+544|0;i=v[d+4>>2];v[p>>2]=v[d>>2];v[p+4>>2]=i;np(p+8|0,d+8|0);zc(d);d=0;v[22708]=0;g=Rd(p);i=v[22708];v[22708]=0;if((i|0)==1){break n}v[e+2708>>2]=v[p>>2];if(!g){break g}}d=w[a+3|0];if(d>>>0>17){break p}i=1<<d;v:{if(!(i&63503)){h=0;if(i&198144){break v}break p}h=!w[a|0]}if(h|y[b>>2]<262145){break p}d=v[e+2708>>2];i=w[a+3|0];v[22708]=0;v[e+520>>2]=((i|0)==10)<<4;i=Fb(e+520|0,e+2708|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[e+544>>2]=d-v[i>>2];d=w[a+3|0];if(d>>>0>15){break r}w:{if(!(1<<d&63503)){if((d|0)==10){break w}break r}if(!(w[a|0]&7)){break r}}d=v[e+544>>2];if(d>>>0<=2147483647){d=d<<1;break q}d=-1;break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=0;v[22708]=0;i=gp(a);h=v[22708];v[22708]=0;x:{y:{if((h|0)!=1){z:{A:{switch(w[a+3|0]){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:d=w[a|0];break z;case 9:d=16;break z;case 10:d=4;break z;case 16:case 17:break A;default:break z}}d=8}i=B(d,i)>>>3|0;d=i-1|0;h=v[e+544>>2];if(d>>>0>-1-h>>>0){break y}h=d+h|0;break x}a=P()|0;O()|0;break a}h=-1}d=(h>>>0)/(i>>>0)|0}v[f+544>>2]=d;qc(b,d);break o}f=e;B:{C:{D:{E:{if(!(w[a+3|0]==4|w[a+3|0]==5|(w[a+3|0]==8|w[a+3|0]==7))){if(w[a+3|0]!=6){break o}d=0;if(y[e+2708>>2]<10){break g}v[22708]=0;Q(318,c|0,4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;d=T(192,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break E}v[e+520>>2]=d;d=v[e+2708>>2];v[22708]=0;v[e+2704>>2]=d;d=Fb(e+520|0,e+2704|0);i=v[22708];v[22708]=0;if((i|0)==1){break D}v[e+544>>2]=v[d>>2];pg(c,8);d=v[e+544>>2];if(d>>>0>50529027){break C}d=B(d,85);break B}v[e+544>>2]=v[e+2708>>2];v[22708]=0;f=gp(a);i=v[22708];v[22708]=0;h=e;F:{G:{if((i|0)!=1){i=v[e+544>>2];f=8/(f>>>0)|0;if(i>>>0>4294967295/(f>>>0)>>>0){break G}f=B(f,i);break F}a=P()|0;O()|0;break a}f=-1}v[h+544>>2]=f;qc(b,f);break o}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=-1}v[f+544>>2]=d;qc(b,(d>>>0)/(w[a|0]>>>3>>>0)|0)}if(!v[b>>2]){d=0;break g}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[22708]=0;d=T(386,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}if(!d){d=0;v[b>>2]=0;break g}if(je(a,Rc(e+544|0,8,1,0,10))){v[22708]=0;a=Q(1185,c|0,e+544|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){d=0;if(!a){break h}a=v[b>>2];v[22708]=0;v[e+520>>2]=a+1>>>1;a=T(467,c|0)|0;d=v[22708];v[22708]=0;H:{if((d|0)!=1){qc(e+520|0,a);a=zb(g);d=v[e+520>>2];if(d){break H}d=16;break h}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];g=0;while(1){f=e+544|0;i=w[f|w[a|0]&15]+g|0;t[b|0]=i;g=w[f|w[a|0]>>>4]+(i&255)|0;t[b+1|0]=g;a=a+1|0;b=b+2|0;d=d-1|0;if(d){continue}break}d=v[e+520>>2]+16|0;break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=4&w[a+3|0]!=5)){a=w[a+3|0];v[22708]=0;a=da(1186,e+1616|0,c|0,b|0,(a|0)==5|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}xb(a);d=v[c+8>>2]-D|0;break h}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[22708]=0;Q(318,c|0,4)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;a=T(192,c|0)|0;d=v[22708];v[22708]=0;I:{J:{K:{if((d|0)!=1){v[22708]=0;v[e+520>>2]=a;d=T(374,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break K}v[22708]=0;U(1187,e+544|0,c|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break I}a=e+544|0;qc(e+520|0,v[a>>2]);v[22708]=0;f=v[e+520>>2];a=Rd(a);i=v[22708];v[22708]=0;if((i|0)!=1){i=v[e+544>>2];h=v[b+20>>2];b=bj(b);v[22708]=0;ha(1188,a|0,i|0,h|0,b|0,d<<24>>24);a=v[22708];v[22708]=0;if((a|0)!=1){break J}}a=P()|0;O()|0;zc(e+544|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=f+9|0;zc(e+544|0);break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[e+2708>>2];d=x[Rm(e+1608|0)>>1];v[22708]=0;d=KQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16){break m}d=0;v[22708]=0;f=Q(191,c|0,8)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}if(!f){break h}v[22708]=0;f=T(192,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}v[e+2708>>2]=f;if(f>>>0<4){break h}v[22708]=0;U(288,e+520|0,c|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;f=Kp(e+544|0,e+520|0);i=v[22708];v[22708]=0;if((i|0)==1){break c}xb(e+520|0);v[22708]=0;i=T(1190,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break e}if(!v[b>>2]){break j}h=w[a|0];n=(h|0)!=16;while(1){L:{if(n){break L}v[22708]=0;o=Q(200,f|0,8)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break L}a=V(27364)|0;break k}v[22708]=0;l=Q(200,f|0,1)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;a=Q(200,f|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}M:{N:{O:{if(!a){g=8;while(1){v[22708]=0;a=Q(200,f|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break M}if(a){break O}g=g+16|0;continue}}v[22708]=0;a=Q(200,f|0,3)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break N}break l}v[22708]=0;a=Q(200,f|0,4)|0;k=v[22708];v[22708]=0;if((k|0)==1){break l}a=a+g|0}j=(j&255)+(((l?-1:0)^a)&255)|0;P:{if((h|0)!=16){t[v[b+20>>2]+d|0]=j;break P}u[v[b+20>>2]+(d<<1)>>1]=o&255|j<<8}d=d+1|0;if(d>>>0<y[b>>2]){continue}break j}break}a=V(27364)|0;break k}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){d=0;if(y[e+2708>>2]<5){break h}a=zb(zb(v[b+20>>2]));b=bj(b);v[22708]=0;d=W(1191,c|0,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+1|0]!=1&w[a+1|0]!=2|(w[a+3|0]!=16&w[a+3|0]!=17|w[a|0]!=16))){d=v[b>>2];v[22708]=0;f=gp(a);i=v[22708];v[22708]=0;if((i|0)!=1){v[e+544>>2]=B(d,f);qc(e+544|0,v[e+2708>>2]);b=v[b+20>>2];d=v[e+544>>2];f=w[a+3|0];a=v[e+544>>2];v[e+544>>2]=a-1;if((f|0)!=16){if(!a){break h}while(1){E=b,F=x[vd(37268,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}if(!a){break h}while(1){E=b,F=x[vd(36756,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}a=P()|0;O()|0;break a}if(!(w[a|0]!=8|w[a+1|0]!=1)){Q:{R:{S:{T:{a=w[a+3|0];switch(a|0){case 2:break Q;case 1:break S;case 0:break T;default:break R}}v[22708]=0;d=JQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=IQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((a|0)!=11){break h}}a=v[e+2708>>2];d=w[GA(e+512|0)|0];v[22708]=0;d=HQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=8|w[a+1|0]!=3)){U:{V:{W:{X:{f=w[a+3|0];switch(f|0){case 2:break U;case 1:break W;case 0:break X;default:break V}}v[22708]=0;d=GQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=FQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=11){break h}}d=v[e+2708>>2];f=w[GA(e+504|0)|0];v[22708]=0;d=EQ(b,g,d,f);f=v[22708];v[22708]=0;if((f|0)==1){break f}if(w[a+3|0]!=11){break h}f=v[b>>2]<<1;if((f|0)<1){break h}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=8|w[a+1|0]!=2)){d=0;Y:{switch(w[a+3|0]){case 0:v[22708]=0;d=DQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=CQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break Y;default:break h}}a=v[e+2708>>2];d=w[GA(e+496|0)|0];v[22708]=0;d=BQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 2:break Z;case 1:break $;case 0:break aa;default:break _}}v[22708]=0;d=AQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=zQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((a|0)!=11){break h}}a=v[e+2708>>2];d=x[Rm(e+488|0)>>1];v[22708]=0;d=yQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){d=0;ba:{switch(w[a+3|0]){case 0:v[22708]=0;d=xQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=wQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ba;default:break h}}a=v[e+2708>>2];d=x[Rm(e+480|0)>>1];v[22708]=0;d=vQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){ca:{da:{ea:{fa:{f=w[a+3|0];switch(f|0){case 2:break ca;case 1:break ea;case 0:break fa;default:break da}}v[22708]=0;d=uQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=tQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=11){break h}}d=v[e+2708>>2];f=x[Rm(e+472|0)>>1];v[22708]=0;d=sQ(b,g,d,f);f=v[22708];v[22708]=0;if((f|0)==1){break f}if(w[a+3|0]!=11){break h}f=v[b>>2];if(f<<1<1){break h}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){d=0;ga:{switch(w[a+3|0]){case 0:v[22708]=0;d=qQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=pQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ga;default:break h}}a=v[e+2708>>2];d=x[Rm(e+464|0)>>1];v[22708]=0;d=oQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){d=0;ha:{switch(w[a+3|0]){case 0:v[22708]=0;d=nQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=mQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ha;default:break h}}a=v[e+2708>>2];d=x[Rm(e+456|0)>>1];v[22708]=0;d=lQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){d=0;ia:{switch(w[a+3|0]){case 0:v[22708]=0;d=kQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=jQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ia;default:break h}}a=v[e+2708>>2];d=x[Rm(e+448|0)>>1];v[22708]=0;d=iQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=hQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=gQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=fQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=eQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=dQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=cQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=bQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=aQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=$P(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=_P(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=ZP(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=YP(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1231,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1232,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1233,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1234,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1235,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1236,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1237,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1238,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=24|w[a+3|0]!=15)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ja:{if(!w[a+2|0]){v[e+8>>2]=v[e+440>>2];v[e+436>>2]=0;a=v[e+436>>2];v[e>>2]=v[e+432>>2];v[e+4>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+4>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d+2|0])<<24;ka:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break ka}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;la:{if(!a){break la}j=v[k+12>>2];if(!j){break la}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g+2|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ma:{if((f|0)>0|(f|0)>=0){f=qqa(h,f,i,0);h=jb;break ma}l=n;h=qqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3);break ja}v[e+24>>2]=v[e+424>>2];v[e+420>>2]=0;a=v[e+420>>2];v[e+16>>2]=v[e+416>>2];v[e+20>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+20>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+2|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d|0])<<24;na:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break na}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;oa:{if(!a){break oa}j=v[k+12>>2];if(!j){break oa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+2|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;pa:{if((f|0)>0|(f|0)>=0){f=qqa(h,f,i,0);h=jb;break pa}l=n;h=qqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3)}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}f=nqa(x[b+32>>1],0,a,0)+1073741824|0;a=jb;a=f>>>0<1073741824?a+1|0:a;E=b,F=Fd(Qc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=15)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];qa:{if(!w[a+2|0]){v[e+40>>2]=v[e+408>>2];v[e+404>>2]=0;a=v[e+404>>2];v[e+32>>2]=v[e+400>>2];v[e+36>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,d>>>2|0);d=zb(g);a=v[e+36>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=f|zb(w[d+1|0])<<8|zb(w[d+2|0])<<16|zb(w[d+3|0])<<24;ra:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break ra}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;sa:{if(!a){break sa}j=v[k+12>>2];if(!j){break sa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=f|zb(w[g+1|0])<<8|zb(w[g+2|0])<<16|zb(w[g+3|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ta:{if((f|0)>0|(f|0)>=0){f=qqa(h,f,i,0);h=jb;break ta}l=n;h=qqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2;break qa}v[e+56>>2]=v[e+392>>2];v[e+388>>2]=0;a=v[e+388>>2];v[e+48>>2]=v[e+384>>2];v[e+52>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,d>>>2|0);d=zb(g);a=v[e+52>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+3|0]);j=f|zb(w[d+2|0])<<8|zb(w[d+1|0])<<16|zb(w[d|0])<<24;ua:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break ua}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;va:{if(!a){break va}j=v[k+12>>2];if(!j){break va}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+3|0]);o=d;f=f|zb(w[g+2|0])<<8|zb(w[g+1|0])<<16|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;wa:{if((f|0)>0|(f|0)>=0){f=qqa(h,f,i,0);h=jb;break wa}l=n;h=qqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}a=nqa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;E=b,F=Fd(Qc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}xa:{if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=14)){v[e+544>>2]=1065353216;d=v[e+2708>>2];ya:{if(!w[a+2|0]){v[e+372>>2]=0;v[e+376>>2]=1065353216;a=v[e+380>>2];v[e+72>>2]=v[e+376>>2];v[e+76>>2]=a;v[22708]=0;a=v[e+372>>2];v[e+64>>2]=v[e+368>>2];v[e+68>>2]=a;d=fa(1239,b|0,g|0,d|0,e+544|0,e- -64|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break ya}break xa}v[e+356>>2]=0;v[e+360>>2]=1065353216;a=v[e+364>>2];v[e+88>>2]=v[e+360>>2];v[e+92>>2]=a;v[22708]=0;a=v[e+356>>2];v[e+80>>2]=v[e+352>>2];v[e+84>>2]=a;d=fa(1240,b|0,g|0,d|0,e+544|0,e+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break xa}}if(!d){break h}q=z[e+544>>2];if(q==C(1)){break h}a=b;h=a;q=fe(Go(C(q*C(x[a+32>>1])),C(1),C(64)));a=65535;za:{if(q>=C(65535)){break za}a=0;if(q<=C(0)){break za}a=~~q>>>0;if(q<C(4294967296)&q>=C(0)){break za}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}Aa:{if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=64|w[a+3|0]!=14)){v[e+544>>2]=0;v[e+548>>2]=1072693248;d=v[e+2708>>2];Ba:{if(!w[a+2|0]){v[e+336>>2]=0;v[e+340>>2]=1072693248;v[e+328>>2]=0;v[e+332>>2]=0;v[e+104>>2]=0;v[e+108>>2]=0;v[e+112>>2]=0;v[e+116>>2]=1072693248;a=v[e+348>>2];v[e+120>>2]=v[e+344>>2];v[e+124>>2]=a;v[22708]=0;a=v[e+324>>2];v[e+96>>2]=v[e+320>>2];v[e+100>>2]=a;d=fa(1241,b|0,g|0,d|0,e+544|0,e+96|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break Ba}break Aa}v[e+304>>2]=0;v[e+308>>2]=1072693248;v[e+296>>2]=0;v[e+300>>2]=0;v[e+136>>2]=0;v[e+140>>2]=0;v[e+144>>2]=0;v[e+148>>2]=1072693248;a=v[e+316>>2];v[e+152>>2]=v[e+312>>2];v[e+156>>2]=a;v[22708]=0;a=v[e+292>>2];v[e+128>>2]=v[e+288>>2];v[e+132>>2]=a;d=fa(1242,b|0,g|0,d|0,e+544|0,e+128|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break Aa}}if(!d){break h}r=A[e+544>>3];if(r==1){break h}a=b;h=a;r=ee(CA(r*+x[a+32>>1],1,64));a=65535;Ca:{if(r>=65535){break Ca}a=0;if(r<=0){break Ca}a=~~r>>>0;if(r<4294967296&r>=0){break Ca}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=12)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+280>>2]=939524096;v[22708]=0;a=v[e+284>>2];v[e+160>>2]=v[e+280>>2];v[e+164>>2]=a;d=da(1243,b|0,g|0,d|0,e+160|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[e+272>>2]=939524096;v[22708]=0;a=v[e+276>>2];v[e+168>>2]=v[e+272>>2];v[e+172>>2]=a;d=da(1244,b|0,g|0,d|0,e+168|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=12)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+264>>2]=939524096;v[22708]=0;a=v[e+268>>2];v[e+176>>2]=v[e+264>>2];v[e+180>>2]=a;d=da(1245,b|0,g|0,d|0,e+176|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[e+256>>2]=939524096;v[22708]=0;a=v[e+260>>2];v[e+184>>2]=v[e+256>>2];v[e+188>>2]=a;d=da(1246,b|0,g|0,d|0,e+184|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+248>>2]=872415232;v[22708]=0;a=v[e+252>>2];v[e+192>>2]=v[e+248>>2];v[e+196>>2]=a;d=da(1243,b|0,g|0,d|0,e+192|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[e+240>>2]=872415232;v[22708]=0;a=v[e+244>>2];v[e+200>>2]=v[e+240>>2];v[e+204>>2]=a;d=da(1244,b|0,g|0,d|0,e+200|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13){break h}d=v[e+2708>>2];if(!w[a+2|0]){v[e+232>>2]=872415232;v[22708]=0;a=v[e+236>>2];v[e+208>>2]=v[e+232>>2];v[e+212>>2]=a;d=da(1245,b|0,g|0,d|0,e+208|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break h}break f}v[e+224>>2]=872415232;v[22708]=0;a=v[e+228>>2];v[e+216>>2]=v[e+224>>2];v[e+220>>2]=a;d=da(1246,b|0,g|0,d|0,e+216|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(27364)|0}if((O()|0)!=(ea(27364)|0)){break d}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break i}}d=i+4|0;xb(f);break h}a=P()|0;O()|0;break d}v[22708]=0;Q(190,c|0,d+D|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}}zc(p)}gb=e+2736|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);break a}a=P()|0;O()|0;xb(e+520|0);break a}a=P()|0;O()|0}zc(p);S(a|0);L()}function tu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,ca=0,ea=0,ga=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;n=gb-192|0;gb=n;Z=dd(a);p=n+160|0;t[p+26|0]=0;u[p+24>>1]=0;v[p+16>>2]=0;v[p+20>>2]=-1;v[p+8>>2]=-1;v[p+12>>2]=-1;v[p>>2]=0;v[p+4>>2]=0;F=v[d+16>>2];X=w[d+6|0];$=b+484360|0;if(X>>>0>=Ri($)>>>0){X=w[$+16|0]}s=Rj($,X);v[22708]=0;q=Q(1247,n+120|0,b|0)|0;a=v[22708];v[22708]=0;a:{if((a|0)!=1){f=v[q+4>>2];v[22708]=0;G=W(1248,n+80|0,b|0,X|0)|0;a=v[22708];v[22708]=0;b:{if((a|0)!=1){h=x[d+4>>1];c:{d:{if(h>>>0>=tc(s)>>>0){break d}while(1){v[22708]=0;a=Q(472,s|0,h&65535)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(a){break d}v[d>>2]=0;h=h+1|0;u[d+4>>1]=h;if(tc(s)>>>0>(h&65535)>>>0){continue}break}}a=v[d>>2];v[f+52>>2]=a;v[f+48>>2]=a;v[p+16>>2]=a;u[f+74>>1]=h;u[f+72>>1]=h;u[p+24>>1]=h;H=n+72|0;Td(H);ga=vr(n- -64|0);ia=c&7;la=(ia|0)!=7;e:{if(la){break e}Il(H,1);Il(H,2);Il(H,3);Il(H,28);Il(H,38);Il(H,40);Il(H,39);Il(H,41);UP(ga,12);UP(ga,13);if((F|0)!=2){break e}a=x[d+12>>1];if(tc(s)>>>0<=a>>>0){break e}a=x[sc(s,a)>>1];v[22708]=0;k=b+484344|0;h=me(k,a);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!h){break e}e=_b(k,a);h=v[d+8>>2];v[22708]=0;e=SP(e,h);i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!e){break e}e=0;a=_b(k,a);v[22708]=0;h=Yc(a,h,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}if(!x[b+480188>>1]){break e}a=q+20|0;while(1){f:{g:{h:{switch(w[h|0]-253|0){case 0:if(x[b+480192>>1]){break g}break;case 1:case 2:break g;default:break h}}v[22708]=0;k=ce(h);i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!k){break f}if(uu(h)){break f}}sa=ye(a,e),ta=-1,v[sa>>2]=ta}h=h+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}T=f+74|0;J=f+48|0;M=f+80|0;oa=f+44|0;E=q+20|0;ka=q+8|0;aa=c&1;ba=f+20|0;z=b+1074312|0;ma=f+616|0;I=b+484344|0;ca=32768;pa=(F|0)!=3;na=(F|0)!=2;e=0;h=0;i:{j:{while(1){N=h;k:{l:{while(1){i=x[d+12>>1];qa=A[d+8>>3];while(1){v[22708]=0;Sz(n+32|0,b,f,e&1);a=v[22708];v[22708]=0;if((a|0)==1){break c}k=w[n+32|0];if(!pa&A[q+32>>3]>=qa){break l}h=x[f+72>>1];a=f;m:{if(tc(s)>>>0>h>>>0){h=x[sc(s,x[f+72>>1])>>1];break m}h=65535}u[a+70>>1]=h;v[22708]=0;a=me(I,h&65535);h=v[22708];v[22708]=0;if((h|0)==1){break i}if(!(x[f+70>>1]==65535|na|a)&(i|0)==x[f+72>>1]){break l}n:{if(x[f+70>>1]<Te(I)>>>0){break n}while(1){a=f;g=a;o:{p:{if(x[a+70>>1]!=65535){h=x[f+72>>1];if(tc(s)>>>0>h>>>0){break p}}if(x[s+28>>1]==x[f+72>>1]){break n}h=x[s+28>>1];break o}h=x[f+72>>1]+1|0}u[g+72>>1]=h;a=f;q:{if(tc(s)>>>0>(h&65535)>>>0){h=x[sc(s,x[f+72>>1])>>1];break q}h=65535}u[a+70>>1]=h;u[f+74>>1]=x[f+72>>1];v[22708]=0;a=me(I,h&65535);h=v[22708];v[22708]=0;if((h|0)==1){break i}r:{if(a){break r}a=x[f+72>>1];h=Hq(n+32|0,ma);v[22708]=0;a=fa(1251,G|0,a|0,0,h|0,(k|0)!=0|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(!a){break r}if(F>>>0<2){a=x[f+72>>1];v[p+8>>2]=0;u[p+20>>1]=a;if(!F){break n}}v[22708]=0;a=da(1252,G|0,T|0,J|0,1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break i}if(!a){break n}A[p>>3]=A[q+32>>3];v[22708]=0;R(1253,Z|0,p|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[p+16>>2]=v[J>>2];u[p+24>>1]=x[T>>1];v[22708]=0;_(1254,q|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}a=x[f+74>>1];u[f+72>>1]=a;sa=f,ta=x[sc(s,a)>>1],u[sa+70>>1]=ta;v[f+52>>2]=v[f+48>>2];break n}if(x[f+70>>1]>=Te(I)>>>0){continue}break}}if(x[T>>1]==65535){break j}a=x[f+70>>1];v[22708]=0;a=me(I,a);h=v[22708];v[22708]=0;if((h|0)==1){break i}if(!a){if(x[s+28>>1]==x[f+72>>1]){if(!F){break j}v[22708]=0;a=da(1252,G|0,T|0,J|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}if(!a){break j}A[p>>3]=A[q+32>>3];v[22708]=0;R(1253,Z|0,p|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[p+16>>2]=v[J>>2];u[p+24>>1]=x[T>>1];v[22708]=0;_(1254,q|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[f+52>>2]=v[f+48>>2];continue}u[f+74>>1]=x[f+72>>1]+1;continue}break}if(y[f+48>>2]>=y[_b(I,x[f+70>>1])+12>>2]){v[J>>2]=0}if(!(x[f+72>>1]!=x[d+12>>1]|na)&v[J>>2]==v[d+8>>2]){break l}h=0;if(!((F|0)==3|y[G+28>>2]<ca>>>0)){v[q+32>>2]=0;v[q+36>>2]=2146435072;v[G+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;h=1}a=v[f+48>>2];i=x[f+72>>1];g=Hq(n+32|0,ma);v[22708]=0;a=fa(1251,G|0,i|0,a|0,g|0,(k|0)!=0|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}if((a|h)==1){if(F>>>0<2){u[p+20>>1]=x[f+72>>1];v[p+8>>2]=v[f+48>>2];if(!F){break j}}v[22708]=0;a=da(1252,G|0,T|0,J|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(!a){break j}A[p>>3]=A[q+32>>3];v[22708]=0;R(1253,Z|0,p|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[p+16>>2]=v[J>>2];u[p+24>>1]=x[T>>1];v[22708]=0;_(1254,q|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[f+52>>2]=v[f+48>>2];continue}u[p+22>>1]=x[f+72>>1];v[p+12>>2]=v[f+48>>2];v[22708]=0;Rz(b,f,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}if(y[f+48>>2]>=y[_b(I,x[f+70>>1])+12>>2]){v[J>>2]=0}if(k){continue}break}a=_b(I,x[f+70>>1]);k=v[f+48>>2];v[22708]=0;h=Yc(a,k,0);a=v[22708];v[22708]=0;s:{if((a|0)!=1){a=n+32|0;Db(a,z,77);e=Cb(a);g=0;if(x[b+480188>>1]){break s}break k}break c}while(1){t:{if(!(!AA(h)&(!e|!(w[((g<<5)+b|0)+480281|0]&4)))){$o((B(g,872)+f|0)+1404|0);break t}v[22708]=0;a=Bg(h);k=v[22708];v[22708]=0;if((k|0)==1){break c}if(a){u:{if(!aa){break u}a=w[h+1|0];if(a-251>>>0<5|!a){break u}v[22708]=0;k=Fo(h);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;a=Gq(h);i=v[22708];v[22708]=0;if((i|0)==1){break c}u[n+8>>1]=a;a=n+32|0;t[a|0]=w[h+1|0];u[a+2>>1]=x[n+8>>1];v[22708]=0;a=Q(1259,ka|0,a|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}u[a>>1]=k}$o((B(g,872)+f|0)+1404|0);break t}a=B(g,872)+f|0;k=a+1408|0;i=w[h+4|0]|w[h+5|0]<<8;t[k|0]=i;t[k+1|0]=i>>>8;a=a+1404|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[a|0]=k;t[a+1|0]=k>>>8;t[a+2|0]=k>>>16;t[a+3|0]=k>>>24;v:{switch(w[h+3|0]-16|0){case 0:a=w[h+5|0];v[22708]=0;U(1260,b|0,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}break t;case 1:a=n+32|0;Db(a,z,5);if(!Cb(a)){break t}a=w[h+5|0];if(!a){break t}v[22708]=0;U(1260,b|0,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break t}break c;case 4:a=w[h+5|0];k=a&240;if((k|0)!=224){if((k|0)!=96){break t}v[f+24>>2]=v[f+24>>2]+(a&15);break t}if(v[ba>>2]){break t}a=w[h+5|0]&15;if(a?0:v[b+480180>>2]&2){break t}v[ba>>2]=a+1;break t;case 3:break v;default:break t}}a=w[h+5|0];if((a&240)!=224){break t}v[ba>>2]=(a&15)+1}h=h+6|0;g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break}break k}t[p+26|0]=1;break j}k=tk(f);v[22708]=0;v[n+32>>2]=1;a=Mc(ba,n+32|0);h=v[22708];v[22708]=0;w:{if((h|0)!=1){a=v[a>>2];u[f+68>>1]=65535;v[f+60>>2]=-1;v[f+64>>2]=-1;if(!x[b+480188>>1]){break w}K=k-1|0;h=k-a|0;V=B(h,1e4);g=0;while(1){x:{i=B(g,872)+f|0;a=i+1404|0;y:{if(AA(a)){break y}m=i+616|0;e=w[i+1409|0];ea=i+1407|0;l=w[ea|0];z:{A:{if(!aa){break A}j=w[a|0];o=i+1405|0;r=w[o|0];if(r){t[i+1415|0]=0;t[i+1419|0]=r;sa=ye(E,g),ta=255,t[sa+5|0]=ta}v[22708]=0;r=ce(a);D=v[22708];v[22708]=0;if((D|0)==1){break x}if(r){t[i+1415|0]=j}v[22708]=0;r=ce(a);D=v[22708];v[22708]=0;if((D|0)==1){break x}B:{if(!(w[o|0]?1:r)){break B}C:{o=i+1419|0;r=w[o|0];if(!r|r>>>0>x[b+480192>>1]){break C}r=v[((w[o|0]<<2)+b|0)+900380>>2];if(!r|!(t[r+15|0]&1)){break C}r=v[r+8>>2];v[22708]=0;To(m,r,b);r=v[22708];v[22708]=0;if((r|0)!=1){break C}break c}j=bA(b,j,w[o|0]);if(!j){break B}j=B(j,104)+b|0;if(!(w[j+484414|0]&32)){break B}j=x[j+484408>>1];v[22708]=0;To(m,j,b);j=v[22708];v[22708]=0;if((j|0)!=1){break B}break c}D:{E:{F:{j=w[i+1406|0];switch(j-1|0){case 1:break A;case 2:case 3:break E;case 0:break F;default:break D}}sa=ye(E,g),ta=w[i+1408|0],t[sa+5|0]=ta;break A}a=w[i+1408|0];if(!a){break A}t[i+1450|0]=a;break A}if(!w[i+1408|0]|(j|0)!=11){break A}j=n+32|0;zA(j,b,a,0);a=Ve(j);u[i+1384>>1]=x[j>>1];if(w[a|0]){break z}}G:{H:{switch(l-12|0){case 0:v[22708]=0;yA(b,f,g&65535);a=v[22708];v[22708]=0;if((a|0)!=1){break G}break x;case 2:v[22708]=0;a=xA(b,f,g&65535,e);j=v[22708];v[22708]=0;if((j|0)!=1){if((a|0)==-1){break G}v[f+60>>2]=a;break G}break c;case 5:a=n+32|0;Db(a,z,5);if(Cb(a)){break G}a=v[f+48>>2];j=x[f+70>>1];v[22708]=0;a=Qm(b,j,a,g&65535,0);j=v[22708];v[22708]=0;I:{J:{if((j|0)!=1){a=B(a,1e4);if(!aa|!(v[b+480180>>2]&16777250)){break I}if(a>>>0<1e4){break J}t[i+1451|0]=(a>>>0)/1e4;break I}break c}a=B(w[i+1451|0],1e4)}j=(a>>>0)/1e4|0;K:{if(a>>>0>319999){break K}o=B(V,j&15);a=v[f+44>>2];if((j&240)==16){a=a+o|0;break K}j=a-o|0;a=a>>>0<j>>>0?0:j}v[f+44>>2]=a;a=v[v[b+8>>2]+20>>2];j=v[v[b+8>>2]+24>>2];o=n+32|0;Db(o,z,8);Fp(oa,B(a,1e4),Cb(o)?255e4:B(j,1e4));break G;case 8:L:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break G}v[i+704>>2]=v[i+704>>2]&-257|((e|0)==145)<<8;break G;case 1:t[i+1452|0]=e&15;break G;case 2:su(b,f,m,e&15);break G;case 6:break L;default:break G}}t[i+1460|0]=e&15;break G;case 7:a=e&240;if((a|0)!=240){if((a|0)!=96){break G}su(b,f,m,e&15);break G}t[i+1460|0]=e&15;break G;case 1:case 3:case 4:case 6:break G;default:break H}}if((l|0)!=28|(e&240)!=160){break G}a=n+32|0;Db(a,z,58);if(Cb(a)){break G}t[i+1452|0]=e&15}if(!aa){break y}M:{N:{O:{P:{Q:{R:{S:{switch(l-2|0){case 0:if(!e){break z}a=n+32|0;Db(a,z,90);if(!Cb(a)){t[i+1428|0]=e}t[i+1427|0]=e;break z;case 1:if(!e){break z}a=n+32|0;Db(a,z,90);if(!Cb(a)){t[i+1427|0]=e}t[i+1428|0]=e;break z;case 2:if(!e){break z}u[i+1384>>1]=e;break z;case 8:if(!e){break z}v[i+1280>>2]=e<<8;break z;case 4:case 9:if(!e){break z}t[i+1425|0]=e;break z;case 11:sa=ye(E,g),ta=e,t[sa+5|0]=ta;break z;case 21:a=e<<(!(v[b+480180>>2]&59593760)&e<<24>>24>-1)&255;if(a>>>0<=128){v[M>>2]=a<<1;break z}if(v[b+480180>>2]&16777250){break z}v[M>>2]=256;break z;case 22:a=n+32|0;Db(a,z,9);T:{if(Cb(a)){a=i+1433|0;if(e){t[a|0]=e;break T}e=w[a|0];break T}if(e){t[f+1433|0]=e;break T}e=w[f+1433|0]}a=M;l=e&240;j=e&15;U:{if(!(!l|(j|0)!=15)){o=v[M>>2]+(l>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break U}o=v[M>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(l|0)!=240)){break U}o=v[M>>2]+B(h,(e>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(l){break U}o=v[M>>2]-B(h,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=o;Yd(M,0,256);break z;case 19:if(e>>>0>64){break z}v[i+1364>>2]=e;break z;case 20:a=i+1432|0;V:{if(e){t[a|0]=e;break V}e=w[a|0]}l=e&255;j=i+1364|0;a=v[j>>2];o=e&240;e=e&15;W:{if(!(!o|(e|0)!=15)){v[n+32>>2]=a+(l>>>4|0);break W}if(!(!e|(o|0)!=240)){v[n+32>>2]=a-e;break W}if(e){v[n+32>>2]=a-B(e,h);break W}v[n+32>>2]=a+B(h,l>>>4|0)}Yd(n+32|0,0,64);v[j>>2]=v[n+32>>2];break z;case 7:Pm(b,m,e,8);break z;case 25:break M;case 6:break N;case 24:break O;case 3:break P;case 5:break Q;case 18:break R;case 17:break S;default:break z}}if(!x[b+480188>>1]|e>>>0>15){break R}l=(e&1)<<14;a=0;while(1){j=B(a,872)+f|0;v[j+704>>2]=(l|v[j+704>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((e&240)!=128){break z}Pm(b,m,e&15,4);break z}if(e){t[i+1425|0]=e}e=0}Hl(m,e);break z}PP(b,m,e);break z}OP(m,e);break z}NP(m,e)}X:{Y:{switch(w[i+1406|0]-2|0){case 0:Pm(b,m,w[i+1408|0],6);break X;case 5:a=n+32|0;Db(a,z,53);e=Cb(a);a=w[i+1408|0];if(e){t[i+1439|0]=a&15;break X}Hl(m,a<<4);break X;case 6:break Y;default:break X}}Hl(m,w[i+1408|0])}Z:{_:{$:{aa:{a=w[ea|0];switch(a-5|0){case 3:break _;case 0:case 2:break $;case 1:break y;default:break aa}}switch(a-26|0){case 1:break Z;case 0:break $;default:break y}}ba:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ba}}a=h}e=w[i+1439|0];m=n+32|0;Db(m,z,21);m=Cb(m);i=i+1435|0;a=B(a,e);t[i|0]=w[i|0]+(m?a<<2:a);break y}ca:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ca}}a=h}e=w[i+1442|0];m=n+32|0;Db(m,z,21);m=Cb(m);i=i+1436|0;a=B(a,e);t[i|0]=w[i|0]+(m?a<<2:a);break y}a=i+1437|0;t[a|0]=w[a|0]+B(K,w[i+1445|0]);v[22708]=0;Uz(b,m);a=v[22708];v[22708]=0;if((a|0)==1){break x}}g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break w}break}break c}break c}if(v[b+480180>>2]==4&v[f+40>>2]==65535){break j}v[f+32>>2]=v[b+480216>>2];if(MP(_b(I,x[f+70>>1]))){sa=f,ta=v[_b(I,x[f+70>>1])+16>>2],v[sa+32>>2]=ta}v[22708]=0;h=Q(1266,b|0,f|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){a=B(h,k);A[q+32>>3]=A[q+32>>3]+ +(a>>>0)/+y[b+24620>>2];v[f>>2]=a+v[f>>2];if(!(!x[b+480188>>1]|la)){a=0;ea=(N|0)!=0&(h|0)!=(N|0);while(1){da:{if(v[ye(E,a)>>2]==-1){break da}l=B(a,872)+f|0;V=l+1404|0;j=l+1316|0;if(!v[j>>2]){if(AA(V)){break da}}r=1;ea:{fa:{K=l+1407|0;switch(w[K|0]-4|0){case 0:case 2:break ea;default:break fa}}r=w[l+1406|0]==11}if(w[l+1405|0]){v[l+1276>>2]=0}o=l+1409|0;g=w[o|0];v[22708]=0;D=ce(V);e=v[22708];v[22708]=0;if((e|0)==1){break i}i=l+616|0;m=g&15;e=0;ga:{ha:{ia:{ja:{ka:{if(!D){break ka}la:{if(!r){break la}if(!w[ye(E,a)+4|0]){break la}e=v[j>>2];v[22708]=0;ha(1267,n+32|0,b|0,i|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[n+36>>2];v[l+624>>2]=v[n+32>>2];v[l+628>>2]=e}t[l+1418|0]=w[l+1415|0];D=l+1308|0;ra=v[D>>2];e=w[l+1419|0];if(e){v[22708]=0;Eo(b,i,e,r,1,1);e=v[22708];v[22708]=0;if((e|0)==1){break i}}e=w[V|0];v[22708]=0;ja(1269,b|0,i|0,e|0,r|0,1,0,65535);e=v[22708];v[22708]=0;if((e|0)==1){break i}g=g>>>4|0;sa=ye(E,a),ta=1,t[sa+4|0]=ta;j=w[K|0];ma:{if(!((w[o|0]&240)!=208|(j-19&255)>>>0>1)){e=m;if(k>>>0>e>>>0){break ma}}e=(j|0)==33?g>>>0<k>>>0?g:0:0}e=!(v[b+480180>>2]&16777250)|(!e|y[ba>>2]<2)?e:B(v[f+20>>2]-1|0,v[f+24>>2]+v[f+40>>2]|0)+e|0;if(!r){sa=ye(E,a),ta=0,v[sa>>2]=ta}j=w[K|0];na:{oa:{if((j|0)==9){break oa}pa:{if((j|0)!=19){if((j|0)!=20|(g|0)!=8){break pa}break oa}if((g|0)==8){break oa}}if(w[l+1406|0]!=2){break na}}v[D>>2]=ra}qa:{ra:{sa:{switch(j-42|0){default:if((j|0)!=10){break ra}v[22708]=0;Y(1270,b|0,i|0,a&65535,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break i}break ka;case 2:break qa;case 1:break ra;case 0:break sa}}if(!v[l+720>>2]){break ra}v[22708]=0;Y(1271,q|0,a&65535,N|0,-1);e=v[22708];v[22708]=0;if((e|0)==1){break i}e=w[o|0];v[22708]=0;vA(i,e);e=v[22708];v[22708]=0;if((e|0)==1){break i}e=v[f+40>>2]-1|0;break ka}if(!v[l+720>>2]|w[l+1406|0]!=15){break ka}g=l+1408|0;if(w[g|0]>9){break ka}g=w[g|0];ta:{if(!g){j=v[l+1280>>2];break ta}j=v[Pe(v[l+720>>2]+68|0,g-1|0)>>2];v[l+1280>>2]=j}v[22708]=0;Om(b,i,j);g=v[22708];v[22708]=0;if((g|0)!=1){break ka}break c}j=nqa(w[o|0],0,v[l+692>>2],0);g=jb;D=g>>>8|0;g=Qc((g&255)<<24|j>>>8,D);v[22708]=0;Om(b,i,g);g=v[22708];v[22708]=0;if((g|0)==1){break i}}ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{switch(w[V|0]-253|0){case 0:if(x[b+480192>>1]){break Aa}break;case 1:case 2:break Aa;default:break Ba}}j=w[K|0];if((j-19&255)>>>0<=1){g=0;if((w[o|0]&240)!=192){break ya}if(k>>>0>m>>>0){break Aa}break ya}g=0;D=j&255;if((D|0)==33&(m|0)!=0&e+m>>>0<k>>>0){break Aa}if((D|0)!=25){break za}}j=w[K|0];g=1}if((j&255)==13){break xa}}if(w[l+1406|0]==1){v[l+1304>>2]=w[l+1408|0]<<2}if(!v[l+720>>2]|g){break wa}g=0;if((j&255)>>>0>44){break ua}break va}v[l+1304>>2]=w[o|0]<<2;j=13;if(!(!v[l+720>>2]|g)){break va}}if(!g){break ga}break ha}g=n+32|0;Db(g,H,j&255);if(Cb(g)){break ja}g=0;if(w[K|0]!=19){break ua}g=w[o|0]&240;g=(g|0)==16|(g|0)==32}j=w[l+1406|0];if(j>>>0<16){break ia}if(g){break ha}break ga}g=1;j=w[l+1406|0];if(j>>>0>=16){break ha}}m=n+32|0;Al(m,ga,j);m=Cb(m);if(g){break ha}if(!m){break ga}}v[22708]=0;lB(i);e=v[22708];v[22708]=0;if((e|0)==1){break i}sa=ye(E,a),ta=0,v[sa>>2]=ta;break da}if(ea){v[22708]=0;Y(1271,q|0,a&65535,N|0,-1);g=v[22708];v[22708]=0;if((g|0)==1){break i}}g=w[K|0];Ca:{if(g>>>0<=18){if(!k|((g|0)!=11&g-6>>>0>=2|!w[o|0]&v[b+480180>>2]==1)){break Ca}m=l+1467|0;g=0;while(1){t[m|0]=!g|w[m|0]&254;Do(b,i,w[o|0]);g=g+1|0;if((k|0)!=(g|0)){continue}break}break Ca}Da:{switch(g-19|0){case 0:g=w[o|0];if(!(g&15)){if(!(v[b+480180>>2]&1048580)){break Ca}g=w[o|0]}m=l+1467|0;t[m|0]=w[m|0]|1;m=g&240;if((m|0)!=176){if((m|0)!=160){break Ca}Fq(b,i,g&15,0);break Ca}Eq(b,i,g&15,0);break Ca;case 1:Ea:{Fa:{Ga:{g=w[o|0];switch(g-158|0){case 1:break Fa;case 0:break Ga;default:break Ea}}v[22708]=0;Y(1271,q|0,a&65535,N|0,-1);g=v[22708];v[22708]=0;if((g|0)==1){break i}v[l+704>>2]=v[l+704>>2]&-129;break Ca}v[22708]=0;Y(1271,q|0,a&65535,N|0,-1);g=v[22708];v[22708]=0;if((g|0)==1){break i}v[l+704>>2]=v[l+704>>2]|128;if(!v[l+692>>2]|v[i+4>>2]){break Ca}v[22708]=0;g=ce(V);m=v[22708];v[22708]=0;if((m|0)==1){break i}if(!(w[l+704|0]&2?g:1)){break Ca}m=v[l+692>>2]-1|0;v[i>>2]=-1;v[i+4>>2]=m;break Ca}if((g&240)!=112|g>>>0<115){break Ca}v[22708]=0;kB(i,g,b);g=v[22708];v[22708]=0;if((g|0)!=1){break Ca}break i;default:break Da}}if(g-35>>>0>=2){break Ca}v[22708]=0;g=a&65535;Y(1271,q|0,g|0,N|0,-1);m=v[22708];v[22708]=0;if((m|0)==1){break i}v[22708]=0;Y(1276,b|0,g|0,f|0,0);g=v[22708];v[22708]=0;if((g|0)==1){break i}}m=l+1467|0;g=w[m|0]|1;t[m|0]=g;Ha:{Ia:{Ja:{Ka:{La:{o=l+1406|0;switch(w[o|0]-3|0){case 11:break Ia;case 0:case 1:break Ja;case 3:break Ka;case 2:break La;default:break Ha}}g=w[l+1408|0];l=n+32|0;Db(l,z,41);Fq(b,i,g,Cb(l));break Ha}g=w[l+1408|0];l=n+32|0;Db(l,z,41);Eq(b,i,g,Cb(l));break Ha}j=w[l+1408|0];Ma:{if(j){break Ma}g=n+32|0;Db(g,z,41);j=0;if(!Cb(g)){break Ma}j=w[l+1450|0];if(!j){break Ha}}if(!k){break Ha}l=w[o|0]==3?j<<4:j;g=0;while(1){t[m|0]=!g|w[m|0]&254;Do(b,i,l&255);g=g+1|0;if((k|0)!=(g|0)){continue}break}break Ha}i=w[l+1408|0];if(i>>>0>1){break Ha}t[m|0]=g&251|!i<<2}if(w[m|0]&4){break da}if(r){g=ye(E,a);i=v[g>>2];v[g>>2]=i+k;v[22708]=0;Y(1271,q|0,a&65535,h|0,(e+i|0)+1|0);e=v[22708];v[22708]=0;if((e|0)!=1){break da}break c}i=ye(E,a);v[i>>2]=v[i>>2]+(k-e|0)}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}e=IP(b,f,0);continue}break}break c}if(!(!x[b+480188>>1]|(ia|0)!=7)){a=0;while(1){Na:{if(v[ye(E,a)>>2]==-1){break Na}v[22708]=0;Y(1271,q|0,a&65535,N|0,-1);d=v[22708];v[22708]=0;if((d|0)!=1){break Na}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[p+26|0]){u[p+20>>1]=x[f+72>>1];v[p+8>>2]=v[f+48>>2]}A[p>>3]=A[q+32>>3];v[22708]=0;R(1253,Z|0,p|0);a=v[22708];v[22708]=0;Oa:{if((a|0)==1){break Oa}Pa:{Qa:{if(!aa){break Qa}Ra:{Sa:{if(F?w[p+26|0]:1){h=b+1074376|0;e=hc(h,f,614);a=0;while(1){k=B(a,872);d=(k+f|0)+616|0;k=hc((e+k|0)+616|0,d,88);v[k+88>>2]=v[d+88>>2];hc(k+92|0,d+92|0,576);v[k+668>>2]=v[d+668>>2];hc(k+672|0,d+672|0,52);yo(k+724|0,d+724|0);yo(k+732|0,d+732|0);yo(k+740|0,d+740|0);hc(k+748|0,d+748|0,123);a=a+1|0;if((a|0)!=256){continue}break}uA(h);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1298260|0;if(Dd(d)){f=v[d>>2];v[22708]=0;_A(f);f=v[22708];v[22708]=0;if((f|0)==1){break Oa}}if(x[b+480188>>1]){k=(ia|0)==7;while(1){f=B(a,872)+b|0;h=w[f+1075791|0];if(h){t[f+1075794|0]=h}h=ye(E,a);if(!(k|w[h+5|0]==255)){v[22708]=0;t[n+32|0]=64;h=ac(h+5|0,n+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[f+1075680>>2]=w[h|0]<<2}Ta:{h=f+1075096|0;e=v[h>>2];if(!e|!(w[e+35|0]&2)){break Ta}if(!Dd(d)){break Ta}e=v[d>>2];h=v[h>>2];v[22708]=0;g=e;e=a&65535;Eu(g,e,h+68|0);h=v[22708];v[22708]=0;if((h|0)!=1){h=v[d>>2];v[22708]=0;Qi(h,e,1);h=v[22708];v[22708]=0;if((h|0)!=1){break Ta}}break c}v[f+1075008>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=YB(n+32|0);sa=n,ta=nr(ka),v[sa+24>>2]=ta;sa=n,ta=Dh(ka),v[sa+16>>2]=ta;if(!og(n+24|0,n+16|0)){break Sa}while(1){f=Xl(n+24|0);k=w[f|0]-1&255;a=v[(B(k,160)+b|0)+906300>>2];if(a){h=n+8|0;Db(h,d,k);if(!Cb(h)){v[22708]=0;R(1280,d|0,k|0);k=v[22708];v[22708]=0;if((k|0)==1){break Pa}k=v[v[a>>2]+172>>2];v[22708]=0;R(k|0,a|0,-1);k=v[22708];v[22708]=0;if((k|0)==1){break Pa}}k=x[f+2>>1];h=v[v[a>>2]+44>>2];f=x[f+4>>1];v[22708]=0;Aa(h|0,a|0,k|0,C(C(C(f>>>0)/C(999))));a=v[22708];v[22708]=0;if((a|0)==1){break Pa}}a=n+24|0;Sj(a);if(og(a,n+16|0)){continue}break}break Sa}if((c|0)==3){break Ra}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2];break Ra}h=250;a=d;e=a;Ua:{while(1){f=1;if(v[e>>2]){break Ua}e=e+4|0;h=h-32|0;if(h>>>0>31){continue}break}f=(v[a+28>>2]&67108863)!=0}if(!f){break Ra}a=0;while(1){f=n+8|0;Db(f,d,a);Va:{if(!Cb(f)){break Va}f=v[(B(a,160)+b|0)+906300>>2];k=v[v[f>>2]+176>>2];v[22708]=0;_(k|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Va}break c}a=a+1|0;if((a|0)!=250){continue}break}}if(w[$+16|0]==(X|0)){break Qa}v[22708]=0;Si($,X);a=v[22708];v[22708]=0;if((a|0)==1){break Oa}}if(c&9){c=G;b=b+1298224|0;d=b;a=b;if(v[a>>2]){Ec(a);mR(a);iR(a);mm(wb(a),v[a>>2],ug(a));sa=wb(a),ta=0,v[sa>>2]=ta;v[a>>2]=0;v[a+4>>2]=0}kp(d,c);v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];a=wb(c);sa=wb(d),ta=v[a>>2],v[sa>>2]=ta;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;a=b+12|0;Jq(a,v[fc(a)>>2]);b=c+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];fc(b);fc(a);v[a+8>>2]=v[b+8>>2];d=v[wb(a)>>2];c=fc(a);Wa:{if(!d){v[a>>2]=c;break Wa}sa=v[fc(a)>>2],ta=c,v[sa+8>>2]=ta;sa=b,ta=fc(b),v[sa>>2]=ta;sa=fc(b),ta=0,v[sa>>2]=ta;sa=wb(b),ta=0,v[sa>>2]=ta}}Dq(G);HP(q);gb=n+192|0;return}}}}a=P()|0;O()|0;Dq(G);break b}a=P()|0;O()|0}HP(q);break a}a=P()|0;O()|0}en(Z);S(a|0);L()}function q6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=C(0),A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=0,M=0,N=C(0),O=0,P=0,Q=C(0),R=0,S=C(0),T=0,U=0,V=0,W=0,X=C(0),Y=C(0),Z=C(0),_=0,$=0,ba=0,ca=C(0),da=0,ea=C(0),fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;fa=gb-16|0;gb=fa;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{l=b+e|0;if(w[l|0]!=79|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))!=(w[90128]|w[90129]<<8|(w[90130]<<16|w[90131]<<24))){break f}h=b+26|0;if((h|0)>=(a|0)){break e}j=b+27|0;p=e+h|0;c=w[p|0];if((a|0)<=(j+c|0)){break e}i=c+27|0;f=0;if(c){while(1){i=w[e+(f+j|0)|0]+i|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){$=22;f=ky(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){f=ky(f,0);$=$+1|0;if(($|0)!=26){continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=i-26;v[c+1424>>2]=w[l+22|0]|w[l+23|0]<<8|(w[l+24|0]<<16|w[l+25|0]<<24);f=w[e+(h+w[p|0]|0)|0]==255?-1:w[l+6|0]|w[l+7|0]<<8|(w[l+8|0]<<16|w[l+9|0]<<24);v[c+1436>>2]=h;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){l=d+B(a,20)|0;p=l+1432|0;c=v[p>>2];f=0;j=v[l+1436>>2];h=b-j|0;k=l+1428|0;i=v[k>>2];h=(h|0)<(i|0)?h:i;if((h|0)>=1){while(1){c=ky(c,w[e+(f+j|0)|0]);n=f+1|0;f=n;if((h|0)!=(n|0)){continue}break}}f=i-h|0;v[k>>2]=f;v[p>>2]=c;g:{if(!f){f=c;c=l+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+j|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;l=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=l;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!hJ(a)){v[f>>2]=0;b=0;break a}ja=gb-16|0;gb=ja;h=fa+4|0;j=h;l=a;c=l;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}p=Me(g);if(v[g+96>>2]){break i}if((p|0)!=79){break j}if((Me(g)|0)!=103){break j}if((Me(g)|0)!=103){break j}if((Me(g)|0)!=83){break j}if(!cJ(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;ec(g,32);break i}k=hy(g);break i}ec(g,30)}if(!k){break h}if(nc(c,1)){ec(c,35);break h}m=ja;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=nc(c,Dm(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ja+12>>2]=g;k=c+B(g,6)|0;if(!w[k+412|0]){i=v[c+112>>2];g=i>>1;break m}i=v[c+116>>2];g=i>>1;n=nc(c,1);H=nc(c,1);if(n|!w[k+412|0]){break m}v[j>>2]=i-v[c+112>>2]>>2;j=v[c+112>>2]+i>>2;break l}aa(3382,10534,3152,8021);L()}v[j>>2]=0;j=g}v[m+8>>2]=j;n:{if(!(!w[k+412|0]|H)){g=B(i,3);v[fa+8>>2]=g-v[c+112>>2]>>2;i=g+v[c+112>>2]>>2;break n}v[fa+8>>2]=g}v[ja+4>>2]=i;i=1}if(i){o:{ga=v[h>>2];pa=v[fa+8>>2];oa=v[ja+4>>2];ra=h;i=0;R=gb-2368|0;gb=R;q=v[l+404>>2];qa=l+B(v[ja+12>>2],6)|0;D=w[qa+413|0];W=q+B(D,40)|0;ha=W;ba=v[(l+(w[qa+412|0]<<2)|0)+104>>2];p:{p=v[l+4>>2];q:{if((p|0)>0){while(1){c=w[(v[ha+4>>2]+B(i,3)|0)+2|0];O=(R+1344|0)+(i<<2)|0;v[O>>2]=0;g=w[(c+W|0)+9|0];if(!x[(l+(g<<1)|0)+132>>1]){ec(l,21);c=0;break q}h=v[l+260>>2];r:{s:{if(nc(l,1)){c=2;k=v[(l+(i<<2)|0)+996>>2];p=h+B(g,1596)|0;F=v[(w[p+1588|0]<<2)+69708>>2];g=Dm(F)-1|0;Aa=k,Ba=nc(l,g),u[Aa>>1]=Ba;Aa=k,Ba=nc(l,g),u[Aa+2>>1]=Ba;j=0;if(w[p|0]){while(1){T=w[(j+p|0)+1|0];h=T+p|0;n=w[h+33|0];g=0;r=w[h+49|0];t:{if(!r){break t}h=v[l+124>>2]+B(w[h+65|0],2096)|0;if(v[l+1396>>2]<=9){rl(l)}m=v[l+1392>>2];g=u[(h+((m&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=m;m=w[g+v[h+8>>2]|0];v[l+1392>>2]=E>>>m;P=v[l+1396>>2]-m|0;m=(P|0)<0;v[l+1396>>2]=m?0:P;g=m?-1:g;break u}g=Cm(l,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(n){K=-1<<r^-1;h=c+n|0;while(1){m=0;n=u[((p+(T<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((n|0)<0){break v}n=v[l+124>>2]+B(n&65535,2096)|0;if(v[l+1396>>2]<=9){rl(l)}P=v[l+1392>>2];m=u[(n+((P&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){E=P;P=w[m+v[n+8>>2]|0];v[l+1392>>2]=E>>>P;H=v[l+1396>>2]-P|0;P=(H|0)<0;v[l+1396>>2]=P?0:H;m=P?-1:m;break w}m=Cm(l,n)}if(!w[n+23|0]){break v}m=v[v[n+2088>>2]+(m<<2)>>2]}g=g>>r;u[k+(c<<1)>>1]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}j=j+1|0;if(j>>>0<w[p|0]){continue}break}}if(v[l+1396>>2]!=-1){break s}}v[O>>2]=1;break r}u[R+320>>1]=257;j=p+1592|0;c=v[p+1592>>2];if((c|0)>=3){g=2;while(1){h=p+338|0;n=g<<1;r=n+p|0;O=w[r+1088|0];P=O<<1;m=x[h+P>>1];T=w[r+1089|0];K=T<<1;H=u[k+P>>1];r=u[K+k>>1]-H|0;P=r>>31;h=(B(x[h+n>>1]-m|0,P^r+P)|0)/(x[h+K>>1]-m|0)|0;m=H+((r|0)<0?0-h|0:h)|0;P=k+n|0;n=x[P>>1];x:{y:{if(n){h=R+320|0;t[h+T|0]=1;t[h+O|0]=1;t[g+h|0]=1;h=n<<16>>16;r=F-m|0;if((h|0)>=((m|0)>(r|0)?r:m)<<1){if((m|0)<(r|0)){break x}m=F+(n^-1)|0;break y}if(h&1){m=m-(h+1>>>1|0)|0;break y}m=(h>>1)+m|0;break y}t[(R+320|0)+g|0]=0}u[P>>1]=m;c=v[j>>2]}g=g+1|0;if((g|0)<(c|0)){continue}break}}m=0;if((c|0)<=0){break r}while(1){if(!w[(R+320|0)+m|0]){u[k+(m<<1)>>1]=65535;c=v[j>>2]}m=m+1|0;if((m|0)<(c|0)){continue}break}}i=i+1|0;p=v[l+4>>2];if((i|0)<(p|0)){continue}break}}z:{A:{c=v[l+80>>2];if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){hc(R+320|0,R+1344|0,p<<2);h=x[W>>1];if(h){j=v[ha+4>>2];m=0;while(1){i=j+B(m,3)|0;g=w[i+1|0];n=R+1344|0;i=n+(w[i|0]<<2)|0;if(!(v[(g<<2)+n>>2]?v[i>>2]:0)){v[(R+1344|0)+(g<<2)>>2]=0;v[i>>2]=0}m=m+1|0;if((h|0)!=(m|0)){continue}break}}P=ba>>1;ma=q+B(D,40)|0;if(w[ma+8|0]){c=0;while(1){B:{if((p|0)<1){g=0;break B}i=v[ha+4>>2];m=0;g=0;while(1){if(w[(i+B(m,3)|0)+2|0]==(c|0)){k=g+R|0;h=m<<2;C:{if(v[h+(R+1344|0)>>2]){j=1;h=0;break C}j=0;h=v[(h+l|0)+800>>2]}t[k|0]=j;v[(R+256|0)+(g<<2)>>2]=h;g=g+1|0}m=m+1|0;if((m|0)!=(p|0)){continue}break}}ia=R+256|0;D=R;I=gb-16|0;gb=I;h=l;H=v[h+4>>2];m=v[h+396>>2];i=w[(c+ma|0)+24|0];U=m+B(i,24)|0;k=v[U+4>>2];p=P;na=x[(h+(i<<1)|0)+268>>1];j=p<<((na|0)==2);n=j>>>0>k>>>0?k:j;k=v[U>>2];E=(n-(j>>>0>k>>>0?k:j)>>>0)/y[U+8>>2]|0;F=E<<2;j=B(H,F+4|0);V=v[v[h+124>>2]+B(w[U+13|0],2096)>>2];wa=v[h+92>>2];D:{if(v[h+80>>2]){j=bo(h,j);H=v[h+4>>2];break D}j=Cd(j)}k=0;if((H|0)>=1){n=(H<<2)+j|0;while(1){v[(k<<2)+j>>2]=n;n=n+F|0;k=k+1|0;if((H|0)!=(k|0)){continue}break}}F=j;E:{F:{G:{if((g|0)>=1){j=p<<2;k=0;while(1){if(!w[k+D|0]){Qb(v[ia+(k<<2)>>2],0,j)}k=k+1|0;if((k|0)!=(g|0)){continue}break}if((g|0)==1|(na|0)!=2){break G}k=0;while(1){if(!w[k+D|0]){break F}k=k+1|0;if((k|0)!=(g|0)){continue}break}break E}k=0;if((na|0)==2){break F}}sa=m+B(i,24)|0;xa=sa;ya=(E|0)<1;H=0;while(1){if(!ya){j=0;ta=(g|0)<1;za=ta|(H|0)!=0;p=0;while(1){k=0;if(!za){while(1){if(!w[k+D|0]){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){rl(h)}m=v[h+1392>>2];n=u[(i+((m&1023)<<1)|0)+36>>1];H:{if((n|0)>=0){q=m;m=w[n+v[i+8>>2]|0];v[h+1392>>2]=q>>>m;r=v[h+1396>>2]-m|0;m=(r|0)<0;v[h+1396>>2]=m?0:r;n=m?-1:n;break H}n=Cm(h,i)}n=w[i+23|0]?v[v[i+2088>>2]+(n<<2)>>2]:n;if((n|0)==-1){break E}v[v[F+(k<<2)>>2]+(j<<2)>>2]=v[v[sa+16>>2]+(n<<2)>>2]}k=k+1|0;if((k|0)!=(g|0)){continue}break}}I:{if((V|0)<1){break I}n=0;if((p|0)>=(E|0)){break I}while(1){k=0;if(!ta){while(1){J:{if(w[k+D|0]){break J}m=k<<2;i=u[(v[xa+20>>2]+(w[v[v[m+F>>2]+(j<<2)>>2]+n|0]<<4)|0)+(H<<1)>>1];if((i|0)<0){break J}O=h;i=v[h+124>>2]+B(i&65535,2096)|0;da=v[m+ia>>2];_=v[U+8>>2];m=v[U>>2]+B(_,p)|0;K:{L:{M:{if(na){M=0;T=1;if((_|0)<=0){break K}while(1){ka=da+(m<<2)|0;K=_-M|0;r=0;o=C(0);G=$I(O,i);N:{if((G|0)<0){break N}q=i;r=v[i>>2];K=(r|0)<(K|0)?r:K;la=B(r,G);O:{P:{if(w[i+22|0]){G=0;if((K|0)>0){break P}break O}G=0;if((K|0)<=0){break O}while(1){r=ka+(G<<2)|0;z[r>>2]=z[r>>2]+C(z[v[q+28>>2]+(G+la<<2)>>2]+C(0));r=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}while(1){r=ka+(G<<2)|0;o=C(o+z[v[q+28>>2]+(G+la<<2)>>2]);z[r>>2]=z[r>>2]+o;o=C(o+z[q+12>>2]);r=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}r=1}if(!r){break M}r=v[i>>2];m=r+m|0;M=r+M|0;if((_|0)>(M|0)){continue}break}break K}M=0;q=(_|0)/v[i>>2]|0;if((q|0)<=0){break L}ka=da+(m<<2)|0;while(1){la=ka+(M<<2)|0;G=_-(m+M|0)|0;K=q;r=0;o=C(0);ua=$I(O,i);Q:{if((ua|0)<0){break Q}r=1;T=i;da=v[i>>2];va=(G|0)>(da|0)?da:G;if((va|0)<1){break Q}da=B(da,ua);G=0;while(1){r=la+(B(G,K)<<2)|0;s=C(o+z[v[T+28>>2]+(G+da<<2)>>2]);z[r>>2]=z[r>>2]+s;o=w[T+22|0]?s:o;r=1;G=G+1|0;if((va|0)!=(G|0)){continue}break}}if(!r){break M}M=M+1|0;if((q|0)!=(M|0)){continue}break}break L}T=0;break K}T=1}if(!T){break E}}k=k+1|0;if((k|0)!=(g|0)){continue}break}}p=p+1|0;n=n+1|0;if((V|0)<=(n|0)){break I}if((p|0)<(E|0)){continue}break}}j=j+1|0;if((p|0)<(E|0)){continue}break}}H=H+1|0;if((H|0)!=8){continue}break}break E}if((g|0)==(k|0)){break E}m=m+B(i,24)|0;r=m;O=(g|0)!=2;D=(E|0)<1;T=(g|0)<3;n=0;while(1){R:{if(!O){k=0;H=0;if(D){break R}while(1){j=v[U>>2]+B(v[U+8>>2],k)|0;v[I+12>>2]=j&1;v[I+8>>2]=j>>1;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){rl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];S:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break S}j=Cm(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}T:{if((V|0)<1){break T}i=0;if((k|0)>=(E|0)){break T}while(1){j=v[U+8>>2];q=u[(v[r+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];U:{if((q|0)>=0){if(bJ(h,v[h+124>>2]+B(q&65535,2096)|0,ia,2,I+12|0,I+8|0,p,j)){break U}break E}j=v[U>>2]+(j+B(j,k)|0)|0;v[I+8>>2]=j>>1;v[I+12>>2]=j&1}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break T}if((k|0)<(E|0)){continue}break}}H=H+1|0;if((k|0)<(E|0)){continue}break}break R}if(T){break R}k=0;H=0;if(D){break R}while(1){i=v[U>>2]+B(v[U+8>>2],k)|0;j=(i|0)/(g|0)|0;v[I+12>>2]=i-B(g,j);v[I+8>>2]=j;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){rl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];V:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break V}j=Cm(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}W:{if((V|0)<1){break W}i=0;if((k|0)>=(E|0)){break W}while(1){j=v[U+8>>2];q=u[(v[r+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];X:{if((q|0)>=0){if(bJ(h,v[h+124>>2]+B(q&65535,2096)|0,ia,g,I+12|0,I+8|0,p,j)){break X}break E}j=v[U>>2]+(j+B(j,k)|0)|0;q=(j|0)/(g|0)|0;v[I+8>>2]=q;v[I+12>>2]=j-B(g,q)}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break W}if((k|0)<(E|0)){continue}break}}H=H+1|0;if((k|0)<(E|0)){continue}break}}n=n+1|0;if((n|0)!=8){continue}break}}if(!v[h+80>>2]){Yb(F)}v[h+92>>2]=wa;gb=I+16|0;c=c+1|0;if(c>>>0<w[ma+8|0]){p=v[l+4>>2];continue}break}c=v[l+80>>2]}if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){i=x[W>>1];if(i){h=(P|0)>1?P:1;g=l+800|0;while(1){c=i;i=c-1|0;if((ba|0)>=2){j=v[ha+4>>2]+B(i,3)|0;p=v[g+(w[j+1|0]<<2)>>2];j=v[g+(w[j|0]<<2)>>2];m=0;while(1){k=m<<2;n=k+p|0;A=z[n>>2];k=j+k|0;o=z[k>>2];Y:{if(o>C(0)){if(A>C(0)){s=C(o-A);break Y}s=o;o=C(o+A);break Y}if(A>C(0)){s=C(o+A);break Y}s=o;o=C(o-A)}z[k>>2]=o;z[n>>2]=s;m=m+1|0;if((h|0)!=(m|0)){continue}break}}if((c|0)>1){continue}break}}m=0;if(v[l+4>>2]<=0){break z}U=P<<2;while(1){g=m<<2;h=g+l|0;c=h;Z:{if(v[g+(R+320|0)>>2]){Qb(v[c+800>>2],0,U);break Z}g=ba;j=v[c+800>>2];T=v[h+996>>2];k=1;c=l;h=w[(W+w[(v[W+4>>2]+B(m,3)|0)+2|0]|0)+9|0];_:{if(!x[(c+(h<<1)|0)+132>>1]){ec(c,21);break _}r=g>>1;F=v[c+260>>2]+B(h,1596)|0;g=B(w[F+1588|0],u[T>>1]);c=0;n=v[F+1592>>2];if((n|0)>=2){G=F+1592|0;I=F+1588|0;while(1){h=w[(k+F|0)+838|0]<<1;i=u[h+T>>1];if((i|0)>=0){i=B(w[I|0],i&65535);h=x[(h+F|0)+338>>1];if((h|0)!=(c|0)){p=j;n=c;D=i-g|0;q=h-c|0;O=(D|0)/(q|0)|0;K=(h|0)>(r|0)?r:h;$:{if((K|0)<=(c|0)){break $}c=p+(n<<2)|0;z[c>>2]=z[((g&255)<<2)+69728>>2]*z[c>>2];c=n+1|0;if((K|0)<=(c|0)){break $}n=D>>31;E=n+D^n;n=O>>31;n=E-B(q,n+O^n)|0;D=(D|0)>-1?1:-1;H=0;while(1){E=p+(c<<2)|0;H=n+H|0;M=(H|0)<(q|0);g=(g+O|0)+(M?0:D)|0;z[E>>2]=z[((g&255)<<2)+69728>>2]*z[E>>2];H=H-(M?0:q)|0;c=c+1|0;if((K|0)!=(c|0)){continue}break}}n=v[G>>2];c=h}g=i}k=k+1|0;if((n|0)>(k|0)){continue}break}}if((c|0)<(r|0)){o=z[(g<<2)+69728>>2];while(1){g=j+(c<<2)|0;z[g>>2]=o*z[g>>2];c=c+1|0;if((r|0)!=(c|0)){continue}break}}}}m=m+1|0;c=v[l+4>>2];if((m|0)<(c|0)){continue}break}break A}aa(3382,10534,3335,2726);L()}aa(3382,10534,3302,2726);L()}m=0;if((c|0)<=0){break z}while(1){ha=w[qa+412|0];F=ba;V=F>>1;g=V<<2;r=l;na=v[l+92>>2];p=v[(l+(m<<2)|0)+800>>2];c=V<<2;W=p+c|0;aa:{if(v[l+80>>2]){n=bo(r,g);break aa}n=Cd(g)}h=(n+c|0)-8|0;i=v[(r+(ha<<2)|0)+1068>>2];ba:{if(F>>>0<2){c=i;break ba}g=p;c=i;while(1){z[h+4>>2]=C(z[g>>2]*z[c>>2])-C(z[g+8>>2]*z[c+4>>2]);z[h>>2]=C(z[g>>2]*z[c+4>>2])+C(z[g+8>>2]*z[c>>2]);c=c+8|0;h=h-8|0;g=g+16|0;if((W|0)!=(g|0)){continue}break}}if(h>>>0>=n>>>0){g=((V<<2)+p|0)-12|0;while(1){z[h+4>>2]=C(z[g>>2]*z[c+4>>2])-C(z[g+8>>2]*z[c>>2]);z[h>>2]=C(z[c>>2]*C(-z[g>>2]))-C(z[g+8>>2]*z[c+4>>2]);g=g-16|0;c=c+8|0;h=h-8|0;if(n>>>0<=h>>>0){continue}break}}ia=F>>2;if((F|0)>=16){c=ia<<2;h=c+n|0;k=c+p|0;c=(i+(V<<2)|0)-32|0;j=p;g=n;while(1){o=z[g>>2];s=z[h>>2];A=z[h+4>>2];J=z[g+4>>2];z[k+4>>2]=A+J;z[k>>2]=z[h>>2]+z[g>>2];A=C(A-J);o=C(s-o);z[j+4>>2]=C(A*z[c+16>>2])-C(o*z[c+20>>2]);z[j>>2]=C(o*z[c+16>>2])+C(A*z[c+20>>2]);o=z[g+8>>2];s=z[h+8>>2];A=z[h+12>>2];J=z[g+12>>2];z[k+12>>2]=A+J;z[k+8>>2]=z[h+8>>2]+z[g+8>>2];A=C(A-J);o=C(s-o);z[j+12>>2]=C(A*z[c>>2])-C(o*z[c+4>>2]);z[j+8>>2]=C(o*z[c>>2])+C(A*z[c+4>>2]);g=g+16|0;h=h+16|0;j=j+16|0;k=k+16|0;c=c-32|0;if(i>>>0<=c>>>0){continue}break}}D=Dm(F);g=F>>4;k=V-1|0;c=F>>3;h=0-c|0;aJ(g,p,k,h,i);aJ(g,p,k-ia|0,h,i);_=F>>5;g=0-g|0;cq(_,p,k,g,i,16);cq(_,p,k-c|0,g,i,16);cq(_,p,k-(c<<1)|0,g,i,16);cq(_,p,k+B(c,-3)|0,g,i,16);j=2;if((D|0)>=10){j=D-4>>>1|0;h=2;while(1){g=h;h=g+1|0;q=2<<g;if((q|0)>=1){O=8<<g;T=F>>g+4;c=0;g=F>>g+2;K=0-(g>>1)|0;while(1){cq(T,p,k-B(c,g)|0,K,i,O);c=c+1|0;if((q|0)!=(c|0)){continue}break}}if((h|0)!=(j|0)){continue}break}}ma=D-7|0;if((ma|0)>(j|0)){while(1){g=j;j=g+1|0;c=F>>g+6;if((c|0)>=1){T=2<<g;K=8<<g;da=K<<2;H=F>>g+2;U=0-(H>>1)|0;h=i;g=k;while(1){G=p;I=g;E=U;D=h;q=K;M=H;O=T;if((O|0)>=1){ka=D+B(q,12)|0;o=z[ka>>2];la=D+(q<<3)|0;s=z[la>>2];q=D+(q<<2)|0;A=z[q>>2];J=z[ka+4>>2];Q=z[la+4>>2];X=z[q+4>>2];Y=z[D+4>>2];ea=z[D>>2];D=G+(I<<2)|0;G=D+(E<<2)|0;q=0-M<<2;while(1){I=G-4|0;S=z[I>>2];Z=z[D>>2];ca=z[G>>2];z[D>>2]=Z+ca;E=D-4|0;N=z[E>>2];z[E>>2]=N+z[I>>2];Z=C(Z-ca);N=C(N-S);z[I>>2]=C(Y*Z)+C(ea*N);z[G>>2]=C(ea*Z)-C(Y*N);I=G-12|0;Z=z[I>>2];E=D-8|0;N=z[E>>2];M=E;E=G-8|0;ca=z[E>>2];z[M>>2]=N+ca;M=D-12|0;S=z[M>>2];z[M>>2]=S+z[I>>2];N=C(N-ca);S=C(S-Z);z[I>>2]=C(X*N)+C(A*S);z[E>>2]=C(A*N)-C(X*S);I=G-20|0;Z=z[I>>2];E=D-16|0;N=z[E>>2];M=E;E=G-16|0;ca=z[E>>2];z[M>>2]=N+ca;M=D-20|0;S=z[M>>2];z[M>>2]=S+z[I>>2];N=C(N-ca);S=C(S-Z);z[I>>2]=C(Q*N)+C(s*S);z[E>>2]=C(s*N)-C(Q*S);I=G-28|0;Z=z[I>>2];E=D-24|0;N=z[E>>2];M=E;E=G-24|0;ca=z[E>>2];z[M>>2]=N+ca;M=D-28|0;S=z[M>>2];z[M>>2]=S+z[I>>2];N=C(N-ca);S=C(S-Z);z[I>>2]=C(J*N)+C(o*S);z[E>>2]=C(o*N)-C(J*S);G=q+G|0;D=q+D|0;I=(O|0)>1;O=O-1|0;if(I){continue}break}}g=g-8|0;h=(da<<2)+h|0;D=(c|0)>1;c=c-1|0;if(D){continue}break}}if((j|0)!=(ma|0)){continue}break}}c=p;g=F;if((0-(_<<4)|0)<=-1){c=c+(k<<2)|0;h=c-(_<<6)|0;o=z[i+(g>>3<<2)>>2];ea=C(-o);while(1){Q=z[c>>2];g=c-32|0;X=z[g>>2];z[c>>2]=Q+X;j=c-4|0;s=z[j>>2];i=j;j=c-36|0;Y=z[j>>2];z[i>>2]=s+Y;i=c-8|0;A=z[i>>2];k=i;i=c-40|0;N=z[i>>2];z[k>>2]=A+N;k=c-12|0;J=z[k>>2];q=k;k=c-44|0;S=z[k>>2];z[q>>2]=J+S;z[g>>2]=Q-X;z[j>>2]=s-Y;j=c-16|0;s=z[j>>2];q=j;j=c-48|0;Z=z[j>>2];z[q>>2]=s+Z;A=C(A-N);J=C(J-S);z[i>>2]=o*C(A+J);z[k>>2]=o*C(J-A);i=c-28|0;A=z[i>>2];k=c-60|0;J=z[k>>2];D=c-24|0;Q=z[D>>2];q=c-56|0;X=z[q>>2];O=c-20|0;Y=z[O>>2];E=O;O=c-52|0;N=z[O>>2];z[E>>2]=Y+N;z[D>>2]=Q+X;z[i>>2]=A+J;z[j>>2]=Y-N;z[O>>2]=-C(s-Z);s=C(A-J);A=C(Q-X);z[q>>2]=o*C(s-A);z[k>>2]=C(A+s)*ea;_I(c);_I(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}D=V-4|0;c=(n+(ia<<2)|0)-16|0;if(n>>>0<=c>>>0){h=n+(D<<2)|0;g=v[(r+(ha<<2)|0)+1100>>2];while(1){j=(x[g>>1]<<2)+p|0;z[h+12>>2]=z[j>>2];z[h+8>>2]=z[j+4>>2];z[c+12>>2]=z[j+8>>2];z[c+8>>2]=z[j+12>>2];j=(x[g+2>>1]<<2)+p|0;z[h+4>>2]=z[j>>2];z[h>>2]=z[j+4>>2];z[c+4>>2]=z[j+8>>2];z[c>>2]=z[j+12>>2];g=g+4|0;h=h-16|0;c=c-16|0;if(n>>>0<=c>>>0){continue}break}}h=n+(V<<2)|0;i=h-16|0;if(n>>>0<i>>>0){g=v[(r+(ha<<2)|0)+1084>>2];k=h;c=n;while(1){o=z[c+4>>2];j=k-4|0;s=z[j>>2];A=C(o-s);J=z[g+4>>2];o=C(o+s);s=z[c>>2];q=k-8|0;Q=z[q>>2];X=C(s-Q);Y=z[g>>2];ea=C(C(J*o)-C(X*Y));z[c+4>>2]=A+ea;s=C(s+Q);o=C(C(X*J)+C(o*Y));z[c>>2]=s+o;z[j>>2]=ea-A;z[q>>2]=s-o;o=z[c+12>>2];j=k-12|0;s=z[j>>2];A=C(o-s);J=z[g+12>>2];o=C(o+s);s=z[c+8>>2];Q=z[i>>2];X=C(s-Q);Y=z[g+8>>2];ea=C(C(J*o)-C(X*Y));z[c+12>>2]=A+ea;s=C(s+Q);o=C(C(X*J)+C(o*Y));z[c+8>>2]=s+o;z[i>>2]=s-o;z[j>>2]=ea-A;g=g+16|0;c=c+16|0;k=i;i=i-16|0;if(c>>>0<i>>>0){continue}break}}i=h-32|0;if(n>>>0<=i>>>0){c=v[(r+(ha<<2)|0)+1076>>2]+(V<<2)|0;g=(D<<2)+p|0;k=((F<<2)+p|0)-16|0;while(1){o=z[h-8>>2];s=z[c-4>>2];A=z[h-4>>2];J=z[c-8>>2];Q=C(C(o*s)-C(A*J));z[p>>2]=Q;z[g+12>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W>>2]=o;z[k+12>>2]=o;o=z[h-16>>2];s=z[c-12>>2];A=z[h-12>>2];J=z[c-16>>2];Q=C(C(o*s)-C(A*J));z[p+4>>2]=Q;z[g+8>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+4>>2]=o;z[k+8>>2]=o;o=z[h-24>>2];s=z[c-20>>2];A=z[h-20>>2];J=z[c-24>>2];Q=C(C(o*s)-C(A*J));z[p+8>>2]=Q;z[g+4>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+8>>2]=o;z[k+4>>2]=o;o=z[i>>2];s=z[c-28>>2];A=z[h-28>>2];c=c-32|0;J=z[c>>2];Q=C(C(o*s)-C(A*J));z[p+12>>2]=Q;z[g>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+12>>2]=o;z[k>>2]=o;k=k-16|0;g=g-16|0;W=W+16|0;p=p+16|0;h=i;i=h-32|0;if(n>>>0<=i>>>0){continue}break}}if(!v[r+80>>2]){Yb(n)}v[r+92>>2]=na;m=m+1|0;if((m|0)<v[l+4>>2]){continue}break}}eJ(l);ca:{if(w[l+1377|0]){v[l+1060>>2]=0-P;t[l+1377|0]=0;v[l+1064>>2]=1;v[l+1412>>2]=ba-oa;break ca}c=v[l+1412>>2];if(!c){break ca}g=pa-ga|0;if((g|0)<=(c|0)){v[l+1412>>2]=c-g;v[ra>>2]=pa;ga=pa;break ca}ga=c+ga|0;v[ra>>2]=ga;v[l+1412>>2]=0}g=v[l+1064>>2];c=l;da:{ea:{fa:{if(v[c+1388>>2]==v[c+1404>>2]){ga:{if(!g|!(w[l+1375|0]&4)){break ga}g=v[l+1408>>2];h=v[l+1060>>2];if(g>>>0>=h+(oa-ga|0)>>>0){break ga}c=g-h|0;c=(c>>>0>g>>>0?0:c)+ga|0;c=(c|0)>(oa|0)?oa:c;v[fa+12>>2]=c;v[l+1060>>2]=c+v[l+1060>>2];break da}v[l+1064>>2]=1;g=v[l+1408>>2]+(ga-P|0)|0;break fa}if(!g){break ea}g=v[l+1060>>2]}v[c+1060>>2]=(pa-ga|0)+g}if(v[l+84>>2]!=v[l+92>>2]?v[l+80>>2]:0){break p}v[fa+12>>2]=oa}c=1}gb=R+2368|0;break o}aa(3382,10534,3451,2726);L()}}else{c=0}gb=ja+16|0;if(!c){ha:{ia:{ja:{c=v[a+100>>2];switch(c-32|0){case 0:break ia;case 3:break ja;default:break ha}}v[a+100>>2]=0;while(1){if(Aa=0,Ba=(ph(a)|0)!=-1,Ca=v[a+96>>2],Ca?Aa:Ba){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ha}v[a+100>>2]=0;while(1){if(Aa=0,Ba=(ph(a)|0)!=-1,Ca=v[a+96>>2],Ca?Aa:Ba){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}j=fa;p=v[j+12>>2];n=v[j+4>>2];k=n;g=v[j+8>>2];ka:{la:{ma:{na:{c=a;i=v[c+992>>2];oa:{if(!i){h=v[c+4>>2];i=0;break oa}F=i<<1;pa:{if((F|0)==v[c+112>>2]){h=l+1092|0}else{h=0;if((F|0)!=v[l+116>>2]){break pa}h=l+1096|0}h=v[h>>2]}l=h;if(!l){break la}h=v[c+4>>2];if((h|0)<=0){break na}F=(i|0)<1;while(1){if(!F){ba=c+($<<2)|0;m=ba;h=0;while(1){R=v[ba+800>>2]+(h+k<<2)|0;q=R;o=z[R>>2];R=h<<2;z[q>>2]=C(o*z[R+l>>2])+C(z[R+v[m+928>>2]>>2]*z[l+(i+(h^-1)<<2)>>2]);h=h+1|0;if((i|0)!=(h|0)){continue}break}h=v[c+4>>2]}$=$+1|0;if(($|0)<(h|0)){continue}break}i=v[c+992>>2]}F=p-g|0;v[c+992>>2]=F;if((h|0)>=1){$=0;while(1){if((g|0)<(p|0)){ba=c+($<<2)|0;m=ba;h=0;l=g;while(1){z[v[m+928>>2]+(h<<2)>>2]=z[v[ba+800>>2]+(l<<2)>>2];h=h+1|0;l=g+h|0;if((h|0)!=(F|0)){continue}break}h=v[c+4>>2]}$=$+1|0;if(($|0)<(h|0)){continue}break}}if(!i){break la}break ma}v[c+992>>2]=p-g}h=c;i=v[c+1416>>2];c=((g|0)>(p|0)?p:g)-k|0;v[h+1416>>2]=i+c;break ka}c=0}g=c;v[j+12>>2]=c;l=v[a+4>>2];if((l|0)>=1){c=0;while(1){h=(c<<2)+a|0;v[h+864>>2]=v[h+800>>2]+(n<<2);c=c+1|0;if((l|0)!=(c|0)){continue}break}}if(d){v[d>>2]=l}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}gb=fa+16|0;return b|0}function p6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=C(0);s=gb-1520|0;gb=s;f=s+8|0;g=Qb(f,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;p=gb-1024|0;gb=p;t[f+1377|0]=1;a:{if(!pt(f)){break a}e=w[f+1375|0];if(!(e&2)){ec(f,34);break a}if(e&4){ec(f,34);break a}if(e&1){ec(f,34);break a}if(v[f+1116>>2]!=1){ec(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!jy(f,p+1018|0,6)|w[p+1018|0]!=102|(w[p+1019|0]!=105|w[p+1020|0]!=115)){break b}if(w[p+1021|0]!=104|w[p+1022|0]!=101|w[p+1023|0]!=97){break b}if((Me(f)|0)!=100){break b}if(Me(f)){break b}ec(f,38);break a}ec(f,34);break a}if((Me(f)|0)!=1){ec(f,34);break a}if(!jy(f,p+1018|0,6)){ec(f,10);break a}if(!iy(p+1018|0)){ec(f,34);break a}if(zj(f)){ec(f,34);break a}e=Me(f);v[f+4>>2]=e;if(!e){ec(f,34);break a}if(e>>>0>=17){ec(f,5);break a}e=zj(f);v[f>>2]=e;if(!e){ec(f,34);break a}zj(f);zj(f);zj(f);e=Me(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){ec(f,20);break a}if((e<<24)-1610612736>>24<=-1){ec(f,20);break a}if(g>>>0>h>>>0){ec(f,20);break a}if(!(Me(f)&1)){ec(f,34);break a}if(!pt(f)){break a}if(!hy(f)){break a}if(!gy(f)){break a}c:{d:{if((ph(f)|0)==3){while(1){Q=(p+1018|0)+b|0,R=ph(f),t[Q|0]=R;b=b+1|0;if((b|0)!=6){continue}break}if(!iy(p+1018|0)){ec(f,20);break c}g=fy(f);e=_d(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=ph(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=fy(f);v[f+28>>2]=0;v[f+24>>2]=b;e:{f:{if((b|0)<1){break f}b=_d(f,b<<2);v[f+28>>2]=b;if(!b){ec(f,3);break c}if(v[f+24>>2]<1){break f}while(1){g=fy(f);b=_d(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=ph(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(ph(f)&1)){ec(f,20);break c}gJ(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=gy(f);gJ(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!hy(f)){break a}if(!hJ(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){h=e<<24;g=0;while(1){h=h>>31&79764919^h<<1;g=g+1|0;if((g|0)!=8){continue}break}v[(e<<2)+459712>>2]=h;e=e+1|0;if((e|0)!=256){continue}break}if((ph(f)|0)==5){while(1){Q=(p+1018|0)+b|0,R=ph(f),t[Q|0]=R;b=b+1|0;if((b|0)!=6){continue}break}if(!iy(p+1018|0)){ec(f,20);break c}b=nc(f,8)+1|0;v[f+120>>2]=b;b=_d(f,B(b,2096));v[f+124>>2]=b;if(!b){ec(f,3);break c}Qb(b,0,B(v[f+120>>2],2096));g:{h:{i:{j:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((nc(f,8)&255)!=66){ec(f,20);break c}if((nc(f,8)&255)!=67){ec(f,20);break c}if((nc(f,8)&255)!=86){ec(f,20);break c}e=b+B(G,2096)|0;Q=e,R=nc(f,8)&255|nc(f,8)<<8,v[Q>>2]=R;Q=e,R=nc(f,8)&255|(nc(f,8)<<8&65280|nc(f,8)<<16),v[Q+4>>2]=R;b=0;k=nc(f,1);if(!k){b=nc(f,1)}t[e+23|0]=b;q=e+4|0;g=v[q>>2];k:{if(v[e>>2]){h=g;break k}h=0;if(!g){break k}ec(f,20);break c}l:{if(b&255){h=bo(f,h);break l}h=_d(f,h);v[e+8>>2]=h}if(!h){ec(f,3);break c}m:{if(!k){b=0;j=0;g=v[q>>2];if((g|0)<=0){break m}while(1){n:{o:{if(w[e+23|0]){if(!nc(f,1)){break o}}g=nc(f,5)+1|0;t[b+h|0]=g;if((g&255)!=32){j=j+1|0;break n}ec(f,20);break c}t[b+h|0]=255}b=b+1|0;g=v[q>>2];if((b|0)<(g|0)){continue}break}break m}i=nc(f,5);j=0;b=0;g=v[q>>2];if((g|0)<1){break m}while(1){k=nc(f,Dm(g-b|0));i=i+1|0;if((i|0)>=32){ec(f,20);break c}g=b+k|0;if((g|0)>v[q>>2]){ec(f,20);break c}Qb(b+h|0,i,k);b=g;g=v[q>>2];if((b|0)<(g|0)){continue}break}}p:{q:{if(w[e+23|0]){if(g>>2>(j|0)){break q}b=e;k=f;if(v[f+16>>2]<(g|0)){v[f+16>>2]=g;g=v[q>>2]}j=b;b=_d(k,g);v[j+8>>2]=b;if(!b){ec(f,3);break c}hc(b,h,v[q>>2]);yj(f,h,v[q>>2]);h=v[e+8>>2];t[e+23|0]=0;g=v[q>>2]}k=0;b=0;i=0;if((g|0)>=1){while(1){i=((w[b+h|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((g|0)!=(b|0)){continue}break}}v[e+2092>>2]=i;b=_d(f,g<<2);v[e+32>>2]=b;if(b){l=e+2092|0;break p}ec(f,3);break c}v[e+2092>>2]=j;l=e+2092|0;r:{if(!j){k=0;b=0;break r}b=_d(f,j);v[e+8>>2]=b;if(!b){ec(f,3);break c}b=bo(f,v[l>>2]<<2);v[e+32>>2]=b;if(!b){ec(f,3);break c}k=bo(f,v[l>>2]<<2);if(!k){break j}g=v[q>>2];b=v[l>>2]}b=(b<<3)+g|0;if(b>>>0<=y[f+16>>2]){break p}v[f+16>>2]=b}j=e;o=h;n=v[q>>2];i=k;m=0;b=gb-128|0;gb=b;A=Qb(b,0,128);s:{t:{u:{v:{w:{x:{y:{z:{if((n|0)<1){break z}while(1){if(w[m+o|0]!=255){break z}m=m+1|0;if((n|0)!=(m|0)){continue}break}break y}if((m|0)!=(n|0)){break x}}g=1;if(!v[j+2092>>2]){break w}aa(12835,10534,1103,4632);L()}b=m+o|0;g=w[b|0];if(g>>>0>=32){break v}ZI(j,0,m,0,g,i);g=w[b|0];if(g){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;r=(b|0)==(g|0);b=b+1|0;if(!r){continue}break}}K=1;r=m+1|0;if((n|0)<=(r|0)){g=1;break w}while(1){M=o+r|0;m=w[M|0];A:{if((m|0)==255){break A}if(m>>>0>31){break u}g=0;b=m;if(!b){break w}while(1){N=A+(b<<2)|0;I=v[N>>2];if(!I){I=(b|0)>1;b=b-1|0;if(I){continue}break w}break}v[N>>2]=0;ZI(j,Bm(I),r,K,m,i);K=K+1|0;m=w[M|0];if((m|0)<=(b|0)){break A}while(1){g=A+(m<<2)|0;if(v[g>>2]){break t}v[g>>2]=I+(1<<32-m);m=m-1|0;if((m|0)>(b|0)){continue}break}}g=1;r=r+1|0;if((n|0)!=(r|0)){continue}break}}gb=A+128|0;break s}aa(12357,10534,1104,4632);L()}aa(12350,10534,1118,4632);L()}aa(12879,10534,1133,4632);L()}if(!g){if(w[e+23|0]){yj(f,k,0)}ec(f,20);break c}b=v[l>>2];if(b){b=_d(f,(b<<2)+4|0);v[e+2084>>2]=b;if(!b){ec(f,3);break c}b=_d(f,(v[l>>2]<<2)+4|0);v[e+2088>>2]=b;if(!b){ec(f,3);break c}v[e+2088>>2]=b+4;v[b>>2]=-1;m=h;o=k;i=0;n=0;B:{b=e;if(w[b+23|0]){n=v[b+2092>>2];if((n|0)<=0){break B}while(1){g=i<<2;Q=g+v[b+2084>>2]|0,R=Bm(v[g+v[b+32>>2]>>2]),v[Q>>2]=R;i=i+1|0;n=v[b+2092>>2];if((i|0)<(n|0)){continue}break}break B}if(v[b+4>>2]>=1){while(1){if(YI(b,w[i+m|0])){Q=v[b+2084>>2]+(n<<2)|0,R=Bm(v[v[b+32>>2]+(i<<2)>>2]),v[Q>>2]=R;n=n+1|0}i=i+1|0;if((i|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(n|0)){break B}aa(4573,10534,1200,7252);L()}MI(v[b+2084>>2],n,2286);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;C:{n=w[b+23|0];I=v[b+(n?2092:4)>>2];if((I|0)<1){break C}g=0;while(1){D:{j=g;i=b;if(n&255){j=v[o+(g<<2)>>2]}M=w[j+m|0];E:{if(!YI(i,M)){break E}N=g<<2;j=Bm(v[N+v[b+32>>2]>>2]);A=v[b+2084>>2];i=0;n=v[b+2092>>2];if((n|0)>=2){while(1){r=n>>>1|0;O=r+i|0;K=j>>>0<y[A+(O<<2)>>2];i=K?i:O;n=K?r:n-r|0;if((n|0)>1){continue}break}}n=i<<2;if((j|0)!=v[n+A>>2]){break D}if(w[b+23|0]){v[n+v[b+2088>>2]>>2]=v[o+N>>2];t[v[b+8>>2]+i|0]=M;break E}v[n+v[b+2088>>2]>>2]=g}g=g+1|0;if((I|0)==(g|0)){break C}n=w[b+23|0];continue}break}aa(9485,10534,1230,7252);L()}}if(w[e+23|0]){yj(f,k,v[l>>2]<<2);yj(f,v[e+32>>2],v[l>>2]<<2);yj(f,h,v[q>>2]);v[e+32>>2]=0}b=e;Qb(b+36|0,255,2048);g=v[b+(w[b+23|0]?2092:4)>>2];if((g|0)>=1){j=(g|0)<32767?g:32767;k=v[b+8>>2];h=0;while(1){F:{if(w[h+k|0]>10){break F}G:{if(w[b+23|0]){g=Bm(v[v[b+2084>>2]+(h<<2)>>2]);break G}g=v[v[b+32>>2]+(h<<2)>>2]}if(g>>>0>1023){break F}while(1){u[(b+(g<<1)|0)+36>>1]=h;k=v[b+8>>2];g=(1<<w[k+h|0])+g|0;if(g>>>0<1024){continue}break}}h=h+1|0;if((j|0)!=(h|0)){continue}break}}b=nc(f,4);t[e+21|0]=b;b=b&255;if(b>>>0>=3){ec(f,20);break c}if(b){Q=e,S=fJ(nc(f,32)),z[Q+12>>2]=S;Q=e,S=fJ(nc(f,32)),z[Q+16>>2]=S;Q=e,R=nc(f,4)+1|0,t[Q+20|0]=R;Q=e,R=nc(f,1),t[Q+22|0]=R;h=v[e>>2];g=v[q>>2];H:{if(w[e+21|0]==1){F=H($w(+C(C(Sp(+C(g|0)))/C(h|0))));I:{if(D(F)<2147483648){b=~~F;break I}b=-2147483648}F=+(h|0);P=H(fk(+C(C(b|0)+C(1)),F));J:{if(D(P)<2147483648){h=~~P;break J}h=-2147483648}b=((h|0)<=(g|0))+b|0;E=C(b|0);if(fk(+C(E+C(1)),F)<=+(g|0)){b=-1}else{F=H(fk(+E,F));K:{if(D(F)<2147483648){h=~~F;break K}h=-2147483648}b=(h|0)>(g|0)?-1:b}if((b|0)>-1){break H}ec(f,20);break c}b=B(g,h)}v[e+24>>2]=b;if(!b){ec(f,20);break c}g=bo(f,b<<1);if(!g){break i}b=0;i=v[e+24>>2];if((i|0)>0){while(1){h=nc(f,w[e+20|0]);if((h|0)==-1){yj(f,g,v[e+24>>2]<<1);ec(f,20);break c}u[g+(b<<1)>>1]=h;b=b+1|0;i=v[e+24>>2];if((b|0)<(i|0)){continue}break}}L:{if(w[e+21|0]==1){h=w[e+23|0];M:{if(h){b=v[l>>2];if(b){break M}break L}b=v[q>>2]}b=_d(f,B(v[e>>2],b)<<2);v[e+28>>2]=b;if(!b){yj(f,g,v[e+24>>2]<<1);ec(f,3);break c}o=v[(h?l:q)>>2];if((o|0)>=1){n=e+2088|0;E=C(0);m=0;while(1){l=m;l=h?v[v[n>>2]+(l<<2)>>2]:l;N:{k=v[e>>2];if((k|0)<1){break N}j=v[e+24>>2];b=1;i=0;while(1){J=C(E+C(C(z[e+16>>2]*C(x[g+(((l>>>0)/(b>>>0)>>>0)%(j>>>0)<<1)>>1]))+z[e+12>>2]));z[v[e+28>>2]+(B(k,m)+i<<2)>>2]=J;E=w[e+22|0]?J:E;i=i+1|0;k=v[e>>2];if((i|0)>=(k|0)){break N}j=v[e+24>>2];nqa(j,0,b,0);if(!jb){b=B(b,j);continue}else{yj(f,g,j<<1);ec(f,20);break c}}}m=m+1|0;if((o|0)!=(m|0)){continue}break}}t[e+21|0]=2;i=v[e+24>>2];break L}b=_d(f,i<<2);v[e+28>>2]=b;i=v[e+24>>2];if(!b){break h}if((i|0)<1){break L}E=C(0);J=C(C(C(z[e+16>>2]*C(x[g>>1]))+z[e+12>>2])+C(0));z[b>>2]=J;b=1;i=v[e+24>>2];if((i|0)<=1){break L}while(1){E=w[e+22|0]?J:E;J=C(E+C(C(z[e+16>>2]*C(x[g+(b<<1)>>1]))+z[e+12>>2]));z[v[e+28>>2]+(b<<2)>>2]=J;b=b+1|0;i=v[e+24>>2];if((b|0)<(i|0)){continue}break}}yj(f,g,i<<1)}G=G+1|0;if((G|0)<v[f+120>>2]){continue}break}}O:{e=nc(f,6)+1&255;if(!e){break O}b=0;while(1){if(!nc(f,16)){b=b+1|0;if((e|0)!=(b|0)){continue}break O}break}ec(f,20);break c}b=nc(f,6)+1|0;v[f+128>>2]=b;b=_d(f,B(b,1596));v[f+260>>2]=b;if(!b){break g}m=0;if(v[f+128>>2]<=0){break d}G=0;P:while(1){b=nc(f,16);u[((m<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(f,20);break c}if(!b){e=v[f+260>>2]+B(m,1596)|0;Q=e,R=nc(f,8),t[Q|0]=R;Q=e,R=nc(f,16),u[Q+2>>1]=R;Q=e,R=nc(f,16),u[Q+4>>1]=R;Q=e,R=nc(f,6),t[Q+6|0]=R;Q=e,R=nc(f,8),t[Q+7|0]=R;b=(nc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){Q=b+g|0,R=nc(f,8),t[Q|0]=R;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}ec(f,4);break c}l=v[f+260>>2]+B(m,1596)|0;e=nc(f,5);t[l|0]=e;b=-1;i=0;g=0;if(e&255){while(1){e=nc(f,4);t[(g+l|0)+1|0]=e;e=e&255;b=(b|0)<(e|0)?e:b;g=g+1|0;if(g>>>0<w[l|0]){continue}break}while(1){e=i+l|0;Q=e,R=nc(f,3)+1|0,t[Q+33|0]=R;g=nc(f,2);t[e+49|0]=g;Q:{if(g&255){g=nc(f,8);t[e+65|0]=g;if(v[f+120>>2]<=(g&255)){ec(f,20);break c}if(w[e+49|0]==31){break Q}}g=0;while(1){R:{h=nc(f,8)-1|0;u[((l+(i<<4)|0)+(g<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break R}g=g+1|0;if((g|0)<1<<w[e+49|0]){continue}break Q}break}ec(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}h=2;Q=l,R=nc(f,2)+1|0,t[Q+1588|0]=R;b=nc(f,4);v[l+1592>>2]=2;k=0;u[l+338>>1]=0;t[l+1589|0]=b;u[l+340>>1]=1<<b;o=l+1592|0;j=w[l|0];S:{if(j){b=l+1589|0;while(1){g=0;e=l+w[(k+l|0)+1|0]|0;if(w[e+33|0]){while(1){h=nc(f,w[b|0]);u[(l+(v[o>>2]<<1)|0)+338>>1]=h;h=v[o>>2]+1|0;v[o>>2]=h;g=g+1|0;if(g>>>0<w[e+33|0]){continue}break}j=w[l|0]}k=k+1|0;if(k>>>0<(j&255)>>>0){continue}break}if((h|0)<=0){break S}}g=0;while(1){b=x[(l+(g<<1)|0)+338>>1];e=(p+16|0)+(g<<2)|0;u[e+2>>1]=g;u[e>>1]=b;h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}}k=l+338|0;MI(p+16|0,h,2285);g=0;h=v[o>>2];b=h-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(g|0)){g=0;T:{if((h|0)<=0){break T}while(1){t[(g+l|0)+838|0]=w[((p+16|0)+(g<<2)|0)+2|0];h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}g=2;if((h|0)<=2){break T}while(1){v[p+12>>2]=0;v[p+8>>2]=0;b=k;h=0;e=g;if((e|0)>=1){i=b+(e<<1)|0;n=-1;q=65536;while(1){A=b+(h<<1)|0;j=x[A>>1];if(!((n|0)>=(j|0)|x[i>>1]<=j>>>0)){v[p+12>>2]=h;j=x[A>>1];n=j}if(!((j|0)>=(q|0)|x[i>>1]>=j>>>0)){v[p+8>>2]=h;q=x[A>>1]}h=h+1|0;if((e|0)!=(h|0)){continue}break}}b=l+(g<<1)|0;t[b+1088|0]=v[p+12>>2];t[b+1089|0]=v[p+8>>2];h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}}G=(h|0)>(G|0)?h:G;m=m+1|0;if((m|0)<v[f+128>>2]){continue P}m=G<<1;break d}e=p+16|0;j=x[e+(g<<2)>>1];g=g+1|0;if((j|0)!=x[e+(g<<2)>>1]){continue}break}break}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}yj(f,g,i<<1);ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}b=nc(f,6)+1|0;v[f+264>>2]=b;b=_d(f,B(b,24));v[f+396>>2]=b;if(!b){ec(f,3);break c}l=0;Qb(b,0,B(v[f+264>>2],24));U:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=nc(f,16);u[((l<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){ec(f,20);break c}h=b+B(l,24)|0;Q=h,R=nc(f,24),v[Q>>2]=R;b=nc(f,24);v[h+4>>2]=b;if(b>>>0<y[h>>2]){ec(f,20);break c}Q=h,R=nc(f,24)+1|0,v[Q+8>>2]=R;Q=h,R=nc(f,6)+1|0,t[Q+12|0]=R;b=nc(f,8);t[h+13|0]=b;V:{W:{if(v[f+120>>2]>(b&255)){b=0;if(w[h+12|0]){break W}g=0;break V}ec(f,20);break c}while(1){g=(p+16|0)+b|0;j=nc(f,3);if(nc(f,1)){e=nc(f,5)}else{e=0}t[g|0]=j+(e<<3);b=b+1|0;g=w[h+12|0];if(b>>>0<g>>>0){continue}break}}b=_d(f,g<<4);v[h+20>>2]=b;if(!b){break U}if(w[h+12|0]){k=0;while(1){e=w[(p+16|0)+k|0];b=0;while(1){X:{if(e>>>b&1){g=nc(f,8);o=b<<1;j=k<<4;u[o+(j+v[h+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[o+(j+v[h+20>>2]|0)>>1]){break X}ec(f,20);break c}u[(v[h+20>>2]+(k<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if(k>>>0<w[h+12|0]){continue}break}}b=_d(f,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);v[h+16>>2]=b;if(!b){ec(f,3);break c}j=0;Qb(b,0,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];g=w[h+13|0];if(v[(b+B(g,2096)|0)+4>>2]>0){while(1){e=v[B(g,2096)+b>>2];b=_d(f,e);k=j<<2;v[k+v[h+16>>2]>>2]=b;Y:{g=v[k+v[h+16>>2]>>2];if(g){if((e|0)<1){break Y}b=e-1|0;t[g+b|0]=(j>>>0)%w[h+12|0];g=j;if((e|0)==1){break Y}while(1){e=b-1|0;o=w[h+12|0];g=(g|0)/(o|0)|0;t[e+v[k+v[h+16>>2]>>2]|0]=(g|0)%(o|0);o=(b|0)>1;b=e;if(o){continue}break}break Y}ec(f,3);break c}j=j+1|0;b=v[f+124>>2];g=w[h+13|0];if((j|0)<v[(b+B(g,2096)|0)+4>>2]){continue}break}}l=l+1|0;if((l|0)<v[f+264>>2]){continue}break}}b=nc(f,6)+1|0;v[f+400>>2]=b;b=_d(f,B(b,40));v[f+404>>2]=b;if(!b){ec(f,3);break c}k=0;Qb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(nc(f,16)){ec(f,20);break c}e=b+B(k,40)|0;b=_d(f,B(v[f+4>>2],3));v[e+4>>2]=b;if(!b){ec(f,3);break c}b=e;if(nc(f,1)){g=nc(f,4)+1|0}else{g=1}t[b+8|0]=g;Z:{if(nc(f,1)){b=nc(f,8)+1|0;u[e>>1]=b;_:{g=v[f+4>>2];b=b&65535;if((g|0)>=(b|0)){j=0;if(b){break _}break Z}ec(f,20);break c}while(1){g=nc(f,Dm(g-1|0));b=B(j,3);t[b+v[e+4>>2]|0]=g;g=nc(f,Dm(v[f+4>>2]-1|0));t[(b+v[e+4>>2]|0)+1|0]=g;g=v[f+4>>2];b=b+v[e+4>>2]|0;h=w[b|0];if((g|0)<=(h|0)){ec(f,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){ec(f,20);break c}if((b|0)!=(h|0)){j=j+1|0;if(j>>>0>=x[e>>1]){break Z}continue}break}ec(f,20);break c}u[e>>1]=0}if(nc(f,2)){ec(f,20);break c}h=v[f+4>>2];$:{aa:{b=w[e+8|0];if(b>>>0<=1){g=0;if((h|0)>0){while(1){t[(v[e+4>>2]+B(g,3)|0)+2|0]=0;g=g+1|0;if((g|0)<v[f+4>>2]){continue}break}b=w[e+8|0]}if(!(b&255)){break $}break aa}g=0;if((h|0)<=0){break aa}while(1){ba:{b=nc(f,4);h=B(g,3);t[(h+v[e+4>>2]|0)+2|0]=b;if(w[(h+v[e+4>>2]|0)+2|0]>=w[e+8|0]){break ba}g=g+1|0;if((g|0)<v[f+4>>2]){continue}break aa}break}ec(f,20);break c}b=0;while(1){nc(f,8);h=b+e|0;g=h;Q=g,R=nc(f,8),t[Q+9|0]=R;h=nc(f,8);t[g+24|0]=h;if(v[f+128>>2]<=w[g+9|0]){ec(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[e+8|0]){break $}continue}break}ec(f,20);break c}k=k+1|0;if((k|0)<v[f+400>>2]){continue}break}}b=nc(f,6);v[f+408>>2]=b+1;ca:{if(b>>>0>=2147483647){break ca}g=0;while(1){b=B(g,6)+f|0;Q=b,R=nc(f,1),t[Q+412|0]=R;Q=b,R=nc(f,16),u[Q+414>>1]=R;Q=b,R=nc(f,16),u[Q+416>>1]=R;e=nc(f,8);t[b+413|0]=e;if(x[b+414>>1]){ec(f,20);break c}if(x[b+416>>1]){ec(f,20);break c}if(v[f+400>>2]>(e&255)){g=g+1|0;if((g|0)>=v[f+408>>2]){break ca}continue}break}ec(f,20);break c}eJ(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;Q=e,R=_d(f,v[f+116>>2]<<2),v[Q+800>>2]=R;Q=e,R=_d(f,v[f+116>>2]<<1&2147483646),v[Q+928>>2]=R;g=_d(f,m);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){ec(f,3);break c}Qb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!dJ(f,0,v[f+112>>2])){break a}if(!dJ(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;l=f;m=h<<1&2147483646;q=m;o=v[f+264>>2];if((o|0)<1){e=4}else{i=v[f+396>>2];h=0;j=0;while(1){k=i+B(j,24)|0;n=v[k+4>>2];e=g>>>0>n>>>0?n:g;n=v[k>>2];k=(e-(g>>>0>n>>>0?n:g)>>>0)/y[k+8>>2]|0;h=(h|0)<(k|0)?k:h;j=j+1|0;if((o|0)!=(j|0)){continue}break}e=(h<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<m>>>0?q:e;v[l+12>>2]=e;da:{ea:{if(!v[f+80>>2]){break ea}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break da}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ea}ec(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}aa(4388,10534,4196,5960);L()}ec(f,3)}b=0}gb=p+1024|0;fa:{ga:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ga}b=_d(s+8|0,1512);if(b){Q=c,R=v[hc(b,s+8|0,1512)+32>>2]-a|0,v[Q>>2]=R;v[d>>2]=0;break fa}}iJ(s+8|0);b=0}gb=s+1520|0;return b|0}function cZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-400|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Ih(b,d+392|0)){break D}if(!DD(d+392|0)){break D}if(!c){q=1;break D}r=le(d+368|0,b);v[22708]=0;R(404,d+352|0,r|0);b=v[22708];v[22708]=0;E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[22708]=0;U(405,d+208|0,d+352|0,1229866575);b=v[22708];v[22708]=0;if((b|0)==1){break J}v[22708]=0;q=Q(406,d+208|0,d+336|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break L}xb(d+208|0);if(!q){break E}v[22708]=0;R(367,a|0,524288);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;Ag(a);b=v[22708];v[22708]=0;if((b|0)!=1){break K}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;xb(d+208|0);break b}v[a+480208>>2]=12;H=a,I=Fd(Ib(w[d+344|0]|w[d+345|0]<<8),1,127),u[H+480188>>1]=I;H=d,I=Ib(w[d+336|0]|w[d+337|0]<<8),u[H+208>>1]=I;v[22708]=0;u[d+312>>1]=255;b=Pc(d+208|0,d+312|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+336|2;H=d,I=Ib(w[b|0]|w[b+1|0]<<8),u[H+208>>1]=I;v[22708]=0;u[d+312>>1]=3999;b=Pc(d+208|0,d+312|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[22708]=0;b=a+1074312|0;W(409,b|0,6,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;Q(410,b|0,21)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;Q(410,b|0,13)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=Q(2,d+208|0,6439)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+208|0,7587)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}Eb(a+1298316|0,b);vb(b);v[22708]=0;R(411,d+312|0,1445);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(412,d+288|0,d+392|4);b=v[22708];v[22708]=0;if((b|0)==1){break j}v[22708]=0;R(412,d+264|0,d+392|5);b=v[22708];v[22708]=0;if((b|0)==1){break l}v[22708]=0;Y(136,d+208|0,d+312|0,d+288|0,d+264|0);b=v[22708];v[22708]=0;if((b|0)==1){break m}b=d+208|0;Eb(a+1298328|0,b);vb(b);vb(d+264|0);vb(d+288|0);b=d+312|0;Hb(b);v[a+1298364>>2]=2;v[22708]=0;U(405,b|0,d+352|0,1312902469);b=v[22708];v[22708]=0;if((b|0)==1){break n}v[22708]=0;b=T(195,d+312|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break p}v[22708]=0;f=a+1298268|0;W(413,d+312|0,f|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}b=0;v[22708]=0;U(405,d+288|0,d+352|0,1397706311);e=v[22708];v[22708]=0;if((e|0)==1){break q}e=a+484360|0;bm(Sb(e));M:{h=d+336|4;h=Ib(w[h|0]|w[h+1|0]<<8);N:{if(!h){break N}while(1){v[22708]=0;i=Q(191,d+288|0,46)|0;g=v[22708];v[22708]=0;O:{if((g|0)!=1){if(!i){break N}v[22708]=0;R(414,d+288|0,d+208|0);i=v[22708];v[22708]=0;if((i|0)!=1){if(!gd(f)){break O}v[22708]=0;Q(415,f|0,d+208|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break O}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}v[22708]=0;i=T(416,d+288|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break M}if(!cd(Sb(e))){v[22708]=0;g=T(417,e|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break M}if((g|0)==255){break N}}g=Sb(e);v[22708]=0;U(6,d+264|0,2,d+208|0);l=v[22708];v[22708]=0;if((l|0)==1){break s}v[22708]=0;R(418,g|0,d+264|0);g=v[22708];v[22708]=0;if((g|0)==1){break t}vb(d+264|0);g=Sb(e);v[22708]=0;U(419,g|0,d+288|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break M}b=b+1|0;if(h>>>0>(b&65535)>>>0){continue}break}}v[22708]=0;Si(e,0);b=v[22708];v[22708]=0;if((b|0)==1){break u}v[22708]=0;U(405,d+264|0,d+352|0,1229869908);b=v[22708];v[22708]=0;if((b|0)==1){break v}v[22708]=0;b=T(421,d+264|0)|0;e=v[22708];v[22708]=0;P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)==1){break W}X:{Y:{Z:{_:{$:{aa:{if(!b){break aa}if(x[a+480192>>1]){b=1;while(1){v[22708]=0;R(422,d+264|0,d+208|0);e=v[22708];v[22708]=0;ba:{ca:{da:{if((e|0)!=1){e=Ib(w[d+238|0]|w[d+239|0]<<8);v[22708]=0;e=W(376,a|0,b&65535,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break da}if(!e){break ba}if(Ib(w[d+238|0]|w[d+239|0]<<8)>>>0>3999){break ba}v[22708]=0;Kr(d+96|0,2,d+208|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;R(324,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)!=1){break ca}}b=P()|0;O()|0;break V}b=P()|0;O()|0;break V}b=P()|0;O()|0;break V}v[22708]=0;Q(301,e+492|0,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}vb(d+120|0);v[22708]=0;Kr(d+96|0,2,d+208|0);f=v[22708];v[22708]=0;if((f|0)==1){break _}v[22708]=0;R(324,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break _}f=Ib(w[d+238|0]|w[d+239|0]<<8);v[22708]=0;Q(301,((f<<5)+a|0)+946304|0,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Z}vb(d+120|0);v[e>>2]=0;H=e,I=Ib(w[d+254|0]|w[d+255|0]<<8)+128&65535,v[H+8>>2]=I;qc(e+8|0,256);t[e+15|0]=w[e+15|0]|1;e=Ib(w[d+238|0]|w[d+239|0]<<8);v[22708]=0;e=B(e,104)+a|0;R(424,e+484380|0,0);f=v[22708];v[22708]=0;if((f|0)==1){break Y}H=d,I=Ib(w[d+240|0]|w[d+241|0]<<8),u[H+120>>1]=I;v[22708]=0;u[d+96>>1]=64;f=Pc(d+120|0,d+96|0);h=v[22708];v[22708]=0;if((h|0)==1){break X}u[e+484410>>1]=x[f>>1]<<2;H=e+484404|0,I=Xb(w[d+242|0]|w[d+243|0]<<8|(w[d+244|0]<<16|w[d+245|0]<<24)),v[H>>2]=I;if(!Xb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))){break ba}if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&3)){break ba}f=Xb(w[d+246|0]|w[d+247|0]<<8|(w[d+248|0]<<16|w[d+249|0]<<24));v[e+484384>>2]=f;H=e+484388|0,I=Xb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))+f|0,v[H>>2]=I;e=e+484414|0;u[e>>1]=x[e>>1]|2;if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&2)){break ba}u[e>>1]=x[e>>1]|4}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}v[22708]=0;U(405,d+184|0,d+352|0,1447382614);b=v[22708];v[22708]=0;if((b|0)==1){break W}b=v[d+196>>2];v[d+40>>2]=v[d+192>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+200>>2];v[22708]=0;b=v[d+188>>2];v[d+32>>2]=v[d+184>>2];v[d+36>>2]=b;Y(425,d+32|0,0,a|0,0);b=v[22708];v[22708]=0;if((b|0)==1){break W}v[22708]=0;U(405,d+160|0,d+352|0,1346719318);b=v[22708];v[22708]=0;if((b|0)==1){break W}b=v[d+172>>2];v[d+16>>2]=v[d+168>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+176>>2];v[22708]=0;b=v[d+164>>2];v[d+8>>2]=v[d+160>>2];v[d+12>>2]=b;Y(425,d+8|0,1,a|0,w[d+396|0]>2|0);b=v[22708];v[22708]=0;if((b|0)==1){break W}if(!x[a+480192>>1]){break aa}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}xb(d+264|0);v[22708]=0;U(405,d+208|0,d+352|0,1346458708);b=v[22708];v[22708]=0;if((b|0)==1){break U}v[22708]=0;b=T(275,d+208|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break T}if(!b|!(c&1)){break I}v[22708]=0;U(405,d+264|0,d+352|0,1347305805);b=v[22708];v[22708]=0;if((b|0)==1){break S}v[22708]=0;Q(318,d+264|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break R}i=0;l=d+336|6;b=Ib(w[l|0]|w[l+1|0]<<8);v[22708]=0;n=a+484344|0;R(330,n|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break R}e=dd(d+144|0);if(Ib(w[l|0]|w[l+1|0]<<8)){break Q}b=0;break P}b=P()|0;O()|0;vb(d+120|0);break V}b=P()|0;O()|0;break V}b=P()|0;O()|0;vb(d+120|0);break V}b=P()|0;O()|0;break V}b=P()|0;O()|0;break V}b=P()|0;O()|0}xb(d+264|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=d+96|0;A=b|5;C=b|3;D=b|4;E=b|2;F=b|1;b=0;while(1){v[22708]=0;z=T(416,d+208|0)|0;f=v[22708];v[22708]=0;ea:{fa:{ga:{ha:{ia:{if((f|0)!=1){v[22708]=0;f=T(426,d+208|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ia}v[22708]=0;U(288,d+96|0,d+208|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break ha}h=d+96|0;f=kc(d+120|0,h);xb(h);v[22708]=0;h=W(331,n|0,i&65535,z|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ga}if(!h){break ea}p=Kb(d+80|0);v[22708]=0;U(427,d+264|0,p|0,-1);h=v[22708];v[22708]=0;if((h|0)!=1){h=_b(n,i);v[22708]=0;Q(428,h|0,p|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break fa}}break A}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break z}h=_b(n,i);v[22708]=0;h=Tf(h,0);g=v[22708];v[22708]=0;if((g|0)==1){break A}Od(e);o=0;ja:{while(1){v[22708]=0;g=Q(191,d+120|0,1)|0;k=v[22708];v[22708]=0;ka:{la:{ma:{if((k|0)!=1){if(!g){break ja}v[22708]=0;k=T(374,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break A}if(k){break la}H=d,I=Vb(e),v[H+72>>2]=I;H=d,I=Zb(e),v[H+64>>2]=I;if(Gb(d+72|0,d- -64|0)){break ma}break ka}break A}while(1){na:{h=v[d+72>>2];g=_b(n,i);k=w[h+1|0];h=w[h|0];v[22708]=0;h=Be(d+96|0,h,k);k=v[22708];v[22708]=0;if((k|0)==1){break na}h=Ue(h,o);v[22708]=0;Q(431,g|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break na}h=d+72|0;Qv(h);if(Gb(h,d- -64|0)){continue}break ka}break}break A}hi(d+96|0);s=x[a+480188>>1];v[22708]=0;g=T(374,f|0)|0;j=v[22708];v[22708]=0;oa:{pa:{if((j|0)!=1){y=k-1|0;qa:{if(!(g&1)){break qa}v[22708]=0;j=T(374,f|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break A}m=k>>>0>s>>>0?d+96|0:B(y,6)+h|0;if((j|0)!=31){if((j-1&255)>>>0>252){break qa}j=(B(j>>>4|0,12)+(j&15)|0)+13|0}else{j=255}t[m|0]=j}if(!(g&2)){break oa}v[22708]=0;j=T(374,f|0)|0;m=v[22708];v[22708]=0;if((m|0)!=1){break pa}}break A}t[(k>>>0>s>>>0?F:(B(y,6)+h|0)+1|0)|0]=j}if(!(g&60)){continue}t[d+63|0]=0;t[d+62|0]=0;t[d+61|0]=0;t[d+60|0]=0;if(g&4){v[22708]=0;j=T(374,f|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break A}t[d+62|0]=j}if(g&8){v[22708]=0;j=T(374,f|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break A}t[d+60|0]=j}if(g&16){v[22708]=0;j=T(374,f|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break A}t[d+63|0]=j}if(g&32){v[22708]=0;g=T(374,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break A}t[d+61|0]=g}RY(d+63|0,d+61|0);RY(d+62|0,d+60|0);g=w[d+62|0];if(!(w[d+63|0]==13|g?(g|0)!=13:0)){gi(d+63|0,d+62|0);gi(d+61|0,d+60|0)}v[22708]=0;to(d- -64|0,d+63|0,d+61|0,d+62|0,d+60|0);g=v[22708];v[22708]=0;ra:{if((g|0)==1){break ra}v[22708]=0;g=rz(w[d+64|0],w[d+65|0]);j=v[22708];v[22708]=0;if((j|0)==1){break ra}sa:{if(!g){break sa}H=d,I=Vb(e),v[H+72>>2]=I;Gd(d+56|0,d+72|0);v[22708]=0;U(434,e|0,v[d+56>>2],d- -64|0);g=v[22708];v[22708]=0;if((g|0)!=1){break sa}break A}g=B(y,6)+h|0;k=k>>>0>s>>>0;t[(k?E:g+2|0)|0]=w[d+63|0];t[(k?D:g+4|0)|0]=w[d+61|0];j=w[d+62|0];t[(k?C:g+3|0)|0]=j;t[(k?A:g+5|0)|0]=w[d+60|0];if((j|0)==43){G=1;continue}if((j|0)!=31){continue}b=1;continue}break A}Od(e);o=o+1|0;if(z>>>0<=o>>>0){break ja}h=_b(n,i);v[22708]=0;h=Tf(h,o);g=v[22708];v[22708]=0;if((g|0)!=1){continue}break}break A}vb(p)}xb(d+120|0);i=i+1|0;if(Ib(w[l|0]|w[l+1|0]<<8)>>>0>i>>>0){continue}break}}Gr(e);h=b;xb(d+264|0);if(!(c&4)){break G}e=0;if(!G){break H}f=x[a+480188>>1];if(!f){e=1;break H}b=0;while(1){e=1;i=(b<<5)+a|0;t[i+480288|0]=1;i=i+480280|0;v[i>>2]=v[i>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break H}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}h=0;e=0;if(!(c&4)){break F}}v[d+120>>2]=-1778364416;v[d+124>>2]=-16756736;v[22708]=0;U(405,d+264|0,d+352|0,1146310725);b=v[22708];v[22708]=0;ta:{ua:{va:{wa:{xa:{ya:{if((b|0)!=1){v[22708]=0;b=T(421,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break va}if(!b){break xa}v[22708]=0;i=T(416,d+264|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break va}if(i){break ya}f=e;break wa}b=P()|0;O()|0;break w}b=0;f=e;while(1){v[22708]=0;g=T(374,d+264|0)|0;l=v[22708];v[22708]=0;za:{Aa:{if((l|0)!=1){if(x[a+480188>>1]<=b>>>0){break za}if(!e){break Aa}l=((b<<5)+a|0)+480280|0;v[l>>2]=v[l>>2]&-67108865|((g|0)!=0)<<26;break za}break va}if(g){break za}f=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((i|0)!=(b|0)){continue}break}break wa}xb(d+264|0);if(!e){break G}break ta}v[22708]=0;Q(435,d+264|0,d+120|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ua}}b=P()|0;O()|0;xb(d+264|0);break w}xb(d+264|0);if(!(f&1)){break G}}v[22708]=0;_(436,a+906300|0);b=v[22708];v[22708]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((b|0)==1){break Ga}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22708]=0;v[d+264>>2]=0;b=a+906332|0;BD(b,b+16|0,d+264|0);b=v[22708];v[22708]=0;if((b|0)==1){break Fa}v[22708]=0;e=Q(70,d+264|0,6713)|0;b=v[22708];v[22708]=0;if((b|0)==1){break Ea}v[22708]=0;Ov(a+906348|0,e);b=v[22708];v[22708]=0;if((b|0)==1){break Da}vb(e);v[22708]=0;e=Q(70,d+264|0,6677)|0;b=v[22708];v[22708]=0;if((b|0)==1){break Ca}v[22708]=0;Ir(a+906380|0,e);b=v[22708];v[22708]=0;if((b|0)==1){break Ba}vb(e);v[22708]=0;b=a+906304|0;R(440,b|0,8);e=v[22708];v[22708]=0;if((e|0)==1){break Ga}PY(d+264|0,w[d+121|0],w[d+123|0],w[d+125|0],w[d+127|0]);e=v[d+268>>2];b=v[b>>2];f=v[d+264>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break G}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(e);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(e);break w}if(!h){break F}b=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{while(1){cb:{v[d+80>>2]=B(b,127)>>>5;v[22708]=0;R(441,d+120|0,1202);e=v[22708];v[22708]=0;if((e|0)==1){break cb}v[22708]=0;R(442,d+96|0,d+80|0);e=v[22708];v[22708]=0;if((e|0)==1){break bb}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);e=v[22708];v[22708]=0;if((e|0)==1){break ab}v[22708]=0;e=(b<<5)+a|0;R(444,d+144|0,e+902204|0);f=v[22708];v[22708]=0;if((f|0)==1){break $a}v[22708]=0;Q(401,d+144|0,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $a}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22708]=0;R(441,f|0,1184);f=v[22708];v[22708]=0;if((f|0)==1){break Ya}v[22708]=0;R(442,d+96|0,d+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break Xa}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break Wa}v[22708]=0;R(444,d+144|0,e+903228|0);f=v[22708];v[22708]=0;if((f|0)==1){break Va}v[22708]=0;Q(401,d+144|0,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Va}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22708]=0;R(441,f|0,1175);f=v[22708];v[22708]=0;if((f|0)==1){break Sa}v[22708]=0;R(442,d+96|0,d+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ra}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break Qa}v[22708]=0;R(444,d+144|0,e+904252|0);f=v[22708];v[22708]=0;if((f|0)==1){break Pa}v[22708]=0;Q(401,d+144|0,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Pa}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22708]=0;R(441,f|0,1148);f=v[22708];v[22708]=0;if((f|0)==1){break Ma}v[22708]=0;R(442,d+96|0,d+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break La}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ka}v[22708]=0;R(444,d+144|0,e+905276|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ja}v[22708]=0;Q(401,d+144|0,d+264|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ja}vb(d+264|0);vb(d+96|0);Hb(d+120|0);b=b+1|0;if((b|0)!=32){continue}break F}break}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Za}b=P()|0;O()|0;break _a}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Ta}b=P()|0;O()|0;break Ua}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Na}b=P()|0;O()|0;break Oa}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Ha}b=P()|0;O()|0;break Ia}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}v[22708]=0;U(405,d+264|0,d+352|0,1397575756);b=v[22708];v[22708]=0;if((b|0)==1){break B}v[22708]=0;b=T(275,d+264|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}if(!(!x[a+480190>>1]|(!b|!(c&2)))){e=1;b=1;while(1){v[22708]=0;c=T(426,d+264|0)|0;f=v[22708];v[22708]=0;db:{if((f|0)!=1){v[22708]=0;f=T(426,d+264|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break C}if(!(c&7)){break db}e=(B(e,104)+a|0)+484380|0;v[e>>2]=f;c=Rc(d+120|0,c&4?32:c&2?16:8,1,1,0);v[22708]=0;W(329,c|0,e|0,d+264|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break db}break C}break C}b=b+1|0;e=b&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}xb(d+264|0);xb(d+208|0);xb(d+288|0);xb(d+312|0)}ke(d+352|0);xb(r)}gb=d+400|0;return q|0}b=P()|0;O()|0;xb(d+264|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(p)}xb(d+120|0)}Gr(e)}xb(d+264|0)}xb(d+208|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;vb(d+264|0);break r}b=P()|0;O()|0}xb(d+288|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}xb(d+312|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+264|0);break k}b=P()|0;O()|0}vb(d+288|0);break i}b=P()|0;O()|0}Hb(d+312|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}ke(d+352|0)}xb(r);S(b|0);L()}function Kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=gb-352|0;gb=d;vc(b);a:{if(!zr(b,d+336|0)){break a}if(!QU(d+336|0)){break a}r=le(d+312|0,b);q=hh(d+296|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[22708]=0;R(844,d|0,r|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}break t}v[22708]=0;R(845,d|0,r|0);b=v[22708];v[22708]=0;if((b|0)==1){break s}}PU(q,d);ke(d);v[22708]=0;U(846,d|0,q|0,1413891155);b=v[22708];v[22708]=0;u:{v:{if((b|0)!=1){v[22708]=0;e=Q(847,d|0,11394)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}xb(d);if(!e){break b}if(c){break u}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;xb(d);break c}v[22708]=0;R(367,a|0,4194304);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22708]=0;U(846,d+272|0,q|0,1280592212);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=T(195,d+272|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}v[22708]=0;W(616,d+272|0,a+1298268|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}m=a+484360|0;bm(Sb(m));l=dd(d+256|0);t[d+255|0]=0;v[22708]=0;U(848,d+240|0,q|0,1196314451);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d+240|0;y=d,z=Vb(b),v[y+232>>2]=z;y=d,z=Zb(b),v[y+224>>2]=z;w:{x:{y:{z:{A:{B:{if(!Gb(d+232|0,d+224|0)){break B}i=d+12|0;f=d+24|0;j=d+44|0;C:{while(1){b=le(d+200|0,v[d+232>>2]);v[22708]=0;e=Q(849,b|0,d+184|0)|0;g=v[22708];v[22708]=0;D:{if((g|0)!=1){if(w[d+193|0]==1?e:0){break D}xb(d+200|0);e=0;break A}b=P()|0;O()|0;break k}y=a,z=Fd(w[d+194|0],x[a+480188>>1],127),u[y+480188>>1]=z;v[22708]=0;k=T(850,d|0)|0;e=v[22708];v[22708]=0;E:{F:{G:{H:{I:{J:{if((e|0)!=1){e=d+168|0;pf(e,d+184|0,9,1);v[22708]=0;R(324,d+120|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break J}v[22708]=0;R(851,d+160|0,j|0);e=v[22708];v[22708]=0;if((e|0)==1){break I}v[22708]=0;Q(401,d+160|0,d+120|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break I}vb(d+120|0);if(cd(Sb(m))){break G}v[22708]=0;e=T(417,m|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break H}if((e|0)!=255){break G}b=2;break F}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}e=Sb(m);v[22708]=0;U(6,d+120|0,5,j|0);g=v[22708];v[22708]=0;K:{L:{M:{N:{O:{if((g|0)!=1){v[22708]=0;R(418,e|0,d+120|0);e=v[22708];v[22708]=0;if((e|0)==1){break O}vb(d+120|0);v[22708]=0;R(845,d+168|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break N}b=d+168|0;y=d,z=Vb(b),v[y+152>>2]=z;y=d,z=Zb(b),v[y+144>>2]=z;if(Gb(d+152|0,d+144|0)){break M}break L}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}while(1){P:{e=v[d+152>>2];rn(d+120|0,e);b=d+160|0;_i(b,e);Q:{b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b|0)!=1212960847){if((b|0)!=1312903248){break Q}b=0;if(!x[a+480188>>1]){break Q}while(1){R:{v[22708]=0;e=Q(191,d+120|0,2)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!e){break Q}v[22708]=0;R(403,d+96|0,d+120|0);e=v[22708];v[22708]=0;S:{T:{U:{V:{if((e|0)!=1){e=d+96|0;g=qd(e);switch(w[e|0]){case 4:break T;case 2:break U;case 0:break V;default:break S}}break P}e=w[g|0];y=lc(d,b),z=e^128,t[y|0]=z;e=d+104|0;Ce(e,f,b);Uf(e,0);break S}y=lc(d,b),z=128,t[y|0]=z;e=d+104|0;Ce(e,f,b);Uf(e,1);break S}y=lc(d,b),z=128,t[y|0]=z;e=d+104|0;Ce(e,f,b);Uf(e,0)}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break Q}break}break P}if(cn(d+160|0)>>>0<9){break Q}b=0;v[22708]=0;Q(318,d+120|0,2)|0;e=v[22708];v[22708]=0;g=65535;if((e|0)==1){break P}while(1){v[22708]=0;e=Q(191,d+120|0,1)|0;h=v[22708];v[22708]=0;W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((h|0)!=1){if(!e){break Q}v[22708]=0;e=T(374,d+120|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}switch(e|0){case 0:break Q;case 14:break X;case 13:break Y;case 12:break _;case 8:break $;case 7:break aa;case 4:break ba;case 1:break ca;default:break Z}}break P}if(x[d+36>>1]==65535){y=d,z=$l(Sb(m)),u[y+36>>1]=z}e=$l(Sb(m));v[22708]=0;u[d+38>>1]=e;e=Q(852,d+120|0,d+255|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}da:{ea:{switch(e-254|0){case 1:v[22708]=0;e=65535;h=v[22708];v[22708]=0;if((h|0)!=1){break da}break P;case 0:break ea;default:break da}}v[22708]=0;e=65534;h=v[22708];v[22708]=0;if((h|0)==1){break P}}h=Sb(m);v[22708]=0;R(710,h|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}g=(g&65535)==65535?b:g;break W}v[22708]=0;e=T(287,d+120|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}if(e>>>0>=(g&65535)>>>0){u[d+40>>1]=e-g}cf(Sb(m),x[d+40>>1]);break W}v[22708]=0;e=T(374,d+120|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}t[d+43|0]=e;break W}v[22708]=0;e=T(374,d+120|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}t[d+42|0]=e;break W}v[22708]=0;e=Q(813,d+120|0,d+104|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}if(w[d+104|0]|!e|(w[d+106|0]|w[d+105|0]!=255)){break Z}if(w[d+107|0]|w[d+108|0]!=1){break Z}if(!w[d+109|0]){break W}}xb(d+120|0);b=1;break K}v[22708]=0;R(723,d+112|0,d+120|0);e=v[22708];v[22708]=0;fa:{ga:{ha:{ia:{if((e|0)!=1){e=d+112|0;h=qd(e);o=Ve(e);n=w[e|0];if(oc(d)>>>0<=n>>>0){break W}switch(w[o|0]){case 4:break ga;case 2:break ha;case 0:break ia;default:break fa}}break P}h=w[h|0];y=lc(d,w[e|0]),z=h^128,t[y|0]=z;h=d+104|0;Ce(h,f,w[e|0]);Uf(h,0);break fa}y=lc(d,w[e|0]),z=128,t[y|0]=z;h=d+104|0;Ce(h,f,w[e|0]);Uf(h,1);break fa}y=lc(d,w[e|0]),z=128,t[y|0]=z;h=d+104|0;Ce(h,f,w[e|0]);Uf(h,0)}ja:{if(p&1){break ja}p=0;if(!cr(l)){break W}if(w[lc(OU(l),w[e|0])|0]!=w[lc(d,w[e|0])|0]){break ja}h=d+104|0;Ce(h,OU(l)+24|0,w[e|0]);h=Cb(h);o=d+96|0;Ce(o,f,w[e|0]);if((Cb(o)|0)==(h|0)){break W}}p=1;break W}v[22708]=0;R(403,d+104|0,d+120|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}e=d+104|0;h=qd(e);o=w[e|0];if(oc(i)>>>0<=o>>>0){break W}h=w[h|0];y=lc(i,w[e|0]),z=(h>>>2|0)+1|0,t[y|0]=z}b=b+1|0;continue}}xb(d+120|0);b=d+152|0;pn(b);if(Gb(b,d+144|0)){continue}break L}break}b=P()|0;O()|0;xb(d+120|0);break E}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break K}b=Sb(m);v[22708]=0;_(855,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=0;v[22708]=0;R(856,l|0,k|0);e=v[22708];v[22708]=0;if((e|0)!=1){break K}}b=P()|0;O()|0;break E}ke(d+168|0)}$u(k);xb(d+200|0);if(b){break C}b=d+232|0;Eh(b);if(Gb(b,d+224|0)){continue}break B}break}ke(d+168|0);break l}e=0;if((b|0)!=2){break A}}e=0;v[22708]=0;Si(m,0);b=v[22708];v[22708]=0;if((b|0)==1){break q}if(cd(l)){break A}if(c&2){v[22708]=0;U(848,d+200|0,q|0,1347244868);b=v[22708];v[22708]=0;if((b|0)==1){break w}b=d+200|0;y=d,z=Vb(b),v[y+184>>2]=z;y=d,z=Zb(b),v[y+160>>2]=z;f=w[d+255|0];if(Gb(d+184|0,d+160|0)){e=a+480190|0;g=d+13|0;k=d+17|0;while(1){b=v[d+184>>2];ka:{la:{ma:{na:{oa:{if(!f){v[22708]=0;i=Q(857,b|0,d|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break oa}if(!i){break ka}i=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break ma}v[22708]=0;i=Ke(e,d+104|0);j=v[22708];v[22708]=0;if((j|0)==1){break oa}u[a+480190>>1]=x[i>>1];v[22708]=0;R(858,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[22708];v[22708]=0;if((i|0)==1){break oa}i=d+168|0;NU(i,g);v[22708]=0;R(324,d+120|0,i|0);i=v[22708];v[22708]=0;pa:{if((i|0)!=1){v[22708]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break pa}vb(d+120|0);break ma}b=P()|0;O()|0;break la}b=P()|0;O()|0;vb(d+120|0);break la}v[22708]=0;i=Q(859,b|0,d|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break na}if(!i){break ka}i=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break ma}v[22708]=0;i=Ke(e,d+104|0);j=v[22708];v[22708]=0;if((j|0)==1){break na}u[a+480190>>1]=x[i>>1];v[22708]=0;R(860,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[22708];v[22708]=0;if((i|0)==1){break na}i=d+168|0;NU(i,k);v[22708]=0;R(324,d+120|0,i|0);i=v[22708];v[22708]=0;qa:{if((i|0)!=1){v[22708]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break qa}vb(d+120|0);break ma}b=P()|0;O()|0;break la}b=P()|0;O()|0;vb(d+120|0);break la}b=P()|0;O()|0;break la}b=P()|0;O()|0;break la}if((x[d+104>>1]-1&65535)>>>0>3998){break ka}i=Rc(d,8,1,0,2);v[22708]=0;W(329,i|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ka}b=P()|0;O()|0}jd(d+200|0);break j}b=d+184|0;Eh(b);if(Gb(b,d+160|0)){continue}break}}jd(d+200|0)}b=0;y=a,z=w[bn(l,0)+43|0],v[y+480196>>2]=z;y=a,z=B(w[bn(l,0)+42|0],1e4),v[y+480204>>2]=z;cf(Sb(m),x[bn(l,0)+40>>1]);if(x[a+480188>>1]){while(1){v[22708]=0;e=(b<<5)+a|0;f=e+480280|0;We(f);g=v[22708];v[22708]=0;if((g|0)==1){break x}y=e+480286|0,z=w[lc(bn(l,0)+12|0,b)|0],u[y>>1]=z;y=e+480284|0,z=w[lc(bn(l,0),b)|0],u[y>>1]=z;Ce(d,bn(l,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ra:{if(w[d+255|0]){v[22708]=0;Q(2,d|0,14205)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ra}break m}v[22708]=0;Q(2,d|0,14078)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}}Eb(a+1298304|0,d);vb(d);v[22708]=0;b=Q(2,d|0,7407)|0;f=v[22708];v[22708]=0;e=1;if((f|0)==1){break y}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;if(!(c&1)|!x[a+480188>>1]){break A}v[22708]=0;U(848,d+120|0,q|0,1146045008);b=v[22708];v[22708]=0;if((b|0)==1){break n}b=Ie(d+120|0);v[22708]=0;i=a+484344|0;R(330,i|0,b&65535);b=v[22708];v[22708]=0;if((b|0)==1){break p}b=d+120|0;y=d,z=Vb(b),v[y+168>>2]=z;y=d,z=Zb(b),v[y+184>>2]=z;if(Gb(d+168|0,d+184|0)){while(1){k=v[d+168>>2];v[22708]=0;b=T(195,k|0)|0;c=v[22708];v[22708]=0;sa:{ta:{ua:{if((c|0)==1){break ua}v[22708]=0;c=T(192,k|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ua}if((b|0)!=(c|0)){break sa}v[22708]=0;b=Q(861,k|0,8)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ua}if(b){break ta}break sa}b=P()|0;O()|0;break o}v[22708]=0;o=Q(852,k|0,d+255|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;h=T(287,k|0)|0;b=v[22708];v[22708]=0;va:{if((b|0)==1){break va}v[22708]=0;b=W(331,i|0,o|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break va}if(!b|!h){break sa}c=0;wa:{xa:{ya:{while(1){za:{b=_b(i,o);v[22708]=0;e=Tf(b,c);b=v[22708];v[22708]=0;if((b|0)==1){break wa}v[22708]=0;b=T(287,k|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break xa}Aa:{if(b>>>0>=3){v[22708]=0;U(288,d+200|0,k|0,b-2|0);b=v[22708];v[22708]=0;if((b|0)==1){break ya}b=d+200|0;j=kc(d,b);xb(b);while(1){v[22708]=0;b=Q(191,d|0,3)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Aa}if(b){v[22708]=0;R(403,d+200|0,j|0);b=v[22708];v[22708]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){b=d+200|0;g=b;b=qd(b);u[d+160>>1]=x[a+480188>>1]-1;b=w[b|0];v[22708]=0;u[d+104>>1]=b;b=Pc(d+160|0,d+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break za}f=x[b>>1];b=t[g|0];if((b|0)>-1){break Ba}v[22708]=0;b=T(374,j|0)|0;n=v[22708];v[22708]=0;if((n|0)==1){break za}if(w[d+255|0]){break Da}if((b|0)!=255){break Ea}b=254;break Ca}break za}if(b>>>0>128){break Ca}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ca}b=b>>>0<85?b+36|0:b}t[e+B(f,6)|0]=b;b=w[g|0]}if(b&64){v[22708]=0;b=T(374,j|0)|0;n=v[22708];v[22708]=0;if((n|0)==1){break za}t[(e+B(f,6)|0)+1|0]=b+1;b=w[g|0]}if(b&32){v[22708]=0;b=T(374,j|0)|0;n=v[22708];v[22708]=0;if((n|0)==1){break za}t[d+160|0]=b;b=e+B(f,6)|0;t[b+2|0]=1;v[22708]=0;t[d+104|0]=127;n=ac(d+160|0,d+104|0);s=v[22708];v[22708]=0;if((s|0)==1){break za}t[b+4|0]=w[n|0]+1>>>1;b=w[g|0]}if(!(b&16)){continue}v[22708]=0;R(403,d+160|0,j|0);b=v[22708];v[22708]=0;if((b|0)==1){break za}b=e+B(f,6)|0;n=d+160|0;g=w[qd(n)|0];t[b+5|0]=g;Fa:{switch(w[n|0]-1|0){case 0:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g<<4|15;continue}t[b+5|0]=g<<3|15;continue;case 1:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g<<4;continue}t[b+5|0]=g<<3&240;continue;case 2:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g|240;continue}t[b+5|0]=g>>>1|240;continue;case 3:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g&15;continue}if(g>>>0<=1){t[b+5|0]=g|240;continue}t[b+5|0]=g>>>1&15;continue;case 10:t[(e+B(f,6)|0)+3|0]=2;y=b,z=_u(g,w[d+255|0])|240,t[y+5|0]=z;continue;case 11:t[(e+B(f,6)|0)+3|0]=2;y=b,z=_u(g,w[d+255|0]),t[y+5|0]=z;continue;case 12:t[(e+B(f,6)|0)+3|0]=3;y=b,z=_u(g,w[d+255|0])|240,t[y+5|0]=z;continue;case 13:t[(e+B(f,6)|0)+3|0]=3;y=b,z=_u(g,w[d+255|0]),t[y+5|0]=z;continue;case 14:t[(e+B(f,6)|0)+3|0]=4;if(w[d+255|0]){continue}t[b+5|0]=(g&252)>>>2;continue;case 16:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&1|16;continue;case 15:t[(e+B(f,6)|0)+3|0]=6;t[b+5|0]=g&240;continue;case 17:t[(e+B(f,6)|0)+3|0]=6;t[b+5|0]=(g&240)>>>4;continue;case 18:t[(e+B(f,6)|0)+3|0]=20;continue;case 20:t[(e+B(f,6)|0)+3|0]=5;continue;case 21:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|48;continue;case 22:t[(e+B(f,6)|0)+3|0]=7;t[b+5|0]=g|240;continue;case 23:t[(e+B(f,6)|0)+3|0]=7;continue;case 30:t[(e+B(f,6)|0)+3|0]=8;continue;case 31:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|64;continue;case 40:t[(e+B(f,6)|0)+3|0]=10;v[22708]=0;f=T(374,j|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break za}t[b+5|0]=f;v[22708]=0;Q(318,d|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}break za;case 41:t[(e+B(f,6)|0)+3|0]=15;continue;case 42:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|192;continue;case 43:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|208;continue;case 50:t[(e+B(f,6)|0)+3|0]=12;t[b+5|0]=(g&254)>>>1;v[22708]=0;Q(318,d|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}break za;case 51:t[(e+B(f,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|176;continue;case 53:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|224;continue;case 60:t[(e+B(f,6)|0)+3|0]=16;continue;case 61:t[(e+B(f,6)|0)+3|0]=17;continue;case 70:t[(e+B(f,6)|0)+3|0]=1;continue;case 71:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|32;continue;case 72:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|128;continue;default:break Fa}}t[(e+B(f,6)|0)+3|0]=0;continue}break}xb(d)}c=c+1|0;if((h|0)==(c|0)){break sa}continue}}break}b=P()|0;O()|0;xb(d);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=d+168|0;Eh(b);if(Gb(b,d+184|0)){continue}break}}if(cr(l)>>>0>=2){g=p&1;p=0;while(1){b=Rj(m,p&255);c=bn(l,p);e=x[sc(b,x[c+36>>1])>>1];v[22708]=0;e=me(i,e);f=v[22708];v[22708]=0;Ga:{Ha:{if((f|0)!=1){if(!e){break Ga}e=x[c+36>>1];v[22708]=0;e=Q(545,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break Ha}}b=P()|0;O()|0;break o}if(!(!g|!x[a+480188>>1])){k=c+24|0;b=0;while(1){Ce(d,k,b);j=Cb(d);f=_b(i,e);Ia:{if(j){v[22708]=0;j=Be(d,20,145);h=v[22708];v[22708]=0;if((h|0)!=1){j=Fh(op(Ue(j,0),b&65535));v[22708]=0;Q(431,f|0,j|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break Ia}}b=P()|0;O()|0;break o}j=w[lc(c,b)|0];v[22708]=0;j=Be(d,9,j);h=v[22708];v[22708]=0;if((h|0)!=1){j=Fh(op(Ue(j,0),b&65535));v[22708]=0;Q(431,f|0,j|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break Ia}}b=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(i,e);f=w[c+43|0];v[22708]=0;f=Be(d,16,f);k=v[22708];v[22708]=0;if((k|0)==1){break z}f=Fh(Ue(f,0));v[22708]=0;Q(431,b|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break z}b=_b(i,e);c=w[c+42|0];v[22708]=0;c=Be(d,17,c);e=v[22708];v[22708]=0;if((e|0)!=1){c=Fh(Ue(c,0));v[22708]=0;Q(431,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break Ga}}b=P()|0;O()|0;break o}p=p+1|0;if(cr(l)>>>0>p>>>0){continue}break}}jd(d+120|0);e=1}jd(d+240|0);LU(l);xb(d+272|0);break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break j}b=P()|0;O()|0}jd(d+120|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}$u(k)}xb(d+200|0)}jd(d+240|0);break h}b=P()|0;O()|0}LU(l);break f}b=P()|0;O()|0}xb(d+272|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}ke(q);xb(r);S(b|0);L()}ke(q);xb(r)}gb=d+352|0;return e|0}function lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;e=f+24|0;k=d+248|0;Dv(e,k);g=yb(e);e=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=e;v[f>>2]=h;v[f+4>>2]=e;e=b;h=f+16|0;cc(h,b,f);h=yb(h);if((h|0)==(g|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(h|0);if(!e){PX(k)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!e){break u}if(!SX(d+248|0)){break u}if(!c){i=1;break u}Hd(a,1024);Ag(a);v[a+480208>>2]=v[a+480208>>2]|12;Rf(a+1074312|0,21);if(Ib(w[d+264|0]|w[d+265|0]<<8)){F=a,G=B(Ib(w[d+264|0]|w[d+265|0]<<8),1e4),v[F+480204>>2]=G}if(Ib(w[d+262|0]|w[d+263|0]<<8)){F=a,G=Ib(w[d+262|0]|w[d+263|0]<<8),v[F+480196>>2]=G}if(!w[d+258|0]){xh(a,1)}e=d+248|4;Rv(b,a+1298268|0,Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=le(d+144|0,b);v[22708]=0;R(519,d+232|0,b|0);e=v[22708];v[22708]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){xb(b);v[22708]=0;U(520,d+144|0,d+232|0,1395544366);b=v[22708];v[22708]=0;if((b|0)==1){break E}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break L}if(!b){break F}v[22708]=0;b=T(416,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break L}v[22708]=0;e=T(416,d+144|0)|0;f=v[22708];v[22708]=0;N:{if((f|0)==1){break N}v[22708]=0;Q(318,d+144|0,4)|0;f=v[22708];v[22708]=0;if((f|0)==1){break N}f=a+484360|0;g=Sb(f);v[22708]=0;fa(521,g|0,d+144|0,b|0,65535,65535)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break M}}break L}a=P()|0;O()|0;xb(b);break a}cf(Sb(f),e);b=d+144|0;xb(b);v[22708]=0;U(520,b|0,d+232|0,1346458708);b=v[22708];v[22708]=0;if((b|0)==1){break K}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}if(!b){break H}v[22708]=0;b=T(416,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[22708]=0;b=T(416,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}v[22708]=0;p=a+484344|0;R(330,p|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break J}v[22708]=0;k=T(426,d+144|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break J}switch(k-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}if(!k){break G}}xb(d+144|0);break A}xb(d+144|0);v[22708]=0;U(520,d+208|0,d+232|0,1398157625);b=v[22708];v[22708]=0;if((b|0)==1){break D}v[22708]=0;b=T(421,d+208|0)|0;e=v[22708];v[22708]=0;O:{if((e|0)==1){break O}if(!b){break B}v[22708]=0;Q(318,d+208|0,2)|0;b=v[22708];v[22708]=0;if((b|0)==1){break O}v[22708]=0;e=T(426,d+208|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[22708]=0;Q(522,d+208|0,d+144|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+80>>2]=G;v[22708]=0;v[d+64>>2]=180;e=pd(d+80|0,d- -64|0);f=v[22708];v[22708]=0;if((f|0)!=1){e=v[e>>2]-90|0;f=e>>31;F=((b<<5)+a|0)+480284|0,G=Ac(oqa(e<<7|45,f<<7|e>>>25,90,0),jb)+128|0,u[F>>1]=G;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}xb(d+144|0);break A}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[22708]=0;Q(318,d+208|0,16)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=Q(191,d+208|0,2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(b){v[22708]=0;b=T(416,d+208|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}u[d+80>>1]=b;v[22708]=0;u[d+64>>1]=256;b=Pc(d+80|0,d- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[22708]=0;Q(318,d+208|0,128)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=Q(522,d+208|0,d+80|0)|0;e=v[22708];v[22708]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+64>>2]=G;v[22708]=0;v[d+40>>2]=128;e=pd(d- -64|0,d+40|0);f=v[22708];v[22708]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}xb(d+208|0);v[22708]=0;U(520,d+144|0,d+232|0,1413830740);b=v[22708];v[22708]=0;R:{S:{if((b|0)!=1){v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(!b){break R}v[22708]=0;R(523,d+144|0,d+80|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}if((Ib(w[d+90|0]|w[d+91|0]<<8)|0)!=65535){break S}v[22708]=0;Q(318,d+144|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break S}break d}a=P()|0;O()|0;break b}v[22708]=0;b=T(467,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;da(509,a+1298292|0,d+144|0,b|0,2)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}}xb(d+144|0);v[22708]=0;U(520,d+80|0,d+232|0,1229869908);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=T(421,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){if(b){v[22708]=0;b=T(416,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}T:{e=b<<16>>16;g=e&32767;if(g>>>0>3999){break T}v[22708]=0;b=Q(191,d+80|0,B(g,(e>>>14&2)+50|0)|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break y}if(!b){break T}u[a+480190>>1]=g;i=a+480190|0;if(!g){break z}h=d+162|0;b=1;j=(e|0)>-1;U:{V:{while(1){W:{e=b;f=d;X:{Y:{Z:{if(!j){v[22708]=0;e=T(416,d+80|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break Z}e=e+1|0}u[f+40>>1]=e;v[22708]=0;R(524,d+80|0,d+144|0);e=v[22708];v[22708]=0;if((e|0)!=1){if((x[d+40>>1]-1&65535)>>>0>3998){break X}v[22708]=0;e=Ke(i,d+40|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Y}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];e=x[d+40>>1];f=Xb(w[d+266|0]|w[d+267|0]<<8|(w[d+268|0]<<16|w[d+269|0]<<24));v[22708]=0;Y(525,d+144|0,(B(e,104)+a|0)+484380|0,f|0,k|0);e=v[22708];v[22708]=0;if((e|0)==1){break W}v[22708]=0;Qk(d- -64|0,2,h);e=v[22708];v[22708]=0;if((e|0)==1){break V}v[22708]=0;R(324,d+208|0,d- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break V}v[22708]=0;Q(301,((x[d+40>>1]<<5)+a|0)+946304|0,d+208|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}vb(d+208|0)}e=b&65535;b=b+1|0;if(e>>>0<g>>>0){continue}break z}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+208|0);break f}xb(d+80|0);break A}break w}a=P()|0;O()|0;break f}break v}v[22708]=0;b=T(416,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break x}}a=P()|0;O()|0;break f}if((b|0)==4){u[d+144>>1]=x[i>>1];v[22708]=0;u[d+208>>1]=255;b=Pc(d+144|0,d+208|0);e=v[22708];v[22708]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[22708]=0;U(520,d+208|0,d+232|0,1229278806);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d- -64|0;g=b|4;i=b|3;h=b|5;j=b|7;while(1){v[22708]=0;b=Q(191,d+80|0,15)|0;e=v[22708];v[22708]=0;_:{if((e|0)!=1){$:{if(b){v[22708]=0;R(527,d+80|0,d- -64|0);b=v[22708];v[22708]=0;aa:{if((b|0)!=1){b=d- -64|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>=x[a+480192>>1]){continue}f=d- -64|0;b=f;b=B(Ib(w[b|0]|w[b+1|0]<<8),104)+a|0;t[b+484524|0]=w[d+72|0];e=w[j|0];t[b+484523|0]=255;t[b+484525|0]=e;b=f;b=Ib(w[b|0]|w[b+1|0]<<8);e=f;e=Ib(w[e|0]|w[e+1|0]<<8);v[22708]=0;e=W(376,a|0,b+1&65535,e+1&65535)|0;b=v[22708];v[22708]=0;if((b|0)==1){break $}if(!e){continue}F=d,G=Ib(w[h|0]|w[h+1|0]<<8),u[F+144>>1]=G;v[22708]=0;u[d+40>>1]=4095;b=Pc(d+144|0,d+40|0);f=v[22708];v[22708]=0;if((f|0)==1){break $}v[e>>2]=x[b>>1];if(w[i|0]==255){continue}b=w[i|0];v[22708]=0;b=Q(190,d+208|0,B(b,34)+2|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}if(!b){continue}v[22708]=0;R(528,d+208|0,d+144|0);b=v[22708];v[22708]=0;if((b|0)==1){break $}t[e+60|0]=w[e+60|0]|1;b=Ib(w[d+144|0]|w[d+145|0]<<8);v[d+60>>2]=3;v[d+44>>2]=16;v[d+48>>2]=240;v[d+40>>2]=b;v[d+56>>2]=d+40;b=v[d+60>>2];v[d+8>>2]=v[d+56>>2];v[d+12>>2]=b;b=QX(d+8|0);v[22708]=0;f=e+48|0;R(446,f|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break $}b=0;if(Nb(f)){break aa}break _}break $}while(1){ba:{t[d+40|0]=64;l=(d+144|0)+(b<<1)|0;n=w[l+2|0];v[22708]=0;t[d+32|0]=n;n=ac(d+40|0,d+32|0);o=v[22708];v[22708]=0;if((o|0)==1){break ba}n=w[n|0];F=Mb(f,b),G=n,t[F+2|0]=G;l=w[l+3|0];F=Mb(f,b),G=l,u[F>>1]=G;b=b+1|0;if(Nb(f)>>>0>b>>>0){continue}break _}break}break $}xb(d+208|0);break w}}a=P()|0;O()|0;xb(d+208|0);break f}if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(cd(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Nb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}xb(d+80|0);v[22708]=0;U(529,d+208|0,d+232|0,1145131092);b=v[22708];v[22708]=0;if((b|0)==1){break j}b=d+208|0;F=d,G=Vb(b),v[F+32>>2]=G;F=d,G=Zb(b),v[F+24>>2]=G;if(Gb(d+32|0,d+24|0)){z=c&1;l=d+80|4;n=(k|0)!=841887798;A=(k|0)!=841887796;while(1){g=v[d+32>>2];v[22708]=0;Q(318,g|0,4)|0;b=v[22708];v[22708]=0;ca:{da:{ea:{if((b|0)!=1){v[22708]=0;f=T(416,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}v[22708]=0;h=T(416,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}h=n?h:(h>>>0)/y[a+480196>>2]|0;if(!z|f>>>0>255){break ca}v[22708]=0;b=W(331,p|0,f|0,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break m}if(!b){break ca}if(n){break da}v[22708]=0;Q(318,g|0,4)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[22708]=0;b=T(416,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ea}v[22708]=0;U(288,d+80|0,g|0,b+(b&1)&65535);b=v[22708];v[22708]=0;if((b|0)==1){break n}b=d+80|0;i=kc(d+144|0,b);xb(b);v[d+80>>2]=0;v[d+84>>2]=0;o=0;fa:{while(1){v[22708]=0;b=Q(191,d+144|0,6)|0;e=v[22708];v[22708]=0;if((e|0)==1){break o}if(!(b&y[d+80>>2]<h>>>0)){break fa}b=_b(p,f);v[22708]=0;b=Yc(b,v[d+80>>2],j&65535);e=v[22708];v[22708]=0;ga:{ha:{if((e|0)!=1){v[22708]=0;R(530,d+40|0,i|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}e=d+40|0;m=qd(e);C=Ve(e);D=fj(e);q=fc(e);E=e+5|0;e=t[e|0];if((e-1&255)>>>0>95){break ha}t[b|0]=e+13;if(!v[d+84>>2]){break ga}t[b+3|0]=19;v[22708]=0;v[d+64>>2]=15;e=pd(l,d- -64|0);s=v[22708];v[22708]=0;if((s|0)==1){break o}t[b+5|0]=w[e|0]|208;break ga}break o}if((e|0)>-1){break ga}if(v[d+84>>2]){t[b+3|0]=19;v[22708]=0;v[d+64>>2]=15;e=pd(l,d- -64|0);s=v[22708];v[22708]=0;if((s|0)!=1){t[b+5|0]=w[e|0]|192;break ga}break o}t[b|0]=254}if(w[m|0]){t[b+2|0]=1;v[22708]=0;t[d+64|0]=64;e=ac(m,d- -64|0);m=v[22708];v[22708]=0;if((m|0)==1){break o}t[b+4|0]=w[e|0]}e=w[C|0];if(e){t[b+1|0]=e}e=w[D|0];if(e|w[q|0]){t[b+3|0]=e;t[b+5|0]=w[q|0];v[22708]=0;Of(b);b=v[22708];v[22708]=0;if((b|0)==1){break o}}b=w[E|0];if(b&128){v[22708]=0;e=T(374,i|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break o}b=e|b<<8&32512}e=v[a+480196>>2];v[22708]=0;o=b+o|0;kt(d- -64|0,o,e);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[d+68>>2];v[d+80>>2]=v[d+64>>2];v[d+84>>2]=b;continue}break}break o}xb(d+144|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}b=_b(p,f);v[22708]=0;b=Yc(b,0,0);e=v[22708];v[22708]=0;if((e|0)==1){break s}j=0;if(!h){break ca}while(1){i=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[22708]=0;R(531,d+144|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break ja}ka:{if(!A){v[d+80>>2]=v[d+144>>2];e=d+80|0;o=qd(e);m=Ve(e);q=fj(e);e=t[e|0];if((e|0)>=1){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}f=b;e=w[o|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[o|0]}t[f+1|0]=e<<4&48|w[m|0]>>>4;t[b+3|0]=w[m|0]&15;t[b+5|0]=w[q|0];break ka}e=v[d+144>>2];v[d+20>>2]=e;v[22708]=0;v[d+16>>2]=e;fr(d+16|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break ja}e=ic(d+144|0,0);t[b+1|0]=w[b+1|0]|w[e|0]&48}v[22708]=0;Of(b);e=v[22708];v[22708]=0;if((e|0)==1){break ja}e=w[b+3|0];la:{if(e>>>0>11){break la}e=1<<e;ma:{if(!(e&2240)){if(!(e&12)){break la}if(!w[b+5|0]){break ma}break la}e=w[b+5|0];f=e&240;if(f){t[b+5|0]=f;break la}if(e){break la}}t[b+3|0]=0}b=b+6|0;i=i+1|0;if(x[a+480188>>1]>(i&65535)>>>0){continue}break ia}break}a=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(h|0)){continue}break}}b=d+32|0;Eh(b);if(Gb(b,d+24|0)){continue}break}}jd(d+208|0);v[22708]=0;U(520,d+144|0,d+232|0,1346458702);b=v[22708];v[22708]=0;if((b|0)==1){a=P()|0;O()|0;break b}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((e|0)!=1){if(b){e=Kb(d+80|0);b=0;Ba:{while(1){Ca:{v[22708]=0;f=Q(191,d+144|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Ca}if(!f){break Ba}if(Te(p)>>>0<=b>>>0){break Ba}v[22708]=0;W(533,d+144|0,e|0,32)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Ca}f=_b(p,b);v[22708]=0;Q(428,f|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Ca}b=b+1|0;continue}break}a=P()|0;O()|0;vb(e);break Aa}vb(e)}b=d+144|0;xb(b);v[22708]=0;U(520,b|0,d+232|0,1414679374);b=v[22708];v[22708]=0;if((b|0)==1){break za}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break va}if(!b){break wa}e=Kb(d+80|0);b=0;while(1){v[22708]=0;f=Q(191,d+144|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ya}if(!f|x[a+480188>>1]<=b>>>0){break xa}v[22708]=0;W(533,d+144|0,e|0,32)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ya}v[22708]=0;Q(399,((b<<5)+a|0)+480289|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ya}b=b+1|0;continue}}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e);break ua}vb(e)}b=d+144|0;xb(b);v[22708]=0;U(529,b|0,d+232|0,1145129300);b=v[22708];v[22708]=0;if((b|0)==1){break ta}b=d+144|0;F=d,G=Vb(b),v[F+80>>2]=G;F=d,G=Zb(b),v[F+208>>2]=G;if(Gb(d+80|0,d+208|0)){e=c&2;while(1){b=v[d+80>>2];v[22708]=0;c=T(416,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Rc(d- -64|0,f&1?16:8,f&64?2:1,1,0);v[22708]=0;W(329,f|0,c+484484|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}}b=d+80|0;Eh(b);if(Gb(b,d+208|0)){continue}break}}jd(d+144|0);b=Kb(d+80|0);if((k|0)!=841887798){break ra}v[22708]=0;c=Q(2,d+144|0,6647)|0;e=v[22708];v[22708]=0;if((e|0)==1){break sa}Eb(b,c);vb(c);break qa}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}v[22708]=0;U(520,d+144|0,d+232|0,1447383635);c=v[22708];v[22708]=0;Da:{Ea:{Fa:{Ga:{Ha:{if((c|0)!=1){v[22708]=0;c=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break pa}if(!c){break Ea}v[22708]=0;c=T(426,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ha}v[22708]=0;R(411,d- -64|0,1401);e=v[22708];v[22708]=0;if((e|0)==1){break Ga}v[d+40>>2]=c>>>4;v[22708]=0;v[d+32>>2]=c&15;Y(534,d+208|0,d- -64|0,d+40|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break Fa}c=d+208|0;Eb(b,c);vb(c);Hb(d- -64|0);break Da}a=P()|0;O()|0;break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;Hb(d- -64|0);break r}v[22708]=0;c=Q(2,d+208|0,5656)|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}Eb(b,c);vb(c)}xb(d+144|0)}v[22708]=0;c=Q(2,d+144|0,5656)|0;e=v[22708];v[22708]=0;if((e|0)==1){break oa}Eb(a+1298304|0,c);vb(c);v[22708]=0;c=Q(2,d+144|0,7403)|0;e=v[22708];v[22708]=0;if((e|0)==1){break na}Eb(a+1298316|0,c);vb(c);Eb(a+1298328|0,b);v[a+1298364>>2]=2;vb(b);i=1;break v}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}ke(d+232|0)}gb=d+272|0;return i|0}a=P()|0;O()|0;break r}a=P()|0;O()|0;break k}xb(d+144|0)}vb(b);break b}a=P()|0;O()|0;jd(d+144|0);break b}a=P()|0;O()|0;xb(d+144|0);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0}jd(d+208|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}xb(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;xb(d+208|0)}ke(d+232|0)}S(a|0);L()}function xI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;x=gb-48|0;gb=x;a:{if(c>>>0<=2){c=c<<2;I=v[c+74780>>2];H=v[c+74768>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=md(b)}if(Am(c)){continue}break}m=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}m=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=md(b)}e:{f:{while(1){if(t[f+2048|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=md(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=x;h=gb-16|0;gb=h;g=(p(C(C(m|0)*C(N))),j(2));c=g&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;m=d<<25;d=c+1065353216|0;break h}m=g<<25;d=g>>>7|2147418112;if(c>>>0>=2139095040){break h}m=0;d=0;if(!c){break h}d=c;c=E(c);Lf(h,d,0,0,0,c+81|0);k=v[h>>2];l=v[h+4>>2];m=v[h+8>>2];d=v[h+12>>2]^65536|16265-c<<16}v[b>>2]=k;v[b+4>>2]=l;v[b+8>>2]=m;v[b+12>>2]=g&-2147483648|d;gb=h+16|0;k=v[x+8>>2];l=v[x+12>>2];h=v[x>>2];g=v[x+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+7248|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=md(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=md(b)}if((f&-33)==88){f=gb-432|0;gb=f;c=b;A=v[b+104>>2];b=v[b+4>>2];p:{if(A>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=md(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){J=1;v[c+4>>2]=b+1;b=w[b|0]}else{J=1;b=md(c)}continue}break}b=md(c)}G=1;if((b|0)!=48){break q}while(1){b=k;k=b-1|0;l=l-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=md(c)}if((b|0)==48){continue}break}J=1}A=1073676288;u:{while(1){v:{o=b|32;w:{x:{D=b-48|0;if(D>>>0<10){break x}if((b|0)!=46&o-97>>>0>=6){break u}if((b|0)!=46){break x}if(G){break v}G=1;k=h;l=g;break w}b=(b|0)>57?o-87|0:D;y:{if((g|0)<=0&h>>>0<=7|(g|0)<0){i=b+(i<<4)|0;break y}if((g|0)<=0&h>>>0<=28|(g|0)<0){Vg(f+48|0,b);Ed(f+32|0,r,z,F,A,0,0,0,1073414144);r=v[f+32>>2];z=v[f+36>>2];F=v[f+40>>2];A=v[f+44>>2];Ed(f+16|0,r,z,F,A,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);xg(f,q,e,s,u,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);s=v[f+8>>2];u=v[f+12>>2];q=v[f>>2];e=v[f+4>>2];break y}if(!b|n){break y}Ed(f+80|0,r,z,F,A,0,0,0,1073610752);xg(f- -64|0,q,e,s,u,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);s=v[f+72>>2];u=v[f+76>>2];n=1;q=v[f+64>>2];e=v[f+68>>2]}b=h+1|0;g=b>>>0<1?g+1|0:g;h=b;J=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=md(c)}continue}break}b=46}z:{A:{B:{if(!J){if(!v[c+104>>2]){if(d){break A}break B}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break B}v[c+4>>2]=b-2;if(!G){break A}v[c+4>>2]=b-3;break A}if((g|0)<=0&h>>>0<=7|(g|0)<0){F=h;A=g;while(1){i=i<<4;n=A;A=F+1|0;n=A>>>0<1?n+1|0:n;F=A;A=n;if((F|0)!=8|n){continue}break}}C:{D:{E:{if((b&-33)==80){F=wI(c,d);b=jb;A=b;if(F|(b|0)!=-2147483648){break C}if(d){if(v[c+104>>2]){break E}break D}q=0;e=0;zi(c,0,0);c=0;b=0;break z}if(!v[c+104>>2]){break D}}v[c+4>>2]=v[c+4>>2]-1}F=0;A=0}if(!i){vj(f+112|0,+(m|0)*0);q=v[f+112>>2];e=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=G?k:h;c=(G?l:g)<<2|b>>>30;b=F+(b<<2)|0;c=c+A|0;c=b>>>0<F>>>0?c+1|0:c;h=b-32|0;g=c-(b>>>0<32)|0;b=g;if(h>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[115189]=68;Vg(f+160|0,m);Ed(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Ed(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];e=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=I-226|0;c=b;b=b>>31;if(c>>>0<=h>>>0&(g|0)>=(b|0)|(b|0)<(g|0)){if((i|0)>-1){while(1){xg(f+416|0,q,e,s,u,0,0,0,-1073807360);c=nB(q,e,s,u,1073610752);b=(c|0)<0;xg(f+400|0,q,e,s,u,b?q:v[f+416>>2],b?e:v[f+420>>2],b?s:v[f+424>>2],b?u:v[f+428>>2]);b=h;h=b-1|0;g=g-(b>>>0<1)|0;s=v[f+408>>2];u=v[f+412>>2];q=v[f+400>>2];e=v[f+404>>2];i=i<<1|(c|0)>-1;if((i|0)>-1){continue}break}}b=h;c=I;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=b>>>0<H>>>0&(c|0)<=0|(c|0)<0?(b|0)>0?b:0:H;F:{if((c|0)>=113){Vg(f+384|0,m);k=v[f+392>>2];l=v[f+396>>2];r=v[f+384>>2];z=v[f+388>>2];g=0;b=0;break F}vj(f+352|0,ji(1,144-c|0));Vg(f+336|0,m);r=v[f+336>>2];z=v[f+340>>2];k=v[f+344>>2];l=v[f+348>>2];zI(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],r,z,k,l);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(i&1)&((sn(q,e,s,u,0,0,0,0)|0)!=0&(c|0)<32);_n(f+320|0,c+i|0);Ed(f+304|0,r,z,k,l,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;xg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);b=c;Ed(f+288|0,b?0:q,b?0:e,b?0:s,b?0:u,r,z,k,l);xg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Vx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!sn(b,c,d,g,0,0,0,0)){v[115189]=68}yI(f+224|0,b,c,d,g,h);q=v[f+224>>2];e=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[115189]=68;Vg(f+208|0,m);Ed(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Ed(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];e=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break z}zi(c,0,0)}vj(f+96|0,+(m|0)*0);q=v[f+96>>2];e=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[x+16>>2]=q;v[x+20>>2]=e;v[x+24>>2]=b;v[x+28>>2]=c;gb=f+432|0;k=v[x+24>>2];l=v[x+28>>2];h=v[x+16>>2];g=v[x+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}i=b;q=m;m=0;f=0;e=gb-8976|0;gb=e;J=H+I|0;O=0-J|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}b=v[i+4>>2];if(b>>>0>=y[i+104>>2]){break I}v[i+4>>2]=b+1;c=w[b|0];break H}}else{b=v[i+4>>2];if(b>>>0<y[i+104>>2]){m=1;v[i+4>>2]=b+1;c=w[b|0]}else{m=1;c=md(i)}continue}break}c=md(i)}o=1;if((c|0)!=48){break G}while(1){b=k;k=b-1|0;l=l-(b>>>0<1)|0;b=v[i+4>>2];J:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;c=w[b|0];break J}c=md(i)}if((c|0)==48){continue}break}m=1}v[e+784>>2]=0;K:{L:{b=(c|0)==46;n=c-48|0;M:{N:{O:{P:{if(!(!b&n>>>0>9)){while(1){Q:{if(b&1){if(!o){k=h;l=g;o=1;break Q}b=!m;break P}b=h+1|0;g=b>>>0<1?g+1|0:g;h=b;if((f|0)<=2044){G=(c|0)==48?G:h;b=(e+784|0)+(f<<2)|0;m=b;if(D){n=(B(v[b>>2],10)+c|0)-48|0}v[m>>2]=n;m=1;c=D+1|0;b=(c|0)==9;D=b?0:c;f=b+f|0;break Q}if((c|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;G=18396}b=v[i+4>>2];R:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;c=w[b|0];break R}c=md(i)}b=(c|0)==46;n=c-48|0;if(b|n>>>0<10){continue}break}}k=o?k:h;l=o?l:g;if(!(!m|(c&-33)!=69)){r=wI(i,d);b=jb;z=b;S:{if(r|(b|0)!=-2147483648){break S}if(!d){break M}r=0;z=0;if(!v[i+104>>2]){break S}v[i+4>>2]=v[i+4>>2]-1}if(!m){break N}n=l+z|0;b=k+r|0;n=b>>>0<r>>>0?n+1|0:n;k=b;l=n;break L}b=!m;if((c|0)<0){break O}}if(!v[i+104>>2]){break O}v[i+4>>2]=v[i+4>>2]-1}if(!b){break L}}v[115189]=28}h=0;g=0;zi(i,0,0);c=0;b=0;break K}b=v[e+784>>2];if(!b){vj(e,+(q|0)*0);h=v[e>>2];g=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((h|0)!=(k|0)|(g|0)!=(l|0)|(h>>>0>9&(g|0)>=0|(g|0)>0)|(b>>>H|0?(H|0)<=30:0))){Vg(e+48|0,q);_n(e+32|0,b);Ed(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);h=v[e+16>>2];g=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if(k>>>0>(I|0)/-2>>>0&(l|0)>=0|(l|0)>0){v[115189]=68;Vg(e+96|0,q);Ed(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Ed(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);h=v[e+64>>2];g=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(l|0)<=(b|0)|(b|0)>(l|0)){v[115189]=68;Vg(e+144|0,q);Ed(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Ed(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);h=v[e+112>>2];g=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(D){if((D|0)<=8){b=(e+784|0)+(f<<2)|0;i=v[b>>2];while(1){i=B(i,10);D=D+1|0;if((D|0)!=9){continue}break}v[b>>2]=i}f=f+1|0}T:{o=k;if((G|0)>(k|0)|(G|0)>=9|(k|0)>17){break T}if((o|0)==9){Vg(e+192|0,q);_n(e+176|0,v[e+784>>2]);Ed(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);h=v[e+160>>2];g=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((o|0)<=8){Vg(e+272|0,q);_n(e+256|0,v[e+784>>2]);Ed(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Vg(e+224|0,v[(0-o<<2)+74768>>2]);bF(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);h=v[e+208>>2];g=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}b=(B(o,-3)+H|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break T}Vg(e+352|0,q);_n(e+336|0,c);Ed(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Vg(e+304|0,v[(o<<2)+74696>>2]);Ed(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);h=v[e+288>>2];g=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=f;f=f-1|0;if(!v[(e+784|0)+(f<<2)>>2]){continue}break}D=0;b=(o|0)%9|0;U:{if(!b){b=0;break U}d=(o|0)>-1?b:b+9|0;V:{if(!c){b=0;c=0;break V}g=v[(0-d<<2)+74768>>2];h=1e9/(g|0)|0;n=0;i=0;b=0;while(1){k=n;l=(e+784|0)+(i<<2)|0;n=v[l>>2];m=(n>>>0)/(g>>>0)|0;k=k+m|0;v[l>>2]=k;k=!k&(b|0)==(i|0);b=k?b+1&2047:b;o=k?o-9|0:o;n=B(h,n-B(g,m)|0);i=i+1|0;if((i|0)!=(c|0)){continue}break}if(!n){break V}v[(e+784|0)+(c<<2)>>2]=n;c=c+1|0}o=(o-d|0)+9|0}while(1){h=(e+784|0)+(b<<2)|0;W:{while(1){if(((o|0)!=36|y[h>>2]>10384592)&(o|0)>=36){break W}m=c+2047|0;n=0;while(1){l=n;g=m&2047;m=(e+784|0)+(g<<2)|0;d=v[m>>2];n=d>>>3|0;k=d<<29;d=l+k|0;n=d>>>0<k>>>0?n+1|0:n;k=d;l=n;if(!l&k>>>0<1000000001){n=0}else{n=qqa(k,l,1e9,0);k=k-nqa(n,jb,1e9,0)|0}v[m>>2]=k;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:k?c:g;m=g-1|0;if((b|0)!=(g|0)){continue}break}D=D-29|0;if(!n){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;g=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[g>>2]=v[g>>2]|v[d+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=n;continue}break}X:{Y:while(1){d=c+1&2047;k=(e+784|0)+((c-1&2047)<<2)|0;while(1){g=(o|0)>45?9:1;Z:{while(1){m=b;i=0;_:{while(1){$:{b=i+m&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];h=v[(i<<2)+74720>>2];if(b>>>0<h>>>0){break $}if(b>>>0>h>>>0){break _}i=i+1|0;if((i|0)!=4){continue}}break}if((o|0)!=36){break _}k=0;l=0;i=0;h=0;g=0;while(1){b=i+m&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Ed(e+768|0,k,l,h,g,0,0,1342177280,1075633366);_n(e+752|0,v[(e+784|0)+(b<<2)>>2]);xg(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);h=v[e+744>>2];g=v[e+748>>2];k=v[e+736>>2];l=v[e+740>>2];i=i+1|0;if((i|0)!=4){continue}break}Vg(e+720|0,q);Ed(e+704|0,k,l,h,g,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);h=v[e+712>>2];g=v[e+716>>2];k=0;l=0;r=v[e+704>>2];z=v[e+708>>2];o=D+113|0;d=o-I|0;n=(d|0)<(H|0);b=n?(d|0)>0?d:0:H;if((b|0)<=112){break Z}break X}D=g+D|0;b=c;if((m|0)==(b|0)){continue}break}l=1e9>>>g|0;n=-1<<g^-1;i=0;b=m;while(1){h=i;f=(e+784|0)+(m<<2)|0;i=v[f>>2];h=h+(i>>>g|0)|0;v[f>>2]=h;h=!h&(b|0)==(m|0);b=h?b+1&2047:b;o=h?o-9|0:o;i=B(l,i&n);m=m+1&2047;if((m|0)!=(c|0)){continue}break}if(!i){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=i;c=d;continue Y}v[k>>2]=v[k>>2]|1;b=d;continue}break}break}vj(e+656|0,ji(1,225-b|0));zI(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],r,z,h,g);F=v[e+696>>2];A=v[e+700>>2];K=v[e+688>>2];L=v[e+692>>2];vj(e+640|0,ji(1,113-b|0));IE(e+672|0,r,z,h,g,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];l=v[e+676>>2];s=v[e+680>>2];u=v[e+684>>2];Vx(e+624|0,r,z,h,g,k,l,s,u);xg(e+608|0,K,L,F,A,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);h=v[e+616>>2];g=v[e+620>>2];r=v[e+608>>2];z=v[e+612>>2]}f=m+4&2047;aa:{if((f|0)==(c|0)){break aa}f=v[(e+784|0)+(f<<2)>>2];ba:{if(f>>>0<=499999999){if(!f&(m+5&2047)==(c|0)){break ba}vj(e+496|0,+(q|0)*.25);xg(e+480|0,k,l,s,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);s=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];l=v[e+484>>2];break ba}if((f|0)!=5e8){vj(e+592|0,+(q|0)*.75);xg(e+576|0,k,l,s,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);s=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];l=v[e+580>>2];break ba}M=+(q|0);if((m+5&2047)==(c|0)){vj(e+528|0,M*.5);xg(e+512|0,k,l,s,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);s=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];l=v[e+516>>2];break ba}vj(e+560|0,M*.75);xg(e+544|0,k,l,s,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);s=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];l=v[e+548>>2]}if((b|0)>111){break aa}IE(e+464|0,k,l,s,u,0,0,0,1073676288);if(sn(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}xg(e+448|0,k,l,s,u,0,0,0,1073676288);s=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];l=v[e+452>>2]}xg(e+432|0,r,z,h,g,k,l,s,u);Vx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],K,L,F,A);h=v[e+424>>2];g=v[e+428>>2];r=v[e+416>>2];z=v[e+420>>2];ca:{if((-2-J|0)>=(o&2147483647)){break ca}v[e+408>>2]=h;v[e+412>>2]=g&2147483647;v[e+400>>2]=r;v[e+404>>2]=z;Ed(e+384|0,r,z,h,g,0,0,0,1073610752);A=v[e+400>>2];F=v[e+404>>2];f=v[e+408>>2];o=v[e+412>>2];c=nB(A,F,f,o,1081081856);m=(c|0)<0;i=m;h=i?h:v[e+392>>2];g=i?g:v[e+396>>2];r=i?r:v[e+384>>2];z=i?z:v[e+388>>2];D=((c|0)>-1)+D|0;if((D+110|0)<=(O|0)){if((((nB(A,F,f,o,1081081856)|0)<0?n:n&(b|0)!=(d|0))|0)!=1){break ca}if(!sn(k,l,s,u,0,0,0,0)){break ca}}v[115189]=68}yI(e+368|0,r,z,h,g,D);h=v[e+368>>2];g=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[x+32>>2]=h;v[x+36>>2]=g;v[x+40>>2]=b;v[x+44>>2]=c;gb=e+8976|0;k=v[x+40>>2];l=v[x+44>>2];h=v[x+32>>2];g=v[x+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=md(b)}if((c|0)==40){f=1;break da}l=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=md(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){f=f+1|0;continue}break}l=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[115189]=28;zi(b,0,0)}l=0}v[a>>2]=h;v[a+4>>2]=g;v[a+8>>2]=k;v[a+12>>2]=l;gb=x+48|0}function Lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-416|0;gb=d;vc(b);e=d+408|0;g=Yv(b,e);if(!g){qW(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!g){break q}if(!BW(d+408|0)){break q}if(!c){p=1;break q}A=le(d+384|0,b);v[22708]=0;R(666,d+368|0,A|0);b=v[22708];v[22708]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[22708]=0;U(667,d+344|0,d+368|0,20041);b=v[22708];v[22708]=0;if((b|0)==1){break F}v[22708]=0;b=T(275,d+344|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}if(!b){break r}v[22708]=0;b=Q(668,d+344|0,d+248|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}if(!b){break r}v[22708]=0;R(367,a|0,16384);b=v[22708];v[22708]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[22708]=0;b=a+1074312|0;W(409,b|0,9,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;Q(410,b|0,21)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;Q(410,b|0,30)|0;b=v[22708];v[22708]=0;if((b|0)==1){break w}v[22708]=0;b=Q(2,d+208|0,5413)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+208|0,8009)|0;e=v[22708];v[22708]=0;if((e|0)==1){break B}Eb(a+1298316|0,b);vb(b);v[22708]=0;b=Q(2,d+96|0,14606)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}e=w[d+412|0];switch(e-16|0){case 1:break z;case 0:break E;default:break D}}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22708]=0;Q(2,d+232|0,12226)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break x}break e}if(!e){break y}v[22708]=0;Q(2,d+232|0,18726)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}break x}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22708]=0;Q(2,d+232|0,12244)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break x}break e}v[22708]=0;Q(2,d+232|0,10607)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}}v[22708]=0;U(3,d+208|0,b|0,d+232|0);e=v[22708];v[22708]=0;if((e|0)==1){break f}e=d+208|0;Eb(a+1298328|0,e);vb(e);vb(d+232|0);vb(b);v[a+1298364>>2]=5;v[22708]=0;Je(d+96|0,3,d+248|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;R(324,d+208|0,d+96|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}b=d+208|0;Eb(a+1298268|0,b);vb(b);v[22708]=0;Yj(d+232|0,3,d+280|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(324,d+96|0,d+232|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;U(13,d+208|0,5,d+96|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d+208|0;Eb(a+1298280|0,b);vb(b);vb(d+96|0);v[a+480200>>2]=w[d+304|0]+1;H=a,I=Fd(w[d+305|0],1,255),v[H+480196>>2]=I;H=a,I=B(Fd(w[d+306|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Sb(b);g=w[d+300|0]|w[d+301|0]<<8;v[22708]=0;fa(521,e|0,d+344|0,g|0,65535,65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}cf(Sb(b),w[d+302|0]|w[d+303|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[22708]=0;e=(b<<5)+a|0;g=e+480280|0;We(g);f=v[22708];v[22708]=0;if((f|0)==1){break j}f=b+d|0;h=w[f+307|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;G:{if(t[f+307|0]<=-1){v[g>>2]=v[g>>2]|1024;break G}u[a+480188>>1]=b+1}v[22708]=0;R(669,d+344|0,e+480289|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[22708]=0;U(667,d+208|0,d+368|0,17741);b=v[22708];v[22708]=0;if((b|0)==1){break k}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22708]=0;b=T(195,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;da(509,a+1298292|0,d+344|0,b|0,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break w}v[22708]=0;U(667,d+208|0,d+368|0,21321);b=v[22708];v[22708]=0;if((b|0)==1){break l}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22708]=0;b=T(275,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}H:{if(b){v[22708]=0;U(667,d+208|0,d+368|0,16723);b=v[22708];v[22708]=0;if((b|0)==1){break m}v[22708]=0;k=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break n}I:{if(!k){break I}m=c&2;g=0;while(1){v[22708]=0;e=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break n}if(!e){break I}v[22708]=0;b=Q(191,d+344|0,56)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}if(!b){break I}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[22708]=0;b=B(e,104)+a|0;f=b+484380|0;R(424,f|0,0);h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;W(474,d+344|0,((e<<5)+a|0)+946304|0,32)|0;e=v[22708];v[22708]=0;if((e|0)==1){break n}v[22708]=0;W(477,d+344|0,b+484423|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break n}J:{if(w[d+412|0]<=15){v[22708]=0;e=T(287,d+344|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break J}break n}v[22708]=0;e=T(192,d+344|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}}v[b+484404>>2]=e<<1;v[22708]=0;e=T(192,d+344|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}v[f>>2]=e;v[22708]=0;h=T(192,d+344|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=h;v[22708]=0;h=T(192,d+344|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break n}j=b+484388|0;v[j>>2]=h;if(h){i=b+484414|0;u[i>>1]=x[i>>1]|2;v[j>>2]=h+v[e>>2]}v[22708]=0;h=T(374,d+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break H}if(w[d+412|0]<=15){u[b+484410>>1]=h}v[22708]=0;h=T(374,d+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}l=b+484414|0;b=x[l>>1];i=8;if(h&1){b=b|1;u[l>>1]=b;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[j>>2]=v[j>>2]>>>1;i=16}u[l>>1]=b&65531|h<<1&4;b=Rc(d+96|0,i,1,0,((h&12)!=0)<<3);K:{if(!m){break K}v[22708]=0;W(329,b|0,f|0,d+208|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break K}break n}g=g+1|0;if(k>>>0>(g&255)>>>0){continue}break}}xb(d+208|0)}v[22708]=0;U(667,d+208|0,d+368|0,18761);b=v[22708];v[22708]=0;if((b|0)==1){break p}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22708]=0;b=T(275,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}if(b){k=dd(d+96|0);i=dd(d+232|0);l=dd(d+192|0);v[22708]=0;U(667,d+168|0,d+368|0,17750);b=v[22708];v[22708]=0;if((b|0)==1){break o}e=v[d+180>>2];b=d- -64|0;v[b>>2]=v[d+176>>2];v[b+4>>2]=e;v[d+72>>2]=v[d+184>>2];v[22708]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(670,d+56|0,k|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[22708]=0;U(667,d+144|0,d+368|0,17744);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[22708]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(670,d+32|0,i|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[22708]=0;U(667,d+120|0,d+368|0,17734);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[22708]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(670,d+8|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}j=0;v[22708]=0;o=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}if(o){b=d+208|0;y=b|4;z=b|2;q=b|6;r=b|5;s=b|3;e=b|1;while(1){v[22708]=0;R(403,d+80|0,d+344|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=d+80|0;m=qd(b);L:{M:{N:{if(!w[b|0]){break N}g=w[m|0];v[22708]=0;g=Q(191,d+344|0,B(g,14)+32|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}if(!g){break N}b=w[b|0];v[22708]=0;h=W(376,a|0,b|0,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}if(h){break M}}b=w[m|0];v[22708]=0;Q(318,d+344|0,B(b,14)+32|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break L}break o}v[22708]=0;W(474,d+344|0,h+492|0,32)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}if(!w[m|0]){break L}C=h+88|0;D=h+68|0;E=h+48|0;F=h+236|0;f=0;b=0;while(1){v[22708]=0;R(671,d+344|0,d+208|0);g=v[22708];v[22708]=0;if((g|0)==1){break o}O:{if(!w[d+208|0]|x[a+480190>>1]<w[d+208|0]){break O}g=e;if(w[e|0]>128){t[g|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){g=w[d+208|0];H=vd(F,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}G=w[e|0];b=w[s|0];v[22708]=0;U(672,E|0,b|0,k|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=w[r|0];v[22708]=0;U(672,D|0,b|0,i|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=w[d+221|0];v[22708]=0;U(672,C|0,b|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[h>>2]=(w[q|0]|w[q+1|0]<<8)+1>>>1;b=w[d+208|0];P:{if(w[s|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break P}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}u[d+118>>1]=w[y|0]<<1;v[22708]=0;u[d+116>>1]=254;n=Pc(d+118|0,d+116|0);g=v[22708];v[22708]=0;Q:{R:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[n>>1];t[g+484418|0]=w[(w[d+219|0]&3)+28885|0];n=g+484419|0;t[n|0]=w[d+218|0];p=g+484420|0;t[p|0]=w[d+217|0]+3>>>2;t[g+484421|0]=w[d+216|0];b=w[n|0];if(b){break R}p=255;break Q}break o}p=fm(Qc((((w[p|0]<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0))}b=G+1|0;t[n|0]=p;if(!(w[r|0]&64)){break O}g=g+484414|0;u[g>>1]=x[g>>1]|32}f=f+1|0;if(w[m|0]>(f&255)>>>0){continue}break}}j=j+1|0;if(o>>>0>(j&255)>>>0){continue}break}}ep(l);ep(i);ep(k)}p=1;k=mc(d+232|0);if(!(c&1)){break s}v[22708]=0;U(667,d+208|0,d+368|0,21076);b=v[22708];v[22708]=0;S:{T:{U:{if((b|0)!=1){b=Vc(d+344|0,d+208|0);v[22708]=0;b=T(275,b|0)|0;c=v[22708];v[22708]=0;V:{W:{X:{Y:{Z:{_:{if((c|0)!=1){xb(d+208|0);$:{if(!b){break $}v[22708]=0;c=T(287,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break _}v[22708]=0;R(673,k|0,c+1|0);b=v[22708];v[22708]=0;if((b|0)==1){break _}if(!c){break $}b=1;while(1){v[22708]=0;e=T(287,d+344|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Z}v[22708]=0;U(288,d+96|0,d+344|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break Z}e=d+208|0;g=d+96|0;f=kc(e,g);Vc(Kg(k,b),f);f=(b|0)==(c|0);xb(e);xb(g);b=b+1|0;if(!f){continue}break}}v[22708]=0;U(667,d+208|0,d+368|0,16720);b=v[22708];v[22708]=0;if((b|0)==1){break Y}b=Vc(d+344|0,d+208|0);v[22708]=0;b=T(275,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break X}xb(d+208|0);if(!b){break V}f=0;v[22708]=0;l=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}if(l){while(1){m=32;aa:{if(w[d+412|0]>=16){v[22708]=0;R(674,d+344|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break U}if(!(w[d+208|0]>32|x[a+480188>>1]>=w[d+208|0])){u[a+480188>>1]=w[d+208|0]}m=w[d+208|0];if(!m){break aa}}b=0;while(1){v[22708]=0;c=T(287,d+344|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break T}ba:{if(!c){break ba}c=b&65535;if(c>>>0>31|c>>>0<x[a+480188>>1]){break ba}u[a+480188>>1]=b+1}b=b+1|0;if((b&65535)>>>0<m>>>0){continue}break}}f=f+1|0;if(l>>>0>(f&65535)>>>0){continue}break}}v[22708]=0;Q(190,d+344|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break W}break u}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}v[22708]=0;o=a+484344|0;R(330,o|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break u}if(!l){break V}b=d+208|0;C=b|2;D=b|1;g=0;while(1){q=Kb(d+96|0);r=64;s=32;if(w[d+412|0]>=16){v[22708]=0;R(674,d+344|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break v}s=w[d+208|0];b=w[D|0];v[22708]=0;AW(d+80|0,3,C);c=v[22708];v[22708]=0;if((c|0)==1){break v}v[22708]=0;R(324,d+192|0,d+80|0);c=v[22708];v[22708]=0;if((c|0)==1){break v}c=d+192|0;Eb(q,c);vb(c);r=b+1|0}v[22708]=0;b=W(331,o|0,g&65535,r|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}ca:{if(!b){v[22708]=0;Q(318,d+344|0,s<<1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ca}break v}b=_b(o,g);v[22708]=0;Q(428,b|0,q|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}j=0;if(!s){break ca}while(1){v[22708]=0;b=T(287,d+344|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}da:{if(!b){break da}if(Ie(k)>>>0<=b>>>0){break da}n=j&65535;if(n>>>0>=x[a+480188>>1]){break da}h=Kg(k,b);vc(h);c=0;while(1){v[22708]=0;b=Q(191,h|0,1)|0;e=v[22708];v[22708]=0;ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){if(!b){break da}b=_b(o,g);v[22708]=0;b=Yc(b,c,n);e=v[22708];v[22708]=0;if((e|0)==1){break v}v[22708]=0;f=T(374,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}e=f>>>2|0;switch((f&3)-1|0){case 2:break ga;case 1:break ha;case 0:break ia;default:break ja}}break v}c=(c+e|0)+1|0;break ea}if(!c){c=0;break ea}f=_b(o,g);v[22708]=0;f=Yc(f,c-1|0,n);i=v[22708];v[22708]=0;if((i|0)!=1){while(1){i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;c=c+1|0;if(r>>>0<=c>>>0){break ea}b=B(x[a+480188>>1],6)+b|0;i=e&255;e=e-1|0;if(i){continue}break ea}}break v}if(c>>>0<=e>>>0){break fa}f=_b(o,g);v[22708]=0;e=Yc(f,e,n);f=v[22708];v[22708]=0;if((f|0)==1){break S}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break fa}if(e&1){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break S}t[b|0]=f>>>0>120?-1:f}if(e&2){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break S}t[b+1|0]=f}f=0;m=0;if(e&4){v[22708]=0;m=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break v}}y=0;if(e&8){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break v}y=f>>>4|0;f=f&15}i=0;z=0;if(e&16){v[22708]=0;z=T(374,h|0)|0;E=v[22708];v[22708]=0;if((E|0)==1){break v}}if(e&32){v[22708]=0;i=T(374,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}}v[22708]=0;zW(b,m,f,y,z,i);b=v[22708];v[22708]=0;if((b|0)==1){break v}}c=c+1|0}if(c>>>0<r>>>0){continue}break}}j=j+1|0;if((j&65535)>>>0<s>>>0){continue}break}}vb(q);g=g+1|0;if((l|0)!=(g|0)){continue}break}}v[22708]=0;U(667,d+208|0,d+368|0,20048);b=v[22708];v[22708]=0;ka:{la:{ma:{if((b|0)!=1){b=Vc(d+344|0,d+208|0);v[22708]=0;b=T(275,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ma}xb(d+208|0);if(!b){break s}a=a+484344|0;if(!Te(a)){break s}while(1){v[22708]=0;b=Q(191,d+344|0,16)|0;c=v[22708];v[22708]=0;if((c|0)==1){break la}if(!b){break s}v[22708]=0;R(677,d+344|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break ka}b=_b(a,0);v[22708]=0;R(678,b|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break ka}if(Te(a)){continue}break}break s}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}break v}break n}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(q);break t}e=P()|0;O()|0}jd(k);break c}jd(k)}xb(d+344|0);ke(d+368|0);xb(A)}gb=d+416|0;return p|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;ep(l);ep(i);ep(k);break c}e=P()|0;O()|0;xb(d+208|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+96|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+232|0);break d}e=P()|0;O()|0}vb(b)}xb(d+344|0)}ke(d+368|0)}xb(A);S(e|0);L()}function mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=gb-272|0;gb=e;vc(b);a:{b:{c:{if(!bv(b,e+176|0)){break c}if(!tU(e+176|0)){break c}if(!Pb(b,Qc(sU(e+176|0),jb))){break c}if(!c){s=1;break c}Hd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=Kb(e+160|0);i=e+216|0;if((w[i|0]|w[i+1|0]<<8)==20479){g=w[e+230|0]|w[e+231|0]<<8}else{g=(w[i|0]|w[i+1|0]<<8)-16464|0}d:{e:{f:{g:{h:{i:{j:{k:{switch((w[i|0]|w[i+1|0]<<8)>>>12|0){case 0:if((w[i|0]|w[i+1|0]<<8)!=520){break d}v[22708]=0;f=Q(2,e+32|0,9553)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a;case 1:l:{if(w[e+238|0]|w[e+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[e+228|0]|w[e+208|0]&15)){break l}if((w[e+214|0]|w[e+215|0]<<8)&65455){break l}m:{if(t[e+227|0]<=-1){v[a+1074308>>2]=18219008;v[22708]=0;f=Q(2,e+32|0,11966)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break m}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[22708]=0;f=Q(2,e+32|0,10694)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}}Eb(k,f);vb(f);v[22708]=0;j=1;W(409,a+1074312|0,81,1)|0;d=v[22708];v[22708]=0;f=1;if((d|0)!=1){break d}break b}n:{if(w[e+238|0]|w[e+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[e+228|0]|(w[e+214|0]|w[e+215|0]<<8))){break n}if(w[e+229|0]){break n}v[22708]=0;f=Q(2,e+32|0,6633)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a}v[22708]=0;d=Q(2,e+32|0,5641)|0;h=v[22708];v[22708]=0;s=1;if((h|0)!=1){Eb(k,d);vb(d);break f}b=P()|0;O()|0;break a;case 2:v[22708]=0;d=Q(2,e+32|0,3830)|0;h=v[22708];v[22708]=0;f=1;if((h|0)!=1){Eb(k,d);vb(d);break f}b=P()|0;O()|0;break a;case 3:o:{p:{q:{l=w[i|0]|w[i+1|0]<<8;r:{if(l>>>0<=12820){v[22708]=0;d=Q(2,e+32|0,5688)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(k,d);vb(d);break r}b=P()|0;O()|0;break a}v[22708]=0;R(597,e+144|0,1124);d=v[22708];v[22708]=0;if((d|0)==1){break q}d=w[i|0]|w[i+1|0]<<8;v[22708]=0;v[e+128>>2]=d-12820;U(598,e+32|0,e+144|0,e+128|0);d=v[22708];v[22708]=0;if((d|0)==1){break p}d=e+32|0;Eb(k,d);vb(d);Hb(e+144|0)}if((w[i|0]|w[i+1|0]<<8)>>>0<12807){break g}if(w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24)){break o}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hb(e+144|0);break a}d=w[i|0]|w[i+1|0]<<8;f=w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24);v[22708]=0;d=uw(d,f);f=v[22708];v[22708]=0;if((f|0)==1){break i}f=Cr(e+32|0);v[f+44>>2]=d;v[22708]=0;R(601,a+1298368|0,f|0);d=v[22708];v[22708]=0;if((d|0)!=1){break g}b=P()|0;O()|0;break a;case 4:if((w[i|0]|w[i+1|0]<<8)==16640){v[22708]=0;d=Q(2,e+32|0,5473)|0;h=v[22708];v[22708]=0;f=1;if((h|0)!=1){Eb(k,d);vb(d);v[22708]=0;W(409,a+1074312|0,81,1)|0;d=v[22708];v[22708]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a}d=w[i|0]|w[i+1|0]<<8;f=w[e+230|0]|w[e+231|0]<<8;v[22708]=0;U(602,e+32|0,d|0,f|0);d=v[22708];v[22708]=0;s:{if((d|0)!=1){d=e+32|0;Eb(k,d);vb(d);v[a+480260>>2]=1;if((g|0)<4201){break s}v[22708]=0;W(409,a+1074312|0,7,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}break h}b=P()|0;O()|0;break a}if((g|0)>=2386){break h}f=1;h=1;break d;case 5:l=(w[i|0]|w[i+1|0]<<8)&4095;d=l<<16;f=a;if(l>>>0>=297){d=d|(w[e+230|0]|w[e+231|0]<<8)}v[f+1074308>>2]=d;v[22708]=0;f=Q(2,e+144|0,14719)|0;d=v[22708];v[22708]=0;t:{u:{v:{if((d|0)!=1){v[22708]=0;R(162,e+128|0,a+1074308|0);d=v[22708];v[22708]=0;if((d|0)==1){break v}v[22708]=0;U(3,e+32|0,f|0,e+128|0);d=v[22708];v[22708]=0;if((d|0)==1){break u}d=e+32|0;Eb(k,d);vb(d);vb(e+128|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break t}b=P()|0;O()|0;vb(e+128|0)}vb(f);break a;case 6:v[22708]=0;d=Q(2,e+32|0,5473)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(k,d);vb(d);v[22708]=0;W(409,a+1074312|0,81,1)|0;d=v[22708];v[22708]=0;f=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[22708]=0;f=Q(2,e+32|0,5499)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a;default:break k}}if((w[i|0]|w[i+1|0]<<8)!=51712){break d}v[22708]=0;f=Q(2,e+32|0,6432)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[22708]=0;f=1;W(409,a+1074312|0,38,1)|0;d=v[22708];v[22708]=0;h=1;if((d|0)==1){break b}break d}v[22708]=0;d=a+1074312|0;W(409,d|0,7,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;W(409,d|0,23,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;W(409,d|0,38,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;W(409,d|0,107,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}f=1;v[a+480260>>2]=1;if(l>>>0>12820){break d}}v[22708]=0;_(877,e+144|0);d=v[22708];v[22708]=0;w:{x:{y:{if((d|0)!=1){v[e+16>>2]=w[i+1|0]&15;d=w[i|0];v[22708]=0;v[e>>2]=d;R(599,e+128|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break y}v[22708]=0;ha(878,e+32|0,e+144|0,k|0,e+16|0,e+128|0);d=v[22708];v[22708]=0;if((d|0)==1){break x}d=e+32|0;Eb(k,d);vb(d);vb(e+128|0);Hb(e+144|0);h=0;break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(e+128|0)}Hb(e+144|0);break a}vb(f);f=0}v[22708]=0;d=Q(2,e+32|0,12230)|0;l=v[22708];v[22708]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((l|0)!=1){Eb(a+1298304|0,d);vb(d);v[22708]=0;d=Q(2,e+32|0,7744)|0;l=v[22708];v[22708]=0;if((l|0)==1){break M}Eb(a+1298316|0,d);vb(d);r=a+1298328|0;Eb(r,k);v[a+1298364>>2]=v[a+1074308>>2]?8:5;if(f){v[22708]=0;d=a+1074312|0;Q(410,d|0,77)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(410,d|0,78)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(410,d|0,79)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(410,d|0,80)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(410,d|0,82)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(410,d|0,96)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(410,d|0,113)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}}d=w[i|0]|w[i+1|0]<<8;f=d&61440;j=f>>>0<4097|(f|0)==12288&d>>>0<12820?j:1;v[22708]=0;d=a+901404|0;_(879,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break b}if(!j){v[22708]=0;Wo(d);d=v[22708];v[22708]=0;if((d|0)==1){break b}}v[22708]=0;Mk(e+144|0,1,e+176|0);d=v[22708];v[22708]=0;if((d|0)==1){break L}v[22708]=0;R(324,e+32|0,e+144|0);d=v[22708];v[22708]=0;if((d|0)==1){break L}d=e+32|0;Eb(a+1298268|0,d);vb(d);if(w[e+214|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[e+214|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[e+214|0]&64?0:(w[i|0]|w[i+1|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+225|0];v[a+480196>>2]=d;if(!(!s|(d|0)!=255?d:0)){v[a+480196>>2]=6}v[a+480204>>2]=B(w[e+226|0],1e4);if(w[e+226|0]<=32){v[a+480204>>2]=s?125e4:32e4}t[e+32|0]=w[e+224|0];v[22708]=0;t[e+144|0]=64;d=ac(e+32|0,e+144|0);f=v[22708];v[22708]=0;if((f|0)==1){break H}d=w[d|0];v[a+480200>>2]=d<<2;if(!((w[i|0]|w[i+1|0]<<8)>>>0>4895|d)){v[a+480200>>2]=256}if((w[e+218|0]|w[e+219|0]<<8)!=1|w[e+227|0]>7){break J}v[e+32>>2]=(w[e+227|0]<<4)+16;v[22708]=0;v[e+144>>2]=127;d=pd(e+32|0,e+144|0);f=v[22708];v[22708]=0;if((f|0)==1){break K}v[a+480228>>2]=v[d>>2];break I}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}if(!(w[e+227|0]!=2&w[e+227|0]!=18)){v[a+480228>>2]=32;break I}if(!(w[e+227|0]&127)){v[a+480228>>2]=48;break I}v[e+32>>2]=w[e+227|0]&127;v[22708]=0;v[e+144>>2]=16;d=Hf(e+32|0,e+144|0);f=v[22708];v[22708]=0;if((f|0)==1){break G}v[a+480228>>2]=v[d>>2]}l=v[a+1074308>>2]!=0|t[e+227|0]<0;if(!l){d=v[a+480228>>2];f=d>>>29|0;H=a,I=Qc(qqa(d<<3|5,f,11,0),jb),v[H+480228>>2]=I}u[a+480188>>1]=4;v[a+480232>>2]=h?(g|0)<3299?64:36:36;d=vr(e+120|0);h=0;while(1){v[22708]=0;g=(h<<5)+a|0;o=g+480280|0;We(o);f=v[22708];v[22708]=0;if((f|0)==1){break F}f=e+h|0;j=w[f+240|0];N:{if(w[f+240|0]==255){break N}u[a+480188>>1]=h+1;if(!l){break N}u[g+480284>>1]=j&8?204:51}if(t[f+240|0]<=-1){v[o>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[g+480284>>1]=128;g=e+32|0;Al(g,d,h);Uf(g,1)}h=h+1|0;if((h|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}g=Sb(a+484360|0);f=w[e+208|0]|w[e+209|0]<<8;v[22708]=0;fa(521,g|0,b|0,f|0,255,254)|0;g=v[22708];v[22708]=0;O:{P:{Q:{R:{S:{if((g|0)!=1){y=mc(e+144|0);g=w[e+210|0]|w[e+211|0]<<8;v[22708]=0;W(327,b|0,y|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break S}l=mc(e+128|0);g=w[e+212|0]|w[e+213|0]<<8;v[22708]=0;W(327,b|0,l|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break O}if(w[e+229|0]==252){h=0;v[22708]=0;R(880,b|0,e+32|0);g=v[22708];v[22708]=0;if((g|0)==1){break R}while(1){f=(e+32|0)+h|0;g=w[f|0];T:{if(!(g&32)){break T}j=((h<<5)+a|0)+480284|0;if(s){g=e+16|0;Al(g,d,h);if(Cb(g)){break T}g=w[f|0]}u[j>>1]=(((g&15)<<8|8)>>>0)/15}h=h+1|0;if((h|0)!=32){continue}break}}u[e+32>>1]=w[e+210|0]|w[e+211|0]<<8;h=0;v[22708]=0;u[e+16>>1]=3999;g=Pc(e+32|0,e+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break Q}g=x[g>>1];u[a+480190>>1]=g;if(g){break P}j=0;f=0;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break B}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}o=c&2;g=e+45|0;n=e+80|0;f=0;j=0;U:{V:{W:{while(1){d=sc(y,h);d=w[d|0]|w[d+1|0]<<8;v[22708]=0;d=Q(190,b|0,d<<4)|0;p=v[22708];v[22708]=0;if((p|0)==1){break E}X:{Y:{if(!d){break Y}v[22708]=0;d=Q(881,b|0,e+32|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break E}if(!d){break Y}v[22708]=0;d=h+1|0;p=(B(d,104)+a|0)+484380|0;U(882,e+32|0,p|0,s|0);m=v[22708];v[22708]=0;if((m|0)==1){break E}v[22708]=0;Mk(e,1,n);m=v[22708];v[22708]=0;if((m|0)==1){break X}v[22708]=0;R(324,e+16|0,e|0);m=v[22708];v[22708]=0;if((m|0)==1){break X}v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,e+16|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break W}vb(e+16|0);if(w[e+32|0]>1){break Y}m=w[e+46|0];z=w[e+47|0];d=g;Z:{if(!o|!(w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24))){break Z}d=w[d|0];v[22708]=0;d=Q(190,b|0,z<<12|m<<4|d<<20)|0;m=v[22708];v[22708]=0;if((m|0)==1){break V}if(!d){break Z}d=w[e+218|0]|w[e+219|0]<<8;v[22708]=0;ZQ(e+16|0,e+32|0,(d|0)==1);d=v[22708];v[22708]=0;if((d|0)==1){break U}v[22708]=0;W(329,e+16|0,p|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break U}j=1}f=w[e+72|0]|w[e+73|0]<<8|f}h=h+1|0;if(h>>>0>=x[a+480190>>1]){break D}continue}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;vb(e+16|0);break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break C}_:{$:{aa:{ba:{if(!s){break ba}if(!(!(!j|f&65535)&(w[i|0]|w[i+1|0]<<8)!=4864)){v[22708]=0;g=a+1074312|0;d=f&65535;W(409,g|0,79,d>>>0>1|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break $}v[22708]=0;W(409,g|0,107,d>>>0<2|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break $}v[22708]=0;g=f&65535;Q(154,r|0,(g>>>0>1?14249:14256)|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break $}if(g>>>0<2){break ba}v[a+480228>>2]=48;break ba}v[22708]=0;g=Q(2,e+32|0,6892)|0;d=v[22708];v[22708]=0;if((d|0)==1){break aa}Eb(r,g);vb(g)}g=i;s=1;if(c&1){break _}break z}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=w[g|0]|w[g+1|0]<<8;u[e+32>>1]=w[e+212|0]|w[e+213|0]<<8;v[22708]=0;u[e+16>>1]=255;g=Pc(e+32|0,e+16|0);d=v[22708];v[22708]=0;ca:{da:{if((d|0)!=1){p=x[g>>1];v[22708]=0;g=a+484344|0;R(330,g|0,p|0);d=v[22708];v[22708]=0;if((d|0)==1){break da}m=c>>>0<4896;if(p){break ca}r=0;o=0;break A}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=e+32|0;C=c|5;D=c|3;z=c|4;E=c|2;F=c|1;j=0;o=0;r=0;ea:{fa:{while(1){ga:{v[22708]=0;c=W(331,g|0,j&65535,64)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ga}ha:{if(!c){break ha}c=sc(l,j);if(!(w[c|0]|w[c+1|0]<<8)){break ha}c=sc(l,j);c=w[c|0]|w[c+1|0]<<8;v[22708]=0;c=Q(190,b|0,c<<4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ga}if(!c){break ha}v[22708]=0;Q(318,b|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ga}f=0;c=_b(g,j);v[22708]=0;A=Tf(c,0);c=v[22708];v[22708]=0;if((c|0)==1){break fa}while(1){v[22708]=0;n=T(374,b|0)|0;c=v[22708];v[22708]=0;ia:{ja:{if((c|0)!=1){if(n){break ja}if(f>>>0>62){break ha}c=_b(g,j);v[22708]=0;f=f+1|0;A=Tf(c,f);c=v[22708];v[22708]=0;if((c|0)!=1){break ia}}b=P()|0;O()|0;break C}G=cj(e+32|0);d=n&31;c=d>>>0<x[a+480188>>1];d=B(d,6)+A|0;if(n&32){v[22708]=0;R(403,e+16|0,b|0);h=v[22708];v[22708]=0;ka:{la:{ma:{if((h|0)!=1){h=e+16|0;q=qd(h);h=w[h|0];if(h>>>0>239){break ma}h=(B(h>>>4|0,12)+(h&15)|0)+13|0;break la}b=P()|0;O()|0;break C}na:{switch(h-254|0){case 0:break la;case 1:break na;default:break ka}}h=0}t[(c?d:e+32|0)|0]=h}t[(c?d+1|0:F)|0]=w[q|0]}oa:{if(!(n&64)){break oa}v[22708]=0;h=T(374,b|0)|0;q=v[22708];v[22708]=0;pa:{if((q|0)!=1){q=c?d+2|0:E;t[e+16|0]=h;if(h<<24>>24>-1|h>>>0>192){break pa}t[q|0]=2;t[(c?d+4|0:z)|0]=w[e+16|0]^128;break oa}b=P()|0;O()|0;break C}t[q|0]=1;v[22708]=0;t[e|0]=64;h=ac(e+16|0,e);q=v[22708];v[22708]=0;if((q|0)==1){break ea}t[(c?d+4|0:z)|0]=w[h|0]}if(!(n&128)){break ia}v[22708]=0;R(403,e+16|0,b|0);h=v[22708];v[22708]=0;qa:{if((h|0)!=1){h=e+16|0;q=qd(h);n=c?d+3|0:D;t[n|0]=w[h|0];h=c?d+5|0:C;t[h|0]=w[q|0];Xu(c?d:G,0);ra:{c=w[n|0];if((c|0)==20){if((w[h|0]&240)!=160){break ia}if((w[i|0]|w[i+1|0]<<8)>>>0<4896){break ra}c=w[n|0]}if((c|0)!=31){break ia}c=w[h|0];if(c>>>0<=15){break qa}m=0;break ia}t[h|0]=w[h|0]&15^136;break ia}b=P()|0;O()|0;break C}if(c>>>0<=7){o=o+1|0;break ia}r=((c|0)!=8)+r|0}if(f>>>0<64){continue}break}}j=j+1|0;if((p|0)!=(j|0)){continue}break A}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0}Pk(l)}Pk(y);break a}if(!m){break z}a=x[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break z}c=Te(g)-1&65535;a=0;i=0;if(Te(g)>>>0>c>>>0){while(1){if(ii(bf(g,a))){b=Vb(bf(g,a));d=Zb(bf(g,a));a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){d=a+8|0;b=v[d>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}$j(d);if(Gb(d,a)){continue}break}}gb=a+16|0}i=i+1|0;a=i&65535;if(c>>>0>=a>>>0){continue}break}}}Pk(l);Pk(y);vb(k)}gb=e+272|0;return s|0}b=P()|0;O()|0}vb(k);S(b|0);L()}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-512|0;gb=d;vc(b);g=d+432|0;f=aW(b,g);if(!f){tC(g)}a:{if(!f){break a}if(!dT(d+432|0)){break a}if(!Pb(b,Qc(cT(d+432|0),jb))){break a}b:{if(!c){break b}Hd(a,4);Ag(a);t[a+1074368|0]=4;k=Kb(d+416|0);c:{d:{e:{f:{i=d+470|0;g:{if(!(sd(i,14892,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}v[22708]=0;g=zv(d+449|0,0,20);e=v[22708];v[22708]=0;if((e|0)==1){break d}e=g?1154:34;break e}if(!sd(i,14871,20)){e=1;break e}v[22708]=0;Yj(d+16|0,3,i);g=v[22708];v[22708]=0;h:{i:{j:{if((g|0)==1){break j}v[22708]=0;R(324,d+56|0,d+16|0);g=v[22708];v[22708]=0;if((g|0)==1){break j}v[22708]=0;U(13,d+128|0,5,d+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break i}g=d+128|0;Eb(k,g);vb(g);vb(d+56|0);if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))!=1852141647|(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))!=542396493){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(d+56|0);break c}if(!sd(i,14619,12)){e=16;if((x[d+482>>1]|x[d+484>>1]<<16)==538976288&(x[d+486>>1]|x[d+488>>1]<<16)==538976288){break e}t[a+1074368|0]=5;break e}if(sd(i,8911,20)){break f}}e=48;break e}if(!sd(i,33408,15)){v[22708]=0;g=a+1074312|0;Q(410,g|0,54)|0;e=v[22708];v[22708]=0;C=1;if((e|0)==1){break d}v[22708]=0;Q(410,g|0,51)|0;g=v[22708];v[22708]=0;e=16;if((g|0)==1){break d}break e}if(!sd(i,33424,14)){v[22708]=0;Q(410,a+1074312|0,57)|0;g=v[22708];v[22708]=0;e=16;if((g|0)!=1){break e}break d}e=sd(i,14707,11)?16:256}v[22708]=0;s=d+449|0;Yj(d+56|0,3,s);g=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((g|0)==1){break o}v[22708]=0;R(324,d+128|0,d+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break o}g=d+128|0;Eb(a+1298268|0,g);vb(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;p=a+484360|0;cf(Sb(p),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;u[d+128>>1]=w[d+504|0]|w[d+505|0]<<8;v[22708]=0;u[d+56>>1]=255;g=Pc(g,d+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break n}u[a+480192>>1]=x[g>>1];if(w[d+508|0]|w[d+509|0]<<8){v[a+480196>>2]=w[d+508|0]|w[d+509|0]<<8}if(w[d+510|0]|w[d+511|0]<<8){F=a,G=Fd(B(w[d+510|0]|w[d+511|0]<<8,1e4),32e4,1e7),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+506|0]|w[d+507|0]<<8)<<4&16;g=(w[d+506|0]|w[d+507|0]<<8)<<3&32768;v[a+480208>>2]=g|v[a+480208>>2]&-32769;f=Sb(p);m=w[d+496|0]|w[d+497|0]<<8;v[22708]=0;fa(521,f|0,b|0,m|0,65535,65535)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}f=g>>>15|0?(e|0)==34?146:e:e;if(!(f&1024|(w[d+496|0]|w[d+497|0]<<8))){g=Sb(p);v[22708]=0;U(958,g|0,1,0);g=v[22708];v[22708]=0;if((g|0)==1){break d}}g=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[22708]=0;Q(190,b|0,g+60|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[22708]=0;U(959,b|0,d+432|0,a|0);g=v[22708];v[22708]=0;if((g|0)==1){break d}}t[d+415|0]=0;z=c&2;m=mc(d+400|0);g=-1;if(x[a+480192>>1]){break m}break l}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}D=d+74|0;E=d+161|0;e=1;n=1;while(1){p:{v[22708]=0;j=T(192,b|0)|0;h=v[22708];v[22708]=0;q:{r:{s:{t:{u:{v:{if((h|0)!=1){pg(b,4);v[22708]=0;U(960,b|0,d+128|0,(j?j:263)|0);j=v[22708];v[22708]=0;if((j|0)==1){break p}w:{if((f|0)==1){if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==245){v[a+1074308>>2]=16777381;v[22708]=0;f=Q(2,d+56|0,10694)|0;j=v[22708];v[22708]=0;if((j|0)!=1){Eb(k,f);vb(f);f=17;break w}f=P()|0;O()|0;break k}f=16;if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263){break w}v[a+1074308>>2]=16777395;v[22708]=0;f=Q(2,d+56|0,10618)|0;j=v[22708];v[22708]=0;if((j|0)!=1){Eb(k,f);vb(f);f=17;break w}f=P()|0;O()|0;break k}if(w[d+155|0]|w[d+156|0]<<8){break w}if(!(!(f&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263)){f=f|16;break w}if(!(!(f&256)|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==29)){f=f&-257;break w}if(!(f&160)){break w}f=(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==33?f:0}v[22708]=0;j=W(376,a|0,n&65535,0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break p}if(!j){break q}j=((e<<2)+a|0)+900380|0;e=v[j>>2];v[22708]=0;R(961,d+128|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break p}e=w[d+154|0];x:{if((g|0)==-1){g=e;break x}if(!(f&32)|(e|0)==(g|0)){break x}f=f&-161|128}if(!(w[d+155|0]|w[d+156|0]<<8)){break q}e=w[d+369|0];h=w[d+370|0];o=w[d+371|0]|w[d+372|0]<<8;l=w[d+375|0];q=w[d+155|0]|w[d+156|0]<<8;v[22708]=0;U(962,d+112|0,a|0,q|0);q=v[22708];v[22708]=0;if((q|0)==1){break v}f=l|(o|(e|h))?f&-4:f;e=12;while(1){h=x[vd(v[j>>2]+236|0,e)>>1];if(tc(d+112|0)>>>0>h>>>0){h=x[sc(d+112|0,x[vd(v[j>>2]+236|0,e)>>1])>>1];F=vd(v[j>>2]+236|0,e),G=h,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Nb(m);br(m);qw(m)}e=w[d+155|0]|w[d+156|0]<<8;v[22708]=0;j=Q(963,d+96|0,e|0)|0;e=v[22708];v[22708]=0;y:{if((e|0)!=1){e=0;if(w[d+155|0]|w[d+156|0]<<8){break y}break u}f=P()|0;O()|0;break s}z:{A:{B:{C:{while(1){v[22708]=0;Q(964,b|0,d+56|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break z}v[22708]=0;RN(d+16|0,d+56|0);h=v[22708];v[22708]=0;D:{if((h|0)==1){break D}v[22708]=0;R(966,m|0,d+16|0);h=v[22708];v[22708]=0;if((h|0)==1){break D}h=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);F=Mb(j,e),G=h,v[F>>2]=G;o=w[d+73|0];if(tc(d+112|0)>>>0>e>>>0){h=x[sc(d+112|0,e)>>1];v[22708]=0;l=(B(h,104)+a|0)+484380|0;R(967,d+56|0,l|0);q=v[22708];v[22708]=0;if((q|0)==1){break C}v[22708]=0;SN(E,l);l=v[22708];v[22708]=0;if((l|0)==1){break C}v[22708]=0;Qk(d+40|0,3,D);l=v[22708];v[22708]=0;if((l|0)==1){break B}v[22708]=0;R(324,d+16|0,d+40|0);l=v[22708];v[22708]=0;if((l|0)==1){break B}v[22708]=0;Q(301,((h<<5)+a|0)+946304|0,d+16|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break A}vb(d+16|0);f=(w[d+70|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=o|r;e=e+1|0;if(e>>>0>=(w[d+155|0]|w[d+156|0]<<8)>>>0){break u}continue}break}f=P()|0;O()|0;break t}f=P()|0;O()|0;break t}f=P()|0;O()|0;break t}f=P()|0;O()|0;vb(d+16|0);break t}f=P()|0;O()|0;break t}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break r}e=0;if(!(w[d+155|0]|w[d+156|0]<<8)){break r}E:{while(1){F:{o=w[Mb(m,e)+3|0];h=v[Mb(j,e)>>2];v[22708]=0;U(288,d+16|0,b|0,((o|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[22708];v[22708]=0;if((h|0)==1){break F}h=d+16|0;o=kc(d+56|0,h);xb(h);if(!(!z|tc(d+112|0)>>>0<=e>>>0)){l=x[sc(d+112|0,e)>>1];h=Mb(m,e);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[22708]=0;v[d+12>>2]=h;v[d+8>>2]=h;h=da(969,(B(l,104)+a|0)+484380|0,d+8|0,o|0,d+415|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break E}A=h^1|A}xb(d+56|0);e=e+1|0;if(e>>>0<(w[d+155|0]|w[d+156|0]<<8)>>>0){continue}break r}break}f=P()|0;O()|0;break t}f=P()|0;O()|0;xb(d+56|0)}Lc(j)}Ze(d+112|0);break k}Lc(j);Ze(d+112|0)}n=n+1|0;e=n&65535;if(e>>>0<=x[a+480192>>1]){continue}break l}break}f=P()|0;O()|0;break k}G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if(!(!(f&2)|r&255)){v[22708]=0;e=zv(s,0,20);j=v[22708];v[22708]=0;if((j|0)==1){break X}f=e?f|16:f}Y:{if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break Y}if(c&3){v[22708]=0;U(959,b|0,d+432|0,a|0);c=v[22708];v[22708]=0;if((c|0)==1){break X}}if(!z|!x[a+480190>>1]){break Y}e=1;c=1;while(1){j=Mb(m,e-1|0);v[22708]=0;W(329,j|0,(B(e,104)+a|0)+484380|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break M}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[22708]=0;c=Q(2,d+128|0,13726)|0;e=v[22708];v[22708]=0;if((e|0)==1){break W}v[22708]=0;U(560,a|0,2,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break V}vb(c)}v[22708]=0;c=Q(555,b|0,2650)|0;e=v[22708];v[22708]=0;if((e|0)==1){break X}if(c){v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break X}v[22708]=0;da(509,a+1298292|0,b|0,c|0,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break X}f=f|16}v[22708]=0;j=Q(555,b|0,11374)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}if(j){v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break G}v[22708]=0;e=a+901404|0;U(970,b|0,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break G}v[22708]=0;Ku(e);c=v[22708];v[22708]=0;if((c|0)==1){break G}f=f|16}v[22708]=0;c=Q(555,b|0,11155)|0;e=v[22708];v[22708]=0;if((e|0)==1){break G}if(c){v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}u[d+128>>1]=c>>>5;c=a+484344|0;e=Te(c);v[22708]=0;u[d+56>>1]=e;e=Pc(d+128|0,d+56|0);n=v[22708];v[22708]=0;if((n|0)==1){break T}n=x[e>>1];if(n){e=0;while(1){v[22708]=0;W(766,b|0,d+128|0,32)|0;h=v[22708];v[22708]=0;if((h|0)==1){break S}h=_b(c,e);v[22708]=0;Q(767,h|0,d+128|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break S}e=e+1|0;if((n|0)!=(e|0)){continue}break}}f=f|16}v[22708]=0;c=Q(555,b|0,11160)|0;e=v[22708];v[22708]=0;if((e|0)==1){break G}if(c){v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break R}u[d+128>>1]=(c>>>0)/20;c=x[a+480188>>1];v[22708]=0;u[d+56>>1]=c;c=Pc(d+128|0,d+56|0);e=v[22708];v[22708]=0;if((e|0)==1){break Q}c=x[c>>1];if(c){e=0;while(1){v[22708]=0;W(571,b|0,((e<<5)+a|0)+480289|0,20)|0;n=v[22708];v[22708]=0;if((n|0)==1){break L}e=e+1|0;if((c|0)!=(e|0)){continue}break}}f=f|16}v[22708]=0;c=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break G}if(c){c=v[b+8>>2];v[22708]=0;Q(572,a|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}if(!(f&16)){break N}if(!(f&4)){break O}v[a+1074308>>2]=17367040;v[22708]=0;c=Q(2,d+128|0,11896)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}Eb(k,c);vb(c);break N}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;vb(c);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}if(!(f&2)){break N}v[a+1074308>>2]=18219008;v[22708]=0;c=Q(2,d+128|0,12053)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}Eb(k,c);vb(c)}Z:{if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))==1852141647&(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))==542396493){v[22708]=0;c=Q(971,d+128|0,d+478|0)|0;e=v[22708];v[22708]=0;_:{$:{aa:{if((e|0)!=1){v[22708]=0;U(13,d+56|0,1,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break aa}v[22708]=0;f=T(972,d+56|0)|0;i=v[22708];v[22708]=0;e=1;if((i|0)==1){break $}v[a+1074308>>2]=f;vb(d+56|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;vb(c);c=a+1074308|0;f=24;break Z}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;vb(d+56|0)}vb(c);break k}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;xv(a+1074312|0)}c=a+1074308|0;if(!(f&32)){e=1;break Z}t[a+1074368|0]=5;if(!j){v[22708]=0;Wo(a+901404|0);e=v[22708];v[22708]=0;if((e|0)==1){break G}}e=0;if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break Z}v[22708]=0;W(409,a+1074312|0,4,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break G}}ba:{if(!gd(k)){break ba}if(!(!(f&256)|r&255|g+1>>>0>1)){v[22708]=0;g=Q(2,d+128|0,5425)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(k,g);vb(g);break ba}f=P()|0;O()|0;break k}if(!e){v[22708]=0;g=Q(2,d+128|0,9323)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(k,g);vb(g);break ba}f=P()|0;O()|0;break k}v[22708]=0;g=Q(2,d+128|0,6892)|0;e=v[22708];v[22708]=0;if((e|0)==1){break I}Eb(k,g);vb(g)}t[d+40|0]=0;ca:{if(x[a+480192>>1]){v[22708]=0;g=Q(588,a|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ca}t[d+40|0]=g}v[22708]=0;Y(589,a|0,b|0,1,d+40|0);b=v[22708];v[22708]=0;if((b|0)==1){break ca}e=v[c>>2];da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{if(w[d+40|0]){if(e>>>0>18284543){break ra}v[a+1074308>>2]=18284544;break ra}if(e>>>0<18284544){break qa}}v[22708]=0;b=Q(2,d+56|0,14719)|0;g=v[22708];v[22708]=0;if((g|0)==1){break pa}v[22708]=0;R(973,d+16|0,c|0);g=v[22708];v[22708]=0;if((g|0)==1){break oa}v[22708]=0;U(3,d+128|0,b|0,d+16|0);g=v[22708];v[22708]=0;if((g|0)==1){break na}g=d+128|0;Eb(k,g);vb(g);vb(d+16|0);vb(b);e=v[c>>2]}sa:{if(e-1>>>0>19005952){break sa}v[22708]=0;b=a+484344|0;c=me(b,254);g=v[22708];v[22708]=0;if((g|0)==1){break ca}if(!c){c=Sb(p);v[22708]=0;R(974,c|0,254);c=v[22708];v[22708]=0;if((c|0)==1){break ca}}v[22708]=0;b=me(b,255);c=v[22708];v[22708]=0;if((c|0)==1){break ca}if(b){break sa}b=Sb(p);v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break ca}v[22708]=0;fv(b,255,65535);b=v[22708];v[22708]=0;if((b|0)==1){break ca}}v[22708]=0;R(976,d+56|0,1211);b=v[22708];v[22708]=0;if((b|0)==1){break la}v[d+112>>2]=w[d+491|0];b=w[d+490|0];v[22708]=0;v[d+96>>2]=b;R(599,d+16|0,d+96|0);b=v[22708];v[22708]=0;if((b|0)==1){break ka}v[22708]=0;Y(582,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break ja}b=a+1298304|0;c=d+128|0;Eb(b,c);vb(c);vb(d+16|0);Hb(d+56|0);Eb(a+1298328|0,k);v[a+1298364>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+415|0]){break ea}Eb(a+1298340|0,b);v[22708]=0;c=Q(2,d+128|0,12398)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ha}Eb(b,c);vb(c);v[22708]=0;b=Q(2,d+128|0,7371)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ga}Eb(a+1298316|0,b);vb(b);v[22708]=0;b=Q(2,d+128|0,7372)|0;c=v[22708];v[22708]=0;if((c|0)==1){break fa}Eb(a+1298352|0,b);break da}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ma}f=P()|0;O()|0;vb(d+16|0)}vb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ia}f=P()|0;O()|0;vb(d+16|0)}Hb(d+56|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22708]=0;b=Q(2,d+128|0,7372)|0;c=v[22708];v[22708]=0;if((c|0)==1){break H}Eb(a+1298316|0,b)}vb(b);di(m);vb(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}di(m);break c}f=P()|0;O()|0}vb(k);S(f|0);L()}e=1}gb=d+512|0;return e|0}function r6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=C(0),U=C(0),V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0);D=gb-17168|0;gb=D;v[D+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!eq(a+6152|0,b)){break c}k=sy(b,v[a+6148>>2])+dq(b)|0;v[D+17164>>2]=k;if((c|0)==(k|0)){k=c;break b}d:{if((k+4|0)<=(c|0)){if(eq(b,b+k|0)){break d}}v[D+17164>>2]=0;break c}if(k){break b}}g=b;p=Qb(a,0,6668)+6148|0;I=D+17164|0;f=c;e:{if((f|0)>=5){J=f-4|0;while(1){if(nJ(g)){y=sy(g,v[p>>2]);k=y+dq(g)|0;j=0;f:{g:{if(y){break g}l=4;q=h+4|0;while(1){if((J|0)<=((l<<1)+h|0)){break f}y=0;r=g+l|0;h:{if(!eq(g,r)){break h}s=l-dq(g)|0;G=dq(r)+s|0;if((f|0)<(G+(l+q|0)|0)){break h}if(!eq(g,r+G|0)){break h}v[p>>2]=s;y=s;k=l}j=!y;if(y){break g}s=l>>>0<2303;l=l+1|0;if(s){continue}break}}if((f|0)<(h+k|0)|j){break f}s=g;l=f-h|0;j=0;n=0;i:{while(1){G=j+s|0;j=(sy(G,y)+j|0)+dq(G)|0;q=(n|0)!=0;if((l|0)<(j+4|0)){break i}q=0;if(!eq(s,j+s|0)){break i}n=n+1|0;if((n|0)!=10){continue}break}q=1}if(q){break e}}if(!((f|0)!=(k|0)|h)){h=0;k=f;break e}v[p>>2]=0}g=g+1|0;h=h+1|0;if((J|0)!=(h|0)){continue}break}}k=0;h=f}v[I>>2]=k;n=h;k=v[D+17164>>2];if((h+k|0)<=(c|0)?k:0){break b}v[e>>2]=n;n=0;break a}G=b+n|0;v[a+6152>>2]=w[G|0]|w[G+1|0]<<8|(w[G+2|0]<<16|w[G+3|0]<<24);v[e+4>>2]=n;v[e>>2]=k+n;v[e+8>>2]=w[G+3|0]>191?1:2;ca=e,da=qJ(G),v[ca+12>>2]=da;v[e+16>>2]=4-(w[G+1|0]>>>1&3);ca=e,da=qy(G),v[ca+20>>2]=da;if(!d){n=py(G);break a}pJ(D+17152|0,G+4|0,k-4|0);if(!(t[G+1|0]&1)){$d(D+17152|0,16)}j:{if(v[e+16>>2]==3){n=0;r=D+17152|0;k=D+3740|0;h=0;c=G;g=w[c+1|0];b=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;f=b-((b|0)!=0)|0;l=w[c+3|0]>191?1:2;k:{if(g&8){j=$d(r,9);l=l<<1;h=$d(r,l+7|0);break k}j=$d(r,l|8)>>>l|0}b=B(f,40);I=b+62016|0;q=b+62336|0;s=B(f,23)+61824|0;A=-1;l:{while(1){g=w[c+3|0];f=$d(r,12);u[k+4>>1]=f;b=$d(r,9);u[k+6>>1]=b;if((b&65535)>>>0>288){break l}y=g>>>0>191?h<<4:h;ca=k,da=$d(r,8),t[ca+10|0]=da;b=$d(r,w[c+1|0]&8?4:9);t[k+13|0]=22;t[k+14|0]=0;v[k>>2]=s;u[k+8>>1]=b;m:{if($d(r,1)){b=$d(r,2);t[k+11|0]=b;if(!(b&255)){break l}h=$d(r,1);u[k+18>>1]=65287;t[k+12|0]=h;if(w[k+11|0]==2){b=k;n:{if(!(h&255)){v[k>>2]=I;t[k+18|0]=8;g=39;h=0;break n}v[k>>2]=q;g=30;h=w[c+1|0]&8?8:6}t[b+14|0]=g;t[k+13|0]=h;y=y&3855}b=$d(r,10);ca=k,da=$d(r,3),t[ca+21|0]=da;ca=k,da=$d(r,3),t[ca+22|0]=da;ca=k,da=$d(r,3),t[ca+23|0]=da;h=b<<5;break m}t[k+11|0]=0;t[k+12|0]=0;h=$d(r,15);ca=k,da=$d(r,4),t[ca+18|0]=da;b=$d(r,3);t[k+20|0]=255;t[k+19|0]=b}t[k+17|0]=h&31;t[k+15|0]=h>>>10;t[k+16|0]=h>>>5&31;i=(f&65535)+i|0;b=k;o:{if(w[c+1|0]&8){f=$d(r,1);break o}f=x[k+8>>1]>499}t[b+24|0]=f;ca=k,da=$d(r,1),t[ca+25|0]=da;b=$d(r,1);t[k+27|0]=y>>>12&15;t[k+26|0]=b;k=k+28|0;h=y<<4;l=l-1|0;if(l){continue}break}A=(v[r+4>>2]+i|0)>(v[r+8>>2]+(j<<3)|0)?-1:j}if(!((A|0)<0|v[D+17156>>2]>v[D+17160>>2])){s=D+17152|0;h=v[s+4>>2];k=v[s+8>>2];c=D+912|0;f=v[a+6144>>2];b=f-A|0;g=(f|0)>(A|0)?A:f;f=hc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,g);b=(k-h|0)/8|0;hc(f+g|0,v[s>>2]+(v[s+4>>2]/8|0)|0,b);pJ(c,f,b+g|0);k=v[a+6144>>2]>=(A|0);if(k){Z=a+2304|0;n=v[e+8>>2];_=D+8620|0;$=D+3852|0;b=0;while(1){aa=Qb($,0,4608);s=D+912|0;y=(B(B(b,n),28)+D|0)+3740|0;l=0;r=a;J=r+6152|0;if((n|0)>=1){h=s+7548|0;while(1){f=B(l,28)+y|0;L=x[f+4>>1];M=v[s+4>>2];N=(s+B(l,39)|0)+16156|0;q=s;i=h;g=l;p=gb-48|0;gb=p;j=f;R=!w[f+13|0]+(w[f+14|0]!=0)|0;V=w[f+25|0];c=p;A=c+44|0;I=J;p:{if(w[J+1|0]&8){o=w[j+27|0];m=w[x[j+8>>1]+62752|0];g=m&3;t[p+47|0]=g;t[p+46|0]=g;g=m>>>2|0;t[p+45|0]=g;t[p+44|0]=g;g=B(R,28)+62656|0;break p}g=w[I+3|0]>>>4&(g|0)!=0;H=g?12:0;P=x[j+8>>1]>>>g|0;while(1){E=1;m=3;while(1){g=m;o=w[(g+H|0)+62768|0];t[g+(p+44|0)|0]=((P|0)/(E|0)|0)%(o|0);m=g-1|0;E=B(o,E);if(g){continue}break}H=H+4|0;P=P-E|0;if((P|0)>-1){continue}break}o=-16;g=(B(R,28)+H|0)+62656|0}E=0;while(1){O=w[g+E|0];if(O){q:{if(o&8){hc(c,N,O);break q}S=w[A+E|0];if(!S){Qb(c,0,O);Qb(N,0,O);break q}m=(o|0)>-1?-1:-1<<S^-1;H=0;while(1){R=$d(q,S);t[H+N|0]=(m|0)==(R|0)?-1:R;t[c+H|0]=R;H=H+1|0;if((O|0)!=(H|0)){continue}break}}o=o<<1;c=c+O|0;N=N+O|0;E=E+1|0;if((E|0)!=4){continue}}break}t[c+2|0]=0;t[c|0]=0;t[c+1|0]=0;m=w[j+14|0];r:{if(m){c=2-V|0;o=w[j+23|0]<<c;q=w[j+22|0]<<c;g=w[j+21|0]<<c;c=w[j+13|0];E=0;while(1){A=p+(c+E|0)|0;t[A|0]=g+w[A|0];t[A+1|0]=q+w[A+1|0];t[A+2|0]=o+w[A+2|0];E=E+3|0;if(m>>>0>E>>>0){continue}break}break r}if(!w[j+24|0]){break r}o=0;while(1){c=o+p|0;t[c+11|0]=w[c+11|0]+w[o+62792|0];o=o+1|0;if((o|0)!=10){continue}break}}T=oy(C(2048),((((w[I+3|0]&224)==96)<<1)-w[j+10|0]|0)+258|0);o=0;if((m|0)!=(0-w[j+13|0]|0)){c=V+1|0;while(1){ca=i+(o<<2)|0,ea=oy(T,w[o+p|0]<<c),z[ca>>2]=ea;o=o+1|0;if(o>>>0<w[j+14|0]+w[j+13|0]>>>0){continue}break}}gb=p+48|0;p=(s+B(l,2304)|0)+2940|0;c=h;R=L+M|0;F=C(0);Y=0;I=s;g=v[s+4>>2];q=v[s>>2]+((g|0)/8|0)|0;i=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);i=(i<<24|i<<8&16711680|(i>>>8&65280|i>>>24))<<(g&7);m=g|-8;K=q+4|0;q=f;E=v[f>>2];H=x[f+6>>1];s:{if(!H){H=0;break s}while(1){f=q+Y|0;g=w[f+15|0];X=(u[(g<<1)+67216>>1]<<1)+62832|0;N=w[f+18|0];t:{if(g>>>0>=16){L=w[g+67280|0];A=32-L|0;while(1){M=w[E|0]>>>1|0;o=(H|0)>(M|0)?M:H;F=z[c>>2];while(1){j=u[X+(i>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[X+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}O=j&65535;f=O>>>8|0;m=f+m|0;i=i<<f;P=1;while(1){ba=p;f=O&15;u:{if((f|0)==15){j=i<<L;f=(i>>>A|0)+15|0;m=m+L|0;if((m|0)>=0){while(1){j=w[K|0]<<m|j;i=(m|0)>7;m=m-8|0;K=K+1|0;if(i){continue}break}}W=F;i=f;v:{if((f|0)<=128){U=z[(i<<2)+67376>>2];break v}S=i<<3;g=i;i=(i|0)<1024;V=i?S:g;S=V<<1&64;Q=C(C((V&63)-S|0)/C(S+(V&-64)|0));U=C((i?C(16):C(256))*C(C(C(Q*C(C(Q*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(V+S>>6<<2)+67376>>2]))}W=C(C(W*U)*C(((j|0)>-1?1:-1)|0));break u}j=i;W=C(F*z[(((i>>>27&16|f)^16)<<2)+67312>>2])}z[ba>>2]=W;O=O>>>4|0;p=p+4|0;f=(f|0)!=0;m=f+m|0;i=j<<f;f=P&1;P=0;if(f){continue}break}if((m|0)>-1){while(1){i=w[K|0]<<m|i;f=(m|0)>7;m=m-8|0;K=K+1|0;if(f){continue}break}}o=o-1|0;if(o){continue}break}c=c+4|0;E=E+1|0;H=H-M|0;if((H|0)<1){break t}f=(N|0)>0;N=N-1|0;if(f){continue}break}break t}while(1){o=w[E|0]>>>1|0;P=(o|0)<(H|0)?o:H;F=z[c>>2];while(1){j=u[X+(i>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[X+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}j=j&65535;f=j>>>8|0;m=f+m|0;i=i<<f;f=1;while(1){g=j&15;z[p>>2]=F*z[(((g|i>>>27&16)^16)<<2)+67312>>2];j=j>>>4|0;p=p+4|0;g=(g|0)!=0;m=g+m|0;i=i<<g;g=f&1;f=0;if(g){continue}break}if((m|0)>-1){while(1){i=w[K|0]<<m|i;f=(m|0)>7;m=m-8|0;K=K+1|0;if(f){continue}break}}P=P-1|0;if(P){continue}break}c=c+4|0;E=E+1|0;H=H-o|0;if((H|0)<1){break t}f=(N|0)>0;N=N-1|0;if(f){continue}break}}Y=Y+1|0;if((H|0)>0){continue}break}}f=1-H|0;while(1){w:{g=w[q+26|0]?67200:67168;j=w[g+(i>>>28|0)|0];if(!(j&8)){j=w[g+((i<<4>>>32-(j&3))+(j>>>3)|0)|0]}g=j&7;m=g+m|0;if((R|0)<((m+(K-v[I>>2]<<3)|0)-24|0)){break w}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;F=z[c>>2];f=f>>>1|0;c=c+4|0}i=i<<g;if(j&128){z[p>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if(j&64){z[p+4>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;F=z[c>>2];f=f>>>1|0;c=c+4|0}if(j&32){z[p+8>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if(j&16){z[p+12>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if((m|0)>=0){while(1){i=w[K|0]<<m|i;g=(m|0)>7;m=m-8|0;K=K+1|0;if(g){continue}break}}p=p+16|0;continue}break}v[I+4>>2]=R;l=l+1|0;if((n|0)!=(l|0)){continue}break}}c=w[r+6155|0];x:{if(c&16){j=0;L=gb-16|0;gb=L;o=s+2940|0;f=o+2304|0;i=y;m=v[i>>2];p=w[i+14|0];A=p+w[i+13|0]|0;I=A;M=L+4|0;v[M+8>>2]=-1;v[M>>2]=-1;v[M+4>>2]=-1;if(A>>>0>=1){while(1){c=0;q=j+m|0;g=w[q|0];h=0;y:{if(!g){break y}z:{while(1){l=c<<2;if(z[l+f>>2]!=C(0)|z[(l|4)+f>>2]!=C(0)){break z}c=c+2|0;if(g>>>0>c>>>0){continue}break}h=g;break y}v[M+((j>>>0)%3<<2)>>2]=j;h=w[q|0]}f=((h&255)<<2)+f|0;j=j+1|0;if((I|0)!=(j|0)){continue}break}}if(w[i+13|0]){f=v[L+12>>2];h=v[L+8>>2];c=v[L+4>>2];c=(c|0)<(h|0)?h:c;c=(c|0)<(f|0)?f:c;v[L+12>>2]=c;v[L+8>>2]=c;v[L+4>>2]=c}M=s+16195|0;g=p?3:1;f=A-g|0;j=0;while(1){h=f+j|0;c=h-g|0;if((c|0)<=v[(L+4|0)+(j<<2)>>2]){c=w[J+1|0]<<28>>31&3}else{c=w[c+M|0]}t[h+M|0]=c;j=j+1|0;if((g|0)!=(j|0)){continue}break}p=L+4|0;I=u[i+36>>1]&1;f=0;l=v[i>>2];c=w[l|0];if(c){q=w[J+1|0]&8?7:64;g=l;while(1){i=w[J+3|0]&32;A:{B:{if(v[p+((f>>>0)%3<<2)>>2]>=(f|0)){break B}j=w[f+M|0];if(j>>>0>=q>>>0){break B}h=o;U=i?C(1.4142135381698608):C(1);W=U;C:{if(w[J+1|0]&8){i=j<<3;F=z[i+67908>>2];Q=z[i+67904>>2];break C}T=oy(C(1),j+1>>>1<<I);i=j&1;F=i?C(1):T;Q=i?T:C(1)}Q=C(W*Q);T=C(U*F);m=0;while(1){i=h+(m<<2)|0;F=z[i>>2];z[i+2304>>2]=F*T;z[i>>2]=F*Q;m=m+1|0;if((m|0)!=(c|0)){continue}break}break A}if(!i){break A}mJ(o,c)}o=(w[g|0]<<2)+o|0;f=f+1|0;g=l+f|0;c=w[g|0];if(c){continue}break}}gb=L+16|0;break x}if((c&224)!=96){break x}mJ(s+2940|0,576)}if((n|0)>=1){c=s+7708|0;l=0;while(1){h=w[r+6153|0];J=(w[y+12|0]!=0)<<1<<((B((h>>>3&1)+(h>>>4&1)|0,3)+(w[r+6154|0]>>>2&3)|0)==2);q=(s+B(l,2304)|0)+2940|0;m=q;if(w[y+14|0]){g=((s+B(l,2304)|0)+B(J,72)|0)+2940|0;f=c;o=f;K=v[y>>2]+w[y+13|0]|0;A=w[K|0];if(A){h=g;while(1){I=A<<1;p=0;while(1){z[o>>2]=z[h>>2];z[o+4>>2]=z[(A<<2)+h>>2];i=I<<2;z[o+8>>2]=z[i+h>>2];h=h+4|0;o=o+12|0;p=p+1|0;if((p|0)!=(A|0)){continue}break}h=i+h|0;A=w[K+3|0];K=K+3|0;if(A){continue}break}}hc(g,f,o-f|0);i=J-1|0}else{i=31}if((i|0)>=1){while(1){h=0;while(1){g=h<<2;f=g+m|0;U=z[f+72>>2];I=f;Q=z[g+67968>>2];f=(17-h<<2)+m|0;F=z[f>>2];T=z[g+68e3>>2];z[I+72>>2]=C(U*Q)-C(F*T);z[f>>2]=C(F*Q)+C(U*T);h=h+1|0;if((h|0)!=8){continue}break}m=m+72|0;h=(i|0)>1;i=i-1|0;if(h){continue}break}}h=q;i=r+B(l,1152)|0;f=w[y+11|0];if(J){lJ(h,i,68032,J);i=B(J,36)+i|0;h=B(J,72)+h|0}D:{if((f|0)==2){j=gb-80|0;gb=j;g=32-J|0;if((g|0)>=1){p=j|8;J=j|4;while(1){I=hc(j,h,72);f=v[i+20>>2];v[h+16>>2]=v[i+16>>2];v[h+20>>2]=f;f=v[i+12>>2];v[h+8>>2]=v[i+8>>2];v[h+12>>2]=f;f=v[i+4>>2];v[h>>2]=v[i>>2];v[h+4>>2]=f;f=i+24|0;ny(I,h+24|0,f);ny(J,h+48|0,f);ny(p,i,f);h=h+72|0;i=i+36|0;f=(g|0)>1;g=g-1|0;if(f){continue}break}}gb=j+80|0;break D}lJ(h,i,B((f|0)==3,72)+68032|0,32-J|0)}g=0;j=q+72|0;while(1){h=1;while(1){f=(h<<2)+j|0;z[f>>2]=-z[f>>2];f=h>>>0<16;h=h+2|0;if(f){continue}break}j=j+144|0;h=g>>>0<30;g=g+2|0;if(h){continue}break}y=y+28|0;l=l+1|0;if((n|0)!=(l|0)){continue}break}}oJ(Z,aa,18,v[e+8>>2],d,_);n=v[e+8>>2];d=B(n,1152)+d|0;b=b+1|0;if(b>>>0<(w[G+1|0]&8?2:1)>>>0){continue}break}}b=a;g=D+912|0;d=v[g+8>>2]>>>3|0;c=v[g+4>>2]+7>>>3|0;f=d-c|0;h=(f|0)>511;e=h?511:f;if((f|0)>=1){yh(b+6156|0,(g+(h?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}st(a);break a}q=D+17152|0;n=0;k=0;y=0;b=D;s=b;h=0;E:{F:{G:{c=G;f=w[c+3|0];g=f>>>6|0;switch(g-1|0){case 2:break E;case 0:break G;default:break F}}h=(f>>>2&12)+4|0;break E}h=32}f=w[c+1|0];H:{if((f&6)==6){l=32;c=69436;break H}if(!(f&8)){l=30;c=69439;break H}f=w[c+2|0]>>>2&3;c=qy(c)>>>((g|0)!=3)|0;c=c?c:192;if(c>>>0<=55){l=(f|0)==2?12:8;c=69460;break H}l=c>>>0>95?(f|0)!=1?30:27:27;c=69448}t[s+768|0]=l;t[s+769|0]=(h|0)>(l|0)?l:h;h=c;I:{if(!w[b+768|0]){break I}j=69344;while(1){if((n|0)==(y|0)){j=w[h|0]+69344|0;y=w[h+2|0]+y|0;k=w[h+1|0];h=h+3|0}c=n<<1;g=w[$d(q,k)+j|0];t[(c+b|0)+770|0]=g;i=w[b+769|0];if(n>>>0<i>>>0){g=w[$d(q,k)+j|0];i=w[b+769|0]}t[(b+(c|1)|0)+770|0]=i?g:0;g=w[b+768|0];n=n+1|0;if(g>>>0>n>>>0){continue}break}if(!g){k=g<<1;break I}n=0;while(1){c=b+n|0;J:{if(!w[c+770|0]){k=6;break J}k=2;if((w[G+1|0]&6)==6){break J}k=$d(q,2);g=w[b+768|0]}t[c+834|0]=k;k=g<<1&510;n=n+1|0;if(k>>>0>n>>>0){continue}break}}l=b+770|0;G=b+834|0;c=b;h=0;if((k|0)>=1){while(1){g=w[l|0];f=g?19>>>w[h+G|0]&3|4:0;l=l+1|0;s=B(g,3)-6|0;y=4;F=C(0);while(1){if(f&y){g=$d(q,6);i=(g|0)/3|0;F=C(z[(s+(g-B(i,3)|0)<<2)+69472>>2]*C(2097152>>>i|0))}z[c>>2]=F;c=c+4|0;g=y>>>0>1;y=y>>>1|0;if(g){continue}break}h=h+1|0;if((k|0)!=(h|0)){continue}break}}n=w[b+769|0];c=w[b+768|0];if(n>>>0<c>>>0){while(1){t[(b+(n<<1)|0)+771|0]=0;n=n+1|0;if((c|0)!=(n|0)){continue}break}}n=0;f=Qb(D+3852|0,0,4608);y=a+2304|0;G=D+8620|0;c=0;K:{while(1){s=((c<<2)+D|0)+3852|0;I=D+17152|0;r=v[e+16>>2]|1;i=0;h=D;l=w[h+768|0];b=576;while(1){L:{if(!(l&255)){l=0;break L}j=s+(B(i,r)<<2)|0;A=0;while(1){k=b;l=w[(h+A|0)+770|0];M:{if(!l){break M}if(l>>>0<=16){if((r|0)<1){break M}g=(-1<<l-1)+1|0;b=0;while(1){ca=(b<<2)+j|0,ea=C($d(I,l)+g|0),z[ca>>2]=ea;b=b+1|0;if((r|0)!=(b|0)){continue}break}break M}l=2<<l-17;b=$d(I,(l-(l>>>3|0)|0)+3|0);if((r|0)<1){break M}g=l>>>1|0;q=l|1;l=0;while(1){p=b;b=(b>>>0)/(q>>>0)|0;z[(l<<2)+j>>2]=(p-B(q,b)|0)-g|0;l=l+1|0;if((r|0)!=(l|0)){continue}break}}b=18-k|0;j=(k<<2)+j|0;A=A+1|0;l=w[h+768|0];if(A>>>0<l<<1>>>0){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){g=(n<<2)+D|0;b=f;c=D;h=w[c+769|0];k=f+B(h,72)|0;hc(k+2304|0,k,B(w[c+768|0]-h|0,72));if(w[c+768|0]){l=0;while(1){h=0;while(1){k=(h<<2)+b|0;z[k>>2]=z[g>>2]*z[k>>2];k=k+2304|0;z[k>>2]=z[g+12>>2]*z[k>>2];h=h+1|0;if((h|0)!=12){continue}break}g=g+24|0;b=b+72|0;l=l+1|0;if(l>>>0<w[c+768|0]){continue}break}}oJ(y,f,12,v[e+8>>2],d,G);Qb(f,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[D+17156>>2]<=v[D+17160>>2]){n=n+1|0;if((n|0)==3){break K}continue}break}st(a);n=0;break a}k=1}n=B(py(a+6152|0),k)}gb=D+17168|0;return n|0}function rJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;M=gb-144|0;gb=M;k=v[f>>2];N=g&4;K=N?-1:k+((d^-1)+e|0)|0;s=K+1|0;a:{if(!(!(s&K)&d>>>0<=e>>>0)){v[f>>2]=0;v[c>>2]=0;l=-3;break a}D=e+k|0;r=v[c>>2];z=r+b|0;E=v[a+60>>2];q=v[a+40>>2];k=v[a+36>>2];C=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];j=b;p=e;l=-1;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(v[a>>2]){case 37:v[a>>2]=37;break b;case 21:v[a>>2]=21;break b;case 17:v[a>>2]=17;break b;case 35:v[a>>2]=35;break b;case 10:v[a>>2]=10;break b;case 39:v[a>>2]=39;break b;case 36:v[a>>2]=36;break b;case 34:break g;case 42:break j;case 41:break k;case 53:break l;case 52:break m;case 51:break n;case 38:break o;case 27:break p;case 26:break q;case 25:break r;case 24:break s;case 23:break t;case 18:break u;case 16:break v;case 14:break w;case 11:break x;case 9:break y;case 7:break z;case 6:break A;case 3:break B;case 32:break C;case 5:break D;case 2:break F;case 1:break G;case 0:break H;default:break b}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;q=0;k=0;C=0;i=0;if(g&1){break G}break E}l=1;if((r|0)<1){break c}v[a+8>>2]=w[b|0];j=b+1|0}l=2;if(j>>>0>=z>>>0){break c}n=w[j|0];v[a+12>>2]=n;h=1;j=j+1|0;l=-1;A=36;k=v[a+8>>2];if(((n|k<<8)>>>0)%31|n&32){break d}n=k&15;if(!N){if((n|0)!=8){break d}n=256<<(k>>>4);if(n>>>0>32768){break d}k=0;if(n>>>0<=s>>>0){break E}break d}k=0;if((n|0)!=8){break d}}h=0;break i}if((r|0)<1){l=5;break c}O=i+8|0;j=b+1|0;m=w[b|0]<<i|m;h=2;break i}if((r|0)<1){l=32;break c}j=b+1|0;m=w[b|0]<<i|m;i=i+8|0;break h}h=1;break i}h=4;break i}h=3;break i}h=7;break i}h=9;break i}h=10;break i}h=11;break i}h=12;break i}h=13;break i}h=14;break i}h=15;break i}h=16;break i}h=17;break i}h=8;break i}h=5;break i}h=6;break i}h=18;break i}o=2;break e}o=1;break e}I:while(1){J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{switch(h|0){case 0:if(i>>>0>2){break wa}h=1;continue;case 17:break ea;case 16:break fa;case 15:break ga;case 14:break ha;case 13:break ia;case 12:break ja;case 11:break ka;case 10:break la;case 9:break ma;case 8:break oa;case 7:break pa;case 6:break qa;case 5:break ra;case 4:break ta;case 3:break ua;case 2:break va;case 1:break xa;default:break da}}l=3;while(1){if(j>>>0>=z>>>0){break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h}h=m&7;v[a+20>>2]=h;s=h>>>1|0;v[a+24>>2]=s;i=i-3|0;m=m>>>3|0;if(h>>>0>=2){break na}O=i;break ca}i=O&-8;m=m>>>(O&7)|0;k=0;h=0;break aa}if(j>>>0<z>>>0){break sa}l=7;break c}while(1){if(j>>>0>=z>>>0){l=6;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;h=1;break aa}t[(a+k|0)+10528|0]=w[j|0];j=j+1|0;h=2;break aa}while(1){if(j>>>0>=z>>>0){l=51;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;break M}if(p>>>0>=D>>>0){l=2;A=52;h=k;break d}t[p|0]=C;k=k-1|0;p=p+1|0;break N}if(p>>>0<D>>>0){break ba}l=2;A=9;h=k;break d}if(j>>>0<z>>>0){n=D-p|0;h=z-j|0;h=h>>>0>n>>>0?n:h;h=h>>>0<k>>>0?h:k;k=k-h|0;p=hc(p,j,h)+h|0;j=h+j|0;break L}l=38;break c}l=-1;A=10;n=0;h=k;ya:{switch(s-1|0){case 0:break ya;case 2:break d;default:break $}}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Qb(a- -64|0,8,144);Qb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;F=1;break R}l=k+18707|0;while(1){if(j>>>0>=z>>>0){l=11;break c}m=w[j|0]<<i|m;n=j+1|0;j=n;h=i+8|0;i=h;G=t[l|0];if(h>>>0<G>>>0){continue}break}j=n;n=k;i=h;k=1;break T}while(1){if(j>>>0>=z>>>0){l=14;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h;h=1;break S}if(j>>>0>=z>>>0){l=16;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break _}break Z}while(1){if(j>>>0>=z>>>0){l=18;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}P=C-16|0;j=h;h=3;break Q}if(j>>>0>=z>>>0){l=23;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break Y}break X}if(p>>>0>=D>>>0){l=2;A=24;h=k;break d}t[p|0]=k;p=p+1|0;break P}while(1){if(j>>>0>=z>>>0){l=25;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=3;break O}if(j>>>0>=z>>>0){l=26;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break W}break V}while(1){if(j>>>0>=z>>>0){l=27;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=6;break O}if(p>>>0>=D>>>0){l=2;A=53;h=k;break d}t[p|0]=w[(E-C&K)+d|0];p=p+1|0;E=E+1|0;break U}h=2;continue}h=8;continue}while(1){za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:if(k>>>0>3){break Ca}if(!i){i=0;h=3;continue I}if(i>>>0>7){break Aa}h=4;continue I;case 1:t[(a+k|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break za;default:break Da}}k=k+1|0;break Ba}h=x[a+10528>>1];if((h|0)==(x[a+10530>>1]^65535)){k=h;break N}l=-1;A=39;break d}h=0;continue}h=1;continue}h=2;continue}}k=0;break T}h=1;break Q}h=2;break Q}h=0;break O}h=1;break O}h=4;break O}h=5;break O}h=7;break O}while(1){Ea:{Fa:{Ga:{if(!k){if(n>>>0>2){break Ga}k=n;G=t[k+18707|0];if(G>>>0<=i>>>0){break Ea}h=9;continue I}k=n<<2;v[(k+a|0)+44>>2]=v[k+61700>>2]+((-1<<G^-1)&m);n=n+1|0;i=i-G|0;m=m>>>G|0;break Fa}k=0;Qb(a+7040|0,0,288);h=0;break S}k=0;continue}k=1;continue}}while(1){Ha:{Ia:{Ja:{if(!h){if(y[a+52>>2]<=k>>>0){break Ja}if(i>>>0>2){break Ha}h=10;continue I}t[(w[k+61680|0]+a|0)+7040|0]=m&7;k=k+1|0;i=i-3|0;m=m>>>3|0;break Ia}v[a+52>>2]=19;F=v[a+24>>2];break R}h=0;continue}h=1;continue}}h=0}while(1){Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(h|0){case 0:h=0;if((F|0)<0){break P}H=Qb(M,0,64);l=B(F,3488)+a|0;Qb(l+352|0,0,3200);r=v[a+24>>2];s=v[((r<<2)+a|0)+44>>2];if(s){while(1){n=(w[(h+l|0)- -64|0]<<2)+H|0;v[n>>2]=v[n>>2]+1;h=h+1|0;if((s|0)!=(h|0)){continue}break}}v[H+64>>2]=0;v[H+68>>2]=0;n=0;A=0;h=1;while(1){l=h<<2;h=h+1|0;l=v[l+H>>2];n=l+n<<1;v[(H- -64|0)+(h<<2)>>2]=n;A=l+A|0;if((h|0)!=16){continue}break};if(!((n|0)==65536|A>>>0<=1)){l=-1;A=35;h=k;break d}if(s){l=-1;I=0;J=B(F,3488)+a|0;while(1){r=w[(I+J|0)- -64|0];Va:{if(!r){break Va}n=(H- -64|0)+(r<<2)|0;h=v[n>>2];v[n>>2]=h+1;n=0;A=r;while(1){s=n;n=h&1|n<<1;h=h>>>1|0;A=A-1|0;if(A){continue}break}if(r>>>0<=10){if(n>>>0>1023){break Va}s=1<<r;h=r<<9|I;while(1){u[((n<<1)+J|0)+352>>1]=h;n=n+s|0;if(n>>>0<1024){continue}break}break Va}n=((n&1023)<<1)+J|0;h=u[n+352>>1];Wa:{if(h){n=l;l=h;break Wa}u[n+352>>1]=l;n=l-2|0}h=s>>>8&8388607;if(r>>>0>=12){while(1){h=h>>>1|0;s=(((h&1)+(l^-1)<<1)+J|0)+2400|0;l=u[s>>1];if(!l){u[s>>1]=n;l=n;n=n-2|0}r=r-1|0;if(r>>>0>11){continue}break}}u[(((h>>>1&1)+(l^-1)<<1)+J|0)+2400>>1]=I;l=n}I=I+1|0;r=v[a+24>>2];if(I>>>0<y[((r<<2)+a|0)+44>>2]){continue}break}}h=0;if((r|0)!=2){break Na}break Ra;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];Xa:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break Xa}break Qa}if(i>>>0<11){break Xa}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Qa}}h=11;continue I;case 2:l=u[(((m&1023)<<1)+a|0)+7328>>1];if((l|0)>=0){break Ta}h=10;while(1){n=m>>>h|0;h=h+1|0;l=u[(((n&1)+(l^-1)<<1)+a|0)+9376>>1];if((l|0)<0){continue}break};break Sa;default:break Ua}}l=t[P+14925|0]+((-1<<q^-1)&m)|0;i=i-q|0;m=m>>>q|0;n=a+k|0;Qb(n+10532|0,(C|0)==16?w[n+10531|0]:0,l);h=l+k|0;break Ra}h=l>>9;l=l&511}i=i-h|0;m=m>>>h|0;C=l;if(l>>>0>15){break Pa}t[(a+k|0)+10532|0]=C;h=k+1|0}n=v[a+48>>2];l=v[a+44>>2];k=n+l|0;if(k>>>0<=h>>>0){break Oa}if(i>>>0<=14){if((z-j|0)<=1){k=h;h=1;continue}m=w[j|0]<<i|m|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}k=h}h=2;continue}if(!((C|0)!=16|k)){l=-1;h=0;A=17;C=16;break d}q=t[C+18682|0];if(q>>>0>i>>>0){break Ma}P=C-16|0;break Ka}if((h|0)!=(k|0)){l=-1;A=21;break d}k=a+10532|0;hc(a- -64|0,k,l);hc(a+3552|0,l+k|0,n);r=v[a+24>>2];k=h}F=r-1|0;v[a+24>>2]=F;break La}h=12;continue I}h=0;continue}h=3;continue}}o=m;h=2}Ya:while(1){Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];mb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break mb}break Za}if(i>>>0<11){break mb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Za}}h=13;continue I;case 1:l=u[(((m&1023)<<1)+a|0)+352>>1];if((l|0)>=0){break kb}h=10;while(1){k=m>>>h|0;h=h+1|0;l=u[(((k&1)+(l^-1)<<1)+a|0)+2400>>1];if((l|0)<0){continue}break};k=l;break jb;case 3:break ab;case 4:break bb;case 5:break fb;case 6:break gb;case 2:break lb;default:break hb}}while(1){h=z-j|0;if(!((D-p|0)>1&(h|0)>=4)){if(i>>>0>14){m=o;break Za}if((h|0)<=1){m=o;h=0;continue Ya}m=w[j|0]<<i|o|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0;break Za}nb:{if(i>>>0>14){m=i;h=j;break nb}m=i+16|0;o=(w[j|0]|w[j+1|0]<<8)<<i|o;h=j+2|0}k=u[(((o&1023)<<1)+a|0)+352>>1];ob:{if((k|0)<0){j=10;while(1){i=o>>>j|0;j=j+1|0;k=u[(((i&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}break ob}j=k>>9}i=m-j|0;m=o>>>j|0;if(k&256){j=h;break ib}if(!(i>>>0>14)){m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;i=i+16|0}l=i;j=h;h=u[(((m&1023)<<1)+a|0)+352>>1];pb:{if((h|0)<0){o=10;while(1){i=m>>>o|0;o=o+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break pb}o=h>>9}t[p|0]=k;i=l-o|0;o=m>>>o|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=o;k=h;break ib}h=l>>9;k=l&511}i=i-h|0;m=m>>>h|0;if(k>>>0>255){break ib}h=14;continue I}l=k&511;k=256;if((l|0)==256){break K}q=0;h=m;n=l<<2;k=v[n+60140>>2];s=k;if(l-265>>>0>19){break $a}q=v[n+60268>>2];if(q>>>0>i>>>0){h=15;continue I}h=3;continue}if(!k){o=m;k=-1;break db}k=k-1|0;h=18;continue I}i=i-q|0;o=m>>>q|0;C=((-1<<q^-1)&m)+C|0;break eb}q=u[(((m&1023)<<1)+a|0)+3840>>1];qb:{if((q|0)<0){h=10;while(1){n=m>>>h|0;h=h+1|0;q=u[(((n&1)+(q^-1)<<1)+a|0)+5888>>1];if((q|0)<0){continue}break}n=q;break qb}h=q>>9;n=q&511}i=i-h|0;m=m>>>h|0;h=n<<2;C=v[h+61424>>2];q=0;if(n-4>>>0>25){o=m;break eb}q=v[h+61552>>2];if(q>>>0<=i>>>0){break cb}h=17;continue I}E=p-d|0;if(!(!N|E>>>0>=C>>>0)){l=-1;A=37;m=o;h=k;break d}h=(E-C&K)+d|0;if((h>>>0<p>>>0?p:h)+k>>>0>D>>>0){m=o;h=7;continue}if(k>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;k=k-3|0;if(k>>>0>2){continue}break}}if(!k){break db}t[p|0]=w[h|0];if((k|0)!=1){t[p+1|0]=w[h+1|0]}p=k+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];rb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break rb}break _a}if(i>>>0<11){break rb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break _a}}h=16;continue I}i=i-q|0;h=m>>>q|0;s=((-1<<q^-1)&m)+k|0}k=s;m=h;if(i>>>0>14){break _a}if((z-j|0)<=1){h=4;continue}m=m|w[j|0]<<i|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}h=5;continue}h=1;continue}}if(!k|!i){break L}if(i>>>0>7){break M}h=5;continue}i=i-8|0;C=m&255;m=m>>>8|0;h=6;continue}if(k){break J}k=0}if(t[a+20|0]&1){break h}h=0;continue}h=7;continue}}o=i&-8;sb:{if(!o|b>>>0>=j>>>0){break sb}while(1){o=o-8|0;j=j-1|0;if(j>>>0<=b>>>0){break sb}if(o){continue}break}}if(o){break f}m=(((o&63)>>>0>=32?0:-1<<o)^-1)&m>>>(i&7);h=0;n=0;i=0;if(!(g&1)){break g}o=0;break e}v[a>>2]=34;l=0;break b}aa(3896,10512,2787,3906);L()}while(1){tb:{ub:{vb:{wb:{xb:{yb:{switch(o|0){case 0:if(h>>>0>3){l=0;A=34;i=n;break d}if(n){break xb}i=0;k=h;o=1;continue;case 1:break yb;default:break wb}}if(j>>>0<z>>>0){break ub}l=42;break c}k=h;i=n;if(i>>>0>7){break vb}o=2;continue}while(1){if(j>>>0>=z>>>0){l=41;break c}m=w[j|0]<<i|m;h=i>>>0>4294967287;d=j+1|0;j=d;n=i+8|0;i=n;if(h){continue}break}j=d;h=k}o=m&255;m=m>>>8|0;n=n-8|0;break tb}o=w[j|0];j=j+1|0;h=k;n=i}v[a+16>>2]=v[a+16>>2]<<8|o;h=h+1|0;o=0;continue}}v[a>>2]=A;zb:{if(i>>>0<8|b>>>0>=j>>>0){break zb}while(1){i=i-8|0;j=j-1|0;if(j>>>0<=b>>>0){break zb}if(i>>>0>7){continue}break}}k=h;break b}v[a>>2]=l;l=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=E;v[a+40>>2]=q;v[a+36>>2]=k;v[a+32>>2]=C;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=j-b;c=p-e|0;v[f>>2]=c;if(!(g&9)|(l|0)<0){break a}b=v[a+28>>2];i=b>>>16|0;j=b&65535;if(c){o=(c>>>0)%5552|0;while(1){k=0;if(o>>>0>7){while(1){p=w[e|0]+j|0;n=p+w[e+1|0]|0;m=n+w[e+2|0]|0;h=m+w[e+3|0]|0;f=h+w[e+4|0]|0;d=f+w[e+5|0]|0;b=d+w[e+6|0]|0;j=b+w[e+7|0]|0;i=j+(b+(d+(f+(h+(m+(n+(i+p|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;k=k+8|0;if((k|7)>>>0<o>>>0){continue}break}k=o&8184}m=e;h=k;if(o>>>0>h>>>0){while(1){j=w[m|0]+j|0;i=j+i|0;m=m+1|0;h=h+1|0;if((o|0)!=(h|0)){continue}break}e=(o-k|0)+e|0}c=c-o|0;i=(i>>>0)%65521|0;j=(j>>>0)%65521|0;o=5552;if(c){continue}break}}b=i<<16|j;v[a+28>>2]=b;if(l){break a}l=0;if(!(g&1)){break a}l=(b|0)==v[a+16>>2]?0:-2}gb=M+144|0;return l}function dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Y=0;f=gb-400|0;gb=f;vc(b);j=gb-32|0;gb=j;e=j+24|0;i=f+192|0;bU(e,i);h=yb(e);e=v[j+28>>2];g=v[j+24>>2];v[j+8>>2]=g;v[j+12>>2]=e;v[j>>2]=g;v[j+4>>2]=e;g=j+16|0;e=b;cc(g,e,j);g=yb(g);if((g|0)==(h|0)){Rb(e,yb(j+24|0))}gb=j+32|0;e=(g|0)==(h|0);if(!e){aU(i)}a:{if(!e){break a}if(!jU(f+192|0)){break a}if(!c){d=1;break a}Hd(a,134217728);d=f+136|0;Ef(d,1084);v[22708]=0;n=f+192|4;U(886,f+8|0,d|0,n|0);d=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=f+8|0;Eb(a+1298304|0,d);vb(d);Hb(f+136|0);d=Tb(d,6105);Eb(a+1298316|0,d);vb(d);v[a+480188>>2]=4;v[a+1298364>>2]=2;X=a,Y=Ib(w[f+328|0]|w[f+329|0]<<8),v[X+480196>>2]=Y;d=Ib(w[f+332|0]|w[f+333|0]<<8);v[a+480260>>2]=56;v[a+480264>>2]=13696;X=a,Y=iU(d),v[X+480204>>2]=Y;Dr(Sb(a+484360|0),f+200|0,w[f+192|6]);r=a+480190|0;o=dd(f+176|0);q=mc(f+160|0);j:{k:{l:{m:{if(Ib(w[f+392|0]|w[f+393|0]<<8)){while(1){v[22708]=0;d=T(416,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}u[f+112>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=Ib(w[f+394|0]|w[f+395|0]<<8);if((Ib(w[n|0]|w[n+1|0]<<8)|0)==2){v[22708]=0;d=T(426,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}d=d-2|0}v[22708]=0;U(288,f+136|0,b|0,d|0);d=v[22708];v[22708]=0;n:{o:{p:{if((d|0)!=1){e=f+136|0;d=kc(f+8|0,e);xb(e);v[22708]=0;e=Ke(r,f+112|0);j=v[22708];v[22708]=0;if((j|0)==1){break p}C=x[e>>1];u[a+480190>>1]=C;v[22708]=0;e=B(x[f+112>>1],104)+a|0;h=e+484380|0;R(424,h|0,1);j=v[22708];v[22708]=0;q:{if((j|0)==1){break q}if(Ib(w[n|0]|w[n+1|0]<<8)>>>0>1){break o}v[22708]=0;R(887,d|0,e+484423|0);j=v[22708];v[22708]=0;if((j|0)==1){break q}v[22708]=0;Q(318,f+8|0,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break q}v[22708]=0;W(503,d|0,((x[f+112>>1]<<5)+a|0)+946304|0,30)|0;j=v[22708];v[22708]=0;if((j|0)!=1){break n}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}j=Kb(f+136|0);v[22708]=0;W(533,d|0,j|0,257)|0;i=v[22708];v[22708]=0;r:{s:{if((i|0)==1){break s}v[22708]=0;Q(303,e+484423|0,j|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break s}v[22708]=0;Q(318,f+8|0,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break s}v[22708]=0;W(533,d|0,j|0,31)|0;i=v[22708];v[22708]=0;if((i|0)==1){break s}v[22708]=0;Q(301,((x[f+112>>1]<<5)+a|0)+946304|0,j|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break s}if(!(v[f+16>>2]&1)){break r}v[22708]=0;Q(318,f+8|0,1)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break r}}d=P()|0;O()|0;vb(j);break f}vb(j)}v[22708]=0;R(888,d|0,f+136|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;hU(f+136|0,h);d=v[22708];v[22708]=0;if((d|0)==1){break m}if((Ib(w[n|0]|w[n+1|0]<<8)|0)==2){t[e+484417|0]=w[f+154|0]<<3}t:{if(!Ib(w[n|0]|w[n+1|0]<<8)){break t}v[22708]=0;R(317,q|0,C|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;R(890,o|0,C|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}h=Ad(o,x[f+112>>1]-1|0);Od(h);v[22708]=0;j=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;d=Q(191,b|0,j<<3)|0;i=v[22708];v[22708]=0;if((i|0)==1){break g}if(!d){xb(f+8|0);break c}v[22708]=0;R(891,h|0,j|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}d=0;v[f+128>>2]=0;if(!j){if(!(w[e+484414|0]&2)){break t}d=v[e+484384>>2];v[f+120>>2]=d;e=v[e+484388>>2];v[22708]=0;v[f+124>>2]=e-d;R(892,h|0,f+120|0);d=v[22708];v[22708]=0;if((d|0)!=1){break t}d=P()|0;O()|0;break f}while(1){v[22708]=0;e=T(426,b|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}v[22708]=0;v[f+120>>2]=e;e=T(426,b|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}v[22708]=0;v[f+124>>2]=e;R(892,h|0,f+120|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}d=d+1|0;if(j>>>0>(d&65535)>>>0){continue}break}}xb(f+8|0);p=p+1|0;if(Ib(w[f+392|0]|w[f+393|0]<<8)>>>0>(p&65535)>>>0){continue}break}}D=128;if(Ib(w[n|0]|w[n+1|0]<<8)){break l}v[22708]=0;D=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break l}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=a+480188|0;E=w[f+192|7];u[f+118>>1]=4;u:{v:{if(Ib(w[n|0]|w[n+1|0]<<8)){p=v[b+8>>2];w:{if(!D){break w}g=0;while(1){v[22708]=0;e=T(416,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}if((e|0)==65535){break w}v[22708]=0;E=T(416,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}v[22708]=0;e=T(416,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}u[f+118>>1]=e;if(e>>>0>127){break c}v[22708]=0;e=Ke(d,f+118|0);j=v[22708];v[22708]=0;if((j|0)==1){break v}u[d>>1]=x[e>>1];v[22708]=0;Q(318,b|0,B(x[f+118>>1],E)<<2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}g=g+1|0;if((g&65535)>>>0<D>>>0){continue}break}}v[22708]=0;Q(190,b|0,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}}d=x[d>>1];v[22708]=0;G=Q(893,f+136|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){H=Ib(w[f+330|0]|w[f+331|0]<<8);x:{if(!D){break x}K=a+484344|0;V=c&1;j=0;p=0;while(1){y:{if(!Ib(w[n|0]|w[n+1|0]<<8)){d=x[f+118>>1];e=p;break y}v[22708]=0;e=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break h}if((e|0)==65535){break x}v[22708]=0;E=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break h}v[22708]=0;d=T(416,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break h}u[f+118>>1]=d}v[22708]=0;g=d&65535;F=E&65535;d=F<<2;h=Q(191,b|0,B(g,d)|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break h}if(!h){break x}z:{A:{B:{if(!V){break B}v[22708]=0;M=e&65535;e=W(331,K|0,M|0,F|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break h}if(!e){break B}s=0;if(F){break A}break z}v[22708]=0;Q(318,b|0,B(d,x[f+118>>1])|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break z}break h}while(1){d=_b(K,M);v[22708]=0;i=Tf(d,s);d=v[22708];v[22708]=0;C:{if((d|0)!=1){e=0;A=0;D:{E:{switch((H&3)-1|0){case 0:A=!(s&3);break D;case 1:A=!(s&1);break D;case 2:break E;default:break D}}A=(s&3)!=3}I=0;if(!x[f+118>>1]){break C}while(1){d=v[G>>2];v[22708]=0;R(531,f+120|0,b|0);h=v[22708];v[22708]=0;if((h|0)==1){break h}h=B(e,9)+d|0;d=f+120|0;g=qd(d);z=Ve(d);k=fj(d);l=i+B(e,6)|0;t[l+1|0]=w[d|0];d=w[g|0];t[l|0]=d;g=w[k|0];t[l+5|0]=g;k=l+5|0;if(d){t[l|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[k|0]}m=g&255;z=w[z|0];F:{if(z>>>0>=240){d=m|(z&15)<<8;if(d){v[22708]=0;d=gn(+(iU(d)>>>0)/1e4);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=d;t[l+3|0]=17;break F}break h}t[l+3|0]=0;break F}J=m>>>4|0;N=m<<4;d=J|N;G:{switch(z|0){case 0:d=i+B(e,6)|0;if(g&255){t[d+3|0]=1;break F}t[d+3|0]=0;break F;case 1:t[(i+B(e,6)|0)+3|0]=2;break F;case 2:t[(i+B(e,6)|0)+3|0]=3;break F;case 3:v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 4:v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 7:t[(i+B(e,6)|0)+3|0]=23;j=0;break F;case 8:t[(i+B(e,6)|0)+3|0]=0;j=d;break F;case 9:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|16;break F}break h;case 10:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|32;break F}break h;case 11:t[h+3|0]=d;t[(i+B(e,6)|0)+3|0]=0;break F;case 12:d=i+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break F;case 13:z=i+B(e,6)|0;H:{I:{if(m&240){t[(i+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break I}if(!(m&15)){break H}t[(i+B(e,6)|0)+2|0]=3;d=g&15}t[z+4|0]=d}t[h+3|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 14:t[(i+B(e,6)|0)+3|0]=19;t[k|0]=!(g&255);break F;case 15:t[(i+B(e,6)|0)+3|0]=16;t[k|0]=(g&240)>>>4;H=g&15;break F;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(i+B(e,6)|0)+3|0]=0;break F;case 17:t[h+6|0]=m&15?g:0;t[(i+B(e,6)|0)+3|0]=0;break F;case 18:t[(i+B(e,6)|0)+3|0]=14;break F;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 20:t[(i+B(e,6)|0)+3|0]=12;break F;case 22:J:{d=w[l+1|0];K:{if(!d){break K}if(Ec(o)>>>0<d>>>0){break K}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;v[22708]=0;Q(895,f+8|0,0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break h}v[f+112>>2]=9;d=Ec(d);v[22708]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22708];v[22708]=0;if((m|0)==1){break J}if(y[d>>2]<=(g&255)>>>0){break K}d=i+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 23:d=w[l+1|0];L:{if(!d){break L}if(Ec(o)>>>0<d>>>0){break L}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;g=g&255;if(Ec(d)>>>0<=g>>>0){break L}M:{if(x[Ad(d,g)+8>>1]){break M}if(!fi(a)){g=w[k|0];break M}m=x[r>>1]+1|0;u[r>>1]=m;g=w[k|0];X=Ad(d,g),Y=m,u[X+8>>1]=Y}X=l,Y=w[Ad(d,g)+8|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break F;case 24:N:{d=w[l+1|0];O:{if(!d){break O}if(Ec(o)>>>0<d>>>0){break O}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;v[22708]=0;Q(895,f+8|0,0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break h}v[f+112>>2]=9;d=Ec(d);v[22708]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22708];v[22708]=0;if((m|0)==1){break N}if(y[d>>2]>(g&255)>>>0){d=i+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}P:{if(x[sc(q,w[l+1|0]-1|0)>>1]){break P}if(!fi(a)){break P}d=x[r>>1]+1|0;u[r>>1]=d;X=sc(q,w[l+1|0]-1|0),Y=d,u[X>>1]=Y}X=l,Y=w[sc(q,w[l+1|0]-1|0)|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 25:d=w[l+1|0];Q:{if(!d){break Q}if(Ec(o)>>>0<d>>>0){break Q}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;g=g&255;if(Ec(d)>>>0<=g>>>0){break Q}R:{if(x[Ad(d,g)+10>>1]){break R}if(!fi(a)){g=w[k|0];break R}m=x[r>>1]+1|0;u[r>>1]=m;g=w[k|0];X=Ad(d,g),Y=m,u[X+10>>1]=Y}X=l,Y=w[Ad(d,g)+10|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break F;case 29:t[(i+B(e,6)|0)+3|0]=11;t[k|0]=d;if(m&15){t[k|0]=N|15;break F}if((g&255)>>>0<16){break F}t[k|0]=J|240;break F;case 32:if(m&240){t[h+3|0]=J;t[(i+B(e,6)|0)+3|0]=0;break F}t[(i+B(e,6)|0)+3|0]=19;t[k|0]=g&15|192;break F;case 33:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|208;break F}break h;case 34:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|144;break F}break h;case 73:t[(i+B(e,6)|0)+3|0]=10;break F;case 78:if((g&112|128)==224){t[(i+B(e,6)|0)+3|0]=19;break F}t[(i+B(e,6)|0)+3|0]=0;break F;case 79:d=i+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;H=0;break F}t[d+3|0]=17;break F;default:break G}}t[(i+B(e,6)|0)+3|0]=0}m=0;g=w[h+3|0];if(!(w[l+2|0]|!g)){S:{if(g>>>0>=16){t[l+2|0]=5;g=g>>>4|0;break S}t[l+2|0]=6}t[l+4|0]=g;m=1}T:{if(w[l+3|0]){break T}d=w[h+1|0];U:{if(d){t[l+3|0]=2;break U}d=w[h+2|0];if(d){t[l+3|0]=3;break U}d=w[h|0];if(d){t[l+3|0]=19;break U}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break U}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break U}d=w[h+3|0];if(!(!d|m)){t[l+3|0]=11;t[k|0]=d;if(d&15){d=d|-16;break U}if(!(d&240)){break T}d=d|15;break U}d=w[h+6|0];if(d){t[l+3|0]=8;break U}if(A){t[l+3|0]=20;A=0;d=97;break U}A=0;if(I){break T}d=j&255;if(!d){break T}t[l+3|0]=24;t[k|0]=j;if(j&15){d=j|-16}else{if(!(d&240)){I=1;break T}d=j|15}I=1}t[k|0]=d}e=e+1|0;if(e>>>0<x[f+118>>1]){continue}break}break C}break h}s=s+1|0;if((F|0)!=(s|0)){continue}break}}p=p+1|0;if((p&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[22708]=0;xh(a,1);d=v[22708];v[22708]=0;if((d|0)==1){break h}if(Ib(w[n|0]|w[n+1|0]<<8)){V:{while(1){v[22708]=0;d=Q(191,b|0,2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}if(!d){break V}v[22708]=0;d=T(416,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}if((d|0)==65535){break V}v[22708]=0;Q(318,b|0,2)|0;d=v[22708];v[22708]=0;if((d|0)==1){break h}v[22708]=0;d=T(426,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;Q(318,b|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}}break}break h}v[22708]=0;Q(318,b|0,34)|0;d=v[22708];v[22708]=0;if((d|0)==1){break h}}W:{if(!(!(c&2)|!C)){d=1;p=1;while(1){c=(B(d,104)+a|0)+484380|0;X:{if(!v[c>>2]){break X}e=Rc(f+8|0,8,1,0,0);v[22708]=0;W(329,e|0,c|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break W}if(Ec(o)>>>0<d>>>0){break X}d=d-1|0;e=Ad(o,d);v[22708]=0;R(896,c|0,e|0);e=v[22708];v[22708]=0;Y:{if((e|0)!=1){if(!x[sc(q,d)>>1]){break Y}e=x[sc(q,d)>>1];j=v[c>>2];v[22708]=0;ha(897,c|0,(B(e,104)+a|0)+484380|0,0,j|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){break Y}}break h}d=Ad(o,d);X=f,Y=Vb(d),v[X+8>>2]=Y;X=f,Y=Zb(d),v[X+120>>2]=Y;if(!Gb(f+8|0,f+120|0)){break X}while(1){d=v[f+8>>2];e=x[d+8>>1];if(e){j=v[d+4>>2];h=v[d>>2];v[22708]=0;ha(897,c|0,(B(e,104)+a|0)+484380|0,h|0,j|0,1);e=v[22708];v[22708]=0;if((e|0)==1){break h}}e=x[d+10>>1];if(e){j=v[d+4>>2];d=v[d>>2];v[22708]=0;ha(897,c|0,(B(e,104)+a|0)+484380|0,d|0,j|0,0);d=v[22708];v[22708]=0;if((d|0)==1){break h}}d=f+8|0;rr(d);if(Gb(d,f+120|0)){continue}break}}p=p+1|0;d=p&65535;if(C>>>0>=d>>>0){continue}break}}QB(G);d=1;break b}break h}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;Hb(f+136|0);break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;QB(G);break e}d=P()|0;O()|0}xb(f+8|0)}Ze(q);cU(o)}S(d|0);L()}d=0}Ze(q);cU(o)}gb=f+400|0;return d|0}function Cd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-16|0;gb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=v[116503];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;f=v[b+466060>>2];a=f+8|0;c=v[f+8>>2];b=b+466052|0;l:{if((c|0)==(b|0)){m=466012,n=rqa(-2,d)&e,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[f+4>>2]=b|3;b=b+f|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116505];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+466060>>2];b=v[g+8>>2];a=a+466052|0;m:{if((b|0)==(a|0)){e=rqa(-2,c)&e;v[116503]=e;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=h|3;d=g+h|0;b=c<<3;f=b-h|0;v[d+4>>2]=f|1;v[b+g>>2]=f;if(k){b=k>>>3|0;c=(b<<3)+466052|0;g=v[116508];b=1<<b;n:{if(!(b&e)){v[116503]=b|e;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[116508]=d;v[116505]=f;break a}j=v[116504];if(!j){break k}b=(j&0-j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+466316>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;f=c>>>0<d>>>0;d=f?c:d;b=f?a:b;c=a;continue}break}i=v[b+24>>2];f=v[b+12>>2];if((f|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=f;v[f+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;f=a;c=a+20|0;a=v[c>>2];if(a){continue}c=f+16|0;a=v[f+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[116504];if(!j){break k}d=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}c=v[(e<<2)+466316>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((e|0)==31?0:25-(e>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}f=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|f)){f=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+466316>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;f=c?a:f;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!f|v[116505]-h>>>0<=d>>>0){break k}e=v[f+24>>2];b=v[f+12>>2];if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=f+20|0;a=v[c>>2];if(!a){a=v[f+16>>2];if(!a){break i}c=f+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116505];if(c>>>0>=h>>>0){d=v[116508];b=c-h|0;u:{if(b>>>0>=16){v[116505]=b;a=d+h|0;v[116508]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[116508]=0;v[116505]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[116506];if(i>>>0>h>>>0){b=i-h|0;v[116506]=b;c=v[116509];a=c+h|0;v[116509]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;b=j;if(v[116621]){c=v[116623]}else{v[116624]=-1;v[116625]=-1;v[116622]=4096;v[116623]=4096;v[116621]=l+12&-16^1431655768;v[116626]=0;v[116614]=0;c=4096}g=b+c|0;f=0-c|0;c=g&f;if(c>>>0<=h>>>0){break a}d=v[116613];if(d){b=v[116611];e=b+c|0;if(d>>>0<e>>>0|b>>>0>=e>>>0){break a}}if(w[466456]&4){break f}v:{w:{d=v[116509];if(d){a=466460;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=Tp(0);if((b|0)==-1){break g}e=c;d=v[116622];a=d-1|0;if(a&b){e=(c-b|0)+(a+b&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=v[116613];if(d){a=v[116611];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=Tp(e);if((b|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}b=Tp(e);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=e>>>0)){b=v[116623];b=b+(j-e|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Tp(b)|0)!=-1){e=b+e|0;b=a;break e}Tp(0-e|0);break g}b=a;if((a|0)!=-1){break e}break g}f=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116614]=v[116614]|4}if(c>>>0>2147483646){break d}b=v[22706];c=c+3&-4;a=b+c|0;x:{y:{if(a>>>0<=b>>>0?c:0){break y}if(ax()>>>0<a>>>0){if(!(va(a|0)|0)){break y}}v[22706]=a;break x}v[115189]=48;a=v[22706];b=-1}z:{if(ax()>>>0>=a>>>0){break z}if(va(a|0)|0){break z}v[115189]=48;break d}v[22706]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}e=a-b|0;if(e>>>0<=h+40>>>0){break d}}a=v[116611]+e|0;v[116611]=a;if(a>>>0>y[116612]){v[116612]=a}A:{B:{C:{g=v[116509];if(g){a=466460;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break C}a=v[a+8>>2];if(a){continue}break}break B}a=v[116507];if(!(a>>>0<=b>>>0?a:0)){v[116507]=b}a=0;v[116616]=e;v[116615]=b;v[116511]=-1;v[116512]=v[116621];v[116618]=0;while(1){d=a<<3;c=d+466052|0;v[d+466060>>2]=c;v[d+466064>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116506]=c;a=a+b|0;v[116509]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116510]=v[116625];break A}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break B}v[a+4>>2]=c+e;a=g+8&7?-8-g&7:0;c=a+g|0;v[116509]=c;b=v[116506]+e|0;a=b-a|0;v[116506]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116510]=v[116625];break A}if(y[116507]>b>>>0){v[116507]=b}c=b+e|0;a=466460;D:{E:{F:{G:{H:{I:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break I}break}if(!(w[a+12|0]&8)){break H}}a=466460;while(1){c=v[a>>2];if(c>>>0<=g>>>0){f=c+v[a+4>>2]|0;if(f>>>0>g>>>0){break G}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+e;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=c+(c+8&7?-8-c&7:0)|0;i=h+j|0;c=e-i|0;if((e|0)==(g|0)){v[116509]=i;a=v[116506]+c|0;v[116506]=a;v[i+4>>2]=a|1;break E}if(v[116508]==(e|0)){v[116508]=i;a=v[116505]+c|0;v[116505]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break E}a=v[e+4>>2];if((a&3)==1){g=a&-8;J:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=466012,n=v[116503]&rqa(-2,a),v[m>>2]=n;break J}v[d+12>>2]=b;v[b+8>>2]=d;break J}h=v[e+24>>2];b=v[e+12>>2];K:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break K}L:{a=e+20|0;d=v[a>>2];if(d){break L}a=e+16|0;d=v[a>>2];if(d){break L}b=0;break K}while(1){f=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[f>>2]=0}if(!h){break J}d=v[e+28>>2];a=(d<<2)+466316|0;M:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break M}m=466016,n=v[116504]&rqa(-2,d),v[m>>2]=n;break J}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break J}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break J}v[b+20>>2]=a;v[a+24>>2]=b}e=e+g|0;c=c+g|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;N:{if(!(c&a)){v[116503]=a|c;a=b;break N}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break E}a=31;if(c>>>0<=16777215){a=c>>>8|0;f=a+1048320>>>16&8;a=a<<f;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|f))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;f=(a<<2)+466316|0;d=v[116504];b=1<<a;O:{if(!(d&b)){v[116504]=b|d;v[f>>2]=i;v[i+24>>2]=f;break O}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[f>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break F}b=a>>>29|0;a=a<<1;f=d+(b&4)|0;b=v[f+16>>2];if(b){continue}break}v[f+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break E}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116506]=c;a=a+b|0;v[116509]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116510]=v[116625];a=(f+(f-39&7?39-f&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116618];v[c+16>>2]=v[116617];v[c+20>>2]=a;a=v[116616];v[c+8>>2]=v[116615];v[c+12>>2]=a;v[116617]=c+8;v[116616]=e;v[116615]=b;v[116618]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((c|0)==(g|0)){break A}v[c+4>>2]=v[c+4>>2]&-2;f=c-g|0;v[g+4>>2]=f|1;v[c>>2]=f;if(f>>>0<=255){a=f>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;P:{if(!(c&a)){v[116503]=a|c;a=b;break P}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break A}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+466316|0;c=v[116504];b=1<<a;Q:{if(!(c&b)){v[116504]=b|c;v[d>>2]=g;v[g+24>>2]=d;break Q}a=f<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((f|0)==(v[b+4>>2]&-8)){break D}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break A}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116506];if(a>>>0<=h>>>0){break d}b=a-h|0;v[116506]=b;c=v[116509];a=c+h|0;v[116509]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}v[115189]=48;a=0;break a}R:{if(!e){break R}c=v[f+28>>2];a=(c<<2)+466316|0;S:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break S}j=rqa(-2,c)&j;v[116504]=j;break R}v[e+(v[e+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break R}}v[b+24>>2]=e;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break R}v[b+20>>2]=a;v[a+24>>2]=b}T:{if(d>>>0<=15){a=d+h|0;v[f+4>>2]=a|3;a=a+f|0;v[a+4>>2]=v[a+4>>2]|1;break T}v[f+4>>2]=h|3;e=f+h|0;v[e+4>>2]=d|1;v[d+e>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;U:{if(!(c&a)){v[116503]=a|c;a=b;break U}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a;break T}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[e+28>>2]=a;v[e+16>>2]=0;v[e+20>>2]=0;b=(a<<2)+466316|0;V:{c=1<<a;W:{if(!(c&j)){v[116504]=c|j;v[b>>2]=e;break W}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break V}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=e}v[e+24>>2]=b;v[e+12>>2]=e;v[e+8>>2]=e;break T}a=v[b+8>>2];v[a+12>>2]=e;v[b+8>>2]=e;v[e+24>>2]=0;v[e+12>>2]=b;v[e+8>>2]=a}a=f+8|0;break a}X:{if(!i){break X}c=v[b+28>>2];a=(c<<2)+466316|0;Y:{if(v[a>>2]==(b|0)){v[a>>2]=f;if(f){break Y}m=466016,n=rqa(-2,c)&j,v[m>>2]=n;break X}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=f;if(!f){break X}}v[f+24>>2]=i;a=v[b+16>>2];if(a){v[f+16>>2]=a;v[a+24>>2]=f}a=v[b+20>>2];if(!a){break X}v[f+20>>2]=a;v[a+24>>2]=f}Z:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break Z}v[b+4>>2]=h|3;f=b+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+466052|0;g=v[116508];a=1<<a;_:{if(!(a&e)){v[116503]=a|e;a=c;break _}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[116508]=f;v[116505]=d}a=b+8|0}gb=l+16|0;return a|0}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;a:{b:{c:{d:{e:{f:{if(qe(b,18726)){Kb(a);break f}if(qe(b,7151)){b=gb-96|0;gb=b;c=Kb(a);v[22708]=0;_(155,b- -64|0);a=v[22708];v[22708]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22708]=0;v[b+32>>2]=0;R(2038,b+48|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;Q(1168,c|0,b+48|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break o}vb(b+48|0);v[22708]=0;Q(1919,c|0,13845)|0;a=v[22708];v[22708]=0;q:{if((a|0)==1){break q}v[22708]=0;v[b+32>>2]=6;R(2038,b+48|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break n}v[22708]=0;Q(1168,c|0,b+48|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}vb(b+48|0);v[22708]=0;Q(1919,c|0,13845)|0;a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;v[b+32>>2]=0;R(2038,b+48|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;Q(1168,c|0,b+48|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break k}a=b+48|0;vb(a);v[22708]=0;a=Q(70,a|0,12139)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}e=Ab(a);vb(a);if(!e){break i}v[22708]=0;Q(1919,c|0,12139)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}e=mc(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[22708]=0;v[b+12>>2]=a;R(2038,b+16|0,b+12|0);a=v[22708];v[22708]=0;if((a|0)==1){break D}v[22708]=0;U(2039,b+32|0,6095,b+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break C}v[22708]=0;R(1424,e|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break B}vb(b+32|0);vb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[22708]=0;d=Q(70,b+32|0,10085)|0;a=v[22708];v[22708]=0;if((a|0)==1){break z}v[22708]=0;R(1424,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break y}vb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(!w[(b- -64|0)+17|0]){break w}v[22708]=0;d=Q(70,b+32|0,9785)|0;a=v[22708];v[22708]=0;if((a|0)==1){break v}v[22708]=0;R(1424,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break u}vb(d)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}v[22708]=0;d=Q(70,b+32|0,8321)|0;a=v[22708];v[22708]=0;E:{if((a|0)!=1){v[22708]=0;R(1424,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break E}vb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(cd(e)){break g}v[22708]=0;Q(1919,c|0,13875)|0;a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;d=Q(70,b+16|0,13845)|0;a=v[22708];v[22708]=0;F:{G:{H:{if((a|0)!=1){v[22708]=0;U(2040,b+32|0,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break H}v[22708]=0;Q(1168,c|0,b+32|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break G}vb(b+32|0);vb(d);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;vb(b+32|0)}vb(d);break r}a=P()|0;O()|0}yd(e)}Ff(b- -64|0);break c}yd(e);Ff(b- -64|0);gb=b+96|0;break f}if(qe(b,5265)){v[f>>2]=0;Lq(a,f);break f}if(qe(b,5243)){v[f>>2]=6;Lq(a,f);break f}if(qe(b,8086)){v[f>>2]=0;Lq(a,f);break f}if(qe(b,7883)){Tb(a,12139);break f}if(qe(b,8693)){b=Tb(f,12139);e=Ab(b);v[22708]=0;Q(70,a|0,(e?12908:12589)|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}vb(b);break f}if(qe(b,4456)){b=gb-48|0;gb=b;EG(b+16|0);v[22708]=0;_(173,b|0);e=v[22708];v[22708]=0;I:{J:{K:{L:{if((e|0)!=1){v[22708]=0;U(174,b+32|0,b+16|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break L}v[22708]=0;R(2041,a|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break K}vb(b+32|0);vb(b);vb(b+16|0);gb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(b+16|0);break a}if(qe(b,7179)){b=gb-16|0;gb=b;i=gb-16|0;gb=i;v[i+8>>2]=101;e=b;d=gb-112|0;gb=d;h=mc(d+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{c=v[i+8>>2];if(c&1){v[22708]=0;v[d+48>>2]=19923026;R(162,d- -64|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break $}v[22708]=0;R(142,h|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break _}vb(d- -64|0);c=v[i+8>>2]}if(!(c&4)){break Y}v[22708]=0;c=ga(163)|0;g=v[22708];v[22708]=0;if((g|0)==1){break X}if(!c){break Z}break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}v[22708]=0;_(164,d- -64|0);c=v[22708];v[22708]=0;aa:{if((c|0)!=1){v[22708]=0;R(142,h|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break aa}vb(d- -64|0);break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}ba:{c=v[i+8>>2];if(!(c&32)){break ba}v[22708]=0;_(155,d- -64|0);c=v[22708];v[22708]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((c|0)!=1){v[22708]=0;R(165,d+48|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break da}c=d+48|0;g=gd(c);vb(c);if(!g){v[22708]=0;_(166,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break ua}v[22708]=0;R(165,d+16|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break ta}v[22708]=0;U(167,d+48|0,d+32|0,d+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break sa}v[22708]=0;R(142,h|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break ra}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}if(!gd(Wp(d- -64|0))){v[22708]=0;_(168,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break oa}c=Wp(d- -64|0);v[22708]=0;U(169,d+48|0,d+32|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break na}v[22708]=0;R(142,h|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break ma}vb(d+48|0);Hb(d+32|0)}v[22708]=0;R(170,d+48|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break ka}c=d+48|0;g=gd(c);vb(c);if(!g){v[22708]=0;_(166,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break ja}v[22708]=0;R(170,d+16|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break ia}v[22708]=0;U(167,d+48|0,d+32|0,d+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break ha}v[22708]=0;R(142,h|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break ga}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}Ff(d- -64|0);c=v[i+8>>2];break ba}c=P()|0;O()|0;break N}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break pa}c=P()|0;O()|0;break qa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break la}c=P()|0;O()|0;vb(d+48|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ea}c=P()|0;O()|0;break fa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0}Ff(d- -64|0);break N}va:{if(!(c&64)){break va}v[22708]=0;c=ga(163)|0;g=v[22708];v[22708]=0;if((g|0)==1){break X}if(c){break va}c=d- -64|0;Kb(c);v[22708]=0;R(142,h|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break O}vb(d- -64|0)}if(w[i+8|0]&128){v[22708]=0;_(171,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break W}v[22708]=0;R(142,h|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break V}vb(d- -64|0)}v[22708]=0;g=Q(2,d- -64|0,18726)|0;c=v[22708];v[22708]=0;if((c|0)==1){break U}v[22708]=0;U(172,d|0,h|0,g|0);c=v[22708];v[22708]=0;if((c|0)==1){break T}v[22708]=0;_(173,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break S}v[22708]=0;U(174,e|0,d|0,d+48|0);e=v[22708];v[22708]=0;if((e|0)==1){break R}vb(d+48|0);vb(d);vb(g);sm(h);gb=d+112|0;break M}c=P()|0;O()|0;break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;break P}c=P()|0;O()|0;break Q}c=P()|0;O()|0;vb(d+48|0)}vb(d)}vb(g);break N}c=P()|0;O()|0;vb(d- -64|0)}sm(h);S(c|0);L()}gb=i+16|0;v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7795)){b=gb-48|0;gb=b;Ls(b);v[22708]=0;R(165,b+32|0,b|0);e=v[22708];v[22708]=0;wa:{xa:{if((e|0)!=1){v[22708]=0;R(2041,a|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break xa}vb(b+32|0);Ff(b);gb=b+48|0;break f}a=P()|0;O()|0;break wa}a=P()|0;O()|0;vb(b+32|0)}Ff(b);break a}if(qe(b,8656)){b=gb-32|0;gb=b;Ls(b);e=Wp(b);v[22708]=0;R(2041,a|0,e|0);a=v[22708];v[22708]=0;if((a|0)!=1){Ff(b);gb=b+32|0;break f}a=P()|0;O()|0;Ff(b);break a}if(qe(b,7192)){b=gb-48|0;gb=b;Ls(b+16|0);ya:{if(v[b+28>>2]){e=v[b+28>>2];v[22708]=0;v[b+12>>2]=e;R(2038,a|0,b+12|0);a=v[22708];v[22708]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Ff(b+16|0);break a}Kb(a)}Ff(b+16|0);gb=b+48|0;break f}if(qe(b,10075)){Ls(f);b=w[f+16|0];v[22708]=0;Q(70,a|0,(b?12589:12908)|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Ff(f);break f}a=P()|0;O()|0;Ff(f);break a}if(qe(b,7208)){Ls(f);b=w[f+17|0];v[22708]=0;Q(70,a|0,(b?12589:12908)|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Ff(f);break f}a=P()|0;O()|0;Ff(f);break a}if(qe(b,9467)){Ls(f);b=w[f+18|0];v[22708]=0;Q(70,a|0,(b?12589:12908)|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Ff(f);break f}a=P()|0;O()|0;Ff(f);break a}if(qe(b,9759)){b=gb-16|0;gb=b;e=gb-32|0;gb=e;d=Kb(b);v[22708]=0;_(155,e|0);c=v[22708];v[22708]=0;za:{Aa:{Ba:{if((c|0)!=1){c=Wp(e);v[22708]=0;Q(156,d|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ba}Ff(e);gb=e+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Ff(e)}vb(d);break a}v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,5386)){b=gb-16|0;gb=b;e=gb-48|0;gb=e;d=Kb(b);v[22708]=0;R(158,e+16|0,1244);c=v[22708];v[22708]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((c|0)!=1){v[e+12>>2]=14;v[e+8>>2]=0;v[22708]=0;v[e+4>>2]=0;ha(159,e+32|0,e+16|0,e+12|0,e+8|0,e+4|0);c=v[22708];v[22708]=0;if((c|0)==1){break Ga}v[22708]=0;Q(113,d|0,e+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Fa}vb(e+32|0);Hb(e+16|0);gb=e+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;vb(e+32|0)}Hb(e+16|0)}vb(d);S(a|0);L()}v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,3879)){b=gb-16|0;gb=b;lo(b,0,16672);v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,3512)){b=gb-48|0;gb=b;c=Tb(b+16|0,14756);v[22708]=0;R(2042,b|0,2);e=v[22708];v[22708]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22708]=0;U(3,b+32|0,c|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ka}v[22708]=0;R(2041,a|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break Ja}vb(b+32|0);vb(b);vb(c);gb=b+48|0;break f}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(b+32|0)}vb(b)}break c}if(qe(b,8679)){b=gb-16|0;gb=b;lo(b,0,15072);v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7802)){b=gb-16|0;gb=b;xs(b,0);v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7777)){b=gb-16|0;gb=b;xs(b,2);v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7762)){b=gb-16|0;gb=b;xs(b,3);v[22708]=0;R(2041,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}Kb(a)}gb=f+32|0;break d}a=P()|0;O()|0;vb(b);break a}return}vb(c);break a}a=P()|0;O()|0;vb(b)}S(a|0);L()}function rZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-288|0;gb=e;vc(b);if(Sr(b,14913)){o=Kb(e+272|0);v[22708]=0;f=W(352,b|0,o|0,-1)|0;h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((h|0)!=1){if(!f){break a}v[22708]=0;f=Q(366,b|0,e+264|0)|0;h=v[22708];v[22708]=0;s:{if((h|0)==1){break s}if(!f){break a}if(!ZD(e+264|0)){break a}f=Qc(YD(e+264|0),jb);v[22708]=0;f=Q(191,b|0,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break s}if(!f){break a}if(!c){break b}v[22708]=0;R(367,a|0,4096);d=v[22708];v[22708]=0;if((d|0)==1){break s}v[22708]=0;Q(368,a+1298268|0,o|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break s}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[22708]=0;xh(a,1);d=v[22708];v[22708]=0;if((d|0)==1){break s}v[22708]=0;d=Q(2,e+112|0,6633)|0;f=v[22708];v[22708]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{if((f|0)!=1){Eb(a+1298304|0,d);vb(d);v[22708]=0;d=Q(2,e+112|0,4107)|0;f=v[22708];v[22708]=0;if((f|0)==1){break B}Eb(a+1298316|0,d);vb(d);v[22708]=0;_(370,e+56|0);d=v[22708];v[22708]=0;if((d|0)==1){break A}t[e+232|0]=w[e+264|1];d=w[e+264|0];v[22708]=0;t[e+16|0]=d;R(371,e+248|0,e+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;Y(372,e+112|0,e+56|0,e+232|0,e+248|0);d=v[22708];v[22708]=0;if((d|0)==1){break y}d=e+112|0;Eb(a+1298328|0,d);vb(d);vb(e+248|0);Hb(e+56|0);v[a+1298364>>2]=5;if(w[e+264|0]<2){break u}u[e+112>>1]=8192;v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break w}v[22708]=0;u[e+56>>1]=d;d=Ke(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[22708]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break v}v[22708]=0;t[e+56|0]=d;d=qf(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break v}v[a+480196>>2]=w[d|0];v[22708]=0;Q(318,b|0,3)|0;d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break t}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(e+248|0)}Hb(e+56|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+112|0]=32;v[22708]=0;d=T(374,b|0)|0;f=v[22708];v[22708]=0;C:{D:{if((f|0)==1){break D}v[22708]=0;t[e+56|0]=d;d=qf(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break D}v[a+480204>>2]=B(w[d|0],1e4);v[22708]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break C}v[22708]=0;t[e+56|0]=d;d=qf(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break C}v[a+480196>>2]=w[d|0];v[22708]=0;d=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=mc(e+248|0);m=mc(e+232|0);E:{F:{G:{H:{I:{J:{if(!x[a+480192>>1]){break J}i=1;h=e+88|1;p=e+112|12;while(1){v[22708]=0;f=W(376,a|0,i&65535,0)|0;d=v[22708];v[22708]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[22708]=0;d=W(353,b|0,f+492|0,-1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break M}if(!d){break J}v[22708]=0;k=T(374,b|0)|0;d=v[22708];v[22708]=0;N:{O:{P:{Q:{R:{if((d|0)!=1){Qb(e+112|0,0,120);if(!k){break K}if(w[e+264|0]){v[22708]=0;d=Q(377,b|0,e+112|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!d){break K}}if(!w[e+264|0]){d=wd(e+104|0,p,96);v[22708]=0;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;U(201,e+56|0,b|0,e+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break Q}if(!yb(e+56|0)){break K}}g=f+236|0;d=0;while(1){j=w[(e+112|0)+d|0];l=x[a+480190>>1];r=vd(g,d),s=(j+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[22708]=0;d=f+48|0;U(378,e+16|0,d|0,b|0);g=v[22708];v[22708]=0;if((g|0)==1){break P}v[22708]=0;g=f+68|0;U(378,e+40|0,g|0,b|0);j=v[22708];v[22708]=0;if((j|0)==1){break P}v[22708]=0;j=f+88|0;U(378,e+96|0,j|0,b|0);l=v[22708];v[22708]=0;if((l|0)==1){break P}v[22708]=0;R(379,b|0,e+88|0);l=v[22708];v[22708]=0;if((l|0)==1){break O}v[f>>2]=(w[h|0]|w[h+1|0]<<8)&4095;l=w[h|0]|w[h+1|0]<<8;f=e+88|0;$v(f,d,0);$v(f,g,1);$v(f,j,2);r=e,s=Vb(d),v[r+56>>2]=s;r=e,s=Zb(d),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){break N}break L}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){S:{d=v[e+56>>2];t[e+76|0]=64;f=w[d+2|0];v[22708]=0;t[e+79|0]=((f<<6)- -64>>>0)/127;f=ac(e+76|0,e+79|0);q=v[22708];v[22708]=0;if((q|0)==1){break S}t[d+2|0]=w[f|0];d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break L}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}r=e,s=Vb(g),v[r+56>>2]=s;r=e,s=Zb(g),v[r+80>>2]=s;T:{if(!Gb(e+56|0,e+80|0)){break T}while(1){U:{d=v[e+56>>2];t[e+76|0]=64;f=w[d+2|0];v[22708]=0;t[e+79|0]=((f<<6)+128>>>0)/255;f=ac(e+76|0,e+79|0);g=v[22708];v[22708]=0;if((g|0)==1){break U}t[d+2|0]=w[f|0];d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break T}break}b=P()|0;O()|0;break d}r=e,s=Vb(j),v[r+56>>2]=s;r=e,s=Zb(j),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){j=1<<(l>>>12&3);while(1){l=v[e+56>>2];d=t[l+2|0];d=nqa(d^-128,d>>31^-1,j,0);g=jb;f=g;V:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>-1){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break V}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=l,s=Ac(d,f)^128,t[r+2|0]=s;d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+76>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){d=0;f=0;while(1){v[22708]=0;W(353,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Z}v[22708]=0;R(381,b|0,e+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break Y}v[22708]=0;R(382,e+56|0,(B(x[e+76>>1]+f|0,104)+a|0)+484380|0);f=v[22708];v[22708]=0;if((f|0)==1){break Y}f=w[e+88|0];g=w[e+75|0];v[22708]=0;u[e+80>>1]=f|d<<8&32512|((g&3)!=0)<<15;R(383,m|0,e+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break X}d=d+1|0;f=d&65535;if(k>>>0<=f>>>0){break W}g=x[e+76>>1]+f|0;if(g>>>0<=3999){continue}break}}v[22708]=0;Q(318,b|0,20)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22708]=0;R(383,n|0,e+76|0);d=v[22708];v[22708]=0;if((d|0)==1){break I}v[e+56>>2]=3999;d=x[a+480190>>1];v[22708]=0;v[e+80>>2]=d+k;d=pd(e+56|0,e+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break H}u[a+480190>>1]=v[d>>2]}i=i+1|0;if(x[a+480192>>1]>=(i&65535)>>>0){continue}break}}d=Kb(e+112|0);v[22708]=0;f=W(352,b|0,d|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}if(f){v[22708]=0;U(13,e+56|0,7,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break E}f=e+56|0;Eb(a+1298280|0,f);vb(f)}vb(d);d=0;while(1){v[22708]=0;f=(d<<5)+a|0;We(f+480280|0);h=v[22708];v[22708]=0;if((h|0)==1){break G}v[22708]=0;U(355,b|0,f+480289|0,-1);f=v[22708];v[22708]=0;if((f|0)==1){break G}d=d+1|0;if((d|0)!=32){continue}break}v[22708]=0;d=Q(385,b|0,e+40|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}if(!d){break i}if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))>>>0<12){break m}d=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);v[22708]=0;d=Q(191,b|0,d-11|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}if(d){break F}break m}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[e+96>>2]=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))-11;i=mc(e+112|0);v[22708]=0;W(358,b|0,i|0,v[e+96>>2])|0;d=v[22708];v[22708]=0;if((d|0)==1){break p}v[22708]=0;v[e+56>>2]=50529027;d=Fb(e+96|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}v[e+88>>2]=B(v[d>>2],85);h=Kb(e+56|0);d=e+40|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22708]=0;v[e+16>>2]=d;d=Fb(e+88|0,e+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break r}d=v[d>>2];v[22708]=0;R(60,h|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break r}if(v[e+96>>2]){f=0;while(1){_:{k=w[lc(i,f)|0];d=f+1|0;if(!((k|0)!=255|v[e+96>>2]-d>>>0<2)){d=t[lc(i,d)|0];k=w[lc(i,f+2|0)|0];r=e,s=ff(h),v[r+16>>2]=s;Gd(e+32|0,e+16|0);v[22708]=0;da(359,h|0,v[e+32>>2],k|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){d=f+3|0;break _}break r}v[22708]=0;R(61,h|0,k<<24>>24);f=v[22708];v[22708]=0;if((f|0)!=1){break _}break r}f=d;if(y[e+96>>2]>d>>>0){continue}break}}v[22708]=0;Y(360,e+16|0,5,7,h|0);d=v[22708];v[22708]=0;$:{if((d|0)!=1){d=e+16|0;Eb(h,d);vb(d);d=zb(Jb(h));f=Ab(h);v[22708]=0;fa(361,a+1298292|0,d|0,f|0,74,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break $}vb(h);gc(i);break m}break r}break r}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;vb(h);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}gc(i);break d}b=P()|0;O()|0;vb(d);break d}d=Sb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[22708]=0;fa(362,d|0,b|0,f|0,65535,65535)|0;d=v[22708];v[22708]=0;if((d|0)==1){break l}k=c&1;if(k){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[22708]=0;R(330,a+484344|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}}f=e+264|3;aa:{if(!(w[f|0]|w[f+1|0]<<8)){break aa}h=a+484344|0;d=0;while(1){v[22708]=0;i=Q(191,b|0,4)|0;g=v[22708];v[22708]=0;ba:{if((g|0)!=1){if(i){break ba}break aa}b=P()|0;O()|0;break d}v[22708]=0;i=T(192,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[22708]=0;U(288,e+56|0,b|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break g}g=e+56|0;i=kc(e+112|0,g);xb(g);ca:{if(!k){break ca}v[22708]=0;g=T(374,i|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}v[22708]=0;Q(318,e+112|0,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}v[22708]=0;g=W(331,h|0,d&65535,g+1|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}if(!g){break ca}v[22708]=0;U(356,i|0,e+56|0,-1);g=v[22708];v[22708]=0;if((g|0)==1){break e}g=_b(h,d);v[22708]=0;R(357,g|0,e+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break e}g=_b(h,d);v[22708]=0;U(364,g|0,1,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break e}}xb(e+112|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break i}if(!x[a+480190>>1]){break j}d=0;while(1){if(w[sc(m,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Rc(e+112|0,u[f+484414>>1]&1?16:8,1,0,u[sc(m,d)>>1]>-1?0:6);v[22708]=0;W(329,d|0,f+484380|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break k}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break j}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(!x[a+480190>>1]){break i}b=0;while(1){c=w[sc(m,b)|0];da:{if(!c){break da}c=c-1&65535;if(tc(n)>>>0<=c>>>0){break da}c=(w[sc(m,b)+1|0]&127)+x[sc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break da}f=B(c,104);d=(f+a|0)+484380|0;if(!Md(d)){break da}h=a+484380|0;c=h+B(b+1|0,104)|0;f=f+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[f+34>>1]&1;v[c>>2]=v[d>>2];v[22708]=0;h=T(386,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break h}if(!h){break da}hc(zb(v[c+20>>2]),zb(v[f+20>>2]),bj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}Ze(m);Ze(n);break b}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;xb(e+112|0)}Ze(m);Ze(n)}vb(o);S(b|0);L()}d=1}vb(o)}gb=e+288|0;return d|0}function i8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=gb-48|0;gb=e;d=Tb(e+32|0,8890);f=ah(c,d);vb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){xl(a,v[b+24>>2]+1298316|0);break k}d=Tb(e+32|0,8238);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298304|0);break k}d=Tb(e+32|0,8720);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298352|0);break k}d=Tb(e+32|0,8230);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298340|0);break k}d=Tb(e+32|0,5376);f=ah(c,d);vb(d);if(f){d=e+32|0;c=d;f=v[v[b+24>>2]+480184>>2];b=39056;l:{while(1){if((f|0)==v[b>>2]){lo(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=39104){continue}break}Kb(c)}v[22708]=0;R(2041,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break j}vb(e+32|0);break k}d=Tb(e+32|0,8215);f=ah(c,d);vb(d);if(f){h=v[v[b+24>>2]+480184>>2];c=gb-48|0;gb=c;b=39056;g=Ik(c+32|0);j=e+32|0;d=Kb(j);while(1){if((h|0)==v[b>>2]){f=v[b+4>>2];v[22708]=0;f=Q(2,c+16|0,f|0)|0;i=v[22708];v[22708]=0;m:{n:{o:{p:{q:{r:{if((i|0)!=1){v[22708]=0;U(1415,c|0,g|0,f|0);i=v[22708];v[22708]=0;if((i|0)==1){break p}if(!w[c+4|0]){break m}if(!gd(d)){v[22708]=0;i=Q(2,c|0,14867)|0;k=v[22708];v[22708]=0;if((k|0)==1){break r}v[22708]=0;Q(113,d|0,i|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break q}vb(i)}v[22708]=0;Q(113,d|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(i);break o}b=P()|0;O()|0}vb(f)}vb(d);cO(g);S(b|0);L()}vb(f)}b=b+12|0;if((b|0)!=39104){continue}break}cO(g);gb=c+48|0;v[22708]=0;R(2041,a|0,j|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,5442);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298328|0);break k}d=Tb(e+32|0,2712);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298280|0);break k}d=Tb(e+32|0,9258);f=ah(c,d);vb(d);if(f){c=e+32|0;gg(c,v[b+24>>2]+1298268|0);v[22708]=0;U(2094,a|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,8663);f=ah(c,d);vb(d);if(f){s:{if(!cd(Jy(v[b+24>>2]))){if(v[XK(Jy(v[b+24>>2]))+12>>2]){break s}}Kb(a);break k}p=e+32|0;q=p;b=XK(Jy(v[b+24>>2]));j=gb-192|0;gb=j;hc(j+144|0,b,44);g=v[b+44>>2];if(g){hc(j+44|0,b,44);c=gb-16|0;gb=c;b=jz(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-jz(1970,1,1)|0;b=nqa(b,b>>31,86400,0);d=B(v[j+52>>2],3600);f=d;b=b+d|0;d=jb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[j+48>>2],60);i=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<i>>>0?b+1|0:b;d=v[j+44>>2];i=d;f=d+f|0;d=(d>>31)+b|0;b=BN(c+8|0,f,f>>>0<i>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];gb=c+16|0;v[j+96>>2]=b;v[j+100>>2]=d;d=j+88|0;r=j+96|0;k=r;b=k;f=v[b>>2];i=v[b+4>>2];c=2147483647;n=ee(+(g>>>0)/18.2);b=-1;t:{if(n>=0x8000000000000000){break t}c=-2147483648;b=0;if(n<=-0x8000000000000000){break t}if(D(n)<0x8000000000000000){c=D(n)>=1?~~(n>0?F(H(n*2.3283064365386963e-10),4294967295):I((n-+(~~n>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~n>>>0;break t}b=0}l=d;d=c+i|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=BN(l,f,d);m=gb-16|0;gb=m;g=v[b>>2];o=v[b+4>>2];v[m+12>>2]=0;v[m+8>>2]=0;v[m+4>>2]=0;b=jz(1970,1,1)+oqa(g,o,86400,0)|0;h=b>>31;c=b;d=nqa(b,h,1e4,0)+14780|0;b=jb;i=d;b=d>>>0<14780?b+1|0:b;f=b;d=oqa(d,b,-14609700,-1);b=c;l=d+b|0;d=h+jb|0;d=b>>>0>l>>>0?d+1|0:d;b=l;l=oqa(i,f,365242500,0);b=b+l|0;d=jb+d|0;d=b>>>0<l>>>0?d+1|0:d;l=oqa(i,f,-146097e4,-1);b=l+b|0;d=jb+d|0;d=b>>>0<l>>>0?d+1|0:d;l=b;b=oqa(i,f,3652425,0);f=jb;s=f;i=l;l=nqa(b,f,-365,-1);i=i+l|0;f=jb+d|0;f=i>>>0<l>>>0?f+1|0:f;d=f;if(!((d|0)>0|(d|0)>=0)){d=s-(b>>>0<1)|0;b=b-1|0;f=nqa(b,d,-365,-1)+c|0;d=h+jb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;i=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=(b|0)/100|0;i=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<i>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;i=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<i>>>0?d+1|0:d;i=f}f=b;c=nqa(i,d,100,0)+52|0;b=jb;b=oqa(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[m+12>>2]=f+d;v[m+8>>2]=(c-B(d,12)|0)+1;b=nqa(b,jb,306,0)+5|0;d=jb;b=oqa(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[m+4>>2]=b+1;v[k+40>>2]=0;v[k+32>>2]=0;v[k+36>>2]=0;v[k+24>>2]=0;v[k+28>>2]=0;v[k+20>>2]=v[m+12>>2]-1900;v[k+16>>2]=v[m+8>>2]-1;b=v[m+4>>2];t=k,u=pqa(oqa(g,o,3600,0),jb,24),v[t+8>>2]=u;v[k+12>>2]=b;b=oqa(g,o,60,0);c=jb;t=k,u=pqa(b,c,60),v[t+4>>2]=u;t=k,u=g-nqa(b,c,60,0)|0,v[t>>2]=u;gb=m+16|0;hc(j+144|0,r,44)}i=hc(j,j+144|0,44);c=i;b=gb-112|0;gb=b;d=Kb(b+96|0);v[22708]=0;f=Q(2,b+80|0,10810)|0;g=v[22708];v[22708]=0;u:{v:{w:{x:{y:{if((g|0)!=1){g=v[c+20>>2];if(!g){break v}v[22708]=0;v[b+48>>2]=g+1900;R(112,b- -64|0,b+48|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;Q(113,d|0,b- -64|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break y}vb(b- -64|0);if(y[c+16>>2]>11){break v}v[22708]=0;g=Q(2,b+48|0,13873)|0;h=v[22708];v[22708]=0;z:{A:{B:{C:{D:{E:{if((h|0)!=1){h=v[c+16>>2];v[22708]=0;v[b+16>>2]=h+1;R(114,b+32|0,b+16|0);h=v[22708];v[22708]=0;if((h|0)==1){break E}v[22708]=0;U(3,b- -64|0,g|0,b+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break D}v[22708]=0;Q(113,d|0,b- -64|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break C}vb(b- -64|0);vb(b+32|0);vb(g);if(v[c+12>>2]-1>>>0<=30){break z}break v}a=P()|0;O()|0;break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}v[22708]=0;g=Q(2,b+48|0,13873)|0;h=v[22708];v[22708]=0;F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((h|0)!=1){v[22708]=0;R(114,b+32|0,c+12|0);h=v[22708];v[22708]=0;if((h|0)==1){break ca}v[22708]=0;U(3,b- -64|0,g|0,b+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break ba}v[22708]=0;Q(113,d|0,b- -64|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break aa}vb(b- -64|0);vb(b+32|0);vb(g);g=v[c+8>>2];h=v[c+4>>2];if(!(v[c>>2]|(g|h))|g>>>0>23|h>>>0>59){break v}v[22708]=0;g=Q(2,b- -64|0,10977)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Z}v[22708]=0;Q(113,d|0,g|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Y}vb(g);if(v[c+32>>2]>=1){v[22708]=0;g=Q(2,b- -64|0,12682)|0;h=v[22708];v[22708]=0;if((h|0)==1){break X}Eb(f,g);vb(g)}v[22708]=0;R(114,b+32|0,c+8|0);g=v[22708];v[22708]=0;if((g|0)==1){break W}v[22708]=0;g=Q(2,b+16|0,11846)|0;h=v[22708];v[22708]=0;if((h|0)==1){break V}v[22708]=0;U(3,b+48|0,b+32|0,g|0);h=v[22708];v[22708]=0;if((h|0)==1){break U}v[22708]=0;R(114,b|0,c+4|0);h=v[22708];v[22708]=0;if((h|0)==1){break T}v[22708]=0;U(3,b- -64|0,b+48|0,b|0);h=v[22708];v[22708]=0;if((h|0)==1){break S}v[22708]=0;Q(113,d|0,b- -64|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break R}vb(b- -64|0);vb(b);vb(b+48|0);vb(g);vb(b+32|0);if(y[c>>2]<62){break M}v[22708]=0;U(115,q|0,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break L}break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;break _}a=P()|0;O()|0;break $}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break N}a=P()|0;O()|0;break O}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(g)}vb(b+32|0);break x}v[22708]=0;g=Q(2,b+48|0,11846)|0;h=v[22708];v[22708]=0;if((h|0)==1){break K}v[22708]=0;R(114,b+32|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break J}v[22708]=0;U(3,b- -64|0,g|0,b+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break I}v[22708]=0;Q(113,d|0,b- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break H}vb(b- -64|0);vb(b+32|0);vb(g);v[22708]=0;Q(113,d|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break v}}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break F}a=P()|0;O()|0;break G}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(b- -64|0)}vb(f)}vb(d);S(a|0);L()}Dc(q,d)}vb(f);vb(d);gb=b+112|0;gb=i+192|0;v[22708]=0;R(2041,a|0,p|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,9459);f=ah(c,d);vb(d);if(f){c=b;d=e+32|0;PS(d,v[b+24>>2]+1298292|0);da:{ea:{fa:{if(!gd(d)){break fa}c=v[c+24>>2];v[22708]=0;c=JO(c);d=v[22708];v[22708]=0;if((d|0)==1){break da}ga:{switch(c|0){case 0:v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 1:v[22708]=0;R(2097,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 2:if(gd(e+32|0)){v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}c=e+16|0;Eb(e+32|0,c);vb(c)}if(!gd(e+32|0)){break fa}v[22708]=0;R(2097,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 3:if(gd(e+32|0)){v[22708]=0;R(2097,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}c=e+16|0;Eb(e+32|0,c);vb(c)}if(!gd(e+32|0)){break fa}v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 4:v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;ha:{ia:{if((c|0)!=1){v[22708]=0;R(2097,e|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break ha}if(gd(e+16|0)){break ia}v[22708]=0;Q(1168,e+32|0,e+16|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break ia}break d}c=P()|0;O()|0;break b}if(!gd(e)){v[22708]=0;Q(1168,e+32|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}}vb(e);vb(e+16|0);break fa}c=P()|0;O()|0;break c;case 5:break ga;default:break fa}}v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;ja:{if((c|0)!=1){v[22708]=0;R(2097,e|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break ea}if(gd(e)){break ja}v[22708]=0;Q(1168,e+32|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break ja}break f}c=P()|0;O()|0;break b}if(!gd(e+16|0)){v[22708]=0;Q(1168,e+32|0,e+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}}vb(e);vb(e+16|0)}v[22708]=0;U(2094,a|0,b|0,e+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break da}vb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Tb(e+32|0,2564);f=ah(c,d);vb(d);if(f){c=e+32|0;PS(c,v[b+24>>2]+1298292|0);v[22708]=0;U(2094,a|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}i=c;c=Tb(e+32|0,4379);d=ah(i,c);vb(c);if(d){a=Kb(a);b=b+68|0;t=e,u=Vb(b),v[t+32>>2]=u;t=e,u=Zb(b),v[t+16>>2]=u;if(!Gb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[22708]=0;Q(1919,a|0,18696)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}}v[22708]=0;Q(1168,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}b=e+32|0;v[b>>2]=v[b>>2]+12;c=0;if(Gb(b,e+16|0)){continue}break}break k}Tb(a,18726)}gb=e+48|0;return}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;vb(a);break a}c=P()|0;O()|0;vb(e)}vb(e+16|0);break b}c=P()|0;O()|0;vb(e)}vb(e+16|0)}vb(e+32|0)}S(c|0);L()}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=gb-352|0;gb=e;vc(b);f=e+328|0;g=QD(b,f);if(!g){Wv(f)}a:{b:{c:{d:{e:{f:{g:{if(!g){break g}if(!YX(e+328|0)){break g}if(!Pb(b,Qc(72,0))){break g}if(!c){d=1;break g}Hd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;d=w[e+337|0];u[a+480190>>1]=63;u[a+480188>>1]=d;h:{if(d){d=0;while(1){eu(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}if(!x[a+480190>>1]){break h}}d=1;f=1;while(1){g=(B(d,104)+a|0)+484380|0;ud(g,1);h=(e+256|0)+d|0;d=Ae(b);t[h|0]=d;if(d<<24>>24>=0){C=g,D=VX(b)<<1,v[C>>2]=D}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}_D(b,a+1298268|0,-1);g=e+248|0;f=gb-32|0;gb=f;d=b;i:{if(!Pb(d,8)){t[f+16|0]=0;oi(g,8,f+16|0);break i}es(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;kd(f+16|0,d,f+8|0)}gb=f+32|0;m=mc(e+232|0);j:{if(w[e+338|0]|w[e+339|0]<<8){f=w[e+338|0]|w[e+339|0]<<8;g=w[e+337|0];d=0;v[22708]=0;f=W(498,b|0,m|0,B(f,g)<<1)|0;g=v[22708];v[22708]=0;if((g|0)==1){f=P()|0;O()|0;break a}if(!f){break j}}kn(e+224|0,v[m>>2],oc(m)>>>1|0);l=mc(e+208|0);k:{l:{m:{n:{o:{p:{if(!(w[e+340|0]|w[e+341|0]<<8)){break p}d=w[e+340|0]|w[e+341|0]<<8;f=0;v[22708]=0;R(499,l|0,d<<8);d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!(w[e+340|0]|w[e+341|0]<<8)){break p}while(1){v[e+136>>2]=(w[e+340|0]|w[e+341|0]<<8)-f;v[22708]=0;v[e+160>>2]=2e3;d=pd(e+136|0,e+160|0);g=v[22708];v[22708]=0;q:{if((g|0)!=1){g=v[d>>2];d=mc(e+136|0);v[22708]=0;g=W(498,b|0,d|0,g<<8)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(g){break q}gc(d);d=0;break k}f=P()|0;O()|0;break b}C=e,D=Zb(l),v[C+160>>2]=D;Gd(e+200|0,e+160|0);g=Vb(d);h=Zb(d);v[22708]=0;Y(500,l|0,v[e+200>>2],g|0,h|0);g=v[22708];v[22708]=0;if((g|0)==1){break c}gc(d);f=f+2e3&65535;if(f>>>0<(w[e+340|0]|w[e+341|0]<<8)>>>0){continue}break}}v[22708]=0;Ud(e+184|0,l);d=v[22708];v[22708]=0;if((d|0)==1){break m}d=v[e+188>>2];v[e+64>>2]=v[e+184>>2];v[e+68>>2]=d;rh(e+192|0,e- -64|0);p=a+484360|0;d=Sb(p);f=w[e+338|0]|w[e+339|0]<<8;v[22708]=0;R(502,d|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}if(!(w[e+338|0]|w[e+339|0]<<8)){break l}q=a+484344|0;s=c&1;h=0;while(1){r:{C=sc(Sb(p),h),D=h,u[C>>1]=D;s:{if(!s){break s}v[22708]=0;r=h&65535;d=W(331,q|0,r|0,64)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}k=0;f=x[a+480188>>1];if(!(d&(f|0)!=0)){break s}while(1){d=sc(e+224|0,B(f&65535,h)+k|0);f=w[d|0]|w[d+1|0]<<8;t:{if(f>>>0>=(w[e+340|0]|w[e+341|0]<<8)>>>0){f=x[a+480188>>1];break t}d=_b(q,h);v[22708]=0;d=Yc(d,0,k&65535);g=v[22708];v[22708]=0;if((g|0)==1){break n}i=0;y=0-k|0;z=f<<8;while(1){f=e+136|0;wd(f,v[e+192>>2]+((i<<2)+z|0)|0,4);n=w[lc(f,0)|0]&63;t[d|0]=n?n+48|0:0;g=lc(f,0);C=d,D=w[lc(f,1)|0]<<2&60|w[g|0]>>>6,t[C+1|0]=D;g=w[lc(f,1)|0];o=w[lc(f,2)|0];A=lc(f,2);j=w[lc(f,3)|0];f=j<<4|w[A|0]>>>4;u[e+182>>1]=f;g=o<<2&60|g>>>6;u:{if(!(w[ic(e+248|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break u}t[d+5|0]=f;t[d+3|0]=g;o=j>>>4|0;t[d+4|0]=o;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;v[22708]=0;Of(d);f=v[22708];v[22708]=0;if((f|0)==1){break G}if(!w[d+4|0]){break u}t[d+2|0]=g>>>0<32?3:4;break u;case 3:case 4:case 5:case 6:case 7:case 12:v[22708]=0;Of(d);f=v[22708];v[22708]=0;if((f|0)==1){break G}break u;case 9:t[d+3|0]=10;C=d,D=ei(f>>>1|0),t[C+5|0]=D;break u;case 50:break w;case 48:break x;case 43:break y;case 47:break z;case 17:case 18:case 26:case 27:break A;case 22:case 25:case 28:case 29:case 30:break B;case 16:case 19:case 20:case 21:case 23:case 31:break C;case 13:break D;case 11:case 15:break E;case 10:case 42:break H;default:break v}}if(f>>>0>254){break F}t[d+3|0]=g&15;v[22708]=0;Of(d);f=v[22708];v[22708]=0;if((f|0)!=1){break u}}f=P()|0;O()|0;break b}t[d+3|0]=19;t[d+5|0]=o|(g>>>0<32?16:32);g=j&15;if(g){t[d+2|0]=3;t[d+4|0]=g;break u}t[d+2|0]=4;t[d+4|0]=f&15;break u}t[d+3|0]=(g|0)==11?12:16;C=d,D=Fv(f),t[C+5|0]=D;break u}t[d+3|0]=14;if((f&255)>>>0<64){break u}t[d+5|0]=0;break u}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break u}t[d+3|0]=19;v[22708]=0;u[e+160>>1]=15;f=Pc(e+182|0,e+160|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[d+5|0]=w[f|0]|g<<4;break u}f=P()|0;O()|0;break b}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(j&240)){break u}t[d+2|0]=g>>>0>25?6:5;break u}t[d+5|0]=o|(g>>>0>25?-80:-96);break u}if(!f){break v}t[d+3|0]=17;v[e+160>>2]=8;v[22708]=0;v[e+176>>2]=f+4;f=Hf(e+160|0,e+176|0);g=v[22708];v[22708]=0;if((g|0)!=1){C=d,D=ei(v[f>>2]/8|0),t[C+5|0]=D;break u}f=P()|0;O()|0;break b}t[d+3|0]=14;g=x[a+480188>>1];if(!g){break u}n=B(y,6)+d|0;f=0;while(1){j=n+B(f,6)|0;if(!w[j+3|0]){t[j+3|0]=12;C=j,D=Fv(r),t[C+5|0]=D;g=x[a+480188>>1]}f=f+1|0;if(g>>>0>f>>>0){continue}break}break u}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+28585|0];break u}g=f>>>4|0;if((g|0)==128){break v}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break u}t[d+5|0]=g^-1;break u}t[d+5|0]=0;t[d+3|0]=0;if(!n){t[d|0]=255;break u}t[d+3|0]=25;break u}t[d+3|0]=0}f=x[a+480188>>1];d=B(f,6)+d|0;i=i+1|0;if((i|0)!=64){continue}break}}k=k+1|0;if(k>>>0<(f&65535)>>>0){continue}break}}h=h+1|0;if(h>>>0<(w[e+338|0]|w[e+339|0]<<8)>>>0){continue}break l}break}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(x[a+480190>>1]){k=c&2;d=1;f=1;while(1){v[22708]=0;c=w[(e+256|0)+d|0];W(503,b|0,((d<<5)+a|0)+946304|0,c&63)|0;g=v[22708];v[22708]=0;I:{J:{K:{L:{M:{N:{if((g|0)!=1){if(c<<24>>24<=-1){break I}v[22708]=0;g=T(504,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}c=B(d,104)+a|0;d=c+484392|0;v[d>>2]=g<<1;v[22708]=0;g=T(504,b|0)|0;h=v[22708];v[22708]=0;O:{if((h|0)!=1){g=g<<1;if(g>>>0>=3){v[c+484396>>2]=g+v[d>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22708]=0;d=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break O}break d}f=P()|0;O()|0;break b}u[c+484410>>1]=d<<2;v[22708]=0;d=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}t[c+484417|0]=d<<4;c=c+484380|0;if(!v[c>>2]){break I}v[22708]=0;h=T(374,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break L}d=0;P:{Q:{R:{S:{switch(h|0){case 0:if(!k){break Q}g=mc(e+160|0);h=v[c>>2];v[22708]=0;h=Q(191,b|0,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break N}if(!h){break R}d=v[c>>2];v[22708]=0;W(505,b|0,g|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break N}C=e,D=Vb(g),v[C+136>>2]=D;C=e,D=Zb(g),v[C+176>>2]=D;if(Gb(e+136|0,e+176|0)){break M}break K;case 1:g=mc(e+160|0);d=v[c>>2];v[22708]=0;U(506,e+136|0,b|0,d|0);d=v[22708];v[22708]=0;T:{U:{V:{W:{if((d|0)!=1){d=e+136|0;np(g,d);gc(d);if(!k){break V}v[22708]=0;Ud(e+112|0,g);d=v[22708];v[22708]=0;if((d|0)!=1){d=Td(e+104|0);v[22708]=0;h=v[e+116>>2];v[e+40>>2]=v[e+112>>2];v[e+44>>2]=h;h=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=h;d=W(507,e+136|0,e+40|0,e+32|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break W}}f=P()|0;O()|0;break T}f=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break T}Z(f|0)|0;d=0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){break P}f=P()|0;O()|0;break T}h=Rc(e+176|0,8,1,0,2);v[22708]=0;W(329,h|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break U}xb(e+136|0)}gc(g);break I}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b;case 2:case 3:if(k){d=Rc(e+136|0,(h|0)==2?8:16,1,0,0);v[22708]=0;W(329,d|0,c|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break I}f=P()|0;O()|0;break b}c=v[c>>2];v[22708]=0;Q(318,b|0,B(c,h-1|0)|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break I}break L;case 4:case 5:break S;default:break k}}g=mc(e+160|0);d=v[c>>2];v[22708]=0;U(508,e+136|0,b|0,d|0);d=v[22708];v[22708]=0;X:{Y:{Z:{if((d|0)!=1){d=e+136|0;np(g,d);gc(d);if(k){_:{if((h|0)!=5){break _}C=e,D=Vb(g),v[C+136>>2]=D;C=e,D=Zb(g),v[C+176>>2]=D;if(!Gb(e+136|0,e+176|0)){break _}while(1){d=e+136|0;j=v[d>>2];i=zb(w[j|0]);C=j,D=zb((i^w[(i>>>7|0)+28593|0])&255),t[C|0]=D;Oe(d);if(Gb(d,e+176|0)){continue}break}}v[22708]=0;Ud(e+96|0,g);d=v[22708];v[22708]=0;if((d|0)==1){break Z}d=Td(e+88|0);v[22708]=0;i=v[e+100>>2];v[e+56>>2]=v[e+96>>2];v[e+60>>2]=i;i=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=i;d=W(507,e+136|0,e+56|0,e+48|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Z}h=(h|0)==5;h=Rc(e+176|0,h?16:8,1,0,h?16:1);v[22708]=0;W(329,h|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Y}xb(e+136|0)}gc(g);break I}f=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break X}Z(f|0)|0;d=0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){f=P()|0;O()|0;break X}gc(g);break k}f=P()|0;O()|0;break X}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}gc(g);break k}c=v[c>>2];v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break L}break I}gc(g);break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break J}while(1){d=e+136|0;i=v[d>>2];h=zb(w[i|0]);C=i,D=zb((h<<7|(h^-1)<<24>>>25)&255),t[C|0]=D;Oe(d);if(Gb(d,e+176|0)){continue}break}break K}f=P()|0;O()|0;break b}v[22708]=0;Ud(e+128|0,g);d=v[22708];v[22708]=0;$:{aa:{if((d|0)==1){break aa}d=Td(e+120|0);v[22708]=0;h=v[e+132>>2];v[e+24>>2]=v[e+128>>2];v[e+28>>2]=h;h=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=h;d=W(507,e+136|0,e+24|0,e+16|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break aa}h=Rc(e+176|0,16,1,0,16);v[22708]=0;W(329,h|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break $}xb(e+136|0);gc(g);break I}f=P()|0;O()|0;break J}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}ba:{ca:{da:{ea:{fa:{ga:{ha:{d=w[e+342|0]|w[e+343|0]<<8|w[e+344|0]<<16;if(d){c=mc(e+160|0);v[22708]=0;b=W(498,b|0,c|0,d|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}if(!b){break fa}v[22708]=0;Ud(e+80|0,c);b=v[22708];v[22708]=0;if((b|0)==1){break ha}b=Td(e+72|0);v[22708]=0;f=v[e+84>>2];v[e+8>>2]=v[e+80>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=W(507,e+136|0,e+8|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ha}v[22708]=0;da(509,a+1298292|0,b|0,d|0,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ga}xb(b);gc(c)}v[22708]=0;_(510,e+160|0);b=v[22708];v[22708]=0;if((b|0)==1){break ea}v[22708]=0;U(316,e+136|0,e+160|0,e+336|0);b=v[22708];v[22708]=0;if((b|0)==1){break da}b=e+136|0;Eb(a+1298304|0,b);vb(b);Hb(e+160|0);v[22708]=0;b=Q(2,b|0,7366)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ca}Eb(a+1298316|0,b);vb(b);v[22708]=0;b=Q(2,e+136|0,2197)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ba}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;d=1;break k}f=P()|0;O()|0;break e}f=P()|0;O()|0;xb(b);break e}gc(c);d=0;break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;Hb(e+160|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}gc(l)}gc(m)}gb=e+352|0;return d|0}f=P()|0;O()|0}gc(c);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;gc(d)}gc(l)}gc(m);S(f|0);L()}function sfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=gb-48|0;gb=g;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Rf(a+1074312|0,0)}b=g+32|0;j=a+1074312|0;Db(b,j,0);if(Cb(b)){q=(v[a+480180>>2]&16777248)!=0}b=g+32|0;Db(b,j,0);if(Cb(b)){E=v[a+480180>>2]==4}l=a+1074308|0;b=v[l>>2];if(b>>>0<=18874367){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;F=b,G=v[Fb(g+32|0,g+16|0)>>2],t[F+20|0]=G;c:{d:{e:{if(q){e=v[l>>2];if(e>>>0>18350079){break b}k=t[b+26|0];t[b+26|0]=(((k|0)>-1?1:-1)+k|0)/2;if(e>>>0<18285314){break e}break d}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2}HS(ki(b,2),4,v[a+480180>>2]);e=v[a+1074308>>2];if(e>>>0<18284544){break c}if(e>>>0>18285135){break b}if(!w[b+34|0]){break d}if(!Ij(b)){break d}Ob(j,2,1)}if(y[l>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Ob(j,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}f:{if(!(v[a+480180>>2]&16777248)){break f}b=1;if(!x[a+480190>>1]|y[l>>2]>=18285314&q){break f}while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;d=TS(b);if((d|0)!=(b|0)){while(1){b=c;h=b+32|0;while(1){e=w[b|0];g:{h:{if((e-97&255)>>>0<=5){k=e-32|0;break h}k=99;i:{if(e>>>0<=106){if(e-88>>>0<2){break i}if((e|0)==75){break h}break g}if(e-120>>>0<2){break i}if((e|0)==107){break h}break g}k=122}t[b|0]=k}b=b+1|0;if((h|0)!=(b|0)){continue}break}c=c+32|0;if((d|0)!=(c|0)){continue}break}}b=v[a+1074308>>2]}j:{if(!x[a+480192>>1]|(!(v[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895))){break j}b=1;c=0;while(1){k:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break k}break j}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Ob(j,3,1)}b=v[l>>2];l:{if(!(v[a+480180>>2]&16777248)|(b>>>0>19006225|(b|0)==19005440)){break l}b=g+32|0;Db(b,j,0);if(!Cb(b)){b=g+16|0;Db(b,j,1);if(!Cb(b)){break l}}if(!x[a+480192>>1]){break l}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}m:{n:{o:{if(y[l>>2]<=19007232){c=a+946300|0;b=a+906300|0;while(1){e=g+16|0;k=b+80|0;PO(e,k);v[22708]=0;Y(360,g+32|0,0,8,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break n}vb(g+16|0);v[22708]=0;Ir(k,g+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}vb(g+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}p:{q:{r:{s:{if(v[a+480180>>2]!=4){break s}b=v[l>>2];if(b>>>0<19007257){break q}if(b>>>0>19071235){break r}if(w[a+1074368|0]!=4){break s}jA(a,5)}b=v[l>>2]}if((b|0)==19202048|b>>>0>19202054){break p}}if(!x[a+480192>>1]){break p}c=1;while(1){k=(((c&65535)<<2)+a|0)+900380|0;b=v[k>>2];t:{if(!b|!w[b+20|0]|!w[b+31|0]){break t}b=b+236|0;e=Lu(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break t}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[k>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[l>>2];if(b>>>0<=19267583){if(x[a+480192>>1]){b=1;e=!q;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];u:{if(!c){break u}k=t[c+26|0];t[c+26|0]=(((k|0)>-1?1:-1)+k|0)/2;if(!(e|y[l>>2]<18350080)){break u}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[l>>2]}v:{if(!x[a+480192>>1]|b>>>0>19398673){break v}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Ob(j,94,1);break v}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}w:{if(!x[a+480192>>1]|y[l>>2]>19399427){break w}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Ob(j,101,1);break w}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=gb-16|0;gb=b;u[g+12>>1]=0;v[g+8>>2]=a;c=b+8|0;Db(c,a+1074312|0,0);F=g,G=Cb(c),t[F+14|0]=G;gb=b+16|0;b=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=b;c=gb-16|0;gb=c;o=a+484344|0;k=Te(o);b=v[g+4>>2];e=v[g>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=gb-32|0;gb=e;D=k-1&65535;x:{if(Te(o)>>>0>D>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(ii(bf(o,b))){d=Vb(bf(o,b));h=Zb(bf(o,b));b=e;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;k=b+8|0;m=gb-16|0;gb=m;v[m>>2]=h;v[m+8>>2]=d;if(Gb(m+8|0,m)){while(1){A=m+8|0;d=v[A>>2];C=gb-16|0;gb=C;b=k;n=x[b+4>>1];h=n+1|0;u[b+4>>1]=h;if(x[v[b>>2]+480188>>1]<=(h&65535)>>>0){u[b+4>>1]=0}y:{if(Bg(d)){break y}f=v[b>>2];h=v[f+1074308>>2];p=v[f+480180>>2];z:{A:{B:{if((p|0)==2){if(w[d+3|0]!=23|h>>>0>18415615){break B}zf(d+5|0,64);break A}if(p&16777248){C:{D:{if(h>>>0>=18285314){if(w[b+6|0]){break D}f=0;i=0;if(h>>>0>18874367){break C}}E:{switch(w[d+3|0]-20|0){case 3:zf(d+5|0,128);break D;case 0:break E;default:break D}}f=w[d+5|0];if((f|0)!=208){if((f|0)!=192){break D}t[d|0]=254;t[d+3|0]=0;break D}t[d+3|0]=0}F:{G:{H:{if(h>>>0>=18350080){if(w[b+6|0]){break H}f=0;i=0;if(h>>>0>18874367){break C}}i=w[d+3|0];if(i>>>0>29){break G}f=1;if(!(1<<i&536873152)){break G}break F}f=0;i=0;if(h>>>0>18874367){break C}i=w[d+3|0]}f=0}i=(i|0)==24|(i|0)==22}I:{if(!(i?1:f)){break I}i=w[d+5|0];f=i&15;if(!f|(f|0)==15){break I}i=i&240;if(!i|(i|0)==240){break I}t[d+5|0]=w[d+3|0]==24?i:f}if(!(!x[v[b>>2]+480192>>1]|((h|0)==19005440|h>>>0>19005699)|(w[b+6|0]|x[v[b>>2]+480192>>1]>=w[d+1|0]))){t[d+4|0]=0;t[d+2|0]=1}if(w[d+3|0]!=18|w[d+5|0]!=17){break B}if(h>>>0>19468801){break z}f=C+8|0;Db(f,v[b>>2]+1074312|0,22);if(!Cb(f)|v[v[b>>2]+480208>>2]&4){break B}t[d+5|0]=0;break B}if((p|0)!=4){break B}f=w[b+6|0];if(!((!f|h>>>0<18285314)&h>>>0<=18874367|h>>>0>19137025|w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}J:{K:{L:{if(!(f|h>>>0>18874367?h>>>0>=18415616:0)){i=w[d+3|0];f=w[d+2|0];if((i|0)!=10|(f|0)!=11){break L}t[d+3|0]=0;break J}if(h>>>0>18874639){break K}i=w[d+3|0];f=w[d+2|0]}if((f|0)!=11|(i|0)!=4){break J}f=w[d+4|0];if(!(f|w[b+6|0])){break J}i=w[d+5|0];if(!i){break J}t[d+2|0]=0;F=d,G=Fv(i+(f<<4)|0),t[F+5|0]=G;break J}if(h>>>0>19007240){break z}}if(w[d+5|0]|w[d+3|0]!=16){break B}t[d+3|0]=0}if(h>>>0>18874367){break z}}M:{N:{O:{f=w[d+3|0];i=w[d+5|0]&240;if((f|0)!=28|(i|0)!=96){b=0}else{if(!w[b+6|0]|(p|0)!=4){break O}b=h>>>0<18350080}if(!(b|(f|0)==20&(i|0)==96)|!n){break M}break N}if(!n){break z}}b=d+B(n,-6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}f=w[d+3|0]}if(!n|((f|0)!=20|(i|0)!=224)){break z}b=d+B(n,-6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}b=w[d+2|0];if((b|0)==8){if((h|0)==19333120|h>>>0>19333174){break y}h=w[d+4|0];b=w[d+3|0];if(!(!h|(b|0)!=7)){t[d+3|0]=11;break y}P:{Q:{switch(b-5|0){default:if((b|0)!=26){break y}break;case 1:break y;case 2:break P;case 0:break Q}}f=w[d+5|0];if(!(f&15)){t[d+3|0]=5;t[d+5|0]=f|h&15;break P}R:{switch(b-5|0){case 1:break y;case 0:case 2:break P;default:break R}}if((b|0)!=26){break y}}t[d+2|0]=0;break y}if(!(w[d+3|0]|((p|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break y}if(w[d+3|0]!=10|h>>>0>19922963|(b|0)!=15){break y}if(w[d+4|0]?w[d+5|0]:1){t[d+2|0]=0;break y}t[d+3|0]=0}gb=C+16|0;$j(A);if(Gb(A,m)){continue}break}}b=v[k+4>>2];v[e+16>>2]=v[k>>2];v[e+20>>2]=b;gb=m+16|0}z=z+1|0;if((z&65535)>>>0<=D>>>0){continue}break}v[g+32>>2]=r;v[g+36>>2]=s;break x}k=v[b+4>>2];v[g+32>>2]=v[b>>2];v[g+36>>2]=k}gb=e+32|0;gb=c+16|0;b=v[a+1074308>>2];c=b>>>0<19267584;S:{if(c&q){Ob(j,8,(b|0)==18284544|b>>>0>18285313);b=48232;while(1){c=v[l>>2];e=v[b+4>>2];Ob(j,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=48568){continue}break}break S}if(!(c&E)){break S}Ob(j,8,b>>>0>18285313);b=48584;while(1){Ob(j,v[b>>2],y[l>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=48816){continue}break}}T:{if(v[a+480180>>2]&16777248){b=48816;while(1){c=v[l>>2];e=v[b+4>>2];k=e&-65536;if(!(c>>>0>=k>>>0&(c>>>0<=k>>>0|c>>>0>=e>>>0))){Rf(j,v[b>>2])}b=b+8|0;if((b|0)!=48864){continue}break}break T}if(v[a+480180>>2]==4){b=48864;while(1){if(y[l>>2]<y[b+4>>2]){Rf(j,v[b>>2])}b=b+8|0;if((b|0)!=48928){continue}break}break T}if(v[a+480180>>2]!=2){break T}b=48928;while(1){if(y[l>>2]<y[b+4>>2]){Rf(j,v[b>>2])}b=b+8|0;if((b|0)!=49016){continue}break}}U:{if(v[a+480180>>2]==4){b=v[l>>2];if(b>>>0>18415615){break U}Ob(j,98,1)}b=v[l>>2]}if(b-19333159>>>0<=33){b=0;while(1){c=g+32|0;e=b+77|0;Db(c,j,e);Ob(j,b+86|0,Cb(c));Rf(j,e);b=b+1|0;if((b|0)!=5){continue}break}b=v[l>>2]}c=8;V:{if(b>>>0>=18284544){if(b>>>0>18874627){break V}c=6;if((b|0)==18874368){break V}}Ob(j,c,1);b=v[l>>2]}W:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Rf(j,7);break W}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break W}Ob(j,7,1);break W}if((b|0)==19922944|b>>>0>19922997){break W}Rf(j,7)}b=g+32|0;Db(b,j,31);X:{if(!Cb(b)){break X}b=v[l>>2];if(!x[a+480192>>1]|(b>>>0<19071234|b>>>0>19398722)){break X}b=1;while(1){Y:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break Y}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break Y}Ob(j,97,1);break X}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}Z:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break Z}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break Z}break}_:{$:{aa:{if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216)){b=v[l>>2];if(b>>>0<19398688){break $}if(b>>>0>19464277){break aa}Ob(j,109,1)}b=v[l>>2]}if((b|0)==19922944|b>>>0>19922996){break _}}Rf(j,111)}if(!(v[a+480180>>2]!=2|y[a+1074308>>2]>19464191)){Ob(j,108,1);break Z}if(v[a+480180>>2]==2){break Z}Rf(j,108)}ba:{if(!(!(v[a+480180>>2]&16777252)|v[l>>2]-19333186>>>0>589827)){c=a+946300|0;a=a+906300|0;while(1){ca:{if((w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))!=1146637647|(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))!=-271958638){break ca}if((oc(a+4|0)|0)!=32){break ca}b=Tb(g+32|0,13926);v[22708]=0;Ir(a+80|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break ba}vb(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}gb=g+48|0;return}a=P()|0;O()|0;vb(b);break m}a=P()|0;O()|0;vb(g+32|0);break m}a=P()|0;O()|0;vb(g+16|0)}S(a|0);L()}function d_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;p=Gh(b,11134);a:{if(!p){break a}if(!Pb(b,6)){break a}while(1){b:{l=sg(b);c:{if((l|0)==(An(10984)|0)){break c}i=w[18702]|w[18703]<<8|(w[18704]<<16|w[18705]<<24);if(!(l&1616928864)|l&-2139062144){break c}if((i|0)!=(l|0)){break b}}pg(b,4);break a}m=1;r=Ng(b);if(x[a+480192>>1]){while(1){j=v[(((m&65535)<<2)+a|0)+900380>>2];if(j){d:{i=r;n=b;q=l;if((An(13829)|0)==(l|0)){Rb(n,i);break d}e=q;c=i;d=n;g=0;h=gb-48|0;gb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+23|0]=z;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+18|0]=z;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=ow(d,c),v[s>>2]=z;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+21|0]=z;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break F}s=vd(e,d),z=f,u[s>>1]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+31|0]=z;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+34|0]=z;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+16|0]=z;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+24>>2]=240;s=h,z=wp(d,c),v[s>>2]=z;kh(f+68|0,v[Fb(h+24|0,h)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,1);f=v[22708];v[22708]=0;if((f|0)==1){break k}if(Nb(e)){while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break k}s=Mb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+82|0]=z;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+27|0]=z;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,1);f=v[22708];v[22708]=0;if((f|0)==1){break h}if(Nb(e)){while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}s=Mb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+83|0]=z;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}s=f,z=B(nw(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[s+40>>2]=z;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+36|0]=z;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,2);f=v[22708];v[22708]=0;if((f|0)==1){break l}if(Nb(e)){while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}s=Mb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,2);f=v[22708];v[22708]=0;if((f|0)==1){break i}if(Nb(e)){while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break i}s=Mb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+24|0]=z;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,0);f=v[22708];v[22708]=0;if((f|0)==1){break j}if(Nb(e)){while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break j}s=Mb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+62|0]=z;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,0);f=v[22708];v[22708]=0;if((f|0)==1){break g}if(Nb(e)){while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break g}s=Mb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+63|0]=z;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+15|0]=z;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}Sd(h,d,c);k=kc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22708]=0;g=T(310,k|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break E}v[22708]=0;R(311,e|0,g|0);g=v[22708];v[22708]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22708]=0;Q(301,f+492|0,e|0)|0;c=v[22708];v[22708]=0;g=1;if((c|0)==1){break E}vb(e);xb(k);break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=ow(d,c),v[s+4>>2]=z;g=1;break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=ow(d,c),v[s+8>>2]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+61|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f- -64|0,z=xd(d,c),t[s|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+81|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+84|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+101|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+102|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+103|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+104|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+17|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+19|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+20|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+22|0]=z;g=1;break n}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=QE(d,c),u[s+28>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+30|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=PE(d,c),t[s+26|0]=z;g=1;break n}if(c>>>0>128){break n}e=f+108|0;Sd(h,d,c);c=kc(h+24|0,h);xb(h);d=0;while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break p}s=ic(e,d),z=f,t[s|0]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;vb(e);xb(k);break f}if(c>>>0>32){break n}Sd(h,d,c);k=kc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22708]=0;g=T(310,k|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break m}v[22708]=0;R(311,e|0,g|0);g=v[22708];v[22708]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22708]=0;Q(301,f+524|0,e|0)|0;c=v[22708];v[22708]=0;g=1;if((c|0)!=1){vb(e);xb(k);break n}break m}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=QE(d,c),u[s+12>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+25|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+35|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+105|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+85|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+65|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+100|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+80|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+60|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=PE(d,c),t[s+33|0]=z;g=1;break n}g=1;c=wp(d,c);if(!up(c)){break n}t[f+14|0]=c;break n}v[h+24>>2]=240;s=h,z=wp(d,c),v[s>>2]=z;kh(f+48|0,v[Fb(h+24|0,h)>>2]);g=1;break n}v[h+24>>2]=240;s=h,z=wp(d,c),v[s>>2]=z;kh(f+88|0,v[Fb(h+24|0,h)>>2]);g=1;break n}d=P()|0;O()|0;xb(c);break f}c=nw(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}gb=h+48|0;break e}d=P()|0;O()|0;vb(e);xb(k);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c)}S(d|0);L()}if(!g){Rb(n,i);break d}if((An(13834)|0)==(q|0)){i=w[j+15|0];t[j+15|0]=0;t[j+100|0]=w[j+100|0]&224|(i>>>5&4|i>>>6&1);t[j+60|0]=i>>>1&2|(i<<1&4|(w[j+60|0]&240|i&1));t[j+80|0]=w[j+80|0]&240|(i>>>4&2|(i>>>2&4|i>>>3&1))}}}m=m+1|0;if(x[a+480192>>1]>=(m&65535)>>>0){continue}break}}if(Pb(b,6)){continue}break}}return p|0}function Ppa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=gb+-64|0;gb=f;vc(a);a:{b:{if(b>>>0<=2){b=f+56|0;C=b,D=Ae(a),t[C|0]=D;Rb(a,2);e=b|2;g=Ng(a);t[e|0]=g;t[e+1|0]=g>>>8;b=b|4;e=sg(a);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;break b}Br(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{m=d+484344|0;b=f+56|2;s=Fd(w[b|0]|w[b+1|0]<<8,1,1024);l=kz(m,s,0);if((l|0)!=65535){g=Tf(_b(m,l),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];y=x[Pc(f,f+40|0)>>1];e=y+1|0;if(x[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){t[g+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Mv(f+40|0,e,f);if(s){b=(b|0)!=0;while(1){d:{e:{f:{if(!w[lc(o,0)|0]){v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}e=e<<24>>24;if((e|0)<=-1){v[22708]=0;g=T(374,a|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}C=lc(o,0),D=g,t[C|0]=D}t[f|0]=0;g:{e=e&63;if(!e){break g}v[22708]=0;j=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f|0]=j;h:{i:{switch(e-1|0){case 0:t[c+12|0]=0;v[22708]=0;t[f+36|0]=1;b=qf(f+36|0,f);e=v[22708];v[22708]=0;if((e|0)!=1){t[c+14|0]=w[b|0];t[c+15|0]=0;break h}break c;case 1:if(!j){break g}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break h}t[c+14|0]=B(B(b,j),15);break h;case 2:t[c+13|0]=j>>>4;if(j>>>0<16){break f}b=w[c+12|0];j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b){break e}break d;case 3:p=0;v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d;case 5:if(!j){break g}e=(w[c+12|0]?15:14)+c|0;b=w[e|0];t[e|0]=b>>>0<256-j>>>0?b+j|0:-1;break h;case 6:break i;default:break g}}if(!j){break g}e=(w[c+12|0]?15:14)+c|0;b=w[e|0];t[e|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[f+36>>2]=0;v[f+32>>2]=0;break e}j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}j=0;e=lc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(!(b&1)){break d}break e}j=0;t[c+12|0]=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}b=w[c+13|0];e=w[c+12|0];if(e){p=0;if(!b){break d}}j:{if(e){v[f>>2]=1;e=w[c+15|0];v[22708]=0;v[f+28>>2]=B(b,e)<<1;b=Hf(f,f+28|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[b>>2];break j}e=B(w[c+14|0],30)+30|0}b=255;k:{while(1){g=B(b,e);if(g-1536>>>0<10752){e=g;break k}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(e|0)/48;Yd(f+32|0,32,255);v[22708]=0;v[f>>2]=1;b=Hf(f,f+36|0);e=v[22708];v[22708]=0;if((e|0)!=1){t[c+16|0]=v[b>>2];p=1;break d}break c}b=_b(m,l);v[22708]=0;b=Yc(b,k,1);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(y){z=k-1|0;h=1;q=1;while(1){l:{m:{n:{o:{if(!w[lc(o,h)|0]){v[22708]=0;i=T(374,a|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(i&128){v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}C=lc(o,h),D=e,t[C|0]=D}A=1;if(i&64){v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[b+1|0]=e;A=!e}if(!(i&32)){e=w[b|0];break o}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[b|0]=e;if((e-1&255)>>>0<=107){e=on(e+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C+1|0]=D;break o}if((e+127&255)>>>0<=107){e=on((e&127)+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C|0]=D;t[b|0]=0;break n}if((e|0)!=255){break o}t[b|0]=254;break m}e=lc(o,h);t[e|0]=w[e|0]-1;break l}if(e&255){break m}}if(!w[b+1|0]){break m}e=w[ad(c,h)+1|0];t[b+1|0]=0;t[b|0]=e}v[22708]=0;e=ce(b);g=v[22708];v[22708]=0;if((g|0)==1){break c}if(e){C=ad(c,h),D=0,t[C+5|0]=D}t[f+28|0]=0;t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;if(i&16){t[b+2|0]=1;v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[b+4|0]=e+2>>>2}p:{if(!(i&8)){break p}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[22708]=0;t[f+28|0]=e;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+25|0]=e;q:{r:{s:{t:{u:{v:{w:{x:{g=w[f+28|0];switch(g-1|0){case 0:break r;case 9:break s;case 5:case 6:case 7:case 8:break t;case 4:break u;case 3:break v;case 2:break w;case 1:break x;default:break q}}t[b|0]=255;break q}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break q}e=Lv(e,w[c+16|0]);t[f+25|0]=e;y:{if(e){t[f+28|0]=20;t[f+25|0]=e|208;break y}t[f+28|0]=0}if(w[b|0]){break p}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break p}t[f|0]=1;e=Lv(e,w[c+16|0]);v[22708]=0;t[f+22|0]=e;e=qf(f,f+22|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[f+25|0]=w[e|0];t[f+28|0]=15;C=ad(c,h),D=0,t[C+5|0]=D;break p}break c}z:{if(!k){break z}if((g|0)==w[ad(c,h)+4|0]){break z}e=_b(m,l);v[22708]=0;g=Be(f,20,(w[f+28|0]+122|160)&255);n=v[22708];v[22708]=0;if((n|0)==1){break c}g=pp(op(Ue(g,z),q&65535));v[22708]=0;e=Q(431,e|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!e){break z}C=ad(c,h),D=w[f+28|0],t[C+4|0]=D}t[f+28|0]=10;if(!w[b|0]){C=b,D=w[ad(c,h)+1|0],t[C|0]=D}C=ad(c,h),D=0,t[C+5|0]=D;break p}t[f+28|0]=20;C=f,D=w[ad(c,h)+5|0]?-98:-97,t[C+25|0]=D;e=ad(c,h);t[e+5|0]=w[e+5|0]^1;break p}t[b|0]=254}t[f+28|0]=0}n=0;e=0;A:{if(!(i&4)){break A}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[22708]=0;t[f+27|0]=e;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+24|0]=e;g=f;B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{r=w[f+27|0];switch(r-1|0){case 11:break D;case 10:break E;case 7:case 8:case 9:break F;case 6:break G;case 5:break H;case 3:case 4:break I;case 2:break J;case 1:break K;case 0:break L;default:break C}}v[22708]=0;kt(f,e<<24>>24<<3,128);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;e=ce(b);g=v[22708];v[22708]=0;if((g|0)==1){break c}if(e){C=b,D=on(v[f>>2]+w[b|0]|0),t[C|0]=D}t[f+27|0]=35;t[f+24|0]=w[f+4|0]^128;e=0;break A}e=Lv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|208;e=1;break A}t[f+27|0]=0;e=1;break A}e=1;break B}g=w[c+16|0];v[22708]=0;e=pD(e,g,1);g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+24|0]=e;t[f+27|0]=w[f+27|0]==4?2:3;e=1;break A}if(!w[b|0]){C=b,D=w[ad(c,h)|0],t[C|0]=D;e=w[f+24|0]}g=w[c+16|0];v[22708]=0;e=pD(e&255,g,0);g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+27|0]=4;t[f+24|0]=e;e=1;break A}C=b,D=on(e+25|0),t[C|0]=D;t[f+24|0]=255;t[f+27|0]=4;e=1;break A}M:{if(!k){break M}if((r|0)==w[ad(c,h)+2|0]){break M}e=_b(m,l);v[22708]=0;g=Be(f,20,(w[f+27|0]-8|48)&255);r=v[22708];v[22708]=0;if((r|0)==1){break c}g=pp(op(Ue(g,z),q&65535));v[22708]=0;e=Q(431,e|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!e){break M}C=ad(c,h),D=w[f+27|0],t[C+2|0]=D}t[f+27|0]=5;e=w[c+16|0];v[22708]=0;e=Kv(w[f+24|0],e);g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+24|0]=e;e=1;break A}e=rY(e,w[c+16|0]);t[f+27|0]=18;t[f+24|0]=e;e=1;break A}e=Lv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|192;e=1;break A}t[f+27|0]=0;t[b|0]=254;e=1;break A}e=0}t[g+27|0]=e}N:{if(!(i&2)){break N}v[22708]=0;g=T(374,a|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}v[22708]=0;t[f+26|0]=g;g=T(374,a|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}t[f+23|0]=g;O:{P:{Q:{R:{S:{T:{U:{i=w[f+26|0];switch(i-1|0){case 9:break P;case 7:case 8:break Q;case 6:break R;case 3:case 4:case 5:break S;case 2:break T;case 0:case 1:break U;default:break O}}h=w[c+16|0];v[22708]=0;g=oD(g,h,(i|0)==1);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+26|0]=11;t[f+23|0]=g;n=1;break N}g=rY(g,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=g;n=1;break N}V:{if(!k){break V}if((i|0)==w[ad(c,h)+3|0]){break V}g=_b(m,l);v[22708]=0;i=Be(f,20,(w[f+26|0]-4|64)&255);n=v[22708];v[22708]=0;if((n|0)==1){break c}i=pp(op(Ue(i,z),q&65535));v[22708]=0;g=Q(431,g|0,i|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!g){break V}C=ad(c,h),D=w[f+26|0],t[C+3|0]=D}t[f+26|0]=8;g=w[c+16|0];v[22708]=0;g=Kv(w[f+23|0],g);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break N}t[f+26|0]=9;break N}h=w[c+16|0];v[22708]=0;g=oD(g,h,(i|0)==8);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+26|0]=29;t[f+23|0]=g;n=1;break N}t[f+26|0]=27;h=w[c+16|0];v[22708]=0;g=Kv(g,h);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break N}t[f+26|0]=0}if(e){qY(b,k,x[d+480188>>1],w[f+27|0],f+24|0)}if(n){qY(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}W:{if(!A){break W}v[22708]=0;e=ce(b);g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!e){break W}e=w[f+27|0];if(!e){t[f+24|0]=255;t[f+27|0]=4;break W}if(w[f+26|0]|(e|0)==4){break W}t[f+23|0]=255;t[f+26|0]=4}X:{if(w[b+2|0]!=1){break X}Y:{if(!w[f+27|0]){t[f+27|0]=13;t[f+24|0]=w[b+4|0];break Y}if(w[f+26|0]){break X}t[f+26|0]=13;t[f+23|0]=w[b+4|0]}t[b+2|0]=0}v[22708]=0;to(f,f+27|0,f+24|0,f+26|0,f+23|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}Z:{if(w[b+2|0]){break Z}e=w[f+27|0];if(!e){break Z}t[b+2|0]=e;t[b+4|0]=w[f+24|0]}_:{if(w[f+28|0]){v[22708]=0;to(f,f+26|0,f+23|0,f+28|0,f+25|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}$:{if(w[b+2|0]){break $}e=w[f+26|0];if(!e){break $}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}h=f+25|0;e=w[f+28|0];break _}h=f+23|0;e=w[f+26|0];if(!e){break l}}t[b+3|0]=e;t[b+5|0]=w[h|0]}b=b+6|0;q=q+1|0;h=q&65535;if(y>>>0>=h>>>0){continue}break}}aa:{if(!p){break aa}b=_b(m,l);v[22708]=0;e=Be(f,17,w[f+32|0]);g=v[22708];v[22708]=0;if((g|0)==1){break c}e=Fh(op(Ue(e,k),0));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=_b(m,l);v[22708]=0;e=Be(f,16,w[f+36|0]);g=v[22708];v[22708]=0;if((g|0)!=1){e=Fh(Ue(e,k));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break aa}}break c}ba:{if(!(j&240)){break ba}b=_b(m,l);v[22708]=0;e=Be(f,20,j>>>4|224);g=v[22708];v[22708]=0;if((g|0)!=1){e=pY(Ue(e,k));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ba}}break c}ca:{b=j&15;if(!b){break ca}e=w[c+16|0];g=_b(m,l);b=Fd((B(b,e)>>>0)/15&255,1,15);v[22708]=0;b=Be(f,20,b|96);e=v[22708];v[22708]=0;if((e|0)!=1){b=pY(Ue(b,k));v[22708]=0;Q(431,g|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ca}}break c}b=0;k=k+1|0;if((s|0)!=(k|0)){continue}break}}gc(o)}gb=f- -64|0;return l|0}a=P()|0;O()|0;gc(o);S(a|0);L()}function efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-784|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{if(!Ih(b,d+776|0)){break K}if(!QN(d+776|0)){break K}if(!wC(b,d+768|0)){break K}if(!PN(d+768|0)){break K}e=1313423693;i=w[d+768|0]|w[d+769|0]<<8|(w[d+770|0]<<16|w[d+771|0]<<24);if((i|0)!=1179012417){e=1414090313;if((i|0)!=538987841){break K}}l=le(d+744|0,b);j=hh(d+728|0);L:{if(!c){v[22708]=0;Y(1452,d+144|0,l|0,((i|0)==1179012417?1:2)|0,e|0);b=v[22708];v[22708]=0;if((b|0)!=1){break L}b=P()|0;O()|0;break a}v[22708]=0;U(1453,d+144|0,l|0,((i|0)==1179012417?1:2)|0);b=v[22708];v[22708]=0;if((b|0)==1){break v}}b=d+144|0;PU(j,b);ke(b);v[22708]=0;U(1454,d+704|0,j|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break w}v[22708]=0;b=T(275,d+704|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}M:{if(!b){break M}v[22708]=0;b=Q(1455,d+704|0,d+624|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}if(!b|!w[d+689|0]){break M}b=w[d+689|0];v[22708]=0;g=Q(191,d+704|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}if(!g|!c){break M}v[22708]=0;R(367,a|0,8388608);b=v[22708];v[22708]=0;if((b|0)==1){break u}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+688|0]<<4^-1)&16;u[d+144>>1]=w[d+689|0];v[22708]=0;u[d+512>>1]=127;b=Pc(d+144|0,d+512|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[22708]=0;Q(157,a+1298304|0,((i|0)==1179012417?14044:14010)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}v[22708]=0;b=Q(2,d+144|0,10603)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;v[22708]=0;Fr(d+512|0,2,d+624|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;R(324,d+144|0,d+512|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=d+144|0;Eb(a+1298268|0,b);vb(b);if(x[a+480188>>1]){b=0;h=(i|0)==1179012417;while(1){v[22708]=0;g=(b<<5)+a|0;f=g+480280|0;We(f);e=v[22708];v[22708]=0;N:{O:{P:{Q:{R:{if((e|0)!=1){v[22708]=0;e=T(374,d+704|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break R}if(h){break Q}if(e>>>0<129){break P}break O}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}if(e<<24>>24<=-1){break O}v[d+144>>2]=e<<2;v[22708]=0;v[d+512>>2]=256;e=pd(d+144|0,d+512|0);f=v[22708];v[22708]=0;if((f|0)!=1){u[g+480284>>1]=v[e>>2];break N}b=P()|0;O()|0;break b}u[g+480284>>1]=e<<1;break N}v[f>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}g=gb-16|0;gb=g;e=Vb(j);h=Zb(j);b=gb-32|0;gb=b;v[b+16>>2]=h;v[b+24>>2]=e;v[b+8>>2]=1380209231;if(Gb(b+24|0,b+16|0)){while(1){if(!kD(b+8|0,v[b+24>>2])){e=b+24|0;pn(e);if(Gb(e,b+16|0)){continue}}break}e=v[b+24>>2]}gb=b+32|0;v[g+8>>2]=e;m=g,n=Zb(j),v[m>>2]=n;b=Gb(g+8|0,g);gb=g+16|0;if(b){v[22708]=0;U(1454,d+144|0,j|0,1380209231);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;b=T(374,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}e=Sb(a+484360|0);v[22708]=0;fa(521,e|0,d+144|0,b+1&255,255,254)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}xb(d+144|0)}if(c&1){u[d+496>>1]=0;v[22708]=0;U(1457,d+576|0,j|0,1414807888);b=v[22708];v[22708]=0;if((b|0)==1){break h}b=Ie(d+576|0);v[22708]=0;e=a+484344|0;R(330,e|0,b&65535);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=d+576|0;m=d,n=Vb(b),v[m+88>>2]=n;m=d,n=Zb(b),v[m+56>>2]=n;if(Gb(d+88|0,d+56|0)){g=(i|0)!=1179012417;while(1){b=le(d+144|0,v[d+88>>2]);v[22708]=0;h=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}v[22708]=0;u[d+128>>1]=h;b=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break l}v[22708]=0;U(288,d+512|0,d+144|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break m}b=kc(d+600|0,d+512|0);v[22708]=0;h=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[b+16>>2];h=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=h;Y(1458,d|0,x[d+128>>1],g|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}xb(d+512|0);v[22708]=0;b=Ke(d+496|0,d+128|0);h=v[22708];v[22708]=0;if((h|0)==1){break l}u[d+496>>1]=x[b>>1];xb(d+144|0);b=d+88|0;Eh(b);if(Gb(b,d+56|0)){continue}break}}if(x[d+496>>1]){b=0;while(1){v[22708]=0;g=b&65535;h=me(e,g);f=v[22708];v[22708]=0;S:{if((f|0)!=1){if(h){break S}v[22708]=0;W(331,e|0,g|0,64)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break S}}b=P()|0;O()|0;break i}b=b+1|0;if(x[d+496>>1]>(b&65535)>>>0){continue}break}}jd(d+576|0)}T:{if((i|0)==1179012417){v[22708]=0;U(1457,d+88|0,j|0,1414745673);b=v[22708];v[22708]=0;if((b|0)==1){break I}b=d+88|0;m=d,n=Vb(b),v[m+128>>2]=n;m=d,n=Zb(b),v[m+40>>2]=n;U:{if(Gb(d+128|0,d+40|0)){i=c&2;g=d+520|0;h=d+144|1;while(1){c=le(d+576|0,v[d+128>>2]);v[22708]=0;b=Q(1459,c|0,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}V:{if(!b){break V}b=w[h|0];if((b|0)==255){break V}v[22708]=0;b=W(376,a|0,b+1|0,0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break H}if(!b){break V}e=x[a+480190>>1];v[22708]=0;U(1460,d+144|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break H}b=0;if(!w[d+174|0]){break V}while(1){W:{if(!fi(a)){break W}v[22708]=0;e=Q(1461,c|0,d+512|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break G}if(!e){break W}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;if((w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24))!=1347240275){break W}v[22708]=0;Mk(d+496|0,2,g);f=v[22708];v[22708]=0;X:{Y:{Z:{if((f|0)==1){break Z}v[22708]=0;R(324,d+56|0,d+496|0);f=v[22708];v[22708]=0;if((f|0)==1){break Z}v[22708]=0;e=e&65535;Q(301,((e<<5)+a|0)+946304|0,d+56|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Y}vb(d+56|0);v[22708]=0;e=(B(e,104)+a|0)+484380|0;U(1462,d+512|0,d+144|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}if(!i){break X}f=d+56|0;k=d+550|0;Rc(f,(w[k|0]|w[k+1|0]<<8)&4?16:8,1,0,0);v[22708]=0;W(329,f|0,e|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break W}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;vb(d+56|0);break p}e=bj(e);v[22708]=0;Q(318,d+576|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}}b=b+1|0;if(b>>>0<w[d+174|0]){continue}break}}xb(d+576|0);b=d+128|0;Eh(b);if(Gb(b,d+40|0)){continue}break}}jd(d+88|0);break T}b=P()|0;O()|0;break p}v[22708]=0;U(1457,d+496|0,j|0,1179011410);b=v[22708];v[22708]=0;if((b|0)==1){break F}b=d+496|0;m=d,n=Vb(b),v[m+488>>2]=n;m=d,n=Zb(b),v[m+480>>2]=n;if(Gb(d+488|0,d+480|0)){i=c&2;g=d+512|4;b=d+80|4;h=d+144|5;while(1){c=le(d+576|0,v[d+488>>2]);v[22708]=0;e=T(192,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break E}_:{if((e|0)!=538986817){break _}v[22708]=0;e=Q(1463,c|0,d+472|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break D}if(!e|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24))!=1414745673){break _}v[22708]=0;e=Q(1464,c|0,d+144|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break C}if(!e){break _}e=w[h|0];if((e|0)==255){break _}v[22708]=0;e=W(376,a|0,e+1|0,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break B}if(!e){break _}f=x[a+480190>>1];v[22708]=0;U(1465,d+144|0,e|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break B}v[22708]=0;U(1453,d+512|0,c|0,2);c=v[22708];v[22708]=0;if((c|0)==1){break J}v[22708]=0;U(1457,d+128|0,d+512|0,1179011410);c=v[22708];v[22708]=0;if((c|0)==1){break A}ke(d+512|0);c=d+128|0;m=d,n=Vb(c),v[m+120>>2]=n;m=d,n=Zb(c),v[m+112>>2]=n;$:{if(!Gb(d+120|0,d+112|0)){break $}aa:{while(1){c=le(d+88|0,v[d+120>>2]);v[22708]=0;e=T(192,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break z}ba:{ca:{if((e|0)!=538989377){break ca}if(!fi(a)){break ca}e=w[d+468|0]|w[d+469|0]<<8;f=e-1|0;t[d+468|0]=f;t[d+469|0]=f>>>8;if(!e){xb(d+88|0);break $}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[22708]=0;c=Q(1463,c|0,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break y}if(!c|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275){break aa}c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22708]=0;U(288,d+512|0,d+88|0,c|0);c=v[22708];v[22708]=0;da:{ea:{if((c|0)!=1){c=d+512|0;e=kc(d+56|0,c);xb(c);v[22708]=0;c=Q(1466,e|0,c|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break ba}if(!c){break da}v[22708]=0;Je(d+24|0,2,g);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;R(324,d+40|0,d+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){break ea}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break s}v[22708]=0;c=f&65535;Q(301,((c<<5)+a|0)+946304|0,d+40|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break x}vb(d+40|0);v[22708]=0;c=(B(c,104)+a|0)+484380|0;U(1467,d+512|0,d+144|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break ba}fa:{if(!i){break fa}f=w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24);v[22708]=0;Q(190,d+56|0,f+4|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ba}f=d+40|0;k=d+552|0;Rc(f,(w[k|0]|w[k+1|0]<<8)&4?16:8,1,0,0);v[22708]=0;W(329,f|0,c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break fa}b=P()|0;O()|0;break t}xb(d+56|0);break ca}xb(d+56|0);xb(d+88|0);break $}xb(d+88|0);c=d+120|0;Eh(c);if(Gb(c,d+112|0)){continue}break $}break}b=P()|0;O()|0;break t}xb(d+88|0)}jd(d+128|0)}xb(d+576|0);c=d+488|0;Eh(c);if(Gb(c,d+480|0)){continue}break}}jd(d+496|0)}g=1}xb(d+704|0);ke(j);xb(l)}gb=d+784|0;return g|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;ke(d+512|0);break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break s}b=P()|0;O()|0;vb(d+40|0);break t}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}xb(d+56|0)}xb(d+88|0);jd(d+128|0)}xb(d+576|0);jd(d+496|0);break b}b=P()|0;O()|0}xb(d+576|0);jd(d+88|0);break b}b=P()|0;O()|0;break i}b=P()|0;O()|0;xb(d+512|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0}xb(d+144|0)}jd(d+576|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;xb(d+144|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(d+704|0)}ke(j);xb(l);S(b|0);L()}function Ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;i=gb-240|0;gb=i;a:{if(!Qu(a)){e=i+80|0;hc(e,a,128);f=i+208|0;pf(f,e,128,2);e=i+224|0;Bc(e,f);v[22708]=0;Q(301,b+492|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}vb(i+224|0)}u[c+34>>1]=x[c+34>>1]&65489;o=i+224|0;m=o;e=c;h=gb-48|0;gb=h;f=a;b:{if(!(w[f+128|0]==4|w[f+128|0]==8)){v[h+44>>2]=0;v[h+40>>2]=0;break b}t[h+40|0]=w[f+129|0];t[h+36|0]=100;n=h+36|0;g=w[ac(h+40|0,n)|0];v[h+44>>2]=g;t[h+36|0]=w[f+130|0];t[h+32|0]=100;n=w[ac(n,h+32|0)|0];v[h+40>>2]=n;c:{if(w[f+140|0]&16){k=Ib(w[f+150|0]|w[f+151|0]<<8);f=Ib(w[f+152|0]|w[f+153|0]<<8);s=+y[e>>2]/6553600;g=gr(s*+((k|g<<16)>>>0));v[h+44>>2]=g;v[h+36>>2]=v[e>>2]-g;z=h,A=gr(s*+((f|n<<16)>>>0)),v[z+32>>2]=A;z=h,A=v[Fb(h+36|0,h+32|0)>>2],v[z+40>>2]=A;break c}if(!Md(e)){break c}f=v[e>>2];k=f>>>7|0;g=B(k,(g<<7>>>0)/100|0);v[h+44>>2]=g;v[h+36>>2]=f-g;v[h+32>>2]=B(k,(n<<7>>>0)/100|0);f=v[Fb(h+36|0,h+32|0)>>2];n=h;d:{if(t[e+34|0]&1){kn(h+24|0,v[e+20>>2],B(v[e>>2],fd(e)));k=fd(e);e=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=e;e=v[h+8>>2];e:{if(f){p=u[e+(B(g,k)<<1)>>1];e=e+(B(k,f+g|0)<<1)|0;r=0-k<<1;while(1){g=u[e>>1]-p|0;k=g>>31;q=f;if((k^g+k)>>>0<1536){break e}e=e+r|0;f=f-1|0;if(f){continue}break}}q=0}break d}bc(h+16|0,v[e+20>>2],B(v[e>>2],fd(e)));e=fd(e);k=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=k;k=v[h>>2];f:{if(f){p=0-e|0;r=t[k+B(e,g)|0];e=k+B(e,f+g|0)|0;while(1){g=t[e|0]-r|0;k=g>>31;q=f;if((k^g+k)>>>0<6){break f}e=e+p|0;f=f-1|0;if(f){continue}break}}q=0}}v[n+40>>2]=q}}v[m>>2]=v[h+44>>2];v[m+4>>2]=v[h+40>>2];gb=h+48|0;e=128;n=fc(o);if(!(!v[n>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[o>>2];v[c+8>>2]=v[n>>2]+v[o>>2]}f=i;if(!(!w[a+134|0]|w[a+134|0]>199)){t[i+80|0]=w[a+134|0];t[i+208|0]=100;e=(w[ac(i+80|0,i+208|0)|0]<<7>>>0)/100|0}t[f+79|0]=e;t[i+80|0]=64;e=i+79|0;f=i+80|0;z=c,A=w[qf(e,f)|0]>>>1|0,u[z+32>>1]=A;t[i+80|0]=64;z=b,A=w[ac(e,f)|0],v[z+4>>2]=A;v[c+24>>2]=40460;Po(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){hm(b,127,1);gm(b,0,1)}g:{if(!Md(c)){break g}if(t[a+140|0]&1){f=d;b=c;h:{if(!Md(b)){break h}e=v[b>>2];if(e>>>0<2){break h}i:{if((kj(b)|0)==4){h=v[b+20>>2];g=0;k=e>>>1|0;while(1){xc(h+(g<<2)|0,h+((g^-1)+e<<2)|0);g=g+1|0;if((k|0)!=(g|0)){continue}break}break i}if((kj(b)|0)==2){h=v[b+20>>2];g=0;k=e>>>1|0;while(1){Nz(h+(g<<1)|0,h+((g^-1)+e<<1)|0);g=g+1|0;if((k|0)!=(g|0)){continue}break}break i}if((kj(b)|0)!=1){break h}h=v[b+20>>2];g=0;k=e>>>1|0;while(1){m=h+g|0;p=w[m|0];q=m;m=h+((g^-1)+e|0)|0;t[q|0]=w[m|0];t[m|0]=p;g=g+1|0;if((k|0)!=(g|0)){continue}break}}_h(b,f,0)}}if(w[a+140|0]&4){f=d;b=c;j:{if(!Md(b)){break j}e=v[b>>2];fd(b);g=0;h=B(fd(b),e);k:{if((jj(b)|0)==2){k=v[b+20>>2]+(g<<1)|0;e=0;g=h-g|0;if(g){while(1){h=k+(e<<1)|0;u[h>>1]=x[h>>1]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}break k}if((jj(b)|0)!=1){break j}k=g+v[b+20>>2]|0;e=0;g=h-g|0;if(g){while(1){h=e+k|0;t[h|0]=w[h|0]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}}_h(b,f,0)}}l=w[a+170|0]!=2|w[a+171|0]>100?l:w[a+172|0]<101;if(!(!(w[a+141|0]?1:l|w[a+160|0]!=0)|t[c+34|0]&1)){e=Rq(v[c>>2],fd(c)<<1);if(!e){break g}b=e;h=B(v[c>>2],fd(c));f=v[c+20>>2];k=bj(c);g=gb-16|0;gb=g;v[g+12>>2]=h;qc(g+12|0,k);h=v[g+12>>2];if(h){while(1){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;h=h-1|0;if(h){continue}break}v[g+12>>2]=-1}gb=g+16|0;u[c+34>>1]=x[c+34>>1]|1;MN(c,e,v[c>>2],d)}l:{if(t[a+141|0]>-1){break l}kn(i+80|0,v[c+20>>2],B(v[c>>2],fd(c)));if(t[a+141|0]>=0){break l}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=id(u[b>>1]-id(e,1)|0,1);u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}j=j+1|0;if((j|0)<(0-t[a+141|0]|0)){continue}break}}m:{if(!l){break m}e=i+80|0;kn(e,v[c+20>>2],B(v[c>>2],fd(c)));h=w[a+171|0];b=w[a+172|0];f=w[a+171|0];g=0-(b>>>0<f>>>0)|0;f=b-f|0;b=g<<24|f>>>8;g=f<<24;f=LB(e);j=(f|0)/2|0;g=g+j|0;b=(j>>31)+b|0;g=Ac(oqa(g,g>>>0<j>>>0?b+1|0:b,f,f>>31),jb);b=v[e>>2];l=v[e+4>>2];if((b|0)==(l|0)){break m}e=h<<24;h=e;f=e>>31;e=g;k=e>>31;while(1){g=u[b>>1];g=nqa(h,f,g,g>>31)+838860800|0;j=jb;z=b,A=Ac(oqa(g,g>>>0<838860800?j+1|0:j,1677721600,0),jb),u[z>>1]=A;f=f+k|0;h=e+h|0;f=h>>>0<e>>>0?f+1|0:f;b=b+2|0;if((l|0)!=(b|0)){continue}break}}n:{if(!w[a+160|0]){break n}kn(i+208|0,v[c+20>>2],B(v[c>>2],fd(c)));l=w[a+162|0];k=w[a+163|0];h=0;g=0;if(w[a+161|0]>=2){b=w[a+164|0];e=w[a+162|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;j=f<<23|b>>>9;f=b<<23;e=LB(i+208|0);b=(e|0)/2|0;g=b;f=f+b|0;b=(b>>31)+j|0;g=Ac(oqa(f,f>>>0<g>>>0?b+1|0:b,e,e>>31),jb)}if(w[a+161|0]>=2){b=w[a+165|0];e=w[a+163|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;j=f<<23|b>>>9;e=b<<23;b=LB(i+208|0);f=(b|0)/2|0;h=f;e=e+f|0;f=(f>>31)+j|0;h=Ac(oqa(e,e>>>0<h>>>0?f+1|0:f,b,b>>31),jb)}b=v[i+208>>2];m=v[i+212>>2];if((b|0)==(m|0)){break n}e=l<<23;f=k<<23;k=(i+80|0)+((w[a+160|0]&2)<<2)|0;j=0;l=0;while(1){p=(u[b>>1]>>1)-l|0;v[i+88>>2]=p;r=(e|0)/8388608|0;j=id(B(p,r),8)+j|0;v[i+84>>2]=j;l=id(B(j,r),6)+l|0;l=id(id(B(l,(f|0)/8388608|0),6)+l|0,2);v[i+80>>2]=l;z=b,A=Uc(v[k>>2]),u[z>>1]=A;f=f+h|0;e=e+g|0;b=b+2|0;if((m|0)!=(b|0)){continue}break}}o:{if(t[a+141|0]<1){break o}kn(i+80|0,v[c+20>>2],B(v[c>>2],fd(c)));j=0;if(t[a+141|0]<=0){break o}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=((u[b>>1]<<1)+e|0)/3|0;u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}j=j+1|0;if((j|0)<t[a+141|0]){continue}break}}p:{if(t[c+34|0]&1){kn(i- -64|0,v[c+20>>2],B(v[c>>2],fd(c)));b=v[i+68>>2];v[i+32>>2]=v[i+64>>2];v[i+36>>2]=b;l=gb-16|0;gb=l;k=v[i+36>>2];j=gb-16|0;gb=j;v[j+12>>2]=v[i+32>>2];m=l+8|0;b=j+12|0;f=Pu(m,b,b);e=v[j+12>>2];q:{if((e|0)==(k|0)){break q}b=e+2|0;v[j+12>>2]=b;if((b|0)==(k|0)){break q}z=(Mj(b,v[f>>2])?0:4)+f|0,A=b,v[z>>2]=A;e=e+4|0;if((k|0)==(e|0)){break q}g=f+4|0;while(1){h=b;b=b+4|0;v[j+12>>2]=b;if((b|0)==(k|0)){if(!Mj(e,v[f>>2])){f=g;if(Mj(e,v[f>>2])){break q}}v[f>>2]=e;break q}p=v[f>>2];r:{s:{if(Mj(b,e)){if(Mj(b,p)){v[f>>2]=b}if(!Mj(e,v[g>>2])){break s}break r}if(Mj(e,p)){v[f>>2]=e}e=b;if(Mj(b,v[g>>2])){break r}}v[g>>2]=e}e=h+6|0;v[j+12>>2]=e;if((e|0)!=(k|0)){continue}break}}gb=j+16|0;v[l+4>>2]=0-u[v[m>>2]>>1];z=l,A=u[v[fc(m)>>2]>>1],v[z>>2]=A;b=v[Hf(l+4|0,l)>>2];t:{if((b|0)>=32767|!b){break t}e=v[i+32>>2];f=v[i+36>>2];if((e|0)==(f|0)){break t}while(1){u[e>>1]=(B(u[e>>1],32767)|0)/(b|0);e=e+2|0;if((f|0)!=(e|0)){continue}break}}gb=l+16|0;break p}bc(i+56|0,v[c+20>>2],B(v[c>>2],fd(c)));b=v[i+60>>2];v[i+24>>2]=v[i+56>>2];v[i+28>>2]=b;j=gb-16|0;gb=j;l=v[i+28>>2];f=gb-16|0;gb=f;v[f+4>>2]=v[i+24>>2];k=j+8|0;b=f+4|0;b=Pu(k,b,b);e=v[f+4>>2];u:{if((e|0)==(l|0)){break u}e=e+1|0;v[f+4>>2]=e;if((e|0)==(l|0)){break u}e=(Sl(e,v[b>>2])?0:4)+b|0;h=v[f+4>>2];v[e>>2]=h;g=h+1|0;if((l|0)==(g|0)){break u}e=b+4|0;while(1){h=h+2|0;v[f+4>>2]=h;if((h|0)==(l|0)){if(!Sl(g,v[b>>2])){b=e;if(Sl(g,v[b>>2])){break u}}v[b>>2]=g;break u}v:{w:{if(Sl(h,g)){if(Sl(v[f+4>>2],v[b>>2])){v[b>>2]=v[f+4>>2]}if(!Sl(g,v[e>>2])){break w}break v}if(Sl(g,v[b>>2])){v[b>>2]=g}if(Sl(v[f+4>>2],v[e>>2])){break v}g=v[f+4>>2]}v[e>>2]=g}h=v[f+4>>2];g=h+1|0;v[f+4>>2]=g;if((g|0)!=(l|0)){continue}break}}gb=f+16|0;v[j+4>>2]=0-t[v[k>>2]];z=j,A=t[v[fc(k)>>2]],v[z>>2]=A;b=v[Hf(j+4|0,j)>>2];x:{if((b|0)>=127|!b){break x}e=v[i+24>>2];f=v[i+28>>2];if((e|0)==(f|0)){break x}while(1){t[e|0]=(B(t[e|0],127)|0)/(b|0);e=e+1|0;if((f|0)!=(e|0)){continue}break}}gb=j+16|0}y:{if(w[a+134|0]<101|w[a+134|0]>199){break y}b=B(v[c>>2],fd(c));if(t[c+34|0]&1){e=v[c+20>>2];b=td(i+48|0,e,e+(b<<1)|0);e=w[a+134|0];f=v[b+4>>2];v[i+16>>2]=v[b>>2];v[i+20>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+16>>2];j=v[i+20>>2];if((b|0)!=(j|0)){l=0-f|0;g=32768-f|0;while(1){e=b;h=u[b>>1];z:{if((h|0)>(f|0)){m=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break z}m=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(l|0)){break z}m=(B(h,g)|0)/(f|0)|0}z=e,A=Uc(m),u[z>>1]=A;b=b+2|0;if((j|0)!=(b|0)){continue}break}}break y}e=v[c+20>>2];b=td(i+40|0,e,b+e|0);e=w[a+134|0];f=v[b+4>>2];v[i+8>>2]=v[b>>2];v[i+12>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+8>>2];j=v[i+12>>2];if((b|0)!=(j|0)){l=0-f|0;g=32768-f|0;while(1){e=b;h=t[b|0]<<8;A:{if((h|0)>(f|0)){m=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break A}m=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(l|0)){break A}m=(B(h,g)|0)/(f|0)|0}z=e,A=GV((m|0)/256|0),t[z|0]=A;b=b+1|0;if((j|0)!=(b|0)){continue}break}}}if(!v[n>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break g}v[c+12>>2]=v[o>>2];v[c+16>>2]=v[n>>2]+v[o>>2];if(y[n>>2]>268435456/w[a+131|0]>>>0|y[c>>2]>268435456-B(v[n>>2],w[a+131|0])>>>0){break g}b=kj(c);h=v[o>>2];j=v[n>>2];l=w[a+131|0];g=v[c>>2]+B(v[n>>2],w[a+131|0])|0;e=Rq(g,b);if(!e){break g}v[c>>2]=g;f=hc(e,zb(v[c+20>>2]),B(b,v[n>>2]+v[o>>2]|0));if(w[a+131|0]){e=0;while(1){e=e+1|0;hc(f+B(b,v[o>>2]+B(e,v[n>>2])|0)|0,zb(v[c+20>>2])+B(b,v[o>>2])|0,B(b,v[n>>2]));if(w[a+131|0]>e>>>0){continue}break}}a=h+B(j,l+1|0)|0;hc(f+B(a,b)|0,zb(v[c+20>>2])+B(b,v[n>>2]+v[o>>2]|0)|0,B(b,g-a|0));MN(c,f,v[c>>2],d)}gb=i+240|0;return}a=P()|0;O()|0;vb(i+224|0);S(a|0);L()}function tH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=gb-144|0;gb=d;D=Qb(d,0,144);v[D+76>>2]=-1;v[D+44>>2]=a;v[D+32>>2]=2450;v[D+84>>2]=a;E=c;c=0;k=gb-304|0;gb=k;f=D;e=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(Am(a&255)){while(1){a=e;e=e+1|0;if(Am(w[a+1|0])){continue}break}zi(f,0,0);while(1){b=v[f+4>>2];h:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break h}b=md(f)}if(Am(b)){continue}break}e=v[f+4>>2];if(v[f+104>>2]){e=e-1|0;v[f+4>>2]=e}b=e-v[f+8>>2]|0;h=b>>31;e=b;g=o+v[f+124>>2]|0;b=r+v[f+120>>2]|0;g=b>>>0<r>>>0?g+1|0:g;d=b;b=e+b|0;h=h+g|0;r=b;o=b>>>0<d>>>0?h+1|0:h;break g}i:{j:{k:{b=w[e|0];if((b|0)==37){a=w[e+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}zi(f,0,0);a=((b|0)==37)+e|0;b=v[f+4>>2];l:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break l}b=md(f)}if((b|0)!=w[a|0]){if(v[f+104>>2]){v[f+4>>2]=v[f+4>>2]-1}if((b|0)>-1){break a}x=0;if(F){break a}break c}b=r+1|0;o=b>>>0<1?o+1|0:o;r=b;break g}m=0;a=e+2|0;break i}if(!(!Qh(a)|w[e+2|0]!=36)){a=w[e+1|0]-48|0;b=gb-16|0;v[b+12>>2]=E;a=(a>>>0>1?(a<<2)-4|0:0)+E|0;v[b+8>>2]=a+4;m=v[a>>2];a=e+3|0;break i}m=v[E>>2];E=E+4|0;a=e+1|0}x=0;e=0;if(Qh(w[a|0])){while(1){e=(w[a|0]+B(e,10)|0)-48|0;b=w[a+1|0];a=a+1|0;if(Qh(b)){continue}break}}d=w[a|0];if((d|0)==109){c=0;x=(m|0)!=0;d=w[a+1|0];q=0;a=a+1|0}b=a;a=b+1|0;g=3;m:{n:{switch(d-65|0){case 39:d=b+2|0;b=w[b+1|0]==104;a=b?d:a;g=b?-2:-1;break m;case 43:d=b+2|0;b=w[b+1|0]==108;a=b?d:a;g=b?3:1;break m;case 51:case 57:g=1;break m;case 11:g=2;break m;case 41:break m;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break n;default:break d}}g=0;a=b}b=w[a|0];d=(b&47)==3;G=d?1:g;s=d?b|32:b;o:{if((s|0)==91){break o}p:{if((s|0)!=110){if((s|0)!=99){break p}e=(e|0)>1?e:1;break o}uH(m,G,r,o);break g}zi(f,0,0);while(1){b=v[f+4>>2];q:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break q}b=md(f)}if(Am(b)){continue}break}b=v[f+4>>2];if(v[f+104>>2]){b=b-1|0;v[f+4>>2]=b}b=b-v[f+8>>2]|0;h=b>>31;l=b;b=o+v[f+124>>2]|0;d=r+v[f+120>>2]|0;b=d>>>0<r>>>0?b+1|0:b;o=d;d=l+d|0;h=b+h|0;r=d;o=d>>>0<o>>>0?h+1|0:h}l=e;j=e>>31;zi(f,e,j);b=v[f+104>>2];d=v[f+4>>2];r:{if(b>>>0>d>>>0){v[f+4>>2]=d+1;break r}if((md(f)|0)<0){break d}b=v[f+104>>2]}if(b){v[f+4>>2]=v[f+4>>2]-1}b=16;s:{t:{u:{v:{w:{x:{y:{switch(s-88|0){default:b=s-65|0;if(b>>>0>6|!(1<<b&113)){break s}case 9:case 13:case 14:case 15:xI(k+8|0,f,G,0);b=v[f+4>>2]-v[f+8>>2]|0;if(v[f+120>>2]==(0-b|0)&v[f+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!m){break s}b=v[k+16>>2];d=v[k+20>>2];h=v[k+8>>2];e=v[k+12>>2];switch(G|0){case 2:break u;case 1:break v;case 0:break w;default:break s};case 3:case 11:case 27:if((s&239)==99){Qb(k+32|0,-1,257);t[k+32|0]=0;if((s|0)!=115){break t}t[k+65|0]=0;t[k+46|0]=0;u[k+42>>1]=0;u[k+44>>1]=0;break t}d=w[a+1|0];h=(d|0)==94;Qb(k+32|0,h,257);t[k+32|0]=0;b=h?a+2|0:a+1|0;z:{A:{B:{a=w[(h?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break B}g=(d|0)!=94;a=b;break z}g=(d|0)!=94;t[k+78|0]=g;break A}g=(d|0)!=94;t[k+126|0]=g}a=b+1|0}while(1){b=w[a|0];C:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break C}break t}b=45;d=w[a+1|0];if(!d|(d|0)==93){break C}h=a+1|0;a=w[a-1|0];D:{if(d>>>0<=a>>>0){b=d;break D}while(1){a=a+1|0;t[a+(k+32|0)|0]=g;b=w[h|0];if(b>>>0>a>>>0){continue}break}}a=h}t[(b+k|0)+33|0]=g;a=a+1|0;continue};case 23:b=8;break x;case 12:case 29:b=10;break x;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break s;case 0:case 24:case 32:break x;case 17:break y}}b=0}i=f;l=0;h=0;j=0;g=0;I=0;H=gb-16|0;gb=H;E:{F:{G:{H:{I:{J:{if(b>>>0<=36){while(1){d=v[i+4>>2];K:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break K}d=md(i)}if(Am(d)){continue}break}L:{M:{switch(d-43|0){case 0:case 2:break M;default:break L}}I=(d|0)==45?-1:0;d=v[i+4>>2];if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break L}d=md(i)}N:{if(!(b&-17|(d|0)!=48)){d=v[i+4>>2];O:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break O}d=md(i)}if((d&-33)==88){b=16;d=v[i+4>>2];P:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break P}d=md(i)}if(w[d+74449|0]<16){break I}if(!v[i+104>>2]){break F}v[i+4>>2]=v[i+4>>2]-1;break F}if(b){break N}b=8;break I}b=b?b:10;if(b>>>0>w[d+74449|0]){break N}if(v[i+104>>2]){v[i+4>>2]=v[i+4>>2]-1}zi(i,0,0);v[115189]=28;b=0;d=0;break E}if((b|0)!=10){break I}j=d-48|0;if(j>>>0<=9){b=0;while(1){b=B(b,10)+j|0;e=b>>>0<429496729;d=v[i+4>>2];Q:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break Q}d=md(i)}j=d-48|0;if(e&j>>>0<=9){continue}break}l=b}if(j>>>0>9){break J}n=nqa(l,0,10,0);p=jb;e=j;while(1){b=v[i+4>>2];R:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;d=w[b|0];break R}d=md(i)}j=d-48|0;g=j>>>0>9;h=p;b=e+n|0;h=b>>>0<n>>>0?h+1|0:h;l=b;if((h|0)==429496729&b>>>0>=2576980378|h>>>0>429496729|g){break J}n=nqa(l,h,10,0);b=n;p=jb;g=p;e=j;if((g|0)==-1&(e^-1)>>>0>=b>>>0|(g|0)!=-1){continue}break}b=10;break H}v[115189]=28;b=0;d=0;break E}b=10;if(j>>>0<=9){break H}break G}if(b-1&b){g=w[d+74449|0];if(g>>>0<b>>>0){while(1){j=B(b,j)+g|0;e=j>>>0<119304647;d=v[i+4>>2];S:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break S}d=md(i)}g=w[d+74449|0];if(e&g>>>0<b>>>0){continue}break}l=j}if(b>>>0<=g>>>0){break H}j=b;n=nqa(l,0,b,0);p=jb;e=g;if((p|0)==-1&(e^-1)>>>0<n>>>0){break H}while(1){h=p;d=e+n|0;h=d>>>0<n>>>0?h+1|0:h;l=d;d=v[i+4>>2];T:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break T}d=md(i)}e=w[d+74449|0];if(e>>>0>=b>>>0){break H}rf(H,j,0,0,0,l,h,0,0);if(v[H+8>>2]|v[H+12>>2]){break H}n=nqa(l,h,j,0);g=n;p=jb;if((p|0)==-1&(e^-1)>>>0>=g>>>0|(p|0)!=-1){continue}break}break H}e=t[(B(b,23)>>>5&7)+74705|0];j=w[d+74449|0];if(j>>>0<b>>>0){while(1){g=g<<e|j;l=g>>>0<134217728;d=v[i+4>>2];U:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break U}d=md(i)}j=w[d+74449|0];if(l&j>>>0<b>>>0){continue}break}l=g}if(b>>>0<=j>>>0){break H}n=e&31;if((e&63)>>>0>=32){g=0;p=-1>>>n|0}else{p=-1>>>n|0;g=p;p=g|(1<<n)-1<<32-n}if(!g&l>>>0>p>>>0){break H}while(1){n=j&255;j=l;d=e;l=d&31;if((d&63)>>>0>=32){h=j<<l;d=0}else{h=(1<<l)-1&j>>>32-l|h<<l;d=j<<l}l=n|d;n=b;d=v[i+4>>2];V:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break V}d=md(i)}j=w[d+74449|0];if(n>>>0<=j>>>0){break H}if((h|0)==(g|0)&l>>>0<=p>>>0|h>>>0<g>>>0){continue}break}}if(w[d+74449|0]>=b>>>0){break G}while(1){h=v[i+4>>2];W:{if(h>>>0<y[i+104>>2]){v[i+4>>2]=h+1;d=w[h|0];break W}d=md(i)}if(w[d+74449|0]<b>>>0){continue}break}v[115189]=68;I=0;l=-1;h=-1}if(v[i+104>>2]){v[i+4>>2]=v[i+4>>2]-1}if(I|1?0:(l|0)==-1&(h|0)==-1){v[115189]=68;b=-2;d=-1;break E}b=I;e=b^l;d=b;b=e-b|0;l=h;h=d>>31;d=(l^h)-((d>>>0>e>>>0)+h|0)|0;break E}zi(i,0,0);b=0;d=0}gb=H+16|0;h=v[f+4>>2]-v[f+8>>2]|0;e=h;if(v[f+120>>2]==(0-e|0)&v[f+124>>2]==(0-((e>>31)+((e|0)!=0)|0)|0)){break b}if(!(!m|(s|0)!=112)){v[m>>2]=b;break s}uH(m,G,b,d);break s}J=m,K=vI(h,e,b,d),z[J>>2]=K;break s}J=m,L=dy(h,e,b,d),A[J>>3]=L;break s}v[m>>2]=h;v[m+4>>2]=e;v[m+8>>2]=b;v[m+12>>2]=d;break s}d=(s|0)==99;g=d?e+1|0:31;h=(G|0)!=1;X:{if(!h){b=m;if(x){b=Cd(g<<2);if(!b){break e}}v[k+296>>2]=0;v[k+300>>2]=0;e=0;c=x;while(1){q=b;Y:{while(1){b=v[f+4>>2];Z:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break Z}b=md(f)}if(!w[(b+k|0)+33|0]){break Y}t[k+27|0]=b;b=_p(k+28|0,k+27|0,1,k+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(q){v[(e<<2)+q>>2]=v[k+28>>2];e=e+1|0}if(!(c&(e|0)==(g|0))){continue}break}g=g<<1|1;b=Up(q,g<<2);if(b){continue}break f}break}if(k+296|0?v[k+296>>2]:0){break f}c=0;break X}if(x){e=0;b=Cd(g);if(!b){break e}while(1){c=b;while(1){b=v[f+4>>2];_:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break _}b=md(f)}if(!w[(b+k|0)+33|0]){q=0;break X}t[c+e|0]=b;e=e+1|0;if((g|0)!=(e|0)){continue}break}q=0;g=g<<1|1;b=Up(c,g);if(b){continue}break}break d}e=0;if(m){while(1){b=v[f+4>>2];$:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break $}b=md(f)}if(w[(b+k|0)+33|0]){t[e+m|0]=b;e=e+1|0;continue}else{q=0;c=m;break X}}}while(1){b=v[f+4>>2];aa:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break aa}b=md(f)}if(w[(b+k|0)+33|0]){continue}break}c=0;q=0}b=v[f+4>>2];if(v[f+104>>2]){b=b-1|0;v[f+4>>2]=b}g=b-v[f+8>>2]|0;n=g;b=g+v[f+120>>2]|0;g=v[f+124>>2]+(g>>31)|0;g=b>>>0<n>>>0?g+1|0:g;if(!(g|b)|((b|0)!=(l|0)|(g|0)!=(j|0))&(s|0)==99){break b}ba:{if(!x){break ba}if(!h){v[m>>2]=q;break ba}v[m>>2]=c}if(d){break s}if(q){v[(e<<2)+q>>2]=0}if(!c){c=0;break s}t[c+e|0]=0}b=v[f+4>>2]-v[f+8>>2]|0;h=b>>31;e=b;o=o+v[f+124>>2]|0;b=r+v[f+120>>2]|0;o=b>>>0<r>>>0?o+1|0:o;d=b;b=e+b|0;o=h+o|0;o=b>>>0<d>>>0?o+1|0:o;r=b;F=((m|0)!=0)+F|0}e=a+1|0;a=w[a+1|0];if(a){continue}break a}break}c=0;break d}c=0;q=0}if(F){break b}}F=-1}if(!x){break a}Yb(c);Yb(q)}gb=k+304|0;gb=D+144|0;return F}function fha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;j=gb-288|0;gb=j;h=gb-128|0;gb=h;g=j+104|0;i=le(g,c);v[22708]=0;n=T(215,g+20|0)|0;c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((c|0)!=1){v[22708]=0;p=T(215,g+40|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break A}v[22708]=0;q=T(215,g+60|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break z}v[22708]=0;r=T(215,g+80|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break y}v[22708]=0;o=T(215,g+100|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;k=T(215,g+120|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}m=Ho(g+140|0);vc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22708]=0;f=Q(1429,i|0,h+112|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(!f){break m}c=h+112|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1179011410){c=h+112|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1414744396){break m}}l=h+120|0;f=w[l+1|0]<<8;c=w[l+2|0]<<16|w[l+3|0]<<24;if((w[l|0]|f|c)!=1163280727&(c|(f|w[l|0]))!=1702257015){break m}c=h+112|0;t[g+176|0]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==1414744396;v[22708]=0;U(1430,h+96|0,i|0,2);c=v[22708];v[22708]=0;if((c|0)==1){break u}B:{if($i(h+96|0)>>>0<4){break B}c=h+40|0;_i(c,_t(h+96|0,1));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break B}c=h- -64|0;_i(c,_t(h+96|0,1));if(!(cn(c)&1)){break B}c=h+24|0;_i(c,_t(h+96|0,2));if(cn(c)){break B}c=h+88|0;_i(c,_t(h+96|0,3));if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break B}v[22708]=0;Q(190,g|0,12)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}v[22708]=0;U(1430,h+40|0,i|0,1);c=v[22708];v[22708]=0;if((c|0)==1){break s}c=h+40|0;UN(h+96|0,c);uB(c)}v[22708]=0;U(1431,h- -64|0,h+96|0,544501094);c=v[22708];v[22708]=0;if((c|0)==1){break r}v[22708]=0;l=g+156|0;f=Q(1432,h- -64|0,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}if(!f){break n}if((w[l|0]|w[l+1|0]<<8)==1){v[22708]=0;f=T(467,h- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}if((f|0)==4){break q}}if((w[l|0]|w[l+1|0]<<8)!=65534){break o}v[22708]=0;f=Q(1433,h- -64|0,h+40|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}if(!f){break n}c=v[h+60>>2];v[h+16>>2]=v[h+56>>2];v[h+20>>2]=c;c=v[h+52>>2];v[h+8>>2]=v[h+48>>2];v[h+12>>2]=c;c=h+24|0;f=h+8|0;v[c>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);u[c+4>>1]=w[f+4|0]|w[f+5|0]<<8;u[c+6>>1]=w[f+6|0]|w[f+7|0]<<8;s=c,y=PC(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24)),v[s+8>>2]=y;v[c+12>>2]=jb;u[g+172>>1]=v[c>>2];break o}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}v[22708]=0;i=T(307,h- -64|0)|0;c=v[22708];v[22708]=0;C:{if((c|0)!=1){v[22708]=0;f=T(307,h- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break C}if((i|0)!=2|(f|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22708]=0;U(1431,h+40|0,h+96|0,1635017060);c=v[22708];v[22708]=0;D:{E:{F:{G:{H:{I:{if((c|0)!=1){c=h+40|0;Vc(n,c);xb(c);v[22708]=0;f=T(275,n|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}if(!f){v[22708]=0;U(1431,h+40|0,h+96|0,544039792);c=v[22708];v[22708]=0;if((c|0)==1){break I}c=h+40|0;Vc(n,c);xb(c)}v[22708]=0;U(1431,h+40|0,h+96|0,1952670054);c=v[22708];v[22708]=0;if((c|0)==1){break H}v[22708]=0;f=T(192,h+40|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}v[g+152>>2]=f;xb(h+40|0);if(v[g+152>>2]?(w[l|0]|w[l+1|0]<<8)==17:0){break D}if(!zz(g)){break D}if(Io(g)){if((Io(g)>>>0)/(Lj(g)>>>0)>>>0<zz(g)<<1>>>0){break F}}v[22708]=0;c=T(195,n|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=zz(g);break E}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;xb(h+40|0);break j}v[22708]=0;c=T(195,n|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=Io(g)}v[g+152>>2]=(c>>>0)/(f>>>0)}v[22708]=0;f=Q(1434,g|0,h+96|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}u[g+174>>1]=f;v[22708]=0;R(1435,g|0,h+96|0);c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(1431,h+40|0,h+96|0,1886221175);c=v[22708];v[22708]=0;if((c|0)==1){break l}c=h+40|0;Vc(o,c);xb(c)}xb(h- -64|0);uB(h+96|0)}gb=h+128|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}xb(h- -64|0)}uB(h+96|0)}uB(m);xb(k)}xb(o)}xb(r)}xb(q)}xb(p)}xb(n)}xb(g);S(c|0);L()}v[22708]=0;f=T(1145,g|0)|0;c=v[22708];v[22708]=0;J:{K:{L:{M:{if((c|0)==1){break M}N:{O:{if(!f){break O}if(!Lj(g)){break O}if(Lj(g)>>>0>2){break O}if(!Rl(g)){v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break M}if((f|0)!=85){break O}}if(Rl(g)>>>0<=31){v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break M}if((f|0)==3){break O}}if(Rl(g)>>>0>64){break O}i=0;v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break L}v[j+80>>2]=f;c=v[j+80>>2];f=36544;P:{while(1){h=f;if((c|0)==v[f>>2]){break P}f=f+4|0;if((f|0)!=36568){continue}break}h=36568}if((h|0)==36568){break N}v[22708]=0;Q(1140,a|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break M}v[22708]=0;f=Q(70,j+80|0,18726)|0;c=v[22708];v[22708]=0;Q:{R:{S:{T:{U:{V:{if((c|0)!=1){v[22708]=0;i=((b<<5)+a|0)+946304|0;Q(301,i|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break V}vb(f);v[22708]=0;f=B(b,104)+a|0;k=f+484380|0;R(424,k|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break U}v[k>>2]=v[g+152>>2];v[f+484404>>2]=w[g+160|0]|w[g+161|0]<<8|(w[g+162|0]<<16|w[g+163|0]<<24);v[22708]=0;f=Jk(a);c=v[22708];v[22708]=0;if((c|0)==1){break U}v[22708]=0;Y(1147,g|0,k|0,f|0,i|0);c=v[22708];v[22708]=0;if((c|0)==1){break U}le(j+80|0,g+20|0);i=Rc(j+72|0,8,Lj(g)>>>0>1?2:1,0,0);v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break K}if((f|0)!=17){break T}if(Lj(g)>>>0>2){break T}qc(k,268435456);d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|1;c=Lj(g);u[d>>1]=x[d>>1]&65471|((c|0)==2)<<6;i=0;v[22708]=0;d=T(386,k|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break K}if(!d){break R}i=v[(B(b,104)+a|0)+484400>>2];f=v[k>>2];m=le(j+48|0,j+80|0);d=Io(g);c=Lj(g);v[22708]=0;b=v[m+12>>2];v[j+8>>2]=v[m+8>>2];v[j+12>>2]=b;v[j+16>>2]=v[m+16>>2];b=v[m+4>>2];v[j>>2]=v[m>>2];v[j+4>>2]=b;ha(1148,i|0,f|0,j|0,d|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break K}v[22708]=0;_h(k,a,0);b=v[22708];v[22708]=0;if((b|0)==1){break K}break S}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(f);break J}a=P()|0;O()|0;break J}v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break K}if((f|0)==85){v[22708]=0;c=fa(753,a|0,b|0,j+80|0,0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break Q}if(c){break S}i=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break Q}break R}W:{if(vB(g)|!w[g+177|0]){break W}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)!=1){break W}if((Rl(g)|0)!=32){break W}if((Io(g)|0)!=Lj(g)<<2){break W}Zi(i,32);Cf(i,12);v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break S}break K}X:{if(vB(g)){break X}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)!=1){break X}if((Rl(g)|0)!=24){break X}if((Io(g)|0)!=Lj(g)<<2){break X}Zi(i,32);Cf(i,13);v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}break S}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}Y:{if((c|0)!=6){v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)!=7){break Y}}Zi(i,16);v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}Cf(i,(c|0)==6?17:16);v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}break S}c=(Rl(g)-1>>>3|0)-1|0;b=c<<3;f=b&31;Zi(i,(c>>>0<7?(b&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255);if(Rl(g)>>>0<9){Cf(i,1)}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)==3){Cf(i,3)}if(d){XQ(i)}v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}}if(e){b=j+24|0;le(b,g+100|0);Vc(e,b);xb(b)}b=v[a+480180>>2];v[22708]=0;U(1142,k|0,32,b|0);b=v[22708];v[22708]=0;i=1;if((b|0)==1){break K}v[22708]=0;_h(k,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break K}}xb(j+80|0);break N}break K}i=0}hT(g);gb=j+288|0;return i|0}a=P()|0;O()|0;break J}a=P()|0;O()|0;break J}a=P()|0;O()|0;xb(j+80|0)}hT(g);S(a|0);L()}function BK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-128|0;gb=h;v[h+124>>2]=c;a:{b:{if(g){Ge(h+112|0,f,32);v[22708]=0;W(716,h+96|0,f|0,32)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+112|0);Kb(h+96|0)}u[h+80>>1]=0;u[h+64>>1]=65535;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(Et(h+124|0,h+80|0,h- -64|0)){i=b+24|0;b=v[i>>2];v[22708]=0;b=me(b+484344|0,c&65535);j=v[22708];v[22708]=0;if((j|0)==1){break q}if(b){break r}}v[22708]=0;U(2103,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)!=1){break m}f=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){v[22708]=0;U(2103,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)!=1){break m}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)&(e|0)>=0)){v[22708]=0;U(2103,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}break m}v[22708]=0;c=Yc(b,d,e&65535);b=v[22708];v[22708]=0;if((b|0)==1){break h}Se(h+112|0);Se(h+96|0);v[22708]=0;b=ce(c);d=v[22708];v[22708]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((d|0)!=1){E:{F:{if(!b){if(!Yt(c)){break F}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[22708]=0;Y(2105,h- -64|0,b|0,e|0,d|0);d=v[22708];v[22708]=0;b=1;if((d|0)==1){break D}v[22708]=0;R(2041,h+80|0,h- -64|0);d=v[22708];v[22708]=0;if((d|0)!=1){break E}f=P()|0;O()|0;break A}b=0;v[22708]=0;Q(70,h+80|0,13839)|0;d=v[22708];v[22708]=0;if((d|0)==1){break C}}v[22708]=0;Q(1168,h+112|0,h+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break B}vb(h+80|0);if(b){vb(h- -64|0)}v[22708]=0;b=ce(c);d=v[22708];v[22708]=0;if((d|0)==1){break e}G:{if(b){v[22708]=0;Q(70,h+80|0,7238)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}break G}if(Yt(c)){v[22708]=0;Q(70,h+80|0,7548)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break G}break e}v[22708]=0;Q(70,h+80|0,13839)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}}v[22708]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break z}vb(h+80|0);j=f-1|0;if(j>>>0<5){break s}v[22708]=0;b=Q(70,h+80|0,14911)|0;d=v[22708];v[22708]=0;if((d|0)==1){break y}v[22708]=0;Q(1168,h+112|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}vb(b);v[22708]=0;b=Q(70,h+80|0,14911)|0;d=v[22708];v[22708]=0;if((d|0)==1){break w}v[22708]=0;Q(1168,h+96|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break v}vb(b);b=c+1|0;H:{if(w[c+1|0]){v[22708]=0;R(737,h+80|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){break H}break f}v[22708]=0;Q(70,h+80|0,13844)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}}v[22708]=0;Q(1168,h+112|0,h+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}vb(h+80|0);I:{if(w[b|0]){v[22708]=0;Q(70,h+80|0,8055)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break I}break g}v[22708]=0;Q(70,h+80|0,13844)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}}v[22708]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break t}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}}vb(h- -64|0);break c}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;vb(h+80|0);break c}vb(h+80|0);if(j>>>0<8){break s}v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;J:{K:{L:{M:{N:{O:{P:{Q:{R:{if((d|0)!=1){S:{if(b){v[22708]=0;b=Q(70,h+48|0,14911)|0;d=v[22708];v[22708]=0;if((d|0)==1){break R}v[22708]=0;e=Gq(c);d=v[22708];v[22708]=0;if((d|0)==1){break Q}d=0;v[22708]=0;v[h+16>>2]=e&255;R(735,h+32|0,h+16|0);k=v[22708];v[22708]=0;e=1;if((k|0)==1){break Q}v[22708]=0;U(2060,h+80|0,b|0,h+32|0);b=v[22708];v[22708]=0;if((b|0)!=1){break S}f=P()|0;O()|0;break M}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[22708]=0;b=tz(b,d);d=v[22708];v[22708]=0;if((d|0)==1){break K}v[22708]=0;b=W(716,h+48|0,1,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break K}e=0;v[22708]=0;R(737,h+32|0,c+4|0);k=v[22708];v[22708]=0;d=1;if((k|0)==1){break P}v[22708]=0;U(2060,h+80|0,b|0,h+32|0);k=v[22708];v[22708]=0;if((k|0)!=1){break S}f=P()|0;O()|0;vb(h+32|0);break i}e=0;v[22708]=0;Q(70,h+80|0,13843)|0;b=v[22708];v[22708]=0;d=0;if((b|0)==1){break O}}v[22708]=0;Q(1168,h+112|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break N}vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(e){vb(h+32|0);vb(h+48|0)}v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;if((d|0)==1){break j}T:{if(b){v[22708]=0;Q(70,h+80|0,2580)|0;b=v[22708];v[22708]=0;if((b|0)==1){break j}break T}if(w[c+2|0]){v[22708]=0;Q(70,h+80|0,2576)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break T}break j}v[22708]=0;Q(70,h+80|0,13843)|0;b=v[22708];v[22708]=0;if((b|0)==1){break j}}v[22708]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break J}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break L}f=P()|0;O()|0;break i}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(!e){break c}}vb(h+32|0)}vb(h+48|0);break c}f=P()|0;O()|0;break c}vb(h+80|0);if(j>>>0<12){break s}v[22708]=0;b=Q(70,h+80|0,14911)|0;d=v[22708];v[22708]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((d|0)!=1){v[22708]=0;Q(1168,h+112|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break aa}vb(b);v[22708]=0;b=Q(70,h+80|0,14911)|0;d=v[22708];v[22708]=0;if((d|0)==1){break $}v[22708]=0;Q(1168,h+96|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break _}vb(b);v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;if((d|0)==1){break Z}ba:{if(b){b=0;v[22708]=0;d=Fo(c);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;v[h+28>>2]=d&4095;R(2107,h+80|0,h+28|0);d=v[22708];v[22708]=0;if((d|0)!=1){break ba}}f=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[22708]=0;b=sz(b,d);d=v[22708];v[22708]=0;if((d|0)==1){break Y}v[22708]=0;d=W(716,h+16|0,1,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break Y}v[22708]=0;R(737,h|0,c+5|0);e=v[22708];v[22708]=0;b=1;if((e|0)==1){break X}v[22708]=0;U(2060,h+80|0,d|0,h|0);d=v[22708];v[22708]=0;if((d|0)!=1){break ba}f=P()|0;O()|0;vb(h);break k}b=0;v[22708]=0;Q(70,h+80|0,13839)|0;d=v[22708];v[22708]=0;if((d|0)==1){break V}}v[22708]=0;Q(1168,h+112|0,h+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break W}vb(h+80|0);if(b){vb(h);vb(h+16|0)}v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;if((d|0)==1){break l}ca:{if(b){v[22708]=0;Q(70,h+80|0,8341)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}break ca}if(w[c+3|0]){v[22708]=0;Q(70,h+80|0,8341)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ca}break l}v[22708]=0;Q(70,h+80|0,13839)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}}v[22708]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break U}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}vb(h);break k}f=P()|0;O()|0;break c}vb(h+80|0);if(!f){break n}}da:{ea:{if(Ab(h+112|0)>>>0>f>>>0){v[22708]=0;Y(151,h+80|0,h+112|0,0,f|0);b=v[22708];v[22708]=0;if((b|0)!=1){break ea}f=P()|0;O()|0;break c}if(g){b=Ab(h+112|0);v[22708]=0;b=W(716,h+80|0,f-b|0,32)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}v[22708]=0;Q(1168,h+112|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){f=P()|0;O()|0;vb(b);break c}vb(b);if(Ab(h+96|0)>>>0>f>>>0){break o}break da}if(Ab(h+96|0)>>>0<=f>>>0){break n}break o}b=h+80|0;Eb(h+112|0,b);vb(b);if(Ab(h+96|0)>>>0>f>>>0){break o}if(!g){break n}}b=Ab(h+96|0);v[22708]=0;b=W(716,h+80|0,f-b|0,32)|0;c=v[22708];v[22708]=0;fa:{if((c|0)!=1){v[22708]=0;Q(1168,h+96|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break fa}vb(b);break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}v[22708]=0;Y(151,h+80|0,h+96|0,0,f|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=h+80|0;Eb(h+96|0,b);vb(b);break n}f=P()|0;O()|0;break c}v[22708]=0;U(2103,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}}vb(h+96|0);vb(h+112|0);gb=h+128|0;return}f=P()|0;O()|0;break c}vb(h+16|0);break c}f=P()|0;O()|0;break c}vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}vb(h+96|0)}vb(h+112|0);S(f|0);L()}function $la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;d=gb-1344|0;gb=d;vc(b);h=gb-32|0;gb=h;f=h+24|0;ZU(f,d+232|0);e=yb(f);f=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=f;v[h>>2]=j;v[h+4>>2]=f;f=b;j=h+16|0;cc(j,b,h);j=yb(j);if((j|0)==(e|0)){Rb(f,yb(h+24|0))}gb=h+32|0;a:{b:{c:{if((e|0)!=(j|0)){break c}if(!aV(d+232|0)){break c}if(Pb(b,Qc($U(d+232|0),jb))){break b}}b=0;break a}if(!c){b=1;break a}vc(b);b=le(d+232|0,b);v[22708]=0;R(817,d+216|0,b|0);f=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){xb(b);v[22708]=0;U(818,d+200|0,d+216|0,1196314451);b=v[22708];v[22708]=0;if((b|0)!=1){b=0;v[22708]=0;U(818,d+184|0,d+216|0,1280331091);f=v[22708];v[22708]=0;if((f|0)!=1){if(cd(d+200|0)){break d}if(cd(d+184|0)){break d}v[22708]=0;R(367,a|0,1);b=v[22708];v[22708]=0;k:{if((b|0)==1){break k}v[22708]=0;Ag(a);b=v[22708];v[22708]=0;if((b|0)==1){break k}v[a+480188>>2]=4;v[a+480208>>2]=16842752;b=d+184|0;C=d,D=Vb(b),v[C+24>>2]=D;C=d,D=Zb(b),v[C+144>>2]=D;if(!Gb(d+24|0,d+144|0)){break j}j=c&2;l:{m:{while(1){h=v[d+24>>2];if(!fi(a)){break j}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22708]=0;b=B(b&65535,104)+a|0;e=b+484380|0;R(424,e|0,1);f=v[22708];v[22708]=0;n:{o:{if((f|0)!=1){v[22708]=0;f=Q(819,h|0,d+232|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break o}if(!f){break e}if(cv(d+232|0)){break n}break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}v[22708]=0;f=Q(70,d+56|0,d+232|0)|0;m=v[22708];v[22708]=0;if((m|0)!=1){m=x[a+480190>>1];v[22708]=0;Q(301,((m<<5)+a|0)+946304|0,f|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break m}vb(f);f=w[d+268|0]|w[d+269|0]<<8|(w[d+270|0]<<16|w[d+271|0]<<24);v[e>>2]=f;v[b+484388>>2]=f;v[b+484384>>2]=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);u[b+484410>>1]=255;b=b+484414|0;u[b>>1]=x[b>>1]|2;if(j){b=Rc(d+56|0,8,1,0,0);v[22708]=0;W(329,b|0,e|0,h|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}}b=d+24|0;Eh(b);if(Gb(b,d+144|0)){continue}break j}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(f);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;xb(b);break f}b=d+200|0;C=d,D=Vb(b),v[C+176>>2]=D;C=d,D=Zb(b),v[C+168>>2]=D;n=a+484360|0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if(!Gb(d+176|0,d+168|0)){break z}q=a+484344|0;e=1;s=c&1;j=d+1324|0;m=d+1328|0;o=d+1320|0;y=d+1318|0;z=a+484380|0;while(1){c=v[d+176>>2];if(!(e&1)){v[22708]=0;b=T(417,n|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break y}if(!b){break z}}bm(Sb(n));v[22708]=0;b=Q(820,c|0,d+232|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break x}if(!b|(w[y|0]|w[y+1|0]<<8)){break e}b=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);if(!b|b>>>0>4){break e}b=Sb(n);v[22708]=0;U(6,d+56|0,5,d+232|0);f=v[22708];v[22708]=0;if((f|0)==1){break p}v[22708]=0;R(418,b|0,d+56|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}vb(d+56|0);A:{if(s){b=m;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22708]=0;U(288,d+56|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break A}a=P()|0;O()|0;break i}v[22708]=0;T(215,d+120|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break r}Rw(d+56|0,d+120|0)}b=d+56|0;r=kc(d+144|0,b);xb(b);if(!s){xb(d+120|0)}Qb(d+56|0,0,64);k=1;B:{C:{while(1){v[22708]=0;b=(B(k,34)+d|0)+198|0;c=b+32|0;R(712,d+8|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}D:{if(!w[v[d+8>>2]]){break D}f=w[b- -64|0];if(f>>>0>15){break C}b=w[b+65|0];if(b>>>0>64){break C}if(!cv(c)){break C}if(!x[a+480190>>1]){break D}h=b<<2;e=f<<4;c=1;f=0;b=1;while(1){v[22708]=0;R(713,d+24|0,d+8|0);g=v[22708];v[22708]=0;E:{F:{if((g|0)!=1){v[22708]=0;g=Q(821,d+24|0,((c<<5)+a|0)+946304|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break F}vb(d+24|0);if(g){break E}C=vd(d+56|0,k),D=b,u[C>>1]=D;c=B(c,104)+a|0;g=c+484410|0;l=x[g>>1];if((l|0)!=255){f=b;if(w[c+484417|0]!=(e&255)|(h|0)!=(l|0)){break E}}t[c+484417|0]=e;u[g>>1]=h;break D}a=P()|0;O()|0;break s}a=P()|0;O()|0;vb(d+24|0);break s}b=b+1|0;c=b&65535;if(c>>>0<=x[a+480190>>1]){continue}break}c=f&65535;if(!c){break D}if(!fi(a)){break D}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;C=vd(d+56|0,k),D=b,u[C>>1]=D;b=x[a+480190>>1];v[22708]=0;f=B(b,104);b=f+z|0;Ol(b);g=v[22708];v[22708]=0;if((g|0)==1){break v}g=B(c,104)+z|0;ap(b,g);f=a+f|0;u[f+484410>>1]=h;t[f+484417|0]=e;v[22708]=0;Q(747,b|0,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}f=a+946304|0;b=f+(x[a+480190>>1]<<5)|0;c=f+(c<<5)|0;f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=f;f=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=f;f=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=f}k=k+1|0;if((k|0)!=32){continue}break}h=0;v[d+48>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;A=w[o|0]|w[o+1|0]<<8;c=64;l=65535;k=0;G:{while(1){H:{if(!k){v[22708]=0;b=Q(191,d+144|0,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break G}if(!b){break H}}c=c+1|0;if(c>>>0>=64){v[22708]=0;l=W(544,q|0,64,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break G}if((l|0)==65535){break B}c=0;b=Sb(n);v[22708]=0;R(710,b|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break G}}b=_b(q,l&65535);v[22708]=0;b=Yc(b,c,0);f=v[22708];v[22708]=0;if((f|0)==1){break u}if(!A){continue}e=0;f=0;while(1){g=(d+24|0)+B(e,7)|0;e=w[g+6|0];I:{if(e){t[g+6|0]=e-1;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;k=k-1|0;break I}v[22708]=0;e=Q(191,d+144|0,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break t}if(!e){break I}e=j;if(v[d+152>>2]==(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){h=Sb(n);e=Sb(n);v[22708]=0;e=T(468,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break t}cf(h,e);h=c}v[22708]=0;e=T(374,r|0)|0;i=v[22708];v[22708]=0;J:{if((i|0)!=1){e=e<<24>>24;if((e|0)>-1){break J}i=e&127;t[g+6|0]=i;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;k=i+k|0;break I}a=P()|0;O()|0;break s}if((e-1&255)>>>0<=35){t[b|0]=e+48}v[22708]=0;e=T(374,r|0)|0;i=v[22708];v[22708]=0;K:{L:{if((i|0)!=1){C=b,D=w[vd(d+56|0,e&31)|0],t[C+1|0]=D;if(!(e&128)){break L}t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];break K}a=P()|0;O()|0;break s}v[22708]=0;R(403,d+8|0,r|0);e=v[22708];v[22708]=0;M:{if((e|0)!=1){e=d+8|0;p=qd(e);i=w[e|0];if(i>>>0>19){break K}t[b+3|0]=w[(i<<1)+33264|0];p=w[p|0];t[b+5|0]=p;if((i|0)!=18|p>>>0<32){break M}t[b+3|0]=17;break K}a=P()|0;O()|0;break s}e=w[e|0];if(819137>>>e&1){break K}t[b+5|0]=w[(e<<1)+33265|0]|p&15}e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24;e=w[b+4|0]|w[b+5|0]<<8;t[g+4|0]=e;t[g+5|0]=e>>>8}b=b+6|0;f=f+1|0;e=f&65535;if(A>>>0>e>>>0){continue}break}continue}break}if(!((h|0)!=0|c>>>0<63)){break B}b=l&65535;if((b|0)==65535){break B}b=_b(q,b);v[22708]=0;f=Be(d+8|0,14,h&255);h=v[22708];v[22708]=0;if((h|0)!=1){c=Fh(Ue(f,c));v[22708]=0;Q(431,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break B}}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}xb(d+144|0);break e}xb(d+144|0);b=d+176|0;Eh(b);e=0;if(Gb(b,d+168|0)){continue}break}}v[22708]=0;Si(n,0);b=v[22708];v[22708]=0;N:{O:{if((b|0)!=1){v[22708]=0;b=Q(2,d+232|0,3524)|0;c=v[22708];v[22708]=0;if((c|0)==1){break O}Eb(a+1298304|0,b);vb(b);v[22708]=0;c=Q(2,d+232|0,3826)|0;f=v[22708];v[22708]=0;b=1;if((f|0)==1){break N}Eb(a+1298316|0,c);vb(c);v[a+1298364>>2]=5;break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0}xb(d+144|0);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(d+56|0);break i}a=P()|0;O()|0}jd(d+184|0)}jd(d+200|0)}ke(d+216|0)}S(a|0);L()}b=0}jd(d+184|0);jd(d+200|0);ke(d+216|0)}gb=d+1344|0;return b|0}function Ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-304|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!bv(b,d+208|0)){break j}if(!VU(d+208|0)){break j}if(!Pb(b,Qc(UU(d+208|0),jb))){break j}if(!c){n=1;break j}if(!Wc(b,w[d+208|4])){break j}Hd(a,268435456);Ag(a);v[a+480208>>2]=4;e=d+88|0;h=Tb(e,12448);Eb(a+1298304|0,h);vb(h);h=Tb(e,7552);Eb(a+1298316|0,h);vb(h);v[a+1298364>>2]=5;h=d+16|0;pf(h,d+208|6,48,3);Bc(e,h);Eb(a+1298268|0,e);vb(e);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){e=0;while(1){u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;if(e>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;l=d+192|0;h=vh(l);k:{if(!e){break k}v[22708]=0;R(841,l|0,e|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;lr(l,e);e=v[22708];v[22708]=0;if((e|0)!=1){break k}}a=P()|0;O()|0;ci(h);S(a|0);L()}e=w[d+302|0]|w[d+303|0]<<8;v[22708]=0;U(833,b|0,l|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break i}s=mc(d+176|0);o=mc(d+160|0);e=w[d+301|0];v[22708]=0;W(564,b|0,s|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}h=w[d+300|0];e=0;v[22708]=0;W(564,b|0,o|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break f}if(w[d+300|0]){p=c&2;h=d+88|0;q=h|4;m=d+126|0;r=h|6;while(1){v[22708]=0;h=e;e=e+1|0;i=B(e,104)+a|0;g=i+484380|0;R(424,g|0,0);f=v[22708];v[22708]=0;l:{m:{if((f|0)!=1){f=Mb(o,h);if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break l}f=Mb(o,h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22708]=0;f=Q(190,b|0,f|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(!f){break l}v[22708]=0;f=Q(834,b|0,d+88|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(!f){break l}v[22708]=0;Je(d+72|0,2,r);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;R(324,d+16|0,d+72|0);f=v[22708];v[22708]=0;if((f|0)!=1){break m}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,d+16|0)|0;f=v[22708];v[22708]=0;n:{o:{p:{q:{r:{if((f|0)!=1){vb(d+16|0);v[22708]=0;Lk(d+72|0,2,m);f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;R(324,d+16|0,d+72|0);f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;Q(303,i+484423|0,d+16|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}vb(d+16|0);if(w[d+138|0]<=15){f=i+484414|0;u[f>>1]=x[f>>1]|32;u[i+484408>>1]=B(w[d+138|0],17)}t[d+16|0]=w[d+139|0];v[22708]=0;t[d+72|0]=64;f=ac(d+16|0,d+72|0);k=v[22708];v[22708]=0;if((k|0)==1){break p}u[i+484412>>1]=w[f|0];v[i+484404>>2]=w[d+141|0]|w[d+142|0]<<8;f=i+484384|0;v[f>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);k=i+484388|0;v[k>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break o}n=v[f>>2];f=v[k>>2];break n}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}n=v[f>>2]>>>1|0;v[f>>2]=n;f=v[k>>2]>>>1|0;v[k>>2]=f;v[g>>2]=v[g>>2]>>>1}s:{if(f>>>0<=n>>>0){break s}i=i+484414|0;u[i>>1]=x[i>>1]|2;if(!(w[d+140|0]&2)){break s}u[i>>1]=x[i>>1]|4}v[22708]=0;wk(g);i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!p){break l}h=Mb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=w[q|0];v[22708]=0;Q(190,b|0,h+i|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}h=Rc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[22708]=0;W(329,h|0,g|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break l}e=P()|0;O()|0;break b}if(w[d+300|0]>e>>>0){continue}break}}n=1;t:{if(!(c&1)){break t}v[d+68>>2]=0;f=a+484360|0;bm(Sb(f));F=d,G=Vb(l),v[F+64>>2]=G;F=d,G=Zb(l),v[F+56>>2]=G;k=a+484344|0;if(Gb(d- -64|0,d+56|0)){c=d+88|0;r=c|5;p=c|4;while(1){h=v[d- -64>>2];c=h;u:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break u}c=Mb(s,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}if(!c){break u}v[22708]=0;R(837,b|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}if(!w[p|0]){break u}e=w[h|0]|w[h+1|0]<<8;c=e;t[d+16|0]=w[r|0];i=w[d+262|0];g=w[h+2|0];v[22708]=0;t[d+72|0]=i-g;i=ac(d+16|0,d+72|0);g=v[22708];v[22708]=0;if((g|0)==1){break d}q=w[i|0];i=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[22708]=0;v[d+52>>2]=g+i;i=Mc(d+68|0,d+52|0);g=v[22708];v[22708]=0;if((g|0)==1){break e}v[d+68>>2]=v[i>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break u}y=c>>>6|0;e=e&63;A=0;while(1){v:{w:{x:{y:{z:{A:{B:{i=e>>>0>63;y=i+y|0;c=y&65535;if(tc(Sb(f))>>>0<=c>>>0){g=Sb(f);v[22708]=0;R(502,g|0,y+1&65535);g=v[22708];v[22708]=0;if((g|0)==1){break B}v[22708]=0;g=W(544,k|0,64,0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break B}F=sc(Sb(f),c),G=g,u[F>>1]=G}m=x[sc(Sb(f),c)>>1];v[22708]=0;c=me(k,m);g=v[22708];v[22708]=0;if((g|0)==1){break z}if(!c){break u}c=_b(k,m);g=w[h+2|0];v[22708]=0;z=i?0:e;e=Yc(c,z,g);c=v[22708];v[22708]=0;if((c|0)==1){break w}i=0;if(q){break A}break x}e=P()|0;O()|0;break b}while(1){v[22708]=0;R(839,d+72|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break y}c=d+72|0;g=qd(c);D=Ve(c);C=fj(c);E=fc(c);j=0;c=w[c|0];if((c-1&255)>>>0<=142){j=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+i|0]=j}t[e|0]=j;c=w[g|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];C:{if((c|0)!=255){t[e+4|0]=c;break C}t[e+2|0]=0}c=w[C|0];D:{if(c>>>0>22){break D}t[e+3|0]=w[c+33312|0];g=w[E|0];t[e+5|0]=g;c=e+5|0;E:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break D;case 4:t[c|0]=g&3|48;break D;case 7:if(Nb(l)>>>0<=g>>>0){break D}j=c;c=Mb(l,g);g=w[c|0]|w[c+1|0]<<8;t[j|0]=g>>>6;c=_b(k,m);j=x[a+480188>>1];v[22708]=0;c=Yc(c,z,j-1&65535);j=v[22708];v[22708]=0;if((j|0)!=1){t[c+3|0]=14;t[c+5|0]=g&63;break D}e=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(k,m);g=x[a+480188>>1];v[22708]=0;c=Yc(c,z,g-1&65535);g=v[22708];v[22708]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break D}e=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break D;case 12:v[22708]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[c|0]=w[g|0]|208;break D}e=P()|0;O()|0;break b;case 13:v[22708]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[c|0]=w[g|0]|192;break D}e=P()|0;O()|0;break b;case 14:v[22708]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[c|0]=w[g|0]|224;break D}e=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}j=g&240;if(!j|(j|0)==240){break D}t[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(j&255){break D}t[e|0]=w[(d+16|0)+i|0]}e=e+6|0;i=i+1|0;if((q|0)!=(i|0)){continue}break}break x}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(q>>>0>=w[r|0]){break v}c=w[r|0];v[22708]=0;Q(318,b|0,B(c-q|0,5)|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break v}}e=P()|0;O()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}c=d- -64|0;Qe(c);if(Gb(c,d+56|0)){continue}break}}F:{a=v[d+68>>2];b=a&63;if(!b){break F}c=Sb(f);v[22708]=0;a=a>>>6|0;c=Q(472,c|0,a&65535)|0;e=v[22708];v[22708]=0;if((e|0)!=1){if(!c){break F}a=_b(k,x[sc(Sb(f),a&65535)>>1]);v[22708]=0;da(840,a|0,b|0,0,1)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break F}}e=P()|0;O()|0;break b}a=Sb(f);F=d,G=Vb(a),v[F+88>>2]=G;F=d,G=Zb(a),v[F+16>>2]=G;if(!Gb(d+88|0,d+16|0)){break t}i=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){G:{if((i&65535)!=65535){break G}v[22708]=0;i=W(544,k|0,64,0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break G}e=P()|0;O()|0;break b}u[a>>1]=i}a=d+88|0;of(a);if(Gb(a,d+16|0)){continue}break}}di(o);di(s);ci(l)}gb=d+304|0;return n|0}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}di(o);di(s)}ci(l);S(e|0);L()}function k$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=gb-1504|0;gb=e;vc(b);rs(a);a:{b:{c:{d:{e:{if(!Yw(b,e+1480|0)){break e}if(!fG(e+1480|0)){break e}if(!c){g=1;break e}E=e+1498|0;c=E;if(!qs(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break e}c=E;s=e+1492|0;if(!qs(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[s|0]|w[s+1|0]<<8)<<2)|0)){break e}Xw(a);G=e,H=Ww(),v[G+104>>2]=H;d=e+104|0;Vw(mj(a)+32|0,d);ps(d);n=v[mj(a)+32>>2];c=e+1494|0;v[e+1476>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);G=e,H=lm(b),v[G+1216>>2]=H;v[e+1176>>2]=214748364;c=e+1216|0;G=e,H=B(v[Fb(c,e+1176|0)>>2],20),v[G+104>>2]=H;Mt(n,v[Fb(e+1476|0,d)>>2]);Qb(c,0,256);C=dd(e+1200|0);f:{if(w[s|0]|w[s+1|0]<<8){k=e+1176|4;l=e+1192|0;D=e+1194|0;q=e+1190|0;i=e+1188|0;while(1){c=E;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c+(F<<2)|0)|0;d=v[22708];v[22708]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((d|0)==1){break r}g=0;if(!c){break f}v[22708]=0;c=Q(191,b|0,4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break r}if(!c){break f}v[22708]=0;d=T(192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;c=Q(190,b|0,d|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}if(!c){break f}v[22708]=0;c=Q(193,b|0,e+1176|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}if(!c){break f}c=w[i|0]|w[i+1|0]<<8;v[22708]=0;c=W(194,b|0,C|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}if(!c){break f}c=w[i|0]|w[i+1|0]<<8?v[C>>2]:0;f=w[i|0]|w[i+1|0]<<8;v[22708]=0;j=T(195,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}d=d+20|0;if(j>>>0<=d+(f<<3)>>>0){break f}j=d+((w[i|0]|w[i+1|0]<<8)<<3)|0;if(!(t[q|0]&1)){f=0;if(!(w[i|0]|w[i+1|0]<<8)){break g}while(1){if(!c){break f}v[22708]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}if(!d){break f}v[22708]=0;d=Q(190,b|0,j|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}if(!d){break f}d=c;h=d+4|0;h=wd(e+1168|0,lc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));v[22708]=0;m=v[h+4>>2];v[e+32>>2]=v[h>>2];v[e+36>>2]=m;U(197,e+104|0,b|0,e+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break m}if((yb(e+104|0)|0)!=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))){break f}c=c+8|0;f=f+1|0;if(f>>>0<(w[i|0]|w[i+1|0]<<8)>>>0){continue}break}break g}s:{if(w[q|0]&4){if(!c){break f}v[22708]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}if(!d){break f}u=lc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));r=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!r){break f}h=w[D|0]|w[D+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[22708]=0;d=Q(190,b|0,d+j|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}if(!d){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;d=Q(191,b|0,d-f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}if(!d){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;U(198,e+80|0,b|0,d-f|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;p=Kp(e+104|0,e+80|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}xb(e+80|0);m=0;y=0;j=0;t:{u:{v:{if(!(w[i|0]|w[i+1|0]<<8)){break v}while(1){w:{v[22708]=0;f=Q(200,p|0,h+1|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break w}d=h&15;o=x[(d<<1)+27376>>1];x:{y:{if(o>>>0<=f>>>0){v[22708]=0;d=w[d+27456|0];z=Q(200,p|0,d|0)|0;A=v[22708];v[22708]=0;if((A|0)==1){break w}d=z+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&15;break x}v[22708]=0;d=Q(200,p|0,4)|0;f=v[22708];v[22708]=0;if((f|0)==1){break w}if((d|0)==15){v[22708]=0;d=Q(200,p|0,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break w}f=65535;if(!d){break y}break v}f=d+65520|0}if(f>>>0>65535){break x}}d=f&1?0-(f+1>>>1|0)|0:f>>>1|0;o=j+u|0;A=o;z:{if(w[q|0]&2){y=d+y|0;d=y;break z}d=w[q+1|0]&2?d:d^32768}f=d>>>8|0;z=(w[q|0]|w[q+1|0]<<8)&1024;t[A+1|0]=z?d:f;t[o|0]=z?f:d;j=j+2|0}if(j>>>0>=r>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break v}v[22708]=0;d=(m<<3)+c|0;f=W(196,d|0,n|0,v[e+1476>>2])|0;j=v[22708];v[22708]=0;if((j|0)==1){break w}if(!f){break s}r=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!r){break s}u=lc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break v}break}g=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break t}Z(g|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)==1){break u}}xb(e+104|0);break g}g=P()|0;O()|0}xb(e+104|0);break a}if(!c){break f}v[22708]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}if(!d){break f}y=lc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));r=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break f}v[22708]=0;d=Q(190,b|0,j|0)|0;f=v[22708];v[22708]=0;A:{B:{if((f|0)!=1){if(!d){break f}d=wd(e+72|0,e+1216|0,w[l|0]|w[l+1|0]<<8);v[22708]=0;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;U(201,e+104|0,b|0,e+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break B}if(yb(e+104|0)>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;d=Q(191,b|0,d-f|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break A}}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}if(!d){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;U(198,e+80|0,b|0,d-f|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}v[22708]=0;p=Kp(e+104|0,e+80|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}xb(e+80|0);u=0;j=0;m=0;C:{D:{E:{F:{if(!(w[i|0]|w[i+1|0]<<8)){break F}while(1){G:{v[22708]=0;f=Q(200,p|0,h+1|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break G}d=h&7;o=w[d+27408|0];H:{I:{if(o>>>0<=f>>>0){v[22708]=0;d=w[d+27416|0];z=Q(200,p|0,d|0)|0;A=v[22708];v[22708]=0;if((A|0)==1){break G}d=z+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&7;break H}v[22708]=0;d=Q(200,p|0,3)|0;f=v[22708];v[22708]=0;if((f|0)==1){break G}if((d|0)==7){v[22708]=0;d=Q(200,p|0,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break G}f=255;if(!d){break I}break F}f=d+248|0}if(f>>>0>255){break H}}d=w[(e+1216|0)+f|0];f=d+u|0;o=d;d=(w[q|0]|w[q+1|0]<<8)&2;t[j+y|0]=d?f:o;u=d?f:u;j=j+1|0}if(j>>>0>=r>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break F}v[22708]=0;d=(m<<3)+c|0;f=W(196,d|0,n|0,v[e+1476>>2])|0;j=v[22708];v[22708]=0;if((j|0)==1){break G}if(!f){break E}r=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);y=lc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break F}break}g=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break C}Z(g|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)==1){break D}}xb(e+104|0);break g}xb(e+104|0);break f}g=P()|0;O()|0}xb(e+104|0);break a}xb(e+104|0);break f}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0;break a}F=F+1|0;if(F>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}v[22708]=0;Ud(e+56|0,n);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=v[e+60>>2];v[e+24>>2]=v[e+56>>2];v[e+28>>2]=b;rh(e- -64|0,e+24|0);b=Td(e+48|0);v[22708]=0;c=v[e+68>>2];v[e+16>>2]=v[e+64>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;b=W(203,e+104|0,e+16|0,e+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}Vc(mj(a)+12|0,b);xb(b);g=1}ms(C)}gb=e+1504|0;return g|0}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0}ms(C);S(g|0);L()}function bF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;k=gb-336|0;gb=k;m=h;n=i&65535;o=d;q=e&65535;t=(e^i)&-2147483648;B=i>>>16&32767;F=e>>>16&32767;a:{b:{if(B-1>>>0<32766&F-1>>>0<=32765){break b}u=e&2147483647;l=u;j=d;if(!(!j&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){G=d;t=e|32768;break a}u=i&2147483647;e=u;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){G=h;t=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;t=2147450880;break a}t=t|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){b=0;c=0;break a}if(!(b|j|(c|l))){b=!(d|f|(e|g));G=b?0:G;t=b?2147450880:t;b=0;c=0;break a}if(!(d|f|(e|g))){t=t|2147418112;b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){i=b;d=!(o|q);h=d<<6;j=E(d?b:o)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;Lf(k+320|0,i,c,o,q,b-15|0);p=16-b|0;o=v[k+328>>2];q=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(m|n);e=d<<6;h=E(d?f:m)+32|0;d=E(d?g:n);d=e+((d|0)==32?h:d)|0;Lf(k+304|0,f,g,m,n,d-15|0);p=(d+p|0)-16|0;m=v[k+312>>2];n=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=n|65536;D=e;u=m;d=m;j=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=j;i=1963258675-(j+((d|0)!=0)|0)|0;rf(k+288|0,d,j,0,0,h,i,0,0);j=v[k+296>>2];rf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[k+280>>2];i=h<<1|v[k+276>>2]>>>31;h=v[k+284>>2]<<1|h>>>31;rf(k+256|0,i,h,0,0,d,e,0,0);j=h;h=v[k+264>>2];rf(k+240|0,i,j,0,0,0-h|0,0-(v[k+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+248>>2];l=v[k+252>>2]<<1|h>>>31;i=h<<1|v[k+244>>2]>>>31;h=l;rf(k+224|0,i,h,0,0,d,e,0,0);h=v[k+232>>2];rf(k+208|0,i,l,0,0,0-h|0,0-(v[k+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+216>>2];i=h<<1|v[k+212>>2]>>>31;h=v[k+220>>2]<<1|h>>>31;rf(k+192|0,i,h,0,0,d,e,0,0);j=h;h=v[k+200>>2];rf(k+176|0,i,j,0,0,0-h|0,0-(v[k+204>>2]+((h|0)!=0)|0)|0,0,0);j=d;h=v[k+184>>2];l=v[k+188>>2]<<1|h>>>31;d=h<<1|v[k+180>>2]>>>31;i=d-1|0;l=l-(d>>>0<1)|0;rf(k+160|0,j,e,0,0,i,l,0,0);e=f;rf(k+144|0,e<<15,g<<15|e>>>17,0,0,i,l,0,0);h=v[k+172>>2];n=v[k+160>>2];e=v[k+152>>2];d=n+e|0;m=v[k+164>>2];j=m+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(m|0)==(j|0)&n>>>0>e>>>0|j>>>0<m>>>0;m=n+v[k+168>>2]|0;j=h;j=m>>>0<n>>>0?j+1|0:j;h=m;m=!d&e>>>0>1|(d|0)!=0;h=h+m|0;j=h>>>0<m>>>0?j+1|0:j;rf(k+112|0,i,l,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);rf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,i,l,0,0);P=(F-B|0)+p|0;e=v[k+116>>2];z=e;d=v[k+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;e=j;i=v[k+140>>2];H=i;h=v[k+136>>2];j=i<<1|h>>>31;i=h<<1|v[k+132>>2]>>>31;d=i+m|0;l=e+j|0;l=d>>>0<i>>>0?l+1|0:l;i=d;d=l;e=i;j=d-(e>>>0<13927)|0;e=e-13927|0;l=j;I=j;h=0;p=h;j=q|65536;B=j;F=o;w=(j&2147483647)<<1|o>>>31;A=nqa(l,h,w,0);h=jb;r=A;s=h;h=c;L=(h&2147483647)<<1|b>>>31;J=L;x=0;l=(d|0)==(l|0)&e>>>0<i>>>0|d>>>0>l>>>0;m=(d|0)==(n|0)&i>>>0<m>>>0|d>>>0<n>>>0;d=v[k+120>>2];j=v[k+124>>2]<<1|d>>>31;i=H>>>31|0;d=i+(d<<1|z>>>31)|0;j=d>>>0<i>>>0?j+1|0:j;h=d;d=m+d|0;j=d>>>0<h>>>0?j+1|0:j;i=d;d=l+d|0;h=d>>>0<i>>>0?j+1|0:j;i=d-1|0;C=h-(d>>>0<1)|0;m=0;h=nqa(J,x,C,m);d=h+r|0;j=jb+s|0;j=d>>>0<h>>>0?j+1|0:j;h=j;r=(s|0)==(j|0)&d>>>0<r>>>0|j>>>0<s>>>0;j=0;A=j;z=j;R=0;j=o;Q=c>>>31|0;J=Q|j<<1;M=0;q=nqa(i,z,J,M);l=q+d|0;j=jb+h|0;j=l>>>0<q>>>0?j+1|0:j;n=l;q=j;j=(h|0)==(j|0)&d>>>0>l>>>0|h>>>0>j>>>0;d=j+r|0;h=0;h=d>>>0<j>>>0?1:h;l=nqa(w,K,C,m);d=l+d|0;j=jb+h|0;h=d>>>0<l>>>0?j+1|0:j;o=nqa(w,K,i,z);l=jb;s=d;z=nqa(C,m,J,M);d=z+o|0;j=jb+l|0;j=d>>>0<z>>>0?j+1|0:j;r=d;d=j;j=(l|0)==(j|0)&o>>>0>r>>>0|j>>>0<l>>>0;o=s+d|0;l=h+j|0;l=o>>>0<d>>>0?l+1|0:l;s=o;o=0;d=o+n|0;j=q+r|0;j=d>>>0<o>>>0?j+1|0:j;h=j;o=(q|0)==(j|0)&n>>>0>d>>>0|j>>>0<q>>>0;q=s+o|0;j=l;N=q;l=o>>>0>q>>>0?j+1|0:j;s=d;n=h;o=b<<1;q=c<<1|b>>>31;O=o&-2;r=nqa(i,A,O,0);h=jb;z=e;e=nqa(e,0,J,M);d=e+r|0;j=jb+h|0;j=d>>>0<e>>>0?j+1|0:j;r=(h|0)==(j|0)&d>>>0<r>>>0|h>>>0>j>>>0;h=d;e=j;S=r;H=nqa(I,p,L,x);d=H+d|0;j=jb+j|0;j=d>>>0<H>>>0?j+1|0:j;H=d;r=d;d=j;j=(j|0)==(e|0)&h>>>0>r>>>0|e>>>0>j>>>0;e=S+j|0;h=0;h=e>>>0<j>>>0?1:h;r=e;e=s+e|0;j=h+n|0;j=e>>>0<r>>>0?j+1|0:j;r=e;h=e;e=j;n=(j|0)==(n|0)&h>>>0<s>>>0|j>>>0<n>>>0;h=n+N|0;j=l;N=h;n=h>>>0<n>>>0?j+1|0:j;K=nqa(w,K,z,T);w=jb;l=nqa(C,m,O,U);h=l+K|0;j=jb+w|0;j=h>>>0<l>>>0?j+1|0:j;C=h;l=nqa(L,x,i,A);i=h+l|0;h=j;j=j+jb|0;j=i>>>0<l>>>0?j+1|0:j;m=i;A=nqa(I,p,J,M);i=i+A|0;l=j+jb|0;l=i>>>0<A>>>0?l+1|0:l;A=i;i=l;l=0;s=(i|0)==(j|0)&A>>>0<m>>>0|i>>>0<j>>>0;m=(h|0)==(j|0)&C>>>0>m>>>0|h>>>0>j>>>0;j=m+((h|0)==(w|0)&K>>>0>C>>>0|h>>>0<w>>>0)|0;h=0;m=s+j|0;j=m;h=r+i|0;j=(j|l)+e|0;j=h>>>0<i>>>0?j+1|0:j;s=h;m=j;h=(e|0)==(j|0)&h>>>0<r>>>0|e>>>0>j>>>0;e=h+N|0;j=n;C=e;n=e>>>0<h>>>0?j+1|0:j;r=s;w=H;I=nqa(I,p,O,U);p=jb;h=nqa(L,x,z,T);e=h+I|0;j=jb+p|0;j=e>>>0<h>>>0?j+1|0:j;l=j;j=0;h=(l|0)==(p|0)&e>>>0<I>>>0|l>>>0<p>>>0;e=l+w|0;j=(h|j)+d|0;j=e>>>0<l>>>0?j+1|0:j;h=e;s=(d|0)==(j|0)&h>>>0<w>>>0|d>>>0>j>>>0;l=j+A|0;p=0;i=p+h|0;d=i;l=d>>>0<p>>>0?l+1|0:l;e=(j|0)==(l|0)&d>>>0<h>>>0|j>>>0>l>>>0;d=s+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+r|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;i=(m|0)==(j|0)&d>>>0<r>>>0|j>>>0<m>>>0;h=i+C|0;l=n;l=h>>>0<i>>>0?l+1|0:l;i=l;c:{if((i|0)==131071|i>>>0<131071){j=F;l=B<<1|j>>>31;F=Q|j<<1;B=l|R;rf(k+80|0,d,e,h,i,f,g,u,D);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];s=(j|0)!=0;n=v[k+84>>2];p=s|(n|0)!=0;x=m-p|0;p=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<p>>>0)|0;m=0-j|0;n=0-(n+s|0)|0;b=P+16382|0;break c}d=(e&1)<<31|d>>>1;j=h<<31|e>>>1;e=j;h=(i&1)<<31|h>>>1;i=i>>>1|0;rf(k+96|0,d,j,h,i,f,g,u,D);o=0;m=v[k+104>>2];n=o-m|0;j=v[k+96>>2];l=(j|0)!=0;q=v[k+100>>2];p=l|(q|0)!=0;x=n-p|0;p=((b<<16)-(v[k+108>>2]+(m>>>0>o>>>0)|0)|0)-(n>>>0<p>>>0)|0;m=0-j|0;n=0-(l+q|0)|0;o=b;q=c;b=P+16383|0}if((b|0)>=32767){t=t|2147418112;b=0;c=0;break a}d:{if((b|0)>=1){c=x;j=p<<1|c>>>31;x=c<<1|n>>>31;p=j;o=h;q=i&65535|b<<16;b=m;j=n<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}om(k- -64|0,d,e,h,i,1-b|0);Lf(k+48|0,o,q,F,B,b+112|0);d=v[k+64>>2];e=v[k+68>>2];o=v[k+72>>2];q=v[k+76>>2];rf(k+32|0,f,g,u,D,d,e,o,q);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;m=v[k+36>>2];h=m;b=v[k+56>>2];m=h>>>31|i;i=b-m|0;l=v[k+60>>2]-((b>>>0<m>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;B=v[k+52>>2];j=B;b=v[k+48>>2];j=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;x=i-j|0;p=l-(i>>>0<j>>>0)|0;i=b;b=i-c|0;j=B-((c>>>0>i>>>0)+h|0)|0}rf(k+16|0,f,g,u,D,3,0,0,0);rf(k,f,g,u,D,5,0,0,0);i=d;c=e;l=f;f=g;r=o;m=0;h=j+m|0;n=d&1;d=b+n|0;h=d>>>0<b>>>0?h+1|0:h;o=d;g=h;l=(h|0)==(f|0)&d>>>0>l>>>0|f>>>0<h>>>0;d=(h|0)==(m|0)&n>>>0>d>>>0|h>>>0<m>>>0;b=d+x|0;j=p;j=b>>>0<d>>>0?j+1|0:j;h=b;f=j;d=(h|0)==(u|0)&(j|0)==(D|0)?l:(D|0)==(j|0)&h>>>0>u>>>0|j>>>0>D>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;e=(j|0)==(c|0)&d>>>0<i>>>0|c>>>0>j>>>0;c=r+e|0;j=q;i=c;j=i>>>0<e>>>0?j+1|0:j;c=j;e=d;l=i;d=v[k+20>>2];m=(d|0)==(g|0)&y[k+16>>2]<o>>>0|d>>>0<g>>>0;d=v[k+28>>2];i=v[k+24>>2];i=j>>>0<2147418112&((h|0)==(i|0)&(d|0)==(f|0)?m:(d|0)==(f|0)&i>>>0<h>>>0|d>>>0<f>>>0);d=e+i|0;j=b;j=d>>>0<i>>>0?j+1|0:j;i=d;d=j;e=(j|0)==(b|0)&e>>>0>i>>>0|b>>>0>j>>>0;b=l+e|0;j=c;j=b>>>0<e>>>0?j+1|0:j;e=j;l=b;b=v[k+4>>2];g=(b|0)==(g|0)&y[k>>2]<o>>>0|b>>>0<g>>>0;b=v[k+12>>2];c=v[k+8>>2];c=j>>>0<2147418112&((c|0)==(h|0)&(b|0)==(f|0)?g:(b|0)==(f|0)&c>>>0<h>>>0|b>>>0<f>>>0);b=c+i|0;j=d;j=b>>>0<c>>>0?j+1|0:j;c=j;f=(d|0)==(j|0)&b>>>0<i>>>0|d>>>0>j>>>0;d=l+f|0;j=e;G=d|G;t=t|(d>>>0<f>>>0?j+1|0:j)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=G;v[a+12>>2]=t;gb=k+336|0}function Wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-272|0;gb=e;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!wY(b,e+200|0)){break j}if(!xY(e+200|0)){break j}if(!c){d=1;break j}Hd(a,131072);d=gb-16|0;gb=d;i=e+104|0;f=Tb(d,1061);Dc(i,f);vb(f);gb=d+16|0;v[22708]=0;U(463,e+152|0,i|0,e+200|4);d=v[22708];v[22708]=0;if((d|0)==1){break i}d=e+152|0;Eb(a+1298304|0,d);vb(d);i=e+104|0;Hb(i);f=Tb(d,8333);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;Kr(i,3,e+213|0);Bc(d,i);Eb(a+1298268|0,d);vb(d);f=e+80|0;Yj(f,3,e+243|0);Bc(i,f);v[22708]=0;U(13,d|0,5,i|0);d=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((d|0)!=1){d=e+152|0;Eb(a+1298280|0,d);vb(d);vb(e+104|0);d=Cr(d);m=d,n=Fd(w[e+263|0],1,31),v[m+12>>2]=n;m=d,n=Fd(w[e+264|0],1,12)-1|0,v[m+16>>2]=n;v[d+20>>2]=w[e+265|0];i=a+1298368|0;sD(i);uY(i,d);h=e+112|0;j=e+40|4;i=hh(e+136|0);while(1){v[22708]=0;d=Q(191,b|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}if(!d){break k}v[22708]=0;R(464,b|0,e+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);d=w[e+204|0];p:{if((d|0)==3){g=2;if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1431389523){break p}d=w[e+204|0]}if((d&255)==4){g=4;if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1431389523){break p}d=w[e+204|0]}g=0;if((d&255)>>>0>7){break p}f=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1146113363?-1:f}d=v[e+44>>2];v[e+104>>2]=v[e+40>>2];v[e+108>>2]=d;v[22708]=0;U(288,e+80|0,b|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}kc(h,e+80|0);v[22708]=0;R(465,i|0,e+104|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}ed(e+104|0);xb(e+80|0);v[22708]=0;Q(318,b|0,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e+104|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(e+104|0);xb(e+80|0);break b}v[22708]=0;b=T(215,e+104|0)|0;d=v[22708];v[22708]=0;q:{r:{s:{if((d|0)!=1){v[22708]=0;U(466,e+80|0,i|0,1431389523);d=v[22708];v[22708]=0;if((d|0)==1){break s}d=e+80|0;Vc(b,d);xb(d);u[e+78>>1]=0;u[e+76>>1]=65534;if(w[e+204|0]<3){break q}v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break r}break d}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}u[e+78>>1]=d;if(w[e+204|0]<4){break q}v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}u[e+76>>1]=w[e+204|0]==4?d?d:-2:d}d=a+484360|0;f=Sb(d);v[22708]=0;g=T(467,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break d}v[22708]=0;fa(362,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}f=Sb(d);v[22708]=0;f=T(468,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}yg(e+78|0,f);f=Sb(d);v[22708]=0;f=T(468,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}yg(e+76|0,f);v[22708]=0;U(466,e+80|0,i|0,1414807888);f=v[22708];v[22708]=0;t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){f=e+80|0;Vc(b,f);xb(f);v[22708]=0;f=T(275,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}if(!f|!(c&1)){break t}v[22708]=0;R(469,b|0,e+72|0);f=v[22708];v[22708]=0;if((f|0)==1){break A}m=a,n=Fd(w[e+72|2],1,32)+1|0,u[m+480188>>1]=n;f=w[e+72|0]|w[e+73|0]<<8;v[22708]=0;f=Q(328,e|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break z}m=e,n=Vb(f),v[m+24>>2]=n;m=e,n=Zb(f),v[m+64>>2]=n;if(Gb(e+24|0,e- -64|0)){while(1){j=v[e+24>>2];v[22708]=0;g=w[e+204|0]<3?9:8;Q(318,b|0,g-4|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break y}v[22708]=0;h=T(192,b|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break x}pg(b,g);v[22708]=0;U(288,e+40|0,b|0,g+h|0);g=v[22708];v[22708]=0;if((g|0)==1){break w}h=j;g=e+80|0;j=e+40|0;Vc(h,kc(g,j));xb(g);xb(j);g=e+24|0;Eh(g);if(Gb(g,e- -64|0)){continue}break}}g=x[a+480188>>1];v[22708]=0;g=Q(470,e+80|0,g|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}h=$l(Sb(d));v[22708]=0;j=a+484344|0;R(330,j|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break f}h=Sb(d);m=e,n=Vb(h),v[m+40>>2]=n;m=e,n=Zb(h),v[m+24>>2]=n;if(Gb(e+40|0,e+24|0)){while(1){h=v[e+40>>2];k=x[h>>1];if(Ie(f)>>>0>k>>>0){k=Kg(f,x[h>>1]);v[22708]=0;k=da(471,k|0,w[e+204|0],g|0,a|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break f}u[h>>1]=k}h=e+40|0;of(h);if(Gb(h,e+24|0)){continue}break}}h=Sb(d);v[22708]=0;h=Q(472,h|0,x[e+76>>1])|0;k=v[22708];v[22708]=0;if((k|0)==1){break f}if(!h){break u}if(!x[e+78>>1]){h=x[e+76>>1];k=Sb(d);v[22708]=0;k=T(468,k|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break f}if(h>>>0>=k>>>0){break u}}d=x[sc(Sb(d),x[e+76>>1])>>1];h=_b(j,d);v[22708]=0;k=Be(e+40|0,12,w[e+78|0]);l=v[22708];v[22708]=0;if((l|0)!=1){d=pp(Ue(k,v[_b(j,d)+12>>2]-1|0));v[22708]=0;Q(431,h|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break u}}break f}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}mD(g);jd(f)}v[22708]=0;U(466,e+80|0,i|0,1196641603);d=v[22708];v[22708]=0;if((d|0)==1){break h}d=e+80|0;Vc(b,d);xb(d);v[22708]=0;d=T(275,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}if(d){v[22708]=0;Q(318,b|0,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;d=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}v[22708]=0;fa(473,a+1298292|0,b|0,d|0,40,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}}v[22708]=0;U(466,e+80|0,i|0,1146113363);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;U(466,e+40|0,i|0,1229999443);d=v[22708];v[22708]=0;B:{C:{if((d|0)!=1){d=e+40|0;Vc(b,d);xb(d);v[22708]=0;f=T(374,b|0)|0;g=v[22708];v[22708]=0;d=1;D:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){j=c&2;g=1;while(1){f=30;E:{F:{G:{if(w[e+204|0]>=2){v[22708]=0;f=T(374,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}}v[22708]=0;W(474,b|0,((d<<5)+a|0)+946304|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}v[22708]=0;R(475,b|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break F}v[22708]=0;c=B(d,104)+a|0;f=c+484380|0;R(476,e+24|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break F}d=w[e+204|0];if(d>>>0>=8){v[22708]=0;W(477,b|0,c+484423|0,8)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}d=w[e+204|0]}v[22708]=0;Q(318,b|0,((d&255)>>>0>1?6:2)|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}v[22708]=0;d=T(192,e+80|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(288,e|0,e+80|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){break E}}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}d=e+40|0;h=kc(d,e);xb(e);v[22708]=0;d=T(275,d|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break D}H:{if(!d|!j){break H}c=Rc(e,u[c+484414>>1]&1?16:8,1,0,(w[e+39|0]&12)==4?7:0);v[22708]=0;W(329,c|0,f|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break H}break D}xb(e+40|0);g=g+1|0;d=g&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22708]=0;Ag(a);c=v[22708];v[22708]=0;d=1;if((c|0)!=1){break B}}a=P()|0;O()|0;break C}a=P()|0;O()|0;xb(e+40|0);break C}a=P()|0;O()|0}xb(e+80|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;xb(e+80|0);xb(b);ke(i)}gb=e+272|0;return d|0}a=P()|0;O()|0;Hb(e+104|0);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;mD(g)}jd(f);break c}a=P()|0;O()|0}xb(b)}ke(i)}S(a|0);L()}function Voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=gb-272|0;gb=e;vc(b);f=gb-32|0;gb=f;d=f+24|0;l=e+112|0;zX(d,l);g=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(g|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(i|0);if(!d){yX(l)}a:{b:{c:{d:{if(!d){break d}if(!AX(e+112|0)){break d}if(!c){h=1;break d}Hd(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+28624>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=Tb(d,10447);Eb(a+1298304|0,f);vb(f);f=Tb(d,7583);Eb(a+1298316|0,f);vb(f);f=gb-16|0;gb=f;h=e+8|0;g=Tb(f,1498);Dc(h,g);vb(g);gb=f+16|0;v[22708]=0;Y(349,d|0,h|0,e+191|0,e+188|0);d=v[22708];v[22708]=0;e:{f:{if((d|0)!=1){d=e+48|0;Eb(a+1298328|0,d);vb(d);f=e+8|0;Hb(f);Xc(a+1298352|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+28672|0);Xc(a+1298340|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+28720>>2]);v[a+1298364>>2]=5;Je(f,2,e+112|4);Bc(d,f);Eb(a+1298268|0,d);vb(d);Je(f,2,e+148|0);Bc(d,f);g:{if(wr(d,6892)){v[22708]=0;U(13,e+8|0,5,e+48|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}d=e+8|0;Eb(a+1298280|0,d);vb(d)}vb(e+48|0);u[a+480188>>1]=32;d=0;h:{while(1){h=(d<<5)+a|0;g=h+480280|0;We(g);i:{f=d+e|0;if(w[f+193|0]<=15){v[e+48>>2]=w[f+193|0]<<4|8;v[e+8>>2]=256;s=h+480284|0,y=v[pd(e+48|0,e+8|0)>>2],u[s>>1]=y;break i}if(w[f+193|0]==16){u[h+480284>>1]=128;v[g>>2]=256;break i}if(w[f+193|0]!=255){break i}u[a+480188>>1]=d;break h}d=d+1|0;if((d|0)!=32){continue}break}d=x[a+480188>>1]}h=0;if(!(d&65535)){break d}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;s=a,y=v[Fb(e+48|0,e+8|0)>>2],v[s+480200>>2]=y;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Wc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){jp(Sb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Wc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break d}u[a+480190>>1]=w[e+248|0]+1;i=e+80|0;d=1;l=1;while(1){h=gb-32|0;gb=h;f=h+24|0;k=e+48|0;bc(f,k,62);g=yb(f);f=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=f;v[h>>2]=j;v[h+4>>2]=f;j=h+16|0;f=b;cc(j,f,h);j=yb(j);if((j|0)==(g|0)){Rb(f,yb(h+24|0))}gb=h+32|0;f=(g|0)==(j|0);if(!f){Qb(k,0,62)}if(f){f=B(d,104)+a|0;h=f+484380|0;ud(h,0);g=e+32|0;Je(g,2,e+48|0);k=e+8|0;Bc(k,g);v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,k|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=e+8|0;vb(d);g=e+32|0;Lk(g,2,i);Bc(d,g);v[22708]=0;Q(303,f+484423|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}vb(e+8|0);d=f+484404|0;v[d>>2]=w[e+106|0]|w[e+107|0]<<8;j:{if(!Zl(a)){break j}g=v[d>>2];d=0;while(1){if((g|0)==x[(d<<1)+28768>>1]){t[f+484417|0]=d<<4;break j}d=d+1|0;if((d|0)!=16){continue}break}}u[f+484412>>1]=64;v[h>>2]=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);if(w[e+105|0]&2){d=f+484414|0;u[d>>1]=x[d>>1]|1;v[h>>2]=v[h>>2]>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(t[e+105|0]&1){d=f+484414|0;u[d>>1]=x[d>>1]|2}k:{if(!(!(w[e+105|0]&4)|w[e+108|0]==255)){t[e+8|0]=w[e+108|0];t[e+32|0]=64;s=f+484410|0,y=w[ac(e+8|0,e+32|0)|0]<<2,u[s>>1]=y;break k}d=f+484414|0;u[d>>1]=x[d>>1]|32768}l:{if(!(w[e+105|0]&8)){u[f+484408>>1]=128;break l}d=f+484414|0;u[d>>1]=x[d>>1]|32;m=f+484408|0;if(w[e+109|0]<=15){f=w[e+109|0];v[e+32>>2]=256;v[e+8>>2]=f<<4|8;f=v[pd(e+8|0,e+32|0)>>2]}else{f=128}u[m>>1]=f;u[d>>1]=x[d>>1]&65279|(w[e+109|0]==16)<<8}l=l+1|0;d=l&65535;if(d>>>0<=x[a+480190>>1]){continue}}break}m:{if(!(c&2)){break m}if(!Wc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))|!x[a+480190>>1]){break m}d=1;while(1){f=B(d&65535,104)+a|0;Cg(Rc(e+48|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}o=a+484344|0;zg(o,w[e+239|0]+1|0);f=yq(a);d=gb-16|0;gb=d;v[d+12>>2]=0;fu(d+12|0,f);i=v[d+12>>2];gb=d+16|0;Wc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));q=c&1;k=0;l=1;n:{while(1){o:{d=Ng(b);if(d>>>0>=3){c=e+8|0;Sd(c,b,d-2|0);j=kc(e+48|0,c);xb(c);p:{if(!q){break p}v[22708]=0;c=T(275,e+48|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!c){break p}v[22708]=0;c=W(331,o|0,k&65535,64)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}n=0;if(!c){break p}while(1){c=_b(o,k);v[22708]=0;r=Tf(c,n);c=v[22708];v[22708]=0;if((c|0)==1){break f}q:while(1){v[22708]=0;c=T(374,j|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}r:{if(!c){break r}d=c&31;if(d>>>0>=x[a+480188>>1]){break r}f=B(d,6)+r|0;if(c&32){v[22708]=0;R(403,e+8|0,j|0);d=v[22708];v[22708]=0;if((d|0)==1){break f}d=e+8|0;h=qd(d);g=w[d|0];if(g){m=d;d=(g&127)-1|0;t[m|0]=d;t[f|0]=(B((d&240)>>>4|0,12)+(d&15)|0)+13;v[22708]=0;d=Av(f);g=v[22708];v[22708]=0;if((g|0)==1){break f}l=d&l}t[f+1|0]=w[h|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;h=f+5|0;while(1){v[22708]=0;c=Q(191,e+48|0,2)|0;d=v[22708];v[22708]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)!=1){if(!c){continue q}p=w[h|0];c=w[f+3|0];v[22708]=0;R(403,e+8|0,j|0);d=v[22708];v[22708]=0;if((d|0)==1){break f}d=e+8|0;m=d;g=w[qd(d)|0];t[h|0]=g;d=w[(w[d|0]&31)+28800|0];t[f+3|0]=d;switch(d-2|0){case 4:case 5:break w;case 18:break x;case 13:break y;case 17:break z;case 11:break A;case 0:case 1:break B;default:break t}}break f}if(g>>>0<224){break u}d=223;if(v[a+480180>>2]!=1){break v}break u}v[22708]=0;t[e+32|0]=64;d=ac(h,e+32|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[h|0]=w[d|0];v[22708]=0;d=uz(i,1);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(!d){break u}t[f+2|0]=1;t[f+4|0]=w[h|0];t[f+3|0]=c;t[h|0]=p;d=c;break t}break f}C:{switch(((g&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[h|0]=g&15|224;break s;case 1:t[f+3|0]=3;t[h|0]=g&15|224;break s;default:break C}}v[22708]=0;d=oq(i,19);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(d){break u}v[22708]=0;Zt(f);d=v[22708];v[22708]=0;if((d|0)!=1){break u}break f}v[22708]=0;d=oq(i,15);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(d){break u}v[22708]=0;d=oq(i,19);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(!d){break u}t[f+3|0]=19;t[h|0]=w[h|0]&15|144;break s}d=145;if((g|0)==1){break v}if((g&240)==128){v[22708]=0;d=oq(i,20);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(d){break u}t[f+3|0]=19;break s}t[f+3|0]=0;break s}d=g&240;if(!d){break u}}t[h|0]=d}d=w[f+3|0]}if((d&255)!=20){break s}d=w[h|0];if(w[f+2|0]|(d&240)!=128){break s}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[h|0]=p}if(w[m|0]&32){continue}break}continue}break}n=n+1|0;if((n|0)!=64){continue}break}}xb(e+48|0)}c=w[e+239|0]>k>>>0;k=k+1|0;if(c){continue}break e}break}break f}break f}d=P()|0;O()|0;vb(e+48|0);break a}d=P()|0;O()|0;Hb(e+8|0);break a}d=P()|0;O()|0;xb(e+48|0);break a}c=a;if(v[a+480180>>2]!=1){d=v[a+480208>>2]&-8454145}else{d=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?l&1?8454144:0:0)}v[c+480208>>2]=d;h=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break d}if(!Wc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break d}pB(a+1298292|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4)}gb=e+272|0;return h|0}d=P()|0;O()|0;vb(e+8|0);break a}d=P()|0;O()|0;vb(e+8|0)}S(d|0);L()}function YZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=gb-224|0;gb=g;vc(b);a:{if(!xE(b,g+176|0)){break a}if(!yE(g+176|0)){break a}if(!c){h=1;break a}Hd(a,2048);Ag(a);d=gb-16|0;gb=d;f=g+8|0;e=Tb(d,1075);Dc(f,e);vb(e);gb=d+16|0;v[22708]=0;l=g+176|3;U(316,g+80|0,f|0,l|0);d=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){d=g+80|0;Eb(a+1298304|0,d);vb(d);f=g+8|0;Hb(f);e=Tb(d,8337);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;u[a+480188>>1]=w[g+216|0];u[a+480190>>1]=w[g+212|0];Je(f,2,g+176|4);Bc(d,f);Eb(a+1298268|0,d);vb(d);if(w[l|0]<=8){u[a+480188>>1]=4;pg(b,1);xh(a,1)}d=w[l|0];n:{if(w[l|0]>=11){f=d>>>0>11?32:16;e=0;d=0;while(1){j=uE(b);o:{if((j|0)==100){v[((e<<5)+a|0)+480280>>2]=256;break o}v[g+80>>2]=(j<<1)+128;v[g+8>>2]=0;v[g+160>>2]=256;y=((e<<5)+a|0)+480284|0,z=v[ej(g+80|0,g+8|0,g+160|0)>>2],u[y>>1]=z}d=d+1|0;e=d&65535;if(f>>>0>e>>>0){continue}break}break n}if(d>>>0<9){break n}d=g+80|0;e=gb-32|0;gb=e;f=b;p:{if(!Pb(f,16)){f=gb-16|0;gb=f;j=d+16|0;while(1){If(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=f+16|0;break p}gw(e+24|0,d);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kd(e+16|0,f,e+8|0)}gb=e+32|0;e=0;while(1){u[((e<<5)+a|0)+480284>>1]=t[(g+80|0)+e|0]&1?64:192;e=e+1|0;if((e|0)!=16){continue}break}}q:{if(w[l|0]>=13){e=g+80|0;jw(e,b);j=qd(e);f=a;d=w[e|0];if(d>>>0<=31){t[e|0]=125;d=125}v[f+480204>>2]=B(d,1e4);v[a+480196>>2]=w[j|0];break q}v[a+480196>>2]=6;v[a+480204>>2]=125e4}d=a+484360|0;Bf(Sb(d),w[g+213|0]);n=mc(g+160|0);i=v[b+8>>2];r=w[l|0];r:{if(w[l|0]<14){break r}f=w[g+213|0];v[22708]=0;R(317,n|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break r}a=P()|0;O()|0;break e}s:{if(w[g+213|0]){e=0;while(1){y=sc(Sb(d),e),z=e,u[y>>1]=z;if(w[l|0]>=14){v[22708]=0;f=T(287,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break s}y=sc(n,e),z=f,u[y>>1]=z}f=x[a+480188>>1];v[22708]=0;Q(318,b|0,f<<1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break s}e=e+1|0;if(e>>>0<w[g+213|0]){continue}break}}d=0;t:{u:{if(w[l|0]==10){j=v[b+8>>2];d=0;v:{if(!x[a+480190>>1]){break v}e=1;while(1){v[22708]=0;d=Q(319,b|0,g+80|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break u}w:{if(!d){break w}f=0;d=g+80|0;x:{if(w[d|0]>1|w[g+212|0]<(w[d+46|0]|w[d+47|0]<<8|(w[d+48|0]<<16|w[d+49|0]<<24))>>>0|((w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0>1048576|w[d+56|0]>64)){break x}if((w[d+57|0]|w[d+58|0]<<8|(w[d+59|0]<<16|w[d+60|0]<<24))>>>0>(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0){break x}f=(w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24))>>>0<=(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0}if(f){break w}d=1;break v}e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}d=0}v[22708]=0;Q(190,b|0,j|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break t}}f=x[a+480190>>1];v[22708]=0;v[g+80>>2]=0;q=W(320,g- -64|0,f|0,g+80|0)|0;f=v[22708];v[22708]=0;e=1;if((f|0)!=1){if(x[a+480190>>1]){o=d?59:65;j=g+80|1;f=1;while(1){y:{if(w[l|0]<=9){v[22708]=0;R(321,b|0,g+80|0);h=v[22708];v[22708]=0;z:{A:{B:{if((h|0)==1){break B}v[22708]=0;R(322,g+80|0,(B(e,104)+a|0)+484380|0);h=v[22708];v[22708]=0;if((h|0)==1){break B}v[22708]=0;Je(g+48|0,2,j);h=v[22708];v[22708]=0;if((h|0)==1){break A}v[22708]=0;R(324,g+8|0,g+48|0);h=v[22708];v[22708]=0;if((h|0)==1){break A}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,g+8|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break z}break y}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(g+8|0);break f}v[22708]=0;U(325,b|0,g+80|0,o|0);h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;U(326,g+80|0,(B(e,104)+a|0)+484380|0,d|0);h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;Je(g+48|0,2,j);h=v[22708];v[22708]=0;if((h|0)==1){break h}v[22708]=0;R(324,g+8|0,g+48|0);h=v[22708];v[22708]=0;if((h|0)==1){break h}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,g+8|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break i}}vb(g+8|0);h=w[g+126|0]|w[g+127|0]<<8|(w[g+128|0]<<16|w[g+129|0]<<24);y=Mb(q,e-1|0),z=h,v[y>>2]=z;f=f+1|0;e=f&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}j=mc(g+48|0);d=w[g+214|0]|w[g+215|0]<<8;v[22708]=0;h=W(327,b|0,j|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break m}if(!h){break b}d=0;if(!cd(j)){f=Vb(j);e=Zb(j);d=gb-32|0;gb=d;v[d+16>>2]=e;v[d+24>>2]=f;C:{if(!Gb(d+24|0,d+16|0)){break C}v[d>>2]=f;e=of(d);if(!Gb(e,d+16|0)){break C}while(1){if(pE(v[d+24>>2],v[e>>2])){f=v[d>>2];v[d+24>>2]=f}if(Gb(of(e),d+16|0)){continue}break}}gb=d+32|0;v[g+80>>2]=f;d=v[g+80>>2];d=w[d|0]|w[d+1|0]<<8}v[22708]=0;f=d;o=Q(328,g+32|0,d|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){D:{if(f){e=0;while(1){v[22708]=0;k=T(287,b|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break l}v[22708]=0;Q(318,b|0,1)|0;m=v[22708];v[22708]=0;if((m|0)==1){break l}if(k){m=w[l|0];v[22708]=0;U(288,g+8|0,b|0,B(k,3)+((m|0)==1?3:0)|0);k=v[22708];v[22708]=0;if((k|0)==1){break D}k=g+80|0;m=g+8|0;p=kc(k,m);Vc(Kg(o,e),p);xb(k);xb(m)}e=e+1|0;if((f|0)!=(e|0)){continue}break}}E:{if(!(c&2)){break E}f=1;m=Rc(g+80|0,8,1,0,1);if(!x[a+480190>>1]){break E}k=1;while(1){v[22708]=0;e=Q(191,b|0,1)|0;p=v[22708];v[22708]=0;F:{if((p|0)!=1){if(!e){break E}e=0;if(!x[a+480190>>1]){break F}p=v[b+8>>2];while(1){G:{H:{if(v[Mb(q,e)>>2]!=(f|0)){e=e+1|0;break H}v[22708]=0;Q(190,b|0,p|0)|0;s=v[22708];v[22708]=0;if((s|0)==1){break G}v[22708]=0;e=e+1|0;W(329,m|0,(B(e,104)+a|0)+484380|0,b|0)|0;s=v[22708];v[22708]=0;if((s|0)==1){break G}}if(x[a+480190>>1]>e>>>0){continue}break F}break}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}k=k+1|0;f=k&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}if(!(c&1)){break c}f=w[g+213|0];c=0;v[22708]=0;k=a+484344|0;R(330,k|0,f|0);f=v[22708];v[22708]=0;I:{if((f|0)!=1){if(!w[g+213|0]){break c}r=i+((r>>>0>13)<<1)|0;while(1){J:{e=64;if(tc(n)>>>0>c>>>0){e=x[sc(n,c)>>1]}v[22708]=0;f=W(331,k|0,c&65535,e&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break I}K:{if(f){f=x[a+480188>>1];e=w[l|0];v[22708]=0;Q(190,b|0,r+B(((e>>>0>13)<<1)+(f<<1)|0,c)|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break I}f=mc(g+80|0);e=x[a+480188>>1];v[22708]=0;e=W(327,b|0,f|0,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break K}L:{if(!e){break L}e=0;if(!x[a+480188>>1]){break L}while(1){M:{i=sc(f,e);if(!(w[i|0]|w[i+1|0]<<8)){break M}i=sc(f,e);if((w[i|0]|w[i+1|0]<<8)>>>0>(w[g+214|0]|w[g+215|0]<<8)>>>0){break M}i=sc(f,e);i=sc(j,(w[i|0]|w[i+1|0]<<8)-1|0);i=w[i|0]|w[i+1|0]<<8;if(!i|d>>>0<i>>>0){break M}m=_b(k,c);i=Kg(o,i-1&65535);v[22708]=0;U(332,m|0,e&65535,i|0);i=v[22708];v[22708]=0;if((i|0)!=1){break M}break J}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}Pk(f)}c=c+1|0;if(c>>>0>=w[g+213|0]){break c}continue}}break}a=P()|0;O()|0;Pk(f);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Hb(g+8|0);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0}jd(o)}Pk(j);break f}a=P()|0;O()|0;vb(g+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}Lc(q)}Ze(n)}S(a|0);L()}jd(o)}Pk(j);Lc(q);Ze(n)}gb=g+224|0;return h|0}function E2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2509;b=l+96|0;r=ge(l+136|0,l+144|0,b);k=v[r>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;u=Kb(b);m=Kb(l+80|0);n=Kb(l- -64|0);o=Kb(l+48|0);s=Kb(l+32|0);v[22708]=0;na(2518,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,m|0,n|0,o|0,l+28|0);b=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;p=v[l+28>>2];e=0;f:{while(1){v[22708]=0;b=Q(2487,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}g:{if(!b){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+q|0]){case 1:if((q|0)==3){break g}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;b=W(2519,h|0,8192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(b){v[22708]=0;R(2520,l+16|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[l+16>>2];v[22708]=0;R(63,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((q|0)==3){break g}}while(1){v[22708]=0;b=Q(2487,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break h}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;b=W(2519,h|0,8192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break h}v[22708]=0;R(2520,l+16|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[l+16>>2];v[22708]=0;R(63,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}r:{if(Ab(n)){if(Ab(o)){break r}}if(Ab(n)){v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)!=v[Jb(n)>>2]){break l}v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}e=Ab(n)>>>0>1?n:e;break h}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)!=v[Jb(o)>>2]){break h}v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;e=Ab(o)>>>0>1?o:e;break h}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)==v[Jb(n)>>2]){v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}e=Ab(n)>>>0>1?n:e;break h}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)==v[Jb(o)>>2]){v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;e=Ab(o)>>>0>1?o:e;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(q>>>0<2|e|((q|0)==2&w[l+123|0]!=0|z))){e=0;break h}B=l,C=zd(m),v[B+8>>2]=C;b=Gd(l+16|0,l+8|0);s:{if(!q|w[(l+q|0)+119|0]>1){break s}B=l,C=vi(m),v[B+8>>2]=C;t:{if(!Gb(b,l+8|0)){break t}while(1){c=v[v[b>>2]>>2];v[22708]=0;c=W(2519,h|0,8192,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break k}if(!c){break t}Qe(b);B=l,C=vi(m),v[B+8>>2]=C;if(Gb(b,l+8|0)){continue}break}}B=l,C=zd(m),v[B+8>>2]=C;c=ov(b,l+8|0);if(Ab(s)>>>0>=c>>>0){B=l,C=vi(s),v[B+8>>2]=C;b=gb-16|0;gb=b;v[b+8>>2]=v[l+8>>2];v[b+8>>2]=v[b+8>>2]+(0-c<<2);c=v[b+8>>2];gb=b+16|0;d=vi(s);x=zd(m);b=gb-32|0;gb=b;v[b+16>>2]=d;v[b+24>>2]=c;v[b+8>>2]=x;c=1;u:{if(!Gb(b+24|0,b+16|0)){break u}while(1){c=Qj(v[b+24>>2],v[b+8>>2]);if(!c){break u}d=b+24|0;Qe(d);Qe(b+8|0);if(Gb(d,b+16|0)){continue}break}}gb=b+32|0;if(c){break s}}B=l,C=zd(m),v[B>>2]=C;Gd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];B=l,C=vi(m),v[B>>2]=C;v:{w:{x:{if(!Gb(l+8|0,l)){break x}while(1){v[22708]=0;b=Q(2487,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}if(!b){break x}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}if((b|0)!=v[v[l+8>>2]>>2]){break x}v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}b=l+8|0;Qe(b);B=l,C=vi(m),v[B>>2]=C;if(Gb(b,l)){continue}break}}if(!y){break h}B=l,C=vi(m),v[B>>2]=C;if(!Gb(l+8|0,l)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+28>>2]=p;break a}a=P()|0;O()|0;v[l+28>>2]=p;break a}d=0;x=v[l+112>>2];b=k;y:{while(1){z:{v[22708]=0;c=Q(2487,a|0,l+552|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break z}if(!c){break y}v[22708]=0;c=T(2489,a|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}v[22708]=0;k=W(2519,h|0,2048,c|0)|0;A=v[22708];v[22708]=0;if((A|0)==1){break e}A:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22708]=0;U(2521,i|0,j|0,l+548|0);k=v[22708];v[22708]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=c;d=d+1|0;break A}if(!Ab(u)|!d|(c|0)!=(x|0)){break y}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2515,r|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22708]=0;T(2491,a|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2515,r|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break i}t[g|0]=1;break h}a=P()|0;O()|0;v[l+28>>2]=p;break a}k=b}B:{if((p|0)<1){break B}v[22708]=0;b=Q(2488,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}C:{if(!b){v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}if((b|0)==v[l+116>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}while(1){if((p|0)<1){p=0;break B}v[22708]=0;b=Q(2488,a|0,l+552|0)|0;c=v[22708];v[22708]=0;D:{if((c|0)==1){break D}E:{if(!b){v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break D}v[22708]=0;b=W(2519,h|0,2048,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break D}if(b){break E}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22708]=0;U(2521,i|0,j|0,l+548|0);b=v[22708];v[22708]=0;if((b|0)==1){break D}}v[22708]=0;b=T(2489,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break D}c=v[j>>2];v[j>>2]=c+4;v[c>>2]=b;v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;p=p-1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}q=q+1|0;if((q|0)!=4){continue}}break}v[l+28>>2]=p;F:{if(!e){break F}c=1;while(1){if(Ab(e)>>>0<=c>>>0){break F}v[22708]=0;b=Q(2488,a|0,l+552|0)|0;d=v[22708];v[22708]=0;G:{if((d|0)==1){break G}H:{if(!b){v[22708]=0;b=T(2489,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break G}if((b|0)==v[xk(e,c)>>2]){break H}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;c=c+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[r>>2]==(k|0)){break f}a=0;v[l+16>>2]=0;hf(u,v[r>>2],k,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}Ic(s);Ic(o);Ic(n);Ic(m);vb(u);Hc(r);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ic(s);Ic(o);Ic(n);Ic(m);vb(u);Hc(r);S(a|0);L()}function Bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=gb-320|0;gb=d;a:{if(!Wc(b,1080)){break a}if(!hp(b,d+316|0)){break a}Hd(a,1);m=DV(d+296|0);if(!CV(d+316|0,m)){break a}h=x[m+10>>1];e=h;if(!e|e>>>0>127){break a}if(!c){j=1;break a}u[a+480188>>1]=h;C=w[m+14|0];T=w[m+13|0];g=w[m+12|0];M=1;if(!je(d+316|0,33192)){M=je(d+316|0,33197)}if(w[m+15|0]){Ob(a+1074312|0,5,1);h=x[a+480188>>1]}e=d+316|0;o=je(e,13819);f=1;if(!je(e,14596)){f=je(d+316|0,10894)}J=a+480188|0;G=(h&65535)==8&(T|0)!=0;Wc(b,0);TC(b,a+1298268|0,20);u[a+480190>>1]=31;n=(g|0)!=0;j=1;g=o;while(1){s=B(j,104)+a|0;e=s+484380|0;h=fC(b,d+160|0,e,((j<<5)+a|0)+946304|0,x[a+480188>>1]==4);p=v[e>>2];b:{if(f){t[s+484417|0]=0-(w[d+184|0]<<3);break b}n=p>>>0<65536&n}c:{d:{if(!Ib(w[d+182|0]|w[d+183|0]<<8)){break d}if(Ib(w[d+188|0]|w[d+189|0]<<8)){break d}ba=1;break c}if(Ib(w[d+182|0]|w[d+183|0]<<8)){break c}V=w[d+185|0]==64|V}e=g&1;g=0;e:{if(!e){break e}y=(Ib(w[d+182|0]|w[d+183|0]<<8)<<1)+y|0;if(w[d+184|0]){break e}if(!Ib(w[d+182|0]|w[d+183|0]<<8)){g=1;break e}g=w[d+185|0]==64}N=h+N|0;i=i+p|0;j=j+1|0;if((j|0)!=32){continue}break}f:{g:{h:{i:{j:{k:{X=v[m+4>>2];if(X>>>0>=N>>>0){p=d+160|0;AV(b,p);Wc(b,x[m+8>>1]);z=p|1;e=w[z|0];f=128;l=a+484360|0;Dr(Sb(l),p|2,128);s=!e&g;h=s?y:0;e=w[p|0];l:{if(e>>>0>128){break l}f=e;if(e){break l}g=128;while(1){e=g-1|0;if(!x[sc(Sb(l),e)>>1]){f=1;g=e;if(e>>>0>1){continue}break l}break}f=g}Q=(C|0)!=0;D=zV(b,Sb(l),f&65535,i,J,h,0);if(!(!s|x[a+480188>>1]!=8)){v[m>>2]=8553;Q=1}m:{if(!G){break m}e=Sb(l);da=d,ea=Vb(e),v[da+144>>2]=ea;da=d,ea=Zb(e),v[da+128>>2]=ea;if(!Gb(d+144|0,d+128|0)){break m}while(1){g=d+144|0;e=v[g>>2];u[e>>1]=x[e>>1]>>>1;of(g);if(Gb(g,d+128|0)){continue}break}}cf(Sb(l),w[z|0]);p=f-1&65535;n:{if(p>>>0>=w[z|0]){j=x[J>>1];if(w[z|0]!=120|(j|0)!=4){break n}}cf(Sb(l),0);j=x[J>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;e=Lb(256/((j&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;xh(a,0);t[d+159|0]=0;E=1;j=1;if(!(n&1)){o:{if(!D){e=o;break o}s=d+144|5;e=o;n=0;y=0;while(1){g=0;f=0;while(1){i=cj(d+144|0);gv(b,i);C=Av(i);h=0;p:{q:{r:{s:{t:{l=w[d+147|0];if((l-7&255)>>>0<3){break t}i=w[d+149|0];if((l|0)==14&i>>>0>1){break s}if(!((l|0)==15&(i&255)>>>0>31)){h=C?e:0;if((l|0)!=13){break t}f=f+1|0;if((f&65535)>>>0<2){break q}}h=0;break p}if((l|0)==8){break r}if((l|0)!=14){break q}i=w[d+149|0]}if((i&240)!=128){break q}t[d+128|0]=i<<4;da=d,ea=w[qf(d+159|0,d+128|0)|0],t[da+159|0]=ea;break q}da=d,ea=w[qf(d+159|0,s)|0],t[da+159|0]=ea;e=t[d+149|0];if((e|0)>-1){y=1;break p}n=(e|0)!=-92&(e&255)>>>0>143|n}}e=h;E=C&E;g=g+1|0;if((g|0)!=256){continue}break}q=q+1|0;if(D>>>0>(q&65535)>>>0){continue}break}q=0;if((y^-1|n)&1){break o}q=w[d+159|0]>47}j=e&1}Wc(b,x[m+8>>1]);g=x[a+480188>>1];H=a+484344|0;f=D+G|0;e=f&65535;zg(H,e);Y=G?4:g;r=a+1074312|0;u:{if(!e){q=0;break u}C=q^1;s=c&1;y=Y&65535;Z=f&65535;n=0;q=0;v:{while(1){w:{if(G){f=(F&65534)>>>1|0;e=F&1;if(!e){if(!wh(H,f,64)){break u}}e=Yc(_b(H,f),0,e<<2);break w}if(!wh(H,F&65535,64)){break u}e=Yc(_b(H,F),0,0)}if(!e|!s){break u}f=x[a+480188>>1];t[d+128|0]=0;g=d+128|0;I=Mv(d+144|0,f,g);f=x[a+480188>>1];v[22708]=0;t[d+64|0]=0;K=W(780,g|0,f|0,d- -64|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){l=0;while(1){i=0;D=0;h=0;if(y){while(1){v[22708]=0;k=B(h,6)+e|0;R(781,b|0,k|0);f=v[22708];v[22708]=0;x:{y:{if((f|0)!=1){f=w[k+3|0];z:{A:{B:{if(!f){if(w[k+5|0]){break B}break A}if(!T){break B}C:{switch(f-14|0){case 0:t[k+3|0]=0;t[k+5|0]=0;break B;case 1:break C;default:break B}}if(w[k+5|0]<32){break B}t[k+5|0]=31}Of(k);f=1;D:{E:{F:{g=w[k+3|0];switch(g-14|0){case 2:break z;case 0:break E;case 3:break F;default:break D}}q=w[k+5|0]<100|q;D=1;break A}if(!j){break A}t[k+5|0]=0;break A}if(!(C|(g|0)!=9)){f=w[k+5|0];if((f|0)==164){t[k+3|0]=20;t[k+5|0]=145;break A}da=k,ea=ei(f<<1),t[da+5|0]=ea;break A}if((g|0)!=19){break A}f=w[k+5|0];if(f>>>0>15){break A}f=f&1;g=!f;ca=!f;f=n&1;n=(f|0)==(g|0)?n:ca;_=((f|0)!=(g|0))+_|0}f=i}if(w[k|0]){break y}if(!w[k+1|0]|G){break x}if(!w[lc(I,h)|0]){break x}if(w[lc(I,h)|0]==w[k+1|0]){break x}g=lc(K,h);i=w[g|0]+1|0;t[g|0]=i;if((i&255)>>>0<4){break x}v[22708]=0;W(409,r|0,85,1)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break x}}h=P()|0;O()|0;gc(K);break v}da=lc(K,h),ea=0,t[da|0]=ea}g=w[k+1|0];if(g){da=lc(I,h),ea=g,t[da|0]=ea}i=f;h=h+1|0;if((y|0)!=(h|0)){continue}break}}$=i&D|$;e=B(x[J>>1],6)+e|0;l=l+1|0;if((l|0)!=64){continue}break}gc(K);gc(I);F=F+1|0;if((Z|0)==(F|0)){break u}continue}break}h=P()|0;O()|0}gc(I);break f}G:{H:{I:{if((E^-1|ba)&1){break I}J:{if(je(d+316|0,13819)){break J}if(je(d+316|0,14601)){break J}if(!je(d+316|0,10889)){break I}}v[a+480208>>2]=v[a+480208>>2]|2162688;Ob(r,85,1);Ob(r,91,1);Ob(r,92,1);K:{if(w[d+159|0]>47){break K}Ob(r,84,1);if(w[z|0]==127){break K}Ob(r,83,1)}if(!E){break G}break H}if(E){break H}if(o^1|w[z|0]!=127|p>>>0>w[z|0]+1>>>0){break G}v[m>>2]=5485;break G}if((_|0)>6|Q){break G}v[a+480208>>2]=v[a+480208>>2]|8388608}if((o|Q)==1){Ob(r,89,1)}if(M){Ob(r,84,1)}if(c&2){Wc(b,x[m+8>>1]+(B(Y&65535,Z)<<8)|0);f=(o&E^1|V)&1;j=1;while(1){e=B(j,104)+a|0;i=e+484380|0;if(v[i>>2]){g=d+144|0;if(M){c=2}else{c=yV(b,11149)?10:0}g=Rc(g,8,1,0,c);c=v[b+8>>2]+yv(g,v[i>>2])|0;if(!f){da=i,ea=v[Mc(i,e+484388|0)>>2],v[da>>2]=ea}Cg(g,i,b);Wc(b,c)}j=j+1|0;if((j|0)!=32){continue}break}}L:{if((o&q^-1|$)&1){break L}c=xV(d+104|0,0);b=v[c+20>>2];v[d+40>>2]=v[c+16>>2];v[d+44>>2]=b;b=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=b;b=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=b;b=d+144|0;tu(b,a,0,d+24|0);aa=A[v[b>>2]>>3];en(b);if(!(aa>=600)){break L}Ob(r,5,1);c=wV(d+80|0,aa);b=v[c+20>>2];v[d+16>>2]=v[c+16>>2];v[d+20>>2]=b;b=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=b;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;c=d+144|0;tu(c,a,0,d);b=w[v[c>>2]+26|0];en(c);if(b){Rf(r,5);break L}v[m>>2]=14153}o=d+316|0;f=o;b=f;e=fc(b);g=e;if((b|0)!=(e|0)){while(1){c=w[f|0];t[b|0]=c>>>0>32?c:32;b=b+1|0;f=f+1|0;if((g|0)!=(f|0)){continue}break}}Ef(d+128|0,13906);v[22708]=0;c=W(782,d+48|0,o|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break k}v[22708]=0;U(13,d- -64|0,1,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break j}v[22708]=0;U(167,d+144|0,d+128|0,d- -64|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d+144|0;Eb(a+1298304|0,b);vb(b);vb(d- -64|0);vb(c);Hb(d+128|0);b=Tb(b,9562);Eb(a+1298316|0,b);vb(b);b=v[m>>2];if(b){Xc(a+1298328|0,b)}v[a+1298364>>2]=2}j=N>>>0<=X>>>0;break a}h=P()|0;O()|0;break g}h=P()|0;O()|0;break h}h=P()|0;O()|0;vb(d- -64|0)}vb(c)}Hb(d+128|0)}S(h|0);L()}gb=d+320|0;return j|0}function xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;e=f+24|0;j=d+120|0;AU(e,j);k=yb(e);e=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=e;v[f>>2]=h;v[f+4>>2]=e;h=f+16|0;e=b;cc(h,e,f);h=yb(h);if((h|0)==(k|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(h|0)==(k|0);if(!e){zU(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!KU(d+120|0)){break e}if(!c){i=1;break e}Hd(a,4194304);e=d+32|0;f=Tb(e,14112);Eb(a+1298304|0,f);vb(f);f=Tb(e,7407);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;n=a,o=Fd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[n+480188>>1]=o;f=w[d+189|0];v[a+480228>>2]=(f|0)==255?48:f;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);f=d+96|0;pf(f,d+120|4,59,3);Bc(e,f);Eb(a+1298268|0,e);vb(e);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Wc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!Gh(b,11471)){break f}jp(Sb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Wc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!Gh(b,11108)){break g}while(1){e=(i<<5)+a|0;We(e+480280|0);n=e+480284|0,o=((((Ae(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;i=i+1|0;if((i|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Wc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!Gh(b,11384)){break h}f=d+32|0;Sd(f,b,(w[d+196|0]|w[d+197|0]<<8)<<6);e=kc(d+96|0,f);xb(f);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}k=c&2;j=a+480190|0;h=d+45|0;while(1){v[22708]=0;f=Q(867,e|0,d+32|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!f){break i}f=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=f;j:{if((f-1&65535)>>>0>3998){break j}if(Md((B(f,104)+a|0)+484380|0)){break j}v[22708]=0;f=Ke(j,d+30|0);i=v[22708];v[22708]=0;if((i|0)==1){break c}u[a+480190>>1]=x[f>>1];v[22708]=0;R(868,d+32|0,(B(x[d+30>>1],104)+a|0)+484380|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}pf(d,h,24,1);v[22708]=0;R(324,d+16|0,d|0);f=v[22708];v[22708]=0;k:{if((f|0)!=1){v[22708]=0;Q(301,((x[d+30>>1]<<5)+a|0)+946304|0,d+16|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}vb(d+16|0);if(!k){break j}f=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22708]=0;Q(190,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}i=1;g=d+16|0;f=d+79|0;l=Rc(g,w[f|0]&4?16:8,1,0,0);l:{m:{if(w[f|0]&8){break m}i=2;if(w[f|0]&16){break m}if(w[f|0]&127){break l}}Cf(l,i)}v[22708]=0;W(329,g|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break j}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+16|0);break b}m=m+1|0;if((m&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}xb(e)}i=1;if(!(c&1)){break e}n:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break n}if(!Wc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break n}if(!Gh(b,10974)){break n}h=a+484344|0;zg(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break n}k=d+16|2;m=0;while(1){if(!wC(b,d+16|0)){break n}if((w[d+16|0]|w[d+17|0]<<8)>>>0>3){c=d+96|0;Sd(c,b,((w[d+16|0]|w[d+17|0]<<8)+15&131056)-4|0);f=kc(d+32|0,c);xb(c);c=w[k|0];v[22708]=0;c=W(331,h|0,m&65535,c|0)|0;e=v[22708];v[22708]=0;o:{if((e|0)!=1){p:{j=0;if(!c){break o}while(1){v[22708]=0;c=Q(191,d+32|0,1)|0;e=v[22708];v[22708]=0;q:{r:{s:{if((e|0)!=1){if(!c|w[k|0]<=j>>>0){break r}v[22708]=0;e=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}if(e){break s}j=j+1|0;continue}break p}c=_b(h,m);u[d+96>>1]=e&31;g=x[a+480188>>1];v[22708]=0;u[d>>1]=g-1;g=Pc(d+96|0,d);l=v[22708];v[22708]=0;if((l|0)==1){break p}g=x[g>>1];v[22708]=0;c=Yc(c,j,g);g=v[22708];v[22708]=0;if((g|0)==1){break p}if(e&128){v[22708]=0;R(403,d+96|0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break p}g=d+96|0;l=qd(g);t[c|0]=w[g|0]+36;t[c+1|0]=w[l|0]}if(!(e&64)){break q}t[c+2|0]=1;v[22708]=0;g=T(374,f|0)|0;l=v[22708];v[22708]=0;t:{if((l|0)!=1){t[d+96|0]=g;v[22708]=0;t[d|0]=64;g=ac(d+96|0,d);l=v[22708];v[22708]=0;if((l|0)==1){break t}t[c+4|0]=w[g|0];break q}break p}break p}if(w[k|0]==64){break o}c=_b(h,m);v[22708]=0;e=Be(d+96|0,14,0);f=v[22708];v[22708]=0;if((f|0)!=1){e=Fh(Ue(e,w[k|0]-1|0));v[22708]=0;Q(431,c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break o}}break p}if(!(e&32)){continue}v[22708]=0;R(403,d+96|0,f|0);e=v[22708];v[22708]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((e|0)!=1){g=d+96|0;e=w[qd(g)|0];t[c+5|0]=e;switch(w[g|0]-1|0){case 71:break v;case 70:break w;case 69:break x;case 60:break y;case 59:break z;case 52:break A;case 51:break B;case 50:break C;case 49:break D;case 42:break E;case 41:break F;case 40:break G;case 39:break H;case 30:break I;case 29:break J;case 22:break K;case 21:break L;case 20:break M;case 19:break N;case 16:break O;case 15:break P;case 14:break Q;case 13:break R;case 12:break S;case 11:break T;case 10:break U;case 9:break V;case 3:break W;case 2:break X;case 1:break Y;case 0:break Z;default:break u}}break p}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22708]=0;e=T(374,f|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){t[c+5|0]=e;v[22708]=0;Q(318,d+32|0,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break p}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;xb(d+32|0);break a}xb(d+32|0)}m=m+1|0;if(m>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Wc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));pB(a+1298292|0,b,Ng(b),4)}gb=d+272|0;return i|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(e)}S(b|0);L()}function Soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;f=gb-1344|0;gb=f;vc(b);g=gb-32|0;gb=g;d=g+24|0;h=f+768|0;uX(d,h);k=yb(d);i=v[g+28>>2];d=v[g+24>>2];v[g+8>>2]=d;v[g+12>>2]=i;v[g>>2]=d;v[g+4>>2]=i;i=g+16|0;d=b;cc(i,d,g);i=yb(i);if((i|0)==(k|0)){Rb(d,yb(g+24|0))}gb=g+32|0;d=(i|0)==(k|0);if(!d){tX(h)}a:{b:{c:{if(!d){break c}if(!xX(f+768|0)){break c}if(!Pb(b,Qc(wX(f+768|0),jb))){break c}if(!c){e=1;break c}j=vr(f+760|0);A=1;d:{while(1){g=(e<<5)+a|0;k=g+480280|0;We(k);h=(f+768|0)+(e<<4)|0;u[g+480284>>1]=((w[h+78|0]<<8&65280)>>>0)/255;i=f+496|0;Lk(i,1,h- -64|0);d=f+112|0;Bc(d,i);v[22708]=0;Q(399,g+480289|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(f+112|0);e:{f:{switch(w[h+79|0]){case 0:o=e+1|0;break e;case 1:v[k>>2]=1024;o=m+1|0;break e;case 2:break f;default:break d}}v[k>>2]=1024;d=f+112|0;Al(d,j,e);Uf(d,1)}A=e>>>0<31;m=m+1|0;e=e+1|0;if((e|0)!=32){continue}break}Hd(a,33554432);u[a+480188>>1]=o&255;d=f+112|0;e=Tb(d,3830);Eb(a+1298304|0,e);vb(e);e=Tb(d,8329);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;g:{if(w[f+847|0]){break g}m=1;while(1){if(w[((m<<4)+f|0)+847|0]!=1){break g}e=1;m=m+1|0;if((m|0)!=16){continue}break}while(1){d=((e<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}d=f+496|0;Je(d,1,f+768|0);e=f+112|0;Bc(e,d);Eb(a+1298268|0,e);vb(e);v[a+480208>>2]=v[a+480208>>2]&-17|(w[f+806|0]|w[f+807|0]<<8)<<4&16;v[a+480196>>2]=w[f+816|0];v[a+480204>>2]=B(w[f+817|0],1e4);C=a,D=Fd(w[f+818|0],0,64)<<2,v[C+480200>>2]=D;C=a,D=Fd(w[f+819|0],4,127),v[C+480228>>2]=D;e=w[f+804|0]|w[f+805|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;kw(b,d);Tr(Sb(a+484360|0),d,w[f+800|0]|w[f+801|0]<<8,65535,255);n=c&1;if(n){zg(a+484344|0,w[f+802|0]|w[f+803|0]<<8)}if(w[f+802|0]|w[f+803|0]<<8){p=a+484344|0;while(1){e=Ng(b);z=Ng(b);d=f+48|0;Sd(d,b,e-4|0);q=kc(f+112|0,d);xb(d);h:{if(!n){break h}v[22708]=0;d=W(331,p|0,r&65535,z|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){i:{if(!d){break h}s=0;i=cj(f+24|0);if(!z){break h}while(1){j:{v[22708]=0;m=T(374,q|0)|0;e=v[22708];v[22708]=0;k:{l:{if((e|0)!=1){if(m){break l}s=s+1|0;break k}break i}e=i;l=m&31;if(l>>>0<x[a+480188>>1]){e=_b(p,r);v[22708]=0;e=Yc(e,s,l);d=v[22708];v[22708]=0;if((d|0)==1){break i}}m:{if(!(m&32)){break m}v[22708]=0;R(403,f+48|0,q|0);h=v[22708];v[22708]=0;d=e;n:{o:{if((h|0)!=1){k=f+48|0;h=qd(k);k=w[k|0];t[e|0]=k;t[e+1|0]=w[h|0];if((k|0)!=160){break o}h=255;break n}break i}if((k|0)!=255){t[e|0]=(B(k>>>4|0,12)+(k&15)|0)+13;v[22708]=0;k=XC(e);h=v[22708];v[22708]=0;if((h|0)!=1){h=0;if(!k){break n}break m}break i}h=0}t[d|0]=h}d=m&192;p:{if(!d){break p}if((d|0)==192){v[22708]=0;R(531,f+48|0,q|0);d=v[22708];v[22708]=0;q:{r:{s:{if((d|0)!=1){d=f+48|0;h=d;k=qd(d);m=Ve(d);o=fj(d);g=w[d|0];if((g|0)!=12){break s}v[22708]=0;t[f|0]=64;h=ac(k,f);d=v[22708];v[22708]=0;if((d|0)==1){break i}t[e+4|0]=w[h|0];d=1;break r}break i}d=w[m|0];t:{if((d|0)==12){v[22708]=0;t[f|0]=64;m=ac(o,f);d=v[22708];v[22708]=0;if((d|0)!=1){t[e+4|0]=w[m|0];d=1;break t}break i}if((g|0)==10){t[e+4|0]=(w[k|0]<<6>>>0)/255;d=2;break r}if((d|0)!=10){break q}t[e+4|0]=(w[o|0]<<6>>>0)/255;d=2}m=h;o=k}t[e+2|0]=d;d=w[m|0]}t[e+3|0]=d;t[e+5|0]=w[o|0];break p}v[22708]=0;R(403,f+48|0,q|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}h=f+48|0;d=qd(h);t[e+3|0]=w[h|0];t[e+5|0]=w[d|0]}if(w[e+3|0]){v[22708]=0;_(553,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}}d=f+48|0;Al(d,j,l);if(!Cb(d)){break k}v[22708]=0;h=vX(e);d=v[22708];v[22708]=0;if((d|0)==1){break j}if(!h){break k}t[e+3|0]=0}if(s>>>0<z>>>0){continue}break h}break}}}e=P()|0;O()|0;xb(f+112|0);break a}xb(f+112|0);r=r+1|0;if(r>>>0<(w[f+802|0]|w[f+803|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break d}m=c&2;p=f- -64|0;o=1;d=0;while(1){d=d+1|0;k=d&65535;n=FO(a,k,0);g=gb-32|0;gb=g;c=g+24|0;i=f+112|0;bc(c,i,384);h=yb(c);e=v[g+28>>2];c=v[g+24>>2];v[g+8>>2]=c;v[g+12>>2]=e;v[g>>2]=c;v[g+4>>2]=e;e=g+16|0;c=b;cc(e,c,g);e=yb(e);if((e|0)==(h|0)){Rb(c,yb(g+24|0))}gb=g+32|0;c=(e|0)==(h|0);if(!c){Qb(i,0,384)}if(!(!c|!n)){i=o&65535;l=gb-32|0;gb=l;g=f+112|0;Je(l,1,g);c=l+16|0;Bc(c,l);v[22708]=0;Q(301,n+492|0,c|0)|0;c=v[22708];v[22708]=0;u:{if((c|0)!=1){vb(l+16|0);v:{if(!(w[g+378|0]|w[g+379|0]<<8)){break v}v[l+16>>2]=120;v[l>>2]=116;if(!v[Fb(l+16|0,l)>>2]){break v}e=n+236|0;h=0;while(1){c=w[(g+h|0)+32|0];C=vd(e,h+12|0),D=c+i|0,u[C>>1]=D;v[l+16>>2]=120;v[l>>2]=116;h=h+1|0;if(h>>>0<y[Fb(l+16|0,l)>>2]){continue}break}}c=w[g+376|0]|w[g+377|0]<<8;t[n+33|0]=1;v[n>>2]=c;WC(g,n+48|0,0);WC(g,n+68|0,1);WC(g,n+88|0,2);c=w[n+100|0];if(c&1){t[n+100|0]=c|16}if(!(v[n>>2]|t[n+60|0]&1)){v[n>>2]=32767}gb=l+32|0;break u}a=P()|0;O()|0;vb(l+16|0);S(a|0);L()}e=0;w:{if(!(w[f+490|0]|w[f+491|0]<<8)){break w}while(1){x:{bY(b,f+48|0);y:{if((w[f+108|0]|w[f+109|0]<<8|(w[f+110|0]<<16|w[f+111|0]<<24))!=808538953){break y}c=e+o|0;l=c&65535;if(l>>>0>3999){break y}u[a+480190>>1]=c;i=gb-32|0;gb=i;n=B(l,104)+a|0;h=n+484380|0;g=h;ud(g,0);j=f+48|0;li(i,1,j);c=i+16|0;Bc(c,i);v[22708]=0;Q(303,g+43|0,c|0)|0;c=v[22708];v[22708]=0;z:{if((c|0)!=1){vb(i+16|0);v[g>>2]=w[j+16|0]|w[j+17|0]<<8|(w[j+18|0]<<16|w[j+19|0]<<24);v[g+4>>2]=w[j+20|0]|w[j+21|0]<<8|(w[j+22|0]<<16|w[j+23|0]<<24);v[g+8>>2]=w[j+24|0]|w[j+25|0]<<8|(w[j+26|0]<<16|w[j+27|0]<<24);v[g+24>>2]=w[j+28|0]|w[j+29|0]<<8|(w[j+30|0]<<16|w[j+31|0]<<24);u[g+30>>1]=w[j+32|0]<<2;u[g+28>>1]=w[j+33|0];if(t[j+48|0]&1){u[g+34>>1]=x[g+34>>1]|2}if(w[j+48|0]&2){u[g+34>>1]=x[g+34>>1]|4}if(w[j+48|0]&4){u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}if(w[j+48|0]&8){u[g+34>>1]=x[g+34>>1]|32}gb=i+32|0;break z}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}g=gb-16|0;gb=g;i=g+8|0;VE(i,n+484423|0);c=f+24|0;Yr(c,i);gb=g+16|0;v[22708]=0;Q(301,((l<<5)+a|0)+946304|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break x}vb(f+24|0);if(!(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))){break y}Sd(f,b,w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24));i=kc(f+24|0,f);xb(f);A:{if(!m){break A}c=Rc(f,u[n+484414>>1]&1?16:8,1,0,0);v[22708]=0;W(329,c|0,h|0,i|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break A}e=P()|0;O()|0;xb(f+24|0);break a}xb(f+24|0)}e=e+1|0;if(e>>>0<(w[f+490|0]|w[f+491|0]<<8)>>>0){continue}break w}break}e=P()|0;O()|0;vb(f+24|0);break a}o=(w[f+490|0]|w[f+491|0]<<8)+o|0}if(k>>>0<x[a+480192>>1]){continue}break}}e=!A}gb=f+1344|0;return e&1}e=P()|0;O()|0;vb(f+112|0)}S(e|0);L()}function N2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2509;b=l+104|0;q=ge(l+136|0,l+144|0,b);k=v[q>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;u=Kb(b);m=Kb(l+88|0);n=Kb(l+72|0);p=Kb(l+56|0);s=Kb(l+40|0);v[22708]=0;na(2512,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,m|0,n|0,p|0,l+36|0);b=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;r=v[l+36>>2];e=0;f:{while(1){v[22708]=0;b=Q(2460,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}g:{if(!b){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(nh(h,8192,b)){v[22708]=0;R(2513,l+24|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=t[l+24|0];v[22708]=0;R(61,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break h}}if((e|0)==3){break g}}while(1){v[22708]=0;b=Q(2460,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break h}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!nh(h,8192,b)){break h}v[22708]=0;R(2513,l+24|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=t[l+24|0];v[22708]=0;R(61,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(p)|0)){break h}q:{if(Ab(n)){if(Ab(p)){break q}}if(Ab(n)){v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(n,0)|0]!=(b&255)){break k}v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}o=Ab(n)>>>0>1?n:o;break h}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(p,0)|0]!=(b&255)){break h}v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;o=Ab(p)>>>0>1?p:o;break h}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(n,0)|0]==(b&255)){v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}o=Ab(n)>>>0>1?n:o;break h}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(p,0)|0]==(b&255)){v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;o=Ab(p)>>>0>1?p:o;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|o|((e|0)==2&w[l+123|0]!=0|z))){o=0;break h}A=l,B=zd(m),v[A+16>>2]=B;b=Gd(l+24|0,l+16|0);r:{if(!e|w[(e+l|0)+119|0]>1){break r}A=l,B=ff(m),v[A+16>>2]=B;s:{if(!Gb(b,l+16|0)){break s}while(1){if(!nh(h,8192,t[v[b>>2]])){break s}Oe(b);A=l,B=ff(m),v[A+16>>2]=B;if(Gb(b,l+16|0)){continue}break}}A=l,B=zd(m),v[A+16>>2]=B;b=ak(b,l+16|0);if(Ab(s)>>>0>=b>>>0){A=l,B=ff(s),v[A+16>>2]=B;c=we(l+16|0,0-b|0);d=ff(s);x=zd(m);b=gb-32|0;gb=b;v[b+16>>2]=d;v[b+24>>2]=c;v[b+8>>2]=x;c=1;t:{if(!Gb(b+24|0,b+16|0)){break t}while(1){c=w[v[b+24>>2]]==w[v[b+8>>2]];if(!c){break t}d=b+24|0;Oe(d);Oe(b+8|0);if(Gb(d,b+16|0)){continue}break}}gb=b+32|0;if(c){break r}}A=l,B=zd(m),v[A+8>>2]=B;Gd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];A=l,B=ff(m),v[A+8>>2]=B;u:{v:{w:{if(!Gb(l+16|0,l+8|0)){break w}while(1){v[22708]=0;b=Q(2460,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(!b){break w}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(w[v[l+16>>2]]!=(b&255)){break w}v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}b=l+16|0;Oe(b);A=l,B=ff(m),v[A+8>>2]=B;if(Gb(b,l+8|0)){continue}break}}if(!y){break h}A=l,B=ff(m),v[A+8>>2]=B;if(!Gb(l+16|0,l+8|0)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+36>>2]=r;break a}a=P()|0;O()|0;v[l+36>>2]=r;break a}d=0;x=w[l+118|0];b=k;x:{while(1){y:{v[22708]=0;c=Q(2460,a|0,l+552|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break y}if(!c){break x}v[22708]=0;c=T(2462,a|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}z:{if(nh(h,2048,c)){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22708]=0;U(2514,i|0,j|0,l+548|0);k=v[22708];v[22708]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+1;t[k|0]=c;d=d+1|0;break z}if(!Ab(u)|!d|(x|0)!=(c&255)){break x}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2515,q|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22708]=0;T(2464,a|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[q>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2515,q|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break i}t[g|0]=1;break h}k=b}A:{if((r|0)<1){break A}v[22708]=0;b=Q(2461,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}B:{if(!b){v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}if(w[l+119|0]==(b&255)){break B}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}while(1){if((r|0)<1){r=0;break A}v[22708]=0;b=Q(2461,a|0,l+552|0)|0;c=v[22708];v[22708]=0;C:{if((c|0)==1){break C}D:{if(!b){v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break C}if(nh(h,2048,b)){break D}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22708]=0;U(2514,i|0,j|0,l+548|0);b=v[22708];v[22708]=0;if((b|0)==1){break C}}v[22708]=0;b=T(2462,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break C}c=v[j>>2];v[j>>2]=c+1;t[c|0]=b;v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;r=r-1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;if((e|0)!=4){continue}}break}v[l+36>>2]=r;E:{if(!o){break E}c=1;while(1){if(Ab(o)>>>0<=c>>>0){break E}v[22708]=0;b=Q(2461,a|0,l+552|0)|0;d=v[22708];v[22708]=0;F:{if((d|0)==1){break F}G:{if(!b){v[22708]=0;b=T(2462,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}if(w[pc(o,c)|0]==(b&255)){break G}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;c=c+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[q>>2]==(k|0)){break f}a=0;v[l+24>>2]=0;hf(u,v[q>>2],k,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}vb(s);vb(p);vb(n);vb(m);vb(u);Hc(q);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(s);vb(p);vb(n);vb(m);vb(u);Hc(q);S(a|0);L()}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-224|0;gb=e;vc(c);if(!(!zr(c,e+208|0)|v[e+208>>2]!=1297239878|v[e+216>>2]!=1179011393&(w[e+216|0]|w[e+217|0]<<8|(w[e+218|0]<<16|w[e+219|0]<<24))!=1128679745)){g=gb-32|0;gb=g;h=e+192|0;f=hh(h);a:{b:{c:{d:{e:{while(1){v[22708]=0;i=Q(191,c|0,8)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}if(!i){break d}v[22708]=0;R(1163,g|0,c|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;R(1164,f|0,g|0);i=v[22708];v[22708]=0;if((i|0)==1){break e}ed(g);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(g);break b}gb=g+32|0;break a}a=P()|0;O()|0}ke(f);S(a|0);L()}v[22708]=0;U(1149,e+168|0,h|0,1129270605);c=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[22708]=0;c=Q(1150,e+168|0,e+144|0)|0;g=v[22708];v[22708]=0;n:{if((g|0)!=1){g=0;if(!c){break f}h=e+144|2;if(!Xb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))){break f}if(!Ib(w[e+144|0]|w[e+145|0]<<8)){break f}if(Ib(w[e+144|0]|w[e+145|0]<<8)>>>0>2){break f}f=e+144|6;if(!Ib(w[f|0]|w[f+1|0]<<8)){break f}if(Ib(w[f|0]|w[f+1|0]<<8)>>>0>64){break f}v[e+140>>2]=1162760014;c=1;if((w[e+216|0]|w[e+217|0]<<8|(w[e+218|0]<<16|w[e+219|0]<<24))==1128679745){v[22708]=0;c=Q(798,e+168|0,e+140|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}if(!c){break f}c=v[e+140>>2]!=1936684916}v[22708]=0;U(1149,e+120|0,e+192|0,1397968452);g=v[22708];v[22708]=0;o:{p:{if((g|0)!=1){v[22708]=0;g=Q(1151,e+120|0,e+112|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break o}if(g){break p}break g}g=P()|0;O()|0;break i}i=((Ib(w[f|0]|w[f+1|0]<<8)-1|0)/8|0)-1|0;j=i<<3;f=j&31;f=Rc(e+104|0,(i>>>0<7?(j&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255,(Ib(w[e+144|0]|w[e+145|0]<<8)|0)==2?2:1,c,0);q:{c=v[e+140>>2];if((c|0)<=875981925){if((c|0)<=842230885){if((c|0)==544694642){break q}if((c|0)==842222662){break l}break k}if((c|0)==842230886){break l}if((c|0)!=875973702){break k}break l}if((c|0)<=1463897172){if((c|0)==875981926){break l}if((c|0)!=1463897153){break k}break m}if((c|0)!=1463897173){if((c|0)==2002873441){break m}if((c|0)!=2002873461){break k}}Cf(f,16);Zi(f,16);break k}Cf(f,1);break k}g=P()|0;O()|0;break j}g=P()|0;O()|0;break i}g=P()|0;O()|0;break i}g=P()|0;O()|0;break h}Cf(f,17);Zi(f,16);break k}Cf(f,3)}if(d){XQ(f)}c=Xb(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24));v[22708]=0;c=Q(191,e+120|0,c|0)|0;d=v[22708];v[22708]=0;r:{if((d|0)==1){break r}if(c){c=Xb(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24));v[22708]=0;Q(318,e+120|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}}v[22708]=0;Q(1140,a|0,b|0)|0;c=v[22708];v[22708]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)==1){break B}v[22708]=0;i=(B(b,104)+a|0)+484380|0;R(424,i|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break B}l=i,m=Xb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),v[l>>2]=m;d=e+144|0;c=w[d+13|0]|(w[d+11|0]<<16|w[d+10|0]<<24|w[d+12|0]<<8);h=30-w[d+9|0]|0;C:{if(!(h&255)){d=0;break C}while(1){d=c;c=c>>>1|0;h=h-1|0;if(h&255){continue}break}}v[(B(b,104)+a|0)+484404>>2]=(d&1)+c;v[22708]=0;W(329,f|0,i|0,e+120|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break B}v[22708]=0;U(1149,e+80|0,e+192|0,1296126539);c=v[22708];v[22708]=0;if((c|0)==1){break A}v[22708]=0;c=T(275,e+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}if(!c){break t}v[22708]=0;U(1149,e+32|0,e+192|0,1229869908);c=v[22708];v[22708]=0;if((c|0)==1){break y}v[22708]=0;c=Q(1152,e+32|0,e+56|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}xb(e+32|0);if(!c){break t}v[22708]=0;f=T(416,e+80|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}d=dd(e+32|0);v[22708]=0;R(1153,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)!=1){D:{if(!f){break D}h=e+8|6;c=0;while(1){v[22708]=0;j=Q(1154,e+80|0,e+8|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break v}if(!j){break D}v[22708]=0;R(1155,d|0,e+8|0);j=v[22708];v[22708]=0;if((j|0)==1){break v}j=w[h|0];k=w[h|0];v[22708]=0;Q(318,e+80|0,j+((k^-1)&1)|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}c=c+1|0;if((f|0)!=(c|0)){continue}break}}c=e- -64|0;if(Ib(w[c|0]|w[c+1|0]<<8)){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]|8;c=Ib(w[c|0]|w[c+1|0]<<8);u[f>>1]=x[f>>1]&65519|((c|0)==2)<<4}if(Ib(w[e+70|0]|w[e+71|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2;f=Ib(w[e+70|0]|w[e+71|0]<<8);u[c>>1]=x[c>>1]&65531|((f|0)==2)<<2}l=e,m=Vb(d),v[l+8>>2]=m;l=e,m=Zb(d),v[l+24>>2]=m;if(Gb(e+8|0,e+24|0)){c=B(b,104)+a|0;f=c+484388|0;h=c+484384|0;j=c+484396|0;k=c+484392|0;while(1){c=v[e+8>>2];if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+66|0]|w[e+67|0]<<8)|0)){l=k,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+68|0]|w[e+69|0]<<8)|0)){l=j,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+72|0]|w[e+73|0]<<8)|0)){l=h,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+74|0]|w[e+75|0]<<8)|0)){l=f,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}c=e+8|0;v[c>>2]=v[c>>2]+7;if(Gb(c,e+24|0)){continue}break}}v[22708]=0;wk(i);c=v[22708];v[22708]=0;if((c|0)!=1){break u}}break v}g=P()|0;O()|0;break j}g=P()|0;O()|0;break j}g=P()|0;O()|0;break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;xb(e+32|0);break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;TQ(d);break s}TQ(d)}v[22708]=0;U(1149,e+32|0,e+192|0,1312902469);c=v[22708];v[22708]=0;E:{F:{if((c|0)!=1){v[22708]=0;c=T(275,e+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}G:{H:{I:{J:{if(c){v[22708]=0;c=T(195,e+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}v[22708]=0;W(474,e+32|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break J}break F}v[22708]=0;c=Q(70,e+8|0,18726)|0;d=v[22708];v[22708]=0;if((d|0)==1){break I}v[22708]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break H}vb(c)}b=v[a+480180>>2];v[22708]=0;U(1142,i|0,32,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break G}v[22708]=0;_h(i,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break F}xb(e+32|0);xb(e+80|0);break g}g=P()|0;O()|0;break E}g=P()|0;O()|0;vb(c);break E}g=P()|0;O()|0;break E}g=P()|0;O()|0;break s}g=P()|0;O()|0}xb(e+32|0)}xb(e+80|0);break j}g=P()|0;O()|0}xb(e+120|0)}xb(e+168|0)}ke(e+192|0);S(g|0);L()}xb(e+120|0)}xb(e+168|0);ke(e+192|0)}gb=e+224|0;return g|0}function ru(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-32|0;gb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}l=v[b+104>>2];i=v[b+656>>2];if(!(!i|v[a+480180>>2]!=16777216)){p=v[i+44>>2]!=0}b:{if(!(!i|(c|0)>128)){n=x[vd(i+236|0,c-1|0)>>1];c:{if((n-1&65535)>>>0<=3998){l=(B(n,104)+a|0)+484380|0;break c}n=h+16|0;Db(n,a+1074312|0,43);if(!Cb(n)){break c}if(!sk(b)){break a}}j=w[ic(i+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=j;break b}j=c}if((j|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(j|0)!=255:0)){Co(a,b);if(d){break d}c=h+16|0;Db(c,a+1074312|0,100);if(!Cb(c)|!(w[a+480208|0]&4)|!w[b+789|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}c=h+16|0;Db(c,a+1074312|0,50);if(Cb(c)){break g}}v[b+688>>2]=0}c=h+16|0;Db(c,a+1074312|0,50);if(Cb(c)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}c=h+16|0;Db(c,a+1074312|0,20);if(!Cb(c)){break a}t[b+797|0]=0;t[b+802|0]=0;break a}h:{i:{j:{if(p){if(d){k=w[b+797|0];if(k){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!l)){u[b+770>>1]=t[l+36|0];u[b+772>>1]=t[l+37|0]}if(l){d=h+16|0;Db(d,a+1074312|0,24);j=0;n=1;if(!Cb(d)){break h}v[b+704>>2]=v[l+24>>2];break h}n=0;j=0;break h}n=v[i+44>>2];u[h>>1]=k;u[h+14>>1]=j;v[h+16>>2]=0;n=(v[h+16>>2]+B(u[n+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+852>>2]|0;v[b+708>>2]=n;v[b+852>>2]=0-n}n=(l|0)!=0;j=1;if(Oi(b)){break h}j=h+16|0;k=a+1074312|0;Db(j,k,54);if(Cb(j)){v[b+700>>2]=0;break a}j=h+16|0;Db(j,k,39);j=(Cb(j)^-1)&d}k:{if(Zl(a)){v[h+28>>2]=v[h+28>>2]+u[b+770>>1];Yd(h+28|0,12,131);break k}gV(h+28|0)}k=h+16|0;m=a+1074312|0;Db(k,m,34);d=b;l:{if(Cb(k)){c=on(c);break l}c=v[h+28>>2]}t[d+797|0]=c;t[b+851|0]=w[b+851|0]&219|32;if(!(v[a+480180>>2]&16777250?0:j)){t[b+803|0]=0}o=_g(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;c=h+16|0;Db(c,m,48);if(Cb(c)){EP(a,b,i,l)}m:{if(e^1|j){break m}v[b+776>>2]=0;v[b+780>>2]=0;if(!i){break m}c=h+16|0;Db(c,m,29);if(Cb(c)){t[b+798|0]=w[i+16|0]}if(!(w[i+60|0]&8)){Gj(b+724|0)}if(!(w[i+80|0]&8)){Gj(b+732|0)}if(!(w[i+100|0]&8)){Gj(b+740|0)}if(w[i+20|0]){d=pu(Bo(a));c=w[i+20|0];k=h+16|0;Db(k,m,28);d=((B(c,d)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(k)){k=v[b+752>>2];break n}k=(v[b+688>>2]+1|0)/2|0}u[c+776>>1]=(B(k,d)|0)/199}o:{if(!w[i+19|0]){break o}q=b,r=(B(pu(Bo(a)),w[i+19|0])<<16>>16)/32|0,u[q+778>>1]=r;c=h+16|0;Db(c,m,28);if(Cb(c)|x[b+784>>1]){break o}u[b+784>>1]=x[b+692>>1]+1}k=w[i+23|0];if(k){d=pu(Bo(a));c=w[b+837|0];t[b+796|0]=c+1;u[b+780>>1]=(B(c,(B(k,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}k=w[i+24|0];if(!k){break m}d=pu(Bo(a));c=w[b+838|0];t[b+795|0]=c+1;u[b+782>>1]=(B(c,(B(k,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!n){break a}n=0;p:{q:{if(!o){break q}if(!(v[b+700>>2]?j:0)){v[b+700>>2]=o}r:{s:{if(!p){if(!j){c=h+16|0;Db(c,m,69);if(Cb(c)){break s}Db(h,m,46);if(Cb(h)|v[a+480180>>2]==1){break s}}v[b+708>>2]=o;t[b+851|0]=w[b+851|0]&247}if(!j){break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=l;c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;t:{u:{if(!(v[a+480208>>2]&2097152)){c=h+16|0;Db(c,m,96);if(!Cb(c)){break u}}if(w[b+789|0]){break u}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Fb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break t}v[b+660>>2]=0}c=x[l+34>>1];k=c&1023;d=k|v[b+88>>2]&-525056;v[b+88>>2]=d;v:{w:{if(c&8){v[b+80>>2]=v[l+12>>2];c=v[l+16>>2];v[b+88>>2]=(k&16?d|4:d&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break w}break v}if(!(k&2)){break v}v[b+80>>2]=v[l+4>>2];c=v[l+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break v}}v[b+76>>2]=c}c=h+16|0;Db(c,m,83);if(!(!Cb(c)|v[b+80>>2])){c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}x:{if(w[b+822|0]>3){break x}d=h+16|0;Db(d,m,21);c=b;y:{if(!(Cb(d)|!(v[a+480180>>2]&16777248))){d=16;if(!(v[a+480208>>2]&4)){break y}}d=32;if(v[a+480180>>2]==16){break y}if(v[a+480180>>2]&67633152){break x}d=0}t[c+819|0]=d}c=h+16|0;Db(c,m,21);if(Cb(c)|w[b+825|0]>3){break r}t[b+820|0]=0}c=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=c;c=v[b+80>>2];v[b>>2]=d;v[b+4>>2]=c}if(!j){break q}n=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}c=1;if(!(w[a+480208|0]&8)){break p}c=1;if(!w[b+789|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Nm(b);c=h+16|0;Db(c,m,21);if(!Cb(c)){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(!n|!(w[a+480208|0]&8))){c=1;if(!w[b+789|0]){break p}}if(!(w[b+789|0]?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}c=n}d=h+16|0;Db(d,m,40);z:{A:{if(Cb(d)){if(c){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;l=1;break z}v[b+88>>2]=v[b+88>>2]&-4194305;l=1;break z}j=v[b+88>>2]&-4196353;break A}j=v[b+88>>2]&-4196353;v[b+88>>2]=j;l=1;if(c){break z}}u[b+842>>1]=65535;v[b+88>>2]=j&-6326273|2097152;c=h+16|0;Db(c,m,23);B:{if(Cb(c)){break B}Db(h,m,22);if(Cb(h)){break B}c=h+16|0;Db(c,m,52);if(Cb(c)){break B}Db(h,m,71);if(Cb(h)){break B}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;C:{if(i){D:{E:{if(!XE(i)){if(vw(i)){break E}c=!(c>>>13|0);if(c){break D}break C}q=b,r=YE(i),t[q+838|0]=r;if(!vw(i)){break D}}q=b,r=ZE(i),t[q+837|0]=r}c=1;d=w[i+25|0];if((d|0)==255){break C}t[b+845|0]=d;break C}v[b+776>>2]=0;v[b+780>>2]=0;c=!c}F:{if(w[b+837|0]>=127){d=h+16|0;Db(d,m,36);if(!Cb(d)){break F}}if(!c){break F}if((Iq(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break F}c=a+1298260|0;if(!Dd(c)|(g|0)==65535){break F}Pq(v[c>>2],g,w[b+837|0]>>>1|0,1)}l=0;if(!(w[b+89|0]&2)){break z}d=a+1298260|0;if(!Dd(d)|(g|0)==65535){break z}c=h+16|0;Db(c,m,111);if(Cb(c)){uk(v[d>>2],g);break z}c=h+16|0;Db(c,m,110);if(!Cb(c)){break z}XA(v[d>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}G:{H:{if(w[a+24618|0]&16?c&1024:0){break H}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break H}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break G}}if(f){break G}v[b+700>>2]=0}if(l){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}gb=h+32|0}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-208|0;gb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;ZO(a+900380|0);v[22708]=0;mA(a+946304|0);d=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}d=g+48|0;Qb(d,0,160);d=aP(d);v[22708]=0;e=a+906300|0;U(1298,e|0,e+4e4|0,d|0);e=v[22708];v[22708]=0;f:{g:{h:{i:{if((e|0)!=1){Aq(d);v[22708]=0;d=T(275,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(!d){break f}i=dd(g+48|0);e=0;if(c&16){break h}v[22708]=0;h=(c|0)!=0;e=W(1299,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=4;j:{if(e){break j}v[22708]=0;e=W(1300,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=5;if(e){break j}v[22708]=0;e=W(1301,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=6;if(e){break j}e=0;v[22708]=0;h=W(1302,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=3;if(!h){break h}}if(c){break i}f=1;break b}a=P()|0;O()|0;Aq(d);break c}if(!cd(i)){Ew(b,v[i>>2]+12|0)}e=d}if(c&32){break b}d=37824;k:{l:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[22708]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){if(f){break k}d=d+12|0;if((d|0)==38328){break l}continue}break}break g}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break b}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[22708]=0;R(1124,a+1298224|0,1);d=v[22708];v[22708]=0;if((d|0)!=1){gA(i);break d}}a=P()|0;O()|0;gA(i);break c}v[22708]=0;R(367,a|0,0);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;R(1124,a+1298224|0,1);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[a+1074304>>2]=19923026;break d}a=P()|0;O()|0;break c}d=0;m:{n:{while(1){e=(d<<5)+a|0;yg(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}e=e+480288|0;if(w[e|0]>=251){t[e|0]=0}v[22708]=0;$m((B(d,872)+a|0)+1074992|0,7,a,d&65535,134217728);e=v[22708];v[22708]=0;if((e|0)==1){break n}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1298260|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;o:{if(Md(d)){v[22708]=0;_h(d,a,0);d=v[22708];v[22708]=0;if((d|0)!=1){break o}break m}h=e+484414|0;j=x[h>>1];if(j&16384){break o}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}p:{if(!(w[e+484415|0]&2)){break p}if(!vk(i)){break p}v[22708]=0;_(1304,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;e=0;while(1){q:{f=v[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break q}e=v[a+480180>>2];v[22708]=0;CS(f,e);f=v[22708];v[22708]=0;e=d;if((f|0)!=1){break q}a=P()|0;O()|0;break c}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=e;d=a+480204|0;r:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break r}qc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}d=a+480220|0;e=v[a+480216>>2];if(e>>>0>y[a+480220>>2]){v[d>>2]=e}e=a+480216|0;qc(e,65536);qc(d,65536);qc(a+480200|0,256);s:{d=a+480248|0;if(!cd(d)){e=v[e>>2];v[22708]=0;U(1306,d|0,e|0,16777216);d=v[22708];v[22708]=0;if((d|0)==1){break s}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];e=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=e;v[a+1074456>>2]=v[a+480200>>2];uA(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;u[a+480276>>1]=0;v[22708]=0;_(1307,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break s}d=a+484360|0;l=g,m=Vb(d),v[l+48>>2]=m;l=g,m=Zb(d),v[l+32>>2]=m;t:{if(Gb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[22708]=0;_(1308,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break t}e=x[d+28>>1];if(tc(d)>>>0<=e>>>0){cf(d,0)}d=g+48|0;nS(d);if(Gb(d,g+32|0)){continue}break}}u:{v:{w:{x:{y:{z:{A:{B:{C:{k=v[a+480180>>2];if(k){fu(a+8|0,yq(a));if(v[a+1074308>>2]){v[22708]=0;_(1309,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break s}}f=dd(g+48|0);if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;D:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break D}v[22708]=0;Q(1310,i|0,a|0)|0;c=v[22708];v[22708]=0;E:{if((c|0)!=1){c=v[i>>2];if(!c){break E}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[22708]=0;R(i|0,c|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break D}}a=P()|0;O()|0;break u}e=Vb(f);h=Zb(f);c=gb-32|0;gb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;if(Gb(c+24|0,c+16|0)){while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(!e){e=c+24|0;Qe(e);if(Gb(e,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[g+32>>2]=e;l=g,m=Zb(f),v[l+16>>2]=m;if(Gb(g+32|0,g+16|0)){break D}v[22708]=0;v[g+32>>2]=j+906316;R(1311,f|0,g+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break C}v[22708]=0;c=Q(2,g+16|0,14796)|0;e=v[22708];v[22708]=0;if((e|0)==1){break B}v[22708]=0;R(1312,g|0,i|0);e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;U(3,g+32|0,c|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break z}v[22708]=0;U(560,a|0,2,g+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break y}vb(g+32|0);vb(g);vb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=w[a+1074368|0];v[22708]=0;R(1313,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break v}Gl(f)}f=(k|0)!=0;break a}a=P()|0;O()|0;break u}a=P()|0;O()|0;break u}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g+32|0)}vb(g)}vb(c);break u}a=P()|0;O()|0}Gl(f);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}xb(b);S(a|0);L()}gA(i)}xb(b);gb=g+208|0;return f|0}function Eo(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;j=gb-16|0;gb=j;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;s=v[b+752>>2];h=w[b+802|0];a:{if(!h){i=j+8|0;Db(i,a+1074312|0,11);if(Cb(i)){break a}}b:{c:{if(!g){break c}if(!ve(h)){break c}d:{i=g+236|0;h=h-1|0;if(x[vd(i,h)>>1]){break d}k=j+8|0;Db(k,a+1074312|0,43);if(!Cb(k)){break d}if(Ij(g)){break d}v[b+656>>2]=g;break a}if(w[ic(g+108|0,h)|0]>120){break a}h=x[vd(i,h)>>1];k=(h-1&65535)>>>0<3999?(B(h,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(h>>>0>250){break a}h=j+8|0;Db(h,a+1074312|0,43);if(Cb(h)){if(g){k=0;if(Ij(g)){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}k=0}h=v[b+104>>2];o=(h|0)!=0&(h|0)!=(k|0);i=v[b+656>>2];q=!g|v[a+480180>>2]!=16777216?q:v[g+44>>2]!=0;p=d^1;h=(g|0)!=(i|0);if((p|h|o)==1){u[b+774>>1]=0}r=!o;if(!(r?1:!(d&q)|v[b+656>>2]!=(g|0))){break a}e:{if(p|r){break e}l=j+8|0;m=a+1074312|0;Db(l,m,32);if(!(!Cb(l)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|h:1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Oi(b)){break f}}l=j+8|0;Db(l,m,79);if(!Cb(l)){break e}if(!Oi(b)){break e}}n=1}g:{if(!v[b+16>>2]|(!o|(h|!x[a+480192>>1]))){break g}l=j+8|0;Db(l,a+1074312|0,87);if(!Cb(l)){break g}n=ce(b+788|0)^1|n}h:{i:{j:{k:{l:{if(Oi(b)|!(v[a+480180>>2]&16777248)){break l}if(g){if(Ij(g)){break l}}l=1;break k}if(!(h|o)){break j}l=(g|0)!=(i|0)}if(!d){break i}h=j+8|0;Db(h,a+1074312|0,61);if(!Cb(h)){break i}i=v[b+656>>2];if(!i){m=0;i=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}l=0}v[b+656>>2]=g;m=l;h=k;i=g}m:{if(!e){break m}l=b;n:{o:{p:{if(v[a+480180>>2]&3){if(h){if(Md(h)){break p}}if(!sk(b)){break m}}if(!h){break o}}if(u[h+34>>1]<0){break m}g=x[h+30>>1];break n}g=0;if(!i|!w[i+34|0]){break n}g=b;k=v[b+656>>2];q:{if(k){g=v[k+4>>2]<<2;break q}g=v[g+688>>2]}}v[l+688>>2]=g}if(n){if(!((h|0)!=0&o)){break a}c=j+8|0;Db(c,a+1074312|0,85);if(Cb(c)){u[b+772>>1]=t[h+37|0]}if(v[a+480180>>2]!=2){break a}if(!Md(h)){break a}v[b+704>>2]=v[h+24>>2];break a}t[b+803|0]=0;r:{if(!i){break r}g=j+8|0;Db(g,a+1074312|0,29);if(z=0,A=(D=Cb(g),E=1,F=h,F?D:E),C=w[i+34|0]!=0|m,C?z:A){break r}t[b+798|0]=w[i+16|0]}g=i;n=64;k=b;v[b+752>>2]=64;l=h;if(h){n=x[l+32>>1];v[k+752>>2]=n}if(g){v[k+752>>2]=B(v[g+4>>2],n)>>>6}s:{if(!(v[a+480180>>2]&1048580?e:1)){break s}e=j+8|0;Db(e,a+1074312|0,48);if(Cb(e)){break s}EP(a,b,i,h)}t:{u:{v:{if(!f){break v}f=j+8|0;e=a+1074312|0;Db(f,e,19);w:{x:{y:{z:{A:{B:{C:{D:{E:{if(Cb(f)){if(v[b+76>>2]){if(!(!c|p)){g=(w[a+480208|0]&8)>>>3|0;if(g){break C}break D}g=0;if(c){break D}break C}g=v[b+88>>2];if(!v[b+696>>2]|m){break E}c=g&2048;break B}g=1;F:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break F}g=0;if(!(w[b+89|0]&16)){break F}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|m)){break A}if(!g){break z}g=v[b+88>>2];c=g&6144;break B}v[b+88>>2]=g|2097152;if(!i){break w}break x}if(d){break C}if(!(w[b+89|0]&24)){g=0;break C}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break A}if(!g){break z}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break w}if(c){break x}if(!(w[i+60|0]&8)){Gj(b+724|0)}if(!(w[i+80|0]&8)){Gj(b+732|0)}if(w[i+100|0]&8){break w}Gj(b+740|0);break w}if(g){break y}}if(i){if(t[i+60|0]&1){break v}c=j+8|0;Db(c,e,32);if(Cb(c)){Gj(b+724|0);break v}Nm(b);break v}g=0;if(!h){break u}break t}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break w}}Nm(b)}c=j+8|0;Db(c,e,21);if(Cb(c)){break v}t[b+818|0]=0;v[b+756>>2]=0}g=0;if(h){break t}if(!i){break u}g=1;if(Ij(i)){break t}}v[b+752>>2]=0;v[b+104>>2]=0;break a}c=b;G:{H:{I:{J:{K:{if(!(!d|!h|v[b+104>>2]!=(h|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break K}d=j+8|0;Db(d,a+1074312|0,40);if(!Cb(d)|w[b+789|0]){break K}d=v[b+88>>2];break J}v[b+88>>2]=v[b+88>>2]&-6145;e=j+8|0;f=a+1074312|0;Db(e,f,18);c=b;L:{if(z=Cb(e),A=1,C=v[a+480180>>2]&16777248,C?z:A){e=-640;if(!(v[b+104>>2]!=(h|0)|m)){break L}}e=-768}v[c+88>>2]=e&v[b+88>>2];M:{if(!i){break M}t[b+730|0]=w[i+60|0];t[b+738|0]=w[i+80|0];t[b+746|0]=w[i+100|0];N:{if((w[i+100|0]&17)!=17){break N}c=j+8|0;Db(c,f,36);if(Cb(c)|w[b+837|0]){break N}t[b+837|0]=127}if(vw(i)){z=b,A=ZE(i),t[z+837|0]=A}if(!XE(i)){break M}z=b,A=YE(i),t[z+838|0]=A}if(g){break I}if(!d){break G}break H}d=v[b+88>>2]&-6145}v[c+88>>2]=d&-640;if(!g){break H}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break G}c=j+8|0;d=a+1074312|0;Db(c,d,54);if(!Cb(c)){Db(j,d,39);if(!Cb(j)){break G}}v[b+8>>2]=0;v[b+12>>2]=0}O:{if(w[b+788|0]!=255){break O}c=j+8|0;Db(c,a+1074312|0,100);if(!Cb(c)|(!(v[a+480208>>2]&4)|r)){break O}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}To(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];c=j+8|0;d=a+1074312|0;Db(c,d,83);if(!(!Cb(c)|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;c=j+8|0;Db(c,d,21);if(Cb(c)){t[b+818|0]=0;v[b+756>>2]=0}c=b;P:{Q:{if(q){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|32;e=0;break Q}if(!(v[a+480180>>2]&5?o|p:1)){break P}v[b+704>>2]=v[h+24>>2];e=t[h+37|0]}u[c+772>>1]=e}c=b;if(Zl(a)){e=t[h+36|0]}else{e=0}u[c+770>>1]=e;c=j+8|0;Db(c,d,69);if(!(Cb(c)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}R:{if(!(g&2)){g=v[b+76>>2];break R}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break R}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}gb=j+16|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=C(0),X=0,Y=0,Z=0,_=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];$L(a);if(g==z[a+4268>>2]){break a}Vy(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!ni(p)){break b}q=Nd(p,0);x=Nd(p,1);l=od(p,0);m=od(p,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;m=m+4|0;l=l+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}V=a+4960|0;F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;E=a+4504|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){g=z[q>>2];g=C(g+C(C(z[a+5008>>2]-g)*z[a+4276>>2]));z[a+5008>>2]=g;Z=Cc(u,v[a+4880>>2]),_=g,z[Z>>2]=_;g=z[x>>2];g=C(g+C(C(z[a+5012>>2]-g)*z[a+4276>>2]));z[a+5012>>2]=g;Z=Cc(s,v[a+4904>>2]),_=g,z[Z>>2]=_;g=C(C(C(C(C(Sh(u,v[a+4356>>2])*C(.6800000071525574))-C(Sh(u,v[a+4360>>2])*C(.5)))-C(Sh(u,v[a+4364>>2])*C(.6200000047683716)))-C(Sh(u,v[a+4368>>2])*C(.5)))-C(Sh(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){f=g;g=C(z[Cc(U,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(U,v[a+4832>>2]),_=C(f-C(g*C(.6180340051651001))),z[Z>>2]=_}y=z[a+4280>>2];Z=a,_=C(Sh(u,v[a+4352>>2])+z[a+5020>>2]),z[Z+5020>>2]=_;f=C(Sh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Cc(P,v[a+4644>>2])>>2])*z[a+4444>>2])+z[Cc(P,v[a+4644>>2])>>2]);z[a+4980>>2]=h;Q=C(h*z[a+4440>>2]);j=C(f*C(.7070000171661377));i=C(e*C(-.7070000171661377));e=C(j+i);h=z[a+4272>>2];f=C(Q+C(e*h));Z=Cc(P,v[a+4640>>2]),_=C(e-C(h*f)),z[Z>>2]=_;e=C(C(C(z[a+4976>>2]-z[Cc(O,v[a+4620>>2])>>2])*z[a+4436>>2])+z[Cc(O,v[a+4620>>2])>>2]);z[a+4976>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4432>>2])+C(f*h));Z=Cc(O,v[a+4616>>2]),_=C(f-C(h*e)),z[Z>>2]=_;A=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=C(C(C(z[a+4972>>2]-z[Cc(N,v[a+4596>>2])>>2])*z[a+4428>>2])+z[Cc(N,v[a+4596>>2])>>2]);z[a+4972>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4424>>2])+C(e*h));Z=Cc(N,v[a+4592>>2]),_=C(e-C(h*f)),z[Z>>2]=_;e=C(C(C(z[a+4968>>2]-z[Cc(M,v[a+4572>>2])>>2])*z[a+4420>>2])+z[Cc(M,v[a+4572>>2])>>2]);z[a+4968>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4416>>2])+C(f*h));Z=Cc(M,v[a+4568>>2]),_=C(f-C(h*e)),z[Z>>2]=_;A=C(C(A+C(f*C(.3499999940395355)))+C(e*C(-.3799999952316284)))}Z=Cc(T,v[a+4928>>2]),_=e,z[Z>>2]=_;f=C(z[Cc(T,v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=f+C(C(z[a+5028>>2]-f)*z[a+4500>>2]);f=C(C(C(z[a+4964>>2]-z[Cc(L,v[a+4548>>2])>>2])*z[a+4412>>2])+z[Cc(L,v[a+4548>>2])>>2]);z[a+4964>>2]=f;e=z[a+5028>>2];n=z[a+4272>>2];h=C(C(e*n)+C(f*z[a+4408>>2]));Z=Cc(L,v[a+4544>>2]),_=C(e-C(n*h)),z[Z>>2]=_;f=C(C(C(z[a+4960>>2]-z[Cc(E,v[a+4524>>2])>>2])*z[a+4404>>2])+z[Cc(E,v[a+4524>>2])>>2]);z[a+4960>>2]=f;e=C(f*z[a+4400>>2]);f=z[a+4272>>2];n=C(e+C(h*f));Z=Cc(E,v[a+4520>>2]),_=C(h-C(f*n)),z[Z>>2]=_;z[a+5020>>2]=n;f=C(C(C(C(C(Sh(s,v[a+4380>>2])*C(.7070000171661377))-C(Sh(s,v[a+4384>>2])*C(.6000000238418579)))-C(Sh(s,v[a+4388>>2])*C(.5)))-C(Sh(s,v[a+4392>>2])*C(.6000000238418579)))-C(Sh(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){e=f;f=C(z[Cc(S,v[a+4860>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(S,v[a+4856>>2]),_=C(e-C(f*C(.6180340051651001))),z[Z>>2]=_}W=z[a+4280>>2];e=C(C(C(z[a+5004>>2]-z[Cc(K,v[a+4788>>2])>>2])*z[a+4492>>2])+z[Cc(K,v[a+4788>>2])>>2]);z[a+5004>>2]=e;Q=C(e*z[a+4488>>2]);e=C(i-j);i=z[a+4272>>2];j=C(Q+C(e*i));Z=Cc(K,v[a+4784>>2]),_=C(e-C(i*j)),z[Z>>2]=_;e=C(C(C(z[a+5e3>>2]-z[Cc(J,v[a+4764>>2])>>2])*z[a+4484>>2])+z[Cc(J,v[a+4764>>2])>>2]);z[a+5e3>>2]=e;i=z[a+4272>>2];e=C(C(e*z[a+4480>>2])+C(j*i));Z=Cc(J,v[a+4760>>2]),_=C(j-C(i*e)),z[Z>>2]=_;j=C(C(C(h*C(.3799999952316284))+C(j*C(-.15000000596046448)))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Cc(I,v[a+4740>>2])>>2])*z[a+4476>>2])+z[Cc(I,v[a+4740>>2])>>2]);z[a+4996>>2]=h;i=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(e*i));Z=Cc(I,v[a+4736>>2]),_=C(e-C(i*h)),z[Z>>2]=_;e=C(C(C(z[a+4992>>2]-z[Cc(H,v[a+4716>>2])>>2])*z[a+4468>>2])+z[Cc(H,v[a+4716>>2])>>2]);z[a+4992>>2]=e;i=z[a+4272>>2];e=C(C(e*z[a+4464>>2])+C(h*i));Z=Cc(H,v[a+4712>>2]),_=C(h-C(i*e)),z[Z>>2]=_;j=C(C(j+C(h*C(.3499999940395355)))+C(e*C(-.3799999952316284)))}X=x+4|0;Y=q+4|0;h=C(g*y);A=C(A-C(n*C(.3799999952316284)));n=C(f*W);Z=Cc(R,v[a+4952>>2]),_=e,z[Z>>2]=_;g=C(z[Cc(R,v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=g+C(C(z[a+5032>>2]-g)*z[a+4500>>2]);g=C(C(C(z[a+4988>>2]-z[Cc(G,v[a+4692>>2])>>2])*z[a+4460>>2])+z[Cc(G,v[a+4692>>2])>>2]);z[a+4988>>2]=g;f=z[a+5032>>2];e=z[a+4272>>2];g=C(C(f*e)+C(g*z[a+4456>>2]));Z=Cc(G,v[a+4688>>2]),_=C(f-C(e*g)),z[Z>>2]=_;e=z[a+4284>>2];f=C(C(C(z[a+4984>>2]-z[Cc(F,v[a+4668>>2])>>2])*z[a+4452>>2])+z[Cc(F,v[a+4668>>2])>>2]);z[a+4984>>2]=f;y=z[a+4272>>2];f=C(C(f*z[a+4448>>2])+C(g*y));Z=Cc(F,v[a+4664>>2]),_=C(g-C(y*f)),z[Z>>2]=_;z[a+5024>>2]=f;g=C(g*C(.3799999952316284));y=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}g=C(h+C(C(A+g)*e));f=C(n+C(C(j+C(f*C(-.3799999952316284)))*y));e:{f:{if(w[a+4264|0]&2){q=Y;k=X;break f}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(f+z[a+5040>>2])*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;q=q+8|0;m=m+4|0;l=l+4|0;k=x+8|0}x=k;z[l>>2]=g;z[m>>2]=f;m=m+4|0;l=l+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}Gi(a,b,c,od(p,0),od(p,1),d)}}function woa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=gb-208|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(Gh(b,11139)){if(d){t[d|0]=1}j=a+1074312|0;xv(j);m=a+480216|0;n=a+480220|0;o=a+480224|0;k=a+1074368|0;p=a+480200|0;h:{if(!Pb(b,7)){break h}s=a+480228|0;z=a+480232|0;A=a+484360|0;l=a+480268|0;C=a+1298280|0;D=a+480248|0;while(1){d=sg(b);e=Ng(b);if((d|0)==(w[18702]|w[18703]<<8|(w[18704]<<16|w[18705]<<24))){pg(b,6);break h}if(!(d&1616928864)|d&-2139062144){break h}if(!Pb(b,e)){break h}h=f+24|0;Sd(h,b,e);g=kc(f+184|0,h);xb(h);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break z}if((d|0)!=1129797166){break i}v[22708]=0;v[f+24>>2]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)==1){break w}v[a+1074304>>2]=v[f+24>>2];break i}if((d|0)==1130917459){break r}if((d|0)!=1145525806){break i}v[22708]=0;U(608,g|0,e|0,p|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}if((d|0)<=1213486400){if((d|0)==1146367534){break B}if((d|0)!=1196316499|e>>>0<3){break i}v[22708]=0;R(609,f+8|0,f+184|0);d=v[22708];v[22708]=0;if((d|0)==1){break p}v[22708]=0;R(610,f+168|0,f+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}v[22708]=0;e=W(100,f+24|0,f+168|0,8)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}vb(f+168|0);gc(f+8|0);v[22708]=0;d=T(195,f+184|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}v[22708]=0;U(611,f+24|0,D|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}wf(e);break i}if((d|0)==1213486401){break s}if((d|0)==1280530262){break v}if((d|0)!=1297303086){break i}xv(j);d=0;break k}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break x}if((d|0)!=1347244882){break i}v[22708]=0;U(612,g|0,e|0,l|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}if(up(w[l|0])){break i}t[l|0]=5;break i}if((d|0)==1380340804){break A}if((d|0)==1380986414){break t}if((d|0)!=1380991534){break i}v[22708]=0;U(608,g|0,e|0,m|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}if((d|0)<=1397768493){if((d|0)==1380994350){break j}if((d|0)!=1397052739|e>>>0<3){break i}v[22708]=0;d=T(287,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break i}d=(B(d,104)+a|0)+484448|0;e=mX(d);if((d|0)==(e|0)){break i}while(1){v[22708]=0;h=T(192,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}v[d>>2]=h;d=d+4|0;if((e|0)!=(d|0)){continue}break}break i}if((d|0)==1397768494){break u}if((d|0)==1414344238){break y}if((d|0)!=1448301654){break i}v[22708]=0;U(608,g|0,e|0,z|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}v[22708]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break i}v[22708]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break i}d=P()|0;O()|0;break a}if(c){break i}v[22708]=0;u[f+24>>1]=0;U(613,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)!=1){E=a,F=Fd(x[f+24>>1],x[a+480188>>1],127),u[E+480188>>1]=F;break i}d=P()|0;O()|0;break a}v[22708]=0;U(614,g|0,e|0,o|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}v[22708]=0;U(615,g|0,e|0,k|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}d=P()|0;O()|0;break a}v[22708]=0;v[f+24>>2]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)==1){break f}d=v[f+24>>2];if(!d){break i}v[a+1074308>>2]=d;break i}v[22708]=0;U(608,g|0,e|0,s|0);d=v[22708];v[22708]=0;if((d|0)!=1){break i}break b}if(v[a+480180>>2]==4){break i}v[22708]=0;U(613,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)!=1){cf(Sb(A),x[f+24>>1]);break i}d=P()|0;O()|0;break a}e=Kb(f+24|0);v[22708]=0;d=T(195,f+184|0)|0;h=v[22708];v[22708]=0;C:{if((h|0)==1){break C}v[22708]=0;W(616,g|0,e|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break C}v[22708]=0;U(13,f+168|0,0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break C}d=f+168|0;Eb(C,d);vb(d);vb(e);break i}d=P()|0;O()|0;vb(e);break a}if(e&1|e>>>0>126){break i}u[f+24>>1]=(e>>>1|0)- -64;v[22708]=0;u[f+168>>1]=127;d=Pc(f+24|0,f+168|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}q=x[d>>1];if(q>>>0<65){break i}e=64;while(1){v[22708]=0;R(403,f+24|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}h=f+24|0;d=qd(h);D:{if(w[h|0]==255){break D}i=w[d|0];d=(e<<5)+a|0;r=d+480284|0;u[r>>1]=128;u[d+480286>>1]=i;i=d+480280|0;v[i>>2]=0;v[i>>2]=(w[h|0]&128)<<3;d=w[h|0]&127;t[h|0]=d;if(d>>>0<65){u[r>>1]=d<<2;d=w[h|0]}if((d&255)!=100){break D}v[i>>2]=v[i>>2]|256}e=e+1|0;if((q|0)!=(e|0)){continue}break}break i}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break m}d=P()|0;O()|0;vb(f+168|0)}gc(f+8|0);break a}d=P()|0;O()|0;wf(e);break a}E:{F:{G:while(1){v[22708]=0;e=Q(191,f+184|0,1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break F}if(!(e&d>>>0<114)){break i}v[22708]=0;h=T(374,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break E}e=0;while(1){H:{if(!(!(h>>>e&1)|d>>>0>113)){v[22708]=0;W(409,j|0,d|0,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break H}}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}continue G}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[22708]=0;U(608,g|0,e|0,n|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}}xb(f+184|0);if(Pb(b,7)){continue}break}}Fp(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(w[a+480224|0]>=3){t[o|0]=0}if(w[k|0]>=6){t[k|0]=0}qc(p,256);qc(m,65536);qc(n,65536)}gb=f+208|0;return}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0}xb(f+184|0);S(d|0);L()}function kP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=C(0),M=0,N=0,O=C(0),P=0;k=gb-48|0;gb=k;m=x[a+480192>>1]?v[(B(b,872)+a|0)+1075648>>2]:m;n=a+1074312|0;f=B(b,872)+a|0;q=f+1075791|0;A=f+1075680|0;D=f+1075768|0;s=f+1075744|0;y=f+1075740|0;E=f+1075712|0;F=f+1075684|0;G=f+1075676|0;H=f+1075656|0;I=f+1075778|0;J=f+1075080|0;g=e&127;K=C(g>>>0);r=f+1075842|0;L=C(w[r|0]);f=1;while(1){e=w[d+o|0];if(e){h=e-48|0;a:{b:{c:{if((h&255)>>>0<10){break c}if((e-65&255)>>>0<=5){h=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Lm(a,b,3,0);if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=gx(e,50352,50384);if(!e){break g}h=kb[v[v[e>>2]+188>>2]](e,b)|0;e=(h|0)!=255;h=e?h:0;if(e|!m){break c}break d}if(m){break d}h=0;break c;case 13:h=0;if(!ve(w[q|0])){break e}h=w[q|0]-1|0;break e;case 21:e=k+8|0;Db(e,n,28);h:{if(!Cb(e)){Db(k,n,1);e=0;if(!Cb(k)){break h}}e=u[D>>1]}h=B(v[s>>2],v[y>>2]);e=B(v[a+1074456>>2],e+v[A>>2]|0);h=Lb((Ac(oqa(nqa(h,h>>31,e,e>>31),jb,1048576,0),jb)|0)/2|0,1,127);break e;case 23:v[k+8>>2]=v[F>>2]/2;v[k>>2]=127;h=v[pd(k+8|0,k)>>2];break e;case 24:v[k+8>>2]=v[G>>2]/2;v[k>>2]=127;h=v[pd(k+8|0,k)>>2];break e;case 0:h=0;if(!m){break e}e=x[m+28>>1];if(!e){break e}h=e-1>>>7&127;break e;case 1:h=0;if(!m){break e}e=x[m+28>>1];if(!e){break e}h=e-1&127;break e;case 14:h=v[H>>2]>>>8|0;break e;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[I|0]-1|0}h=e&127;break e;case 12:h=v[J>>2]>>>7&1;break e;case 15:h=0;if(!m){break e}e=w[m+30|0];if(!e){break e}h=e-1&127;break e;case 25:j=r;e=g;i:{if(!c){break i}e=g;if(t[r|0]<0){break i}j:{if(i>>>0<3){break j}l=(k+16|0)+i|0;if(w[l-3|0]!=240){break j}e=g;if(w[l-2|0]>239){break i}}p=Cq(a,L,K);if(p<C(4294967296)&p>=C(0)){e=~~p>>>0;break i}e=0}h=e;t[j|0]=h;break e;case 18:e=i;k:{if(!e){e=0;break k}while(1){e=e-1|0;if(w[e+(k+16|0)|0]==240){break k}if(e){continue}break}}if(w[(k+16|0)+e|0]!=240|i-e>>>0<5){break a}h=0;e=e+5|0;if((i|0)!=(e|0)){while(1){h=w[(k+16|0)+e|0]+h|0;e=e+1|0;if((i|0)!=(e|0)){continue}break}}h=0-h&127;break e;case 20:break f;default:break a}}e=B(v[s>>2],v[y>>2]);h=e;j=e>>31;e=B(v[a+1074456>>2],v[E>>2]);h=Lb((Ac(oqa(nqa(h,j,e,e>>31),jb,67108864,0),jb)|0)/2|0,1,127)}e=((f^-1)&1)+i|0;t[e+(k+16|0)|0]=h;i=e+1|0;f=1;break b}e=m;j=a;h=0;l=b;l:{if(l>>>0>=256){break l}if(w[e+31|0]==17){e=x[(j+B(l,872)|0)+1075778>>1];h=(e?e-1|0:l)&15;break l}if(!Ij(e)){break l}h=w[e+31|0]-1&15}}e=(k+16|0)+i|0;m:{if(f&1){t[e|0]=h;break m}t[e|0]=w[e|0]<<4|h;i=i+1|0}f=(f^-1)&1}}o=o+1|0;if((o|0)!=31){continue}}break}e=((f^-1)&1)+i|0;n:{if(!e){break n}h=0;f=0;while(1){j=(k+16|0)+f|0;d=t[j|0];o:{p:{q:{if((d|0)==-16){if(e-f>>>0>=4){o=4;if((w[(f+k|0)+17|0]&254)==240){break p}}o=f;r:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break r}if(w[(k+16|0)+o|0]!=247){continue}break}d=o-f|0;o=d+1|0;if(o>>>0>=d>>>0){break p}}t[(k+16|0)+e|0]=247;e=e+1|0;o=e-f|0;break q}if((d|0)>=0){if(h&255){f=f-1|0;t[f+(k+16|0)|0]=h;break o}f=f+1|0;h=0;break o}M=k,N=VS(d&255),v[M+8>>2]=N;v[k>>2]=e-f;o=v[Fb(k+8|0,k)>>2]}if(!o){break n}d=w[j|0];h=d>>>0<240?d:h}r=f;d=a;g=b;m=c;l=gb-32|0;gb=l;i=o;v[l+28>>2]=i;f=w[j|0];n=f-250|0;if(!(n>>>0>5|!(1<<n&37))){if(x[d+480188>>1]){f=0;while(1){n=(d+B(f,872)|0)+1075829|0;t[n|0]=127;t[n+1|0]=0;f=f+1|0;if(f>>>0<x[d+480188>>1]){continue}break}}f=w[j|0]}s:{t:{if((f&255)!=240){break t}n=w[j+1|0];if((n&254)!=240){break t}f=i>>>0<4;i=0;if(f){break s}q=(d+B(g,872)|0)+1074992|0;f=t[j+3|0];u:{v:{w:{x:{y:{z:{j=w[j+2|0];switch(j|0){case 3:break w;case 2:break x;case 1:break y;case 0:break z;default:break v}}if((n|0)==241|(f|0)<0){break v}j=d+B(g,872)|0;i=j+1075829|0;n=i;if(m){f=ch(Cq(d,C(w[i|0]),C((f&255)>>>0)))}t[n|0]=f;t[j+1075788|0]=0;i=4;f=j+1075080|0;m=Iq(d,q,!(v[f>>2]&32768),256);if((m|0)<0|!(w[f+1|0]&2)){break s}d=d+1298260|0;if(!Dd(d)){break s}Pq(v[d>>2],g,m>>>2&255,1);break s}if((n|0)==241|(f|0)<0){break v}g=d+B(g,872)|0;i=g+1075830|0;A:{if(!m){break A}p=Cq(d,C(w[i|0]),C((f&255)>>>0));if(p<C(4294967296)&p>=C(0)){f=~~p>>>0;break A}f=0}t[i|0]=f;t[g+1075787|0]=0;Iq(d,q,!(v[g+1075080>>2]&32768),256);i=4;break s}if((n|0)==241){break u}i=4;if((f&255)>>>0>31){break s}g=d+B(g,872)|0;t[g+1075837|0]=(f&240)>>>4;Iq(d,q,!(v[g+1075080>>2]&32768),256);break s}if((n|0)==241){break u}i=4;g=Lm(d,g,3,0);if((f|0)<0|(g-1&255)>>>0>249){break s}g=(d+B(g,160)|0)+906284|0;p=C(C(((f^127)&255)>>>0)/C(127));if(!m){z[g>>2]=p;break s}M=g,O=Cq(d,z[g>>2],p),z[M>>2]=O;break s}if(j&128){break u}if((n|0)!=241){break s}}i=4;g=Lm(d,g,3,0);if((g-1&255)>>>0>249){break s}g=v[(d+B(g,160)|0)+906140>>2];if(!g|(f|0)<0){break s}j=(n|0)==241?j+128|0:j&127;p=C(C((f&255)>>>0)/C(127));if(!m){kb[v[v[g>>2]+44>>2]](g,j,p);break s}N=g,P=j,O=Cq(d,C(kb[v[v[g>>2]+48>>2]](g,j)),p),M=v[v[g>>2]+44>>2],kb[M](N|0,P|0,C(O));break s}B:{if(g>>>0<x[d+480188>>1]){f=g+1|0;break B}f=x[(d+B(g,872)|0)+1075778>>1];if(!f){break s}}if(w[(d+B(g,872)|0)+1075083|0]&4|x[d+480188>>1]<(f&65535)>>>0){break s}f=Lm(d,g,3,0);if((f-1&255)>>>0>249){break s}d=v[(d+B(f,160)|0)+906140>>2];if(!d){break s}f=w[j|0];if((f|0)==240){bc(l+16|0,zb(j),i);f=v[v[d>>2]+72>>2];g=v[l+20>>2];v[l>>2]=v[l+16>>2];v[l+4>>2]=g;kb[f|0](d,l)|0;break s}M=l,P=VS(f),v[M+12>>2]=P;f=l+12|0;g=v[Fb(f,l+28|0)>>2];v[l+12>>2]=0;hc(f,j,g);kb[v[v[d>>2]+68>>2]](d,v[l+12>>2])|0;i=v[l+28>>2]}gb=l+32|0;f=(i?i:o)+r|0}if(e>>>0>f>>>0){continue}break}}gb=k+48|0}function j6(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;m=gb-560|0;gb=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<-1|(g|0)<=-1){A=1;C=2388;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){A=1;C=2391;break a}A=e&1;C=A?2394:2389;F=!A}b:{if((g&2146435072)==2146435072){i=A+3|0;cg(a,32,c,i,e&-65537);uf(a,C,A);d=f&32;uf(a,b!=b?d?7248:11113:d?8325:11422,3);break b}y=m+16|0;c:{d:{e:{b=PI(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;s=f|32;if((s|0)!=97){break e}break c}s=f|32;if((s|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}q=(l|0)<0?m+48|0:m+336|0;h=q;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<1){d=l;g=h;k=q;break f}k=q;d=l;while(1){p=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}d=p;i=0;while(1){u=g;G=i;x=v[g>>2];r=d&31;if((d&63)>>>0>=32){i=x<<r;x=0}else{i=(1<<r)-1&x>>>32-r;x=x<<r}r=G+x|0;i=i+H|0;i=r>>>0<x>>>0?i+1|0:i;i=qqa(r,i,1e9,0);x=u;u=nqa(i,jb,1e9,0);v[x>>2]=r-u;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-p|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<=-1){p=h+1|0;E=(s|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0>k>>>0){u=1e9>>>i|0;r=-1<<i^-1;d=0;h=k;while(1){x=d;d=v[h>>2];v[h>>2]=x+(d>>>i|0);d=B(u,d&r);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0;break h}h=v[k>>2]}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=E?q:k;g=(p|0)<g-h>>2?h+(p<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=k>>>0){break i}h=B(q-k>>2,9);d=10;i=v[k>>2];if(i>>>0<10){break i}while(1){h=h+1|0;d=B(d,10);if(i>>>0>=d>>>0){continue}break}}d=(n-((s|0)==102?0:h)|0)-((s|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-q>>2,9)-9|0)){i=((l|0)<0?4:292)+m|0;l=d+9216|0;p=(l|0)/9|0;i=(i+(p<<2)|0)-4048|0;d=10;l=l-B(p,9)|0;if((l|0)<=7){while(1){d=B(d,10);l=l+1|0;if((l|0)!=8){continue}break}}p=v[i>>2];u=(p>>>0)/(d>>>0)|0;l=p-B(d,u)|0;r=i+4|0;j:{if(!l&(r|0)==(g|0)){break j}b=(g|0)==(r|0)?1:1.5;r=d>>>1|0;z=l>>>0<r>>>0?.5:(r|0)==(l|0)?b:1.5;b=u&1?9007199254740994:9007199254740992;if(!(w[C|0]!=45|F)){z=-z;b=-b}l=p-l|0;v[i>>2]=l;if(b+z==b){break j}d=d+l|0;v[i>>2]=d;if(d>>>0>=1e9){while(1){v[i>>2]=0;i=i-4|0;if(i>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[i>>2]+1|0;v[i>>2]=d;if(d>>>0>999999999){continue}break}}h=B(q-k>>2,9);d=10;l=v[k>>2];if(l>>>0<10){break j}while(1){h=h+1|0;d=B(d,10);if(l>>>0>=d>>>0){continue}break}}d=i+4|0;g=d>>>0<g>>>0?d:g}while(1){l=g;d=g>>>0<=k>>>0;if(!d){g=l-4|0;if(!v[g>>2]){continue}}break}k:{if((s|0)!=103){s=e&8;break k}g=n?n:1;i=(g|0)>(h|0)&(h|0)>-5;n=(i?h^-1:-1)+g|0;f=(i?-1:-2)+f|0;s=e&8;if(s){break k}i=-9;l:{if(d){break l}p=v[l-4>>2];i=-9;if(!p){break l}d=10;g=0;i=0;if((p>>>0)%10|0){break l}while(1){i=g;g=g+1|0;d=B(d,10);if(!((p>>>0)%(d>>>0)|0)){continue}break}i=i^-1}d=B(l-q>>2,9)-9|0;if((f&-33)==70){s=0;d=d+i|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break k}s=0;d=i+(d+h|0)|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}p=(n|s)!=0;d=a;x=c;u=f&-33;if((u|0)==70){f=(h|0)>0?h:0}else{g=h>>31;g=ao(g+h^g,0,y);if((y-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((y-g|0)<2){continue}break}}E=g-2|0;t[E|0]=f;t[g-1|0]=(h|0)<0?45:43;f=y-E|0}i=(f+(p+(n+A|0)|0)|0)+1|0;cg(d,32,x,i,e);uf(a,C,A);cg(a,48,c,i,e^65536);m:{n:{o:{if((u|0)==70){f=m+16|0;d=f|8;f=f|9;k=k>>>0>q>>>0?q:k;h=k;while(1){g=ao(v[h>>2],0,f);p:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break p}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break p}if((f|0)!=(g|0)){break p}t[m+24|0]=48;g=d}uf(a,g,f-g|0);h=h+4|0;if(q>>>0>=h>>>0){continue}break}g=0;if(!p){break n}uf(a,13845,1);if((n|0)<1|h>>>0>=l>>>0){break o}while(1){g=ao(v[h>>2],0,f);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}uf(a,g,(n|0)<9?n:9);g=n-9|0;h=h+4|0;if(l>>>0<=h>>>0){break n}d=(n|0)>9;n=g;if(d){continue}break}break n}q:{if((n|0)<0){break q}q=k>>>0<l>>>0?l:k+4|0;d=m+16|0;f=d|9;d=d|8;h=k;while(1){g=ao(v[h>>2],0,f);if((f|0)==(g|0)){t[m+24|0]=48;g=d}r:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}uf(a,g,1);g=g+1|0;if(s?0:(n|0)<=0){break r}uf(a,13845,1)}l=g;g=f-g|0;uf(a,l,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(q>>>0<=h>>>0){break q}if((n|0)>-1){continue}break}}cg(a,48,n+18|0,18,0);uf(a,E,y-E|0);break m}g=n}cg(a,48,g+9|0,9,0)}break b}n=(f<<26>>31&9)+C|0;s:{if(d>>>0>11){break s}g=12-d|0;if(!g){break s}z=8;while(1){z=z*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(z+(-b-z));break s}b=b+z-z}h=v[m+44>>2];g=h>>31;g=ao(g^g+h,0,y);if((y|0)==(g|0)){t[m+15|0]=48;g=m+15|0}q=A|2;l=f&32;h=v[m+44>>2];k=g-2|0;t[k|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;u=l;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=u|w[g+71216|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i?1:(d|0)>0|b!=0)|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}f=m+16|0;d=!d|((h-m|0)-18|0)>=(d|0)?(y-(f+k|0)|0)+h|0:((d+y|0)-k|0)+2|0;i=d+q|0;cg(a,32,c,i,e);uf(a,n,q);cg(a,48,c,i,e^65536);g=f;f=h-f|0;uf(a,g,f);g=d;d=y-k|0;cg(a,48,g-(d+f|0)|0,0,0);uf(a,k,d)}cg(a,32,c,i,e^8192);gb=m+560|0;return((c|0)>(i|0)?c:i)|0}function ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-336|0;gb=e;Wc(b,60);j=15;a:{if(!Gh(b,11407)){Wc(b,124);j=31;if(!Gh(b,12499)){break a}}Hd(a,536870912);u[a+480190>>1]=j;vc(b);b:{if(x[a+480190>>1]){while(1){d=Jr(b);v[(e+208|0)+(f<<2)>>2]=d;if(d>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;xh(a,1);Rb(b,4);h=Lr(b);if(h>>>0<178){break a}d=a;p=1776930/+(h>>>0)*1e4;c:{if(p<4294967296&p>=0){h=~~p>>>0;break c}h=0}v[d+480204>>2]=h;Rb(b,14);d:{e:{f:{if(x[a+480190>>1]){i=e+62|0;k=1;j=0;m=1;while(1){f=e+40|0;vV(b,f);d=v[((k<<2)+e|0)+204>>2];n=gb-16|0;gb=n;g=(B(k,104)+a|0)+484380|0;ud(g,1);v[g>>2]=d;t[g+37|0]=w[f+24|0]<<4;t[n+15|0]=w[f+25|0];t[n+14|0]=64;q=g,r=w[ac(n+15|0,n+14|0)|0]<<2,u[q+30>>1]=r;d=f+26|0;l=Ib(w[d|0]|w[d+1|0]<<8);d=f+28|0;d=Ib(w[d|0]|w[d+1|0]<<8);h=v[g>>2];g:{if(!h){break g}v[g+4>>2]=l;d=(d<<1)+l|0;v[g+8>>2]=d;if(h>>>0<=l>>>0){l=h-1|0;v[g+4>>2]=l}if(d>>>0>h>>>0){v[g+8>>2]=h;d=h}if(!(!(d>>>0<l>>>0|d>>>0<4)&d-l>>>0>3)){v[g+4>>2]=0;v[g+8>>2]=0;break g}if(d>>>0<=l>>>0){break g}u[g+34>>1]=x[g+34>>1]|2}gb=n+16|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;j=j+1|0}f=f+1|0;if((i|0)!=(f|0)){continue}break}if(j>>>0>127){break b}d=e+176|0;Qk(d,3,e+40|0);h=e+192|0;Bc(h,d);v[22708]=0;Q(301,((k<<5)+a|0)+946304|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}vb(e+192|0);m=m+1|0;k=m&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}d=Tb(e+40|0,11292);v[22708]=0;f=a+946336|0;h=Q(884,f|0,d|0)|0;g=v[22708];v[22708]=0;j=1;h:{i:{j:{k:{if((g|0)!=1){if(!h){v[22708]=0;h=Q(70,e+192|0,11303)|0;j=v[22708];v[22708]=0;if((j|0)==1){break k}v[22708]=0;j=Q(884,f|0,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}vb(h)}vb(d);f=0;d=e+40|0;h=oV(b,d);if(!h){ZB(d)}if(!h){break a}if(!pU(e+40|0)){break a}if(c){break h}break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(h)}vb(d);break e}u[e+38>>1]=0;if(w[e+40|0]){while(1){u[e+192>>1]=w[(e+f|0)+42|0]+1;q=e,r=x[Ke(e+38|0,e+192|0)>>1],u[q+38>>1]=r;f=f+1|0;if(f>>>0<w[e+40|0]){continue}break}}d=e+40|1;h=w[d|0];f=w[e+40|0];g=a+484360|0;cf(Sb(g),f>>>0>h>>>0?w[d|0]:0);Dr(Sb(g),e+40|2,w[e+40|0]);if(x[a+480190>>1]==31){Rb(b,4)}k=0;v[e+32>>2]=0;v[e+28>>2]=0;v[e+24>>2]=0;t[e+23|0]=0;l=c&1;if(l){zg(a+484344|0,x[e+38>>1])}if(x[e+38>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(wh(h,k&65535,64)){break m}}Rb(b,1024);break l}while(1){n=Yc(_b(h,k),m,0);f=0;while(1){g=e+192|0;wn(g,b);d=n+B(f,6)|0;n:{o:{p:{q:{if(w[ic(g,0)|0]!=255){break q}t[(e+32|0)+f|0]=0;t[(e+24|0)+f|0]=0;g=ic(e+192|0,1);i=w[g|0];if((i|0)==252&j){t[g|0]=254;break o}switch(i-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}g=v[e+192>>2];v[e+16>>2]=g;v[e+8>>2]=g;fr(e+8|0,d);g=w[d|0];r:{if(!g){break r}t[(e+24|0)+f|0]=0;t[(e+32|0)+f|0]=g;if(g>>>0>48){break r}t[e+176|0]=8;q=e,r=w[qf(e+23|0,e+176|0)|0],t[q+23|0]=r}s:{t:{u:{v:{w:{x:{switch(w[d+3|0]){case 1:t[d+3|0]=1;break n;case 2:g=w[d+5|0];if(g&240){t[d+3|0]=3;t[d+5|0]=g>>>4;break n}g=g&15;if(g){t[d+3|0]=2;t[d+5|0]=g;break n}t[d+5|0]=0;break t;case 3:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=0;break n;case 4:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=1;break n;case 5:if(!w[d+1|0]){break u}t[d+3|0]=13;t[e+176|0]=63;t[e+15|0]=w[d+5|0]+(x[(B(w[d+1|0],104)+a|0)+484410>>1]>>>2|0);q=d,r=w[ac(e+176|0,e+15|0)|0],t[q+5|0]=r;if(!w[(e+24|0)+f|0]){break w}t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+5|0]=0;break t;case 6:g=w[d+1|0];if(!g){break u}t[d+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;i=w[d+5|0];g=g>>>0<i>>>0?0:g-i|0;t[d+5|0]=g;if(!w[(e+24|0)+f|0]){break w}t[d+4|0]=g;t[d+2|0]=1;t[d+5|0]=0;break t;case 8:i=w[(e+32|0)+f|0];g=w[d+5|0];o=i+(g>>>4|0)|0;t[(e+28|0)+f|0]=o;t[d+3|0]=2;g=g&15;t[(e+24|0)+f|0]=g;q=d,r=oU(g,i,o&255),t[q+5|0]=r;break w;case 9:t[e+176|0]=8;q=e,r=w[qf(e+23|0,e+176|0)|0],t[q+23|0]=r;break t;case 0:break v;case 7:break x;default:break t}}g=w[(e+32|0)+f|0];i=w[d+5|0];o=g-(i>>>4|0)|0;t[(e+28|0)+f|0]=o;t[d+3|0]=3;i=i&15;t[(e+24|0)+f|0]=i;q=d,r=oU(i,o&255,g),t[q+5|0]=r}if(!w[d+3|0]){break s}break n}if(!w[d+5|0]){break s}break t}t[d+5|0]=0}t[d+3|0]=0}i=w[(e+24|0)+f|0];if(!i){break n}o=(e+28|0)+f|0;g=w[o|0];if(g){t[(e+32|0)+f|0]=g;t[d|0]=g;t[d+5|0]=i;t[o|0]=0}t[d+3|0]=4;break n}t[d+3|0]=14;t[e+23|0]=9;break n}t[d+3|0]=13}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[e+38>>1]){continue}break}}y:{z:{A:{B:{if(c&2){j=x[a+480190>>1];if(!j){break A}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){Cg(Rc(e+192|0,8,1,0,0),c,b);j=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(j&65535)>>>0){continue}break}break B}j=x[a+480190>>1]}if((j&65535)!=15){break A}b=gb-16|0;gb=b;c=e+176|0;d=Tb(b,1514);Dc(c,d);vb(d);gb=b+16|0;v[22708]=0;U(463,e+192|0,c|0,e+23|0);b=v[22708];v[22708]=0;f=1;if((b|0)!=1){break z}a=P()|0;O()|0;Hb(e+176|0);break e}f=0;v[22708]=0;Q(2,e+192|0,9566)|0;b=v[22708];v[22708]=0;if((b|0)==1){break y}}b=e+192|0;Eb(a+1298304|0,b);vb(b);if(f){Hb(e+176|0)}Xc(a+1298316|0,x[a+480190>>1]==15?2374:12313);v[a+1298364>>2]=2;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+192|0)}S(a|0);L()}f=1;break a}f=0}gb=e+336|0;return f|0}function CK(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-48|0;gb=g;v[g+44>>2]=c;u[g+32>>1]=0;u[g+16>>1]=65535;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Et(g+44|0,g+32|0,g+16|0)){if(me(v[b+24>>2]+484344|0,c&65535)){break j}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);Di(c,a,b);vb(b);vb(a);break i}c=_b(v[b+24>>2]+484344|0,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Di(c,a,b);vb(b);vb(a);break i}if(!(x[v[b+24>>2]+480188>>1]>(e|0)&(e|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Di(c,a,b);vb(b);vb(a);break i}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Di(c,a,b);vb(b);vb(a);break i}e=Yc(c,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!ce(e)){if(!Yt(e)){break n}}c=g+16|0;KO(c,v[b+24>>2],w[e|0],w[e+1|0]);v[22708]=0;R(2041,g+32|0,c|0);c=v[22708];v[22708]=0;b=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22708]=0;Q(70,g+32|0,13839)|0;c=v[22708];v[22708]=0;if((c|0)==1){break l}}v[22708]=0;c=ce(e);d=v[22708];v[22708]=0;if((d|0)==1){break c}o:{if(c){v[22708]=0;Q(70,g|0,7238)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}break o}if(Yt(e)){v[22708]=0;Q(70,g|0,7548)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break o}break c}v[22708]=0;Q(70,g|0,13839)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}}c=a;a=g+32|0;Di(c,a,g);vb(g);vb(a);if(!b){break i}vb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:b=e+1|0;p:{if(w[e+1|0]){iv(g+32|0,b);break p}Tb(g+32|0,13844)}q:{if(w[b|0]){v[22708]=0;Q(70,g+16|0,8055)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break q}break d}v[22708]=0;Q(70,g+16|0,13844)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}}c=a;a=g+32|0;b=g+16|0;Di(c,a,b);vb(b);vb(a);break i;case 2:r:{if(Bg(e)){Tb(g+32|0,14911);break r}if(w[e+2|0]){Ge(g+32|0,1,tz(v[v[b+24>>2]+8>>2],w[e+2|0]));break r}Tb(g+32|0,14911)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break e}s:{if(b){v[22708]=0;Q(70,g+16|0,14911)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}break s}if(w[e+2|0]){v[22708]=0;Q(70,g+16|0,2597)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break s}break e}v[22708]=0;Q(70,g+16|0,14911)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}}c=a;a=g+32|0;b=g+16|0;Di(c,a,b);vb(b);vb(a);break i;case 4:t:{if(Bg(e)){q=g,r=Gq(e)&255,v[q>>2]=r;kC(g+32|0,g);break t}if(w[e+2|0]){iv(g+32|0,e+4|0);break t}Tb(g+32|0,13844)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break f}u:{if(b){v[22708]=0;Q(70,g+16|0,2581)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}break u}if(w[e+2|0]){v[22708]=0;Q(70,g+16|0,2581)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break u}break f}v[22708]=0;Q(70,g+16|0,13844)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}}c=a;a=g+32|0;b=g+16|0;Di(c,a,b);vb(b);vb(a);break i;case 3:v:{if(Bg(e)){q=g,r=(Fo(e)&3840)!=0,t[q|0]=r;i=gb-32|0;gb=i;t[i+24|0]=44;v[i+16>>2]=-1;v[i+20>>2]=0;v[i+8>>2]=1058;v[i+12>>2]=1;n=g+32|0;c=g;b=gb+-64|0;gb=b;d=b;k=i+8|0;l=v[k>>2]&2?16:10;j=gb-32|0;gb=j;f=Ge(j+16|0,1,0);w:{x:{y:{while(1){h=Jb(f);m=Jb(f);o=Ab(f);p=w[c|0];v[22708]=0;ha(91,j+8|0,h|0,m+o|0,p|0,l|0);h=v[22708];v[22708]=0;if((h|0)==1){break x}if(!v[j+12>>2]){break y}h=Ab(f);v[22708]=0;v[j+4>>2]=h;h=yf(j+4|0);m=v[22708];v[22708]=0;if((m|0)!=1){v[22708]=0;U(75,f|0,h|0,0);h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break x}c=v[j+8>>2];l=Jb(f);v[22708]=0;R(76,f|0,c-l|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;R(77,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break x}vb(f);gb=j+32|0;break w}}a=P()|0;O()|0;vb(f);S(a|0);L()}c=b+16|0;Ll(c,b,k);v[22708]=0;U(89,b+32|0,c|0,k|0);c=v[22708];v[22708]=0;z:{A:{B:{C:{D:{if((c|0)!=1){v[22708]=0;U(90,b+48|0,b+32|0,k|0);c=v[22708];v[22708]=0;if((c|0)==1){break D}v[22708]=0;R(72,n|0,b+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break C}vb(b+48|0);vb(b+32|0);vb(b+16|0);vb(b);gb=b- -64|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b+48|0)}vb(b+32|0)}vb(b+16|0);vb(b);S(a|0);L()}gb=i+32|0;break v}if(w[e+3|0]){Ge(g+32|0,1,sz(v[v[b+24>>2]+8>>2],w[e+3|0]));break v}Tb(g+32|0,13845)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break g}E:{if(b){v[22708]=0;Q(70,g+16|0,9551)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}break E}if(w[e+3|0]){v[22708]=0;Q(70,g+16|0,9551)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break E}break g}v[22708]=0;Q(70,g+16|0,13845)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}}c=a;a=g+32|0;b=g+16|0;Di(c,a,b);vb(b);vb(a);break i;case 5:F:{if(Bg(e)){q=g,r=Fo(e)&255,v[q>>2]=r;kC(g+32|0,g);break F}if(w[e+3|0]){iv(g+32|0,e+5|0);break F}Tb(g+32|0,13844)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break h}G:{if(b){v[22708]=0;Q(70,g+16|0,8342)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}break G}if(w[e+3|0]){v[22708]=0;Q(70,g+16|0,8342)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break G}break h}v[22708]=0;Q(70,g+16|0,13844)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}}c=a;a=g+32|0;b=g+16|0;Di(c,a,b);vb(b);vb(a);break i;default:break k}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);Di(c,a,b);vb(b);vb(a)}gb=g+48|0;return}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);if(!b){break a}}vb(g+16|0)}S(c|0);L()}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-144|0;gb=d;vc(c);a:{b:{c:{d:{e:{f:{g:{if(!(!zr(c,d+128|0)|v[d+128>>2]!=1297239878|!(v[d+136>>2]==1482052408|(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))==1448293937)&(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))!=1146437965)){e=gb-32|0;gb=e;i=hh(d+112|0);h:{i:{j:{k:{l:{while(1){v[22708]=0;h=Q(191,c|0,8)|0;g=v[22708];v[22708]=0;if((g|0)==1){break j}if(!h){break k}v[22708]=0;R(1170,e|0,c|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;R(1171,i|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break l}ed(e);continue}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;ed(e);break i}gb=e+32|0;break h}a=P()|0;O()|0}ke(i);S(a|0);L()}v[22708]=0;i=T(215,d+88|0)|0;c=v[22708];v[22708]=0;m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){h=Rc(d+84|0,8,1,1,0);if((w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))!=1146437965){break z}v[22708]=0;U(1156,d- -64|0,d+112|0,1296581714);c=v[22708];v[22708]=0;if((c|0)==1){break B}v[22708]=0;U(1156,d+40|0,d+112|0,1296318804);c=v[22708];v[22708]=0;if((c|0)==1){break c}c=d+40|0;Vc(i,c);xb(c);v[22708]=0;c=T(1157,d- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!c){break n}v[22708]=0;c=T(275,i|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!c){break n}v[22708]=0;c=T(426,d- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;f=T(416,d- -64|0)|0;e=v[22708];v[22708]=0;C:{if((e|0)==1){break C}v[22708]=0;Q(318,d- -64|0,2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}v[22708]=0;k=T(426,d- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break A}}break c}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22708]=0;R(829,d+40|0,d- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!Ib(w[d+40|0]|w[d+41|0]<<8)){break n}j=d+40|0;e=fc(j);j=Ve(j);k=(k>>>0)/(Ib(w[d+40|0]|w[d+41|0]<<8)>>>0)|0;if((Ib(w[e|0]|w[e+1|0]<<8)|0)!=(Ib(w[j|0]|w[j+1|0]<<8)+1|0)){break n}if((Ib(w[e|0]|w[e+1|0]<<8)|0)==2){Ap(h,2)}D:{if((f|0)!=16){if((f|0)!=8){break n}if(!Ib(w[d+46|0]|w[d+47|0]<<8)){Cf(h,1);break D}if((Ib(w[d+46|0]|w[d+47|0]<<8)|0)==2){Cf(h,17);break D}if((Ib(w[d+46|0]|w[d+47|0]<<8)|0)!=3){break n}Cf(h,16);break D}if(Ib(w[d+46|0]|w[d+47|0]<<8)){break n}Zi(h,16)}xb(d- -64|0);j=0;f=0;break y}v[22708]=0;U(1156,d- -64|0,d+112|0,1447576658);c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;U(1156,d+40|0,d+112|0,1128808782);c=v[22708];v[22708]=0;if((c|0)==1){break w}v[22708]=0;U(1156,d+16|0,d+112|0,1112491097);c=v[22708];v[22708]=0;if((c|0)==1){break g}c=d+16|0;Vc(i,c);xb(c);v[22708]=0;g=T(275,i|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}e=0;c=0;E:{if(!g){break E}v[22708]=0;g=T(275,d- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}c=0;if(!g){break E}v[22708]=0;g=Q(1158,d- -64|0,d+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}c=0;if(!g){break E}c=w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24);v[22708]=0;f=T(426,d+40|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}g=(c|0)!=1482052408;if(g){Rc(d+12|0,16,1,0,0);v[d+84>>2]=v[d+12>>2]}if((f|0)==6){Ap(h,3)}c=d+16|0;l=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=c|4;m=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=Ib(w[d+28|0]|w[d+29|0]<<8);j=Xb(w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24));v[22708]=0;n=T(195,i|0)|0;c=v[22708];v[22708]=0;o=1;if((c|0)==1){break g}c=B((f|0)==6?2:1,g?2:1);f=(l>>>0)/(c>>>0)|0;l=(m>>>0)/(c>>>0)|0;c=(n>>>0)/(c>>>0)|0}xb(d+40|0);xb(d- -64|0);if(!o){break m}}v[22708]=0;Q(1140,a|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}v[22708]=0;g=B(b,104)+a|0;e=g+484380|0;R(424,e|0,0);m=v[22708];v[22708]=0;if((m|0)==1){break p}v[e>>2]=c;l=f+l|0;v[g+484388>>2]=l;v[g+484384>>2]=f;if(!(c>>>0<l>>>0|l>>>0<=f+4>>>0)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2}c=B(b,104)+a|0;v[c+484404>>2]=k?k:22050;f=c+484410|0;c=j>>>8|0;u[f>>1]=c&65535?(j&16776960)>>>0>65536?256:c:256;c=v[a+480180>>2];v[22708]=0;U(1142,e|0,32,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break v}v[22708]=0;U(1156,d- -64|0,d+112|0,1312902469);c=v[22708];v[22708]=0;if((c|0)==1){break u}v[22708]=0;c=T(275,d- -64|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}if(!c){break t}v[22708]=0;c=T(195,d- -64|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}v[22708]=0;W(503,d- -64|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break s}break e}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22708]=0;c=Q(70,d+40|0,18726)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}vb(c)}v[22708]=0;W(329,h|0,e|0,i|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;_h(e,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break e}xb(d- -64|0);e=1;break m}e=P()|0;O()|0;break d}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(c);break d}xb(d- -64|0);e=0}xb(i);ke(d+112|0)}gb=d+144|0;return e|0}e=P()|0;O()|0;xb(d+40|0)}xb(d- -64|0);break b}e=P()|0;O()|0}xb(d- -64|0);break b}e=P()|0;O()|0;xb(d- -64|0)}xb(i)}ke(d+112|0);S(e|0);L()}function zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=gb-1824|0;gb=d;vc(b);g=gb-32|0;gb=g;e=g+24|0;k=d+1224|0;lV(e,k);i=yb(e);e=v[g+28>>2];j=v[g+24>>2];v[g+8>>2]=j;v[g+12>>2]=e;v[g>>2]=j;v[g+4>>2]=e;j=g+16|0;e=b;cc(j,e,g);j=yb(j);if((j|0)==(i|0)){Rb(e,yb(g+24|0))}gb=g+32|0;e=(i|0)==(j|0);if(!e){kV(k)}a:{if(!e){break a}if(!uV(d+1224|0)){break a}if(!eC(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;h=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=h;Hd(a,1);e=a+1074312|0;Rf(e,83);Ob(e,84,1);Ob(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Wc(b,20);j=a+480188|0;h=1;g=1;while(1){i=B(h,104)+a|0;k=i+484380|0;e=((h<<5)+a|0)+946304|0;fC(b,d+16|0,k,e,1);m=v[k>>2];b:{if(!w[ic(e,0)|0]){break b}c:{if(sd(e,13847,3)){if(sd(e,13851,3)){break c}}if(w[ic(e,5)|0]==58){break b}}g=0}if(Ib(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){z=i+484384|0,A=Ib(w[d+42|0]|w[d+43|0]<<8),v[z>>2]=A;z=i+484388|0,A=Ib(w[d+42|0]|w[d+43|0]<<8)+(Ib(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[z>>2]=A;wk(k)}d:{if(Ib(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break d}}v[d+1064>>2]=5;z=d,A=v[bp(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}f=f+m|0;h=h+1|0;if((h|0)!=16){continue}break}r=d+1064|0;e=r;AV(b,e);p=a+484360|0;Dr(Sb(p),e|2,128);h=0;m=zV(b,Sb(p),w[e|0],f,j,0,1);e=e|1;if(!(w[e|0]|w[r|0])&m>>>0<2){break a}if(nf(b)+65536>>>0<(m<<10)+f>>>0){break a}if(!c){h=1;break a}if(!w[e|0]){t[e|0]=120}if(!sd(d+1200|0,12129,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;s=1773447.5/(+(240-w[e|0]|0)*122)*1e4;f:{if(s<4294967296&s>=0){e=~~s>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=g?4:5;z=d,A=v[bp(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A;break e}v[d+16>>2]=g?1:2;z=d,A=v[bp(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;e=d+1048|0;Yj(e,3,d+1200|0);f=d+16|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);k=0;xh(a,0);y=v[b+8>>2];u[d+1046>>1]=0;g:{h:{if(!m){break h}while(1){f=Sb(p);z=d,A=dC(Vb(f),Zb(f),d+1046|0),v[z+16>>2]=A;z=d,A=Zb(f),v[z+1048>>2]=A;f=d+16|0;e=Gb(f,d+1048|0);tV(b,f);if(e){k=cC(d+16|0,0)+k|0;if(k>>>0>512){break g}}j=0;f=0;o=0;while(1){r=sV(d+16|0,j);h=0;while(1){e=f;l=Pe(r,h);q=w[ic(l,2)|0]&15;i=w[ic(l,3)|0];f=0;i:{if(!(e&255)|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))){break i}f=e+1|0;if((f&255)>>>0<33){break i}v[d+1196>>2]=6}j:{k:{l:{switch(q-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1&i>>>0>=32){break k}l=(q|0)!=1;if(!(l|!i|i>>>0>2)){v[d+1048>>2]=2;z=d,A=v[bp(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break j}if(l|(i|0)!=55&(i|0)!=71){break j}if((e|0)<=2){break k}break j;case 10:v[d+1196>>2]=6;break j;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[bp(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((q|0)!=13){break j}o=((i|j)!=0)+o|0;f=1;break j;case 14:break l;default:break j}}v[d+1048>>2]=3;z=d,A=v[bp(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break j}v[d+1196>>2]=g}h=h+1|0;if((h|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}if((o-1&255)>>>0<2){v[d+1196>>2]=6}n=(o&255)+n|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(m>>>0>(f&65535)>>>0){continue}break}if(v[d+1196>>2]!=6|m+32>>>0>=n>>>0){break h}v[d+1196>>2]=5}Wc(b,y);o=c&1;if(o){zg(a+484344|0,m)}if(m){l=a+484344|0;j=0;while(1){tV(b,d+16|0);m:{if(!o){break m}if(!wh(l,j&65535,64)){break m}v[d+1048>>2]=0;n=0;while(1){q=Yc(_b(l,j),n,0);p=sV(d+16|0,n);i=0;while(1){f=Pe(p,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=q+B(i,6)|0;fr(d+8|0,e);n:{o:{p:{q:{r:{s:{t:{u:{f=w[e+5|0];if(f){h=e+3|0;g=(d+1048|0)+i|0;k=w[e+3|0];if((k|0)!=14){break u}t[g|0]=0;break r}h=(d+1048|0)+i|0;t[h|0]=0;k=w[e+3|0];if(!k){break s}h=e+3|0;break t}g=w[g|0];if(!g){break t}v:{if(g>>>0>=16){t[e+2|0]=3;g=g>>>4|0;break v}t[e+2|0]=4}t[e+4|0]=g}w:{x:{switch(k-12|0){case 1:g=v[d+1196>>2];if((g|0)==6){break w}k=10;t[h|0]=10;break p;case 0:f=f&127;t[e+5|0]=f;k=12;break q;case 2:break r;case 3:break x;default:break q}}k=15;f=f&15;t[e+5|0]=f;break q}t[e+5|0]=0;break o}t[h|0]=0;break n}if(f>>>0<=1&v[d+1196>>2]>3){break o}k=10;t[h|0]=10;t[(d+1048|0)+i|0]=f}g=v[d+1196>>2]}if((g|0)>1){break o}y:{z:{A:{switch(k|0){case 0:if(f>>>0>2){break z}break;case 2:break y;case 1:break z;default:break A}}t[h|0]=0;break n}t[h|0]=1;break n}g=f&15;if(g){t[h|0]=2;t[e+5|0]=g;break n}if(f>>>0<16){break n}t[h|0]=3;t[e+5|0]=f>>>4;break n}Of(e)}i=i+1|0;if((i|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}j=j+1|0;if((m|0)!=(j|0)){continue}break}}h=18726;f=v[d+1196>>2];if(f>>>0<7){h=v[(f<<2)+33208>>2]}f=d+16|0;e=Tb(f,5437);Eb(a+1298304|0,e);vb(e);f=Tb(f,8043);Eb(a+1298316|0,f);vb(f);Xc(a+1298328|0,h);v[a+1298364>>2]=2;h=1;if(!(c&2)){break a}i=1;while(1){c=B(i,104)+a|0;f=c+484384|0;Rb(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;c=d+16|0;Rc(c,8,1,1,0);Cg(c,f,b);i=i+1|0;if((i|0)!=16){continue}break}break a}h=0}gb=d+1824|0;return h|0}function cy(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0;h=gb-80|0;gb=h;v[h+76>>2]=b;z=h+55|0;x=h+56|0;b=0;a:{b:{c:while(1){d:{if((p|0)<0){break d}if((2147483647-p|0)<(b|0)){v[115189]=61;p=-1;break d}p=b+p|0}e:{f:{k=v[h+76>>2];b=k;i=w[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(w[b+1|0]!=37){break h}j=b+2|0;v[h+76>>2]=j;i=i+1|0;m=w[b+2|0];b=j;if((m|0)==37){continue}break}}b=i-k|0;if(a){uf(a,k,b)}if(b){continue c}q=-1;i=1;j=h;r=!Qh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(!(r|w[b+2|0]!=36)){q=t[b+1|0]-48|0;y=1;i=3}b=i+b|0;v[j+76>>2]=b;s=0;l=t[b|0];j=l-32|0;i:{if(j>>>0>31){i=b;break i}i=b;j=1<<j;if(!(j&75913)){break i}while(1){i=b+1|0;v[h+76>>2]=i;s=j|s;l=t[b+1|0];j=l-32|0;if(j>>>0>=32){break i}b=i;j=1<<j;if(j&75913){continue}break}}j:{if((l|0)==42){j=h;k:{l:{if(!Qh(t[i+1|0])){break l}b=v[h+76>>2];if(w[b+2|0]!=36){break l}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;o=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break k}if(y){break b}y=0;o=0;if(a){b=v[c>>2];v[c>>2]=b+4;o=v[b>>2]}b=v[h+76>>2]+1|0}v[j+76>>2]=b;if((o|0)>-1){break j}o=0-o|0;s=s|8192;break j}o=VI(h+76|0);if((o|0)<0){break b}b=v[h+76>>2]}m=-1;m:{if(w[b|0]!=46){break m}if(w[b+1|0]==42){n:{if(!Qh(t[b+2|0])){break n}b=v[h+76>>2];if(w[b+3|0]!=36){break n}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;m=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break m}if(y){break b}if(a){b=v[c>>2];v[c>>2]=b+4;m=v[b>>2]}else{m=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break m}v[h+76>>2]=b+1;m=VI(h+76|0);b=v[h+76>>2]}i=0;while(1){r=i;n=-1;if(t[b|0]-65>>>0>57){break a}l=b+1|0;v[h+76>>2]=l;i=t[b|0];b=l;i=w[(i+B(r,58)|0)+70687|0];if(i-1>>>0<8){continue}break}o:{p:{if((i|0)!=19){if(!i){break a}if((q|0)>=0){v[(q<<2)+e>>2]=i;b=(q<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break p}if(!a){break e}UI(h- -64|0,i,c,g);l=v[h+76>>2];break o}if((q|0)>-1){break a}}b=0;if(!a){continue c}}j=s&-65537;i=s&8192?j:s;n=0;q=2378;s=x;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{b=t[l-1|0];b=r?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break q;case 9:case 13:case 14:case 15:break r;case 27:break w;case 12:case 17:break z;case 23:break A;case 0:case 32:break B;case 24:break C;case 22:break D;case 29:break E;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break f;default:break F}}G:{switch(b-65|0){case 0:case 4:case 5:case 6:break r;case 2:break u;case 1:case 3:break f;default:break G}}if((b|0)==83){break v}break f}l=v[h+64>>2];k=v[h+68>>2];q=2378;break y}b=0;H:{switch(r&255){case 0:v[v[h+64>>2]>>2]=p;continue c;case 1:v[v[h+64>>2]>>2]=p;continue c;case 2:i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c;case 3:u[v[h+64>>2]>>1]=p;continue c;case 4:t[v[h+64>>2]]=p;continue c;case 6:v[v[h+64>>2]>>2]=p;continue c;case 7:break H;default:continue c}}i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c}m=m>>>0>8?m:8;i=i|8;b=120}j=x;C=b&32;r=v[h+68>>2];k=r;l=v[h+64>>2];if(k|l){while(1){j=j-1|0;t[j|0]=C|w[(l&15)+71216|0];D=!k&l>>>0>15|(k|0)!=0;r=k;k=k>>>4|0;l=(r&15)<<28|l>>>4;if(D){continue}break}}k=j;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break x}q=(b>>>4|0)+2378|0;n=2;break x}b=x;j=v[h+68>>2];k=j;l=v[h+64>>2];if(j|l){while(1){b=b-1|0;t[b|0]=l&7|48;r=!k&l>>>0>7|(k|0)!=0;j=k;k=j>>>3|0;l=(j&7)<<29|l>>>3;if(r){continue}break}}k=b;if(!(i&8)){break x}b=x-k|0;m=(b|0)<(m|0)?m:b+1|0;break x}b=v[h+68>>2];k=b;l=v[h+64>>2];if((b|0)<-1|(b|0)<=-1){k=0-(k+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=k;n=1;q=2378;break y}if(i&2048){n=1;q=2379;break y}n=i&1;q=n?2380:2378}k=ao(l,k,x)}i=(m|0)>-1?i&-65537:i;b=v[h+68>>2];j=b;l=v[h+64>>2];if(!((l|0)!=0|(b|0)!=0|m)){m=0;k=x;break f}b=!(j|l)+(x-k|0)|0;m=(b|0)<(m|0)?m:b;break f}b=v[h+64>>2];k=b?b:14146;b=mt(k,0,m);s=b?b:k+m|0;i=j;m=b?b-k|0:m;break f}if(m){b=v[h+64>>2];break t}b=0;cg(a,32,o,0,i);break s}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];b=h+8|0;v[h+64>>2]=b;m=-1}j=b;b=0;I:{while(1){k=v[j>>2];if(!k){break I}k=NI(h+4|0,k);l=(k|0)<0;if(!(l|k>>>0>m-b>>>0)){j=j+4|0;b=b+k|0;if(m>>>0>b>>>0){continue}break I}break}n=-1;if(l){break a}}cg(a,32,o,b,i);if(!b){b=0;break s}j=0;l=v[h+64>>2];while(1){k=v[l>>2];if(!k){break s}k=NI(h+4|0,k);j=k+j|0;if((j|0)>(b|0)){break s}uf(a,h+4|0,k);l=l+4|0;if(b>>>0>j>>>0){continue}break}}cg(a,32,o,b,i^8192);b=(b|0)<(o|0)?o:b;continue c}b=kb[f|0](a,A[h+64>>3],o,m,i,b)|0;continue c}t[h+55|0]=v[h+64>>2];m=1;k=z;i=j;break f}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}n=p;if(a){break a}if(!y){break e}b=1;while(1){a=v[(b<<2)+e>>2];if(a){UI((b<<3)+d|0,a,c,g);n=1;b=b+1|0;if((b|0)!=10){continue}break a}break}n=1;if(b>>>0>9){break a}while(1){n=1;b=b+1|0;if((b|0)==10){break a}n=-1;if(!v[(b<<2)+e>>2]){continue}break}break a}l=s-k|0;m=(l|0)>(m|0)?l:m;j=m+n|0;b=(j|0)>(o|0)?j:o;cg(a,32,b,j,i);uf(a,q,n);cg(a,48,b,j,i^65536);cg(a,48,m,l,0);uf(a,k,l);cg(a,32,b,j,i^8192);continue}break}n=0;break a}n=-1}gb=h+80|0;return n}function kL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-448|0;gb=e;a:{if(pk(b)){break a}f=w[ul(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}f=e+184|0;Ld(f);g=v[e+184>>2];Ld(e+416|0);h=tl(g,v[e+420>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=uc(e+432|0,18726);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){a=ba(8)|0;v[22708]=0;c=Q(2059,e+416|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+184|0,14728,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}rc(a,e+184|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);vb(c);break c}b=P()|0;O()|0;break d}if(!d){break k}a=ba(8)|0;v[22708]=0;f=Q(2059,e+384|0,b|0)|0;b=v[22708];v[22708]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((b|0)!=1){v[22708]=0;U(2039,e+400|0,14764,f|0);b=v[22708];v[22708]=0;if((b|0)==1){break s}v[22708]=0;R(2056,e+416|0,e+400|0);b=v[22708];v[22708]=0;d=1;if((b|0)==1){break r}v[22708]=0;c=Q(2059,e+368|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;U(2060,e+184|0,e+416|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break p}rc(a,e+184|0);v[22708]=0;U(186,a|0,54936,1938);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);d=0;break o}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(f);break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0}vb(c)}vb(e+416|0)}vb(e+400|0);vb(f);if(!d){break c}}ca(a|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=uc(e+352|0,18726);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Gc(e+176|0,e+168|0)){a=ba(8)|0;v[22708]=0;c=Q(2059,e+416|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+184|0,14728,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}rc(a,e+184|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);vb(c);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=uc(e+336|0,9597);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Gc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=uc(e+320|0,2693);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Gc(e- -64|0,e+56|0)){v[a+52>>2]=0;break k}v[e+312>>2]=d;v[e+316>>2]=b;f=uc(e+304|0,8575);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Gc(e+48|0,e+40|0)){v[a+52>>2]=1;break k}v[e+296>>2]=d;v[e+300>>2]=b;b=uc(e+288|0,6363);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Gc(e+32|0,e+24|0)){v[a+52>>2]=2;break k}a=ba(8)|0;v[22708]=0;c=Q(2059,e+416|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+184|0,11823,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}rc(a,e+184|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);vb(c);break c}b=P()|0;O()|0;break f}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=uc(e+272|0,8812);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Gc(e+144|0,e+136|0)){break k}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=uc(e+256|0,12689);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;t:{if(Gc(e+128|0,e+120|0)){break t}v[e+248>>2]=c;v[e+252>>2]=d;b=uc(e+240|0,12694);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Gc(e+112|0,e+104|0)){break t}v[e+232>>2]=c;v[e+236>>2]=d;b=uc(e+224|0,9902);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Gc(e+96|0,e+88|0)){break t}v[e+216>>2]=c;v[e+220>>2]=d;b=uc(e+208|0,6427);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Gc(e+80|0,e+72|0)){break t}a=ba(8)|0;v[22708]=0;c=Q(70,e+184|0,8848)|0;b=v[22708];v[22708]=0;if((b|0)==1){break j}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break k}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=AK(v[a+56>>2]),v[i+204>>2]=j;if(!Ny(e+184|0,v[b>>2]+24648|0)){break k}Wz(v[b>>2],e+184|0)}gb=e+448|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;vb(c);break e}b=P()|0;O()|0;vb(c)}ca(a|0);break c}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function oJ(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=C(0),v=0,w=0,x=0,y=0,A=C(0),D=0,E=0,F=0,G=C(0),H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=0,P=0,Q=0,R=0;if((d|0)>=1){while(1){D=B(v,2304)+b|0;p=c;x=0;s=gb-128|0;while(1){m=D+(x<<2)|0;o=0;n=s;j=n;while(1){h=z[B(15-o|0,72)+m>>2];w=B(o,72)+m|0;i=z[w+1152>>2];l=C(h+i);k=z[w>>2];t=z[B(31-o|0,72)+m>>2];A=C(k+t);z[j>>2]=l+A;w=B(o,12);h=C(C(h-i)*z[w+68288>>2]);i=C(C(k-t)*z[w+68292>>2]);z[j+64>>2]=h+i;k=C(A-l);l=z[w+68296>>2];z[j+32>>2]=k*l;z[j+96>>2]=C(i-h)*l;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){l=z[n+8>>2];k=z[n+20>>2];i=C(l+k);t=z[n+4>>2];A=z[n+24>>2];G=C(t+A);h=C(i+G);H=z[n+12>>2];I=z[n+16>>2];J=C(H+I);K=z[n>>2];L=z[n+28>>2];M=C(K+L);N=C(J+M);z[n>>2]=h+N;z[n+16>>2]=C(N-h)*C(.7071067690849304);h=C(M-J);i=C(C(h+C(G-i))*C(.7071067690849304));z[n+24>>2]=C(h-i)*C(1.3065630197525024);z[n+8>>2]=C(h+i)*C(.5411961078643799);h=C(K-L);l=C(l-k);k=C(t-A);t=C(C(l+k)*C(.7071067690849304));i=C(h+t);k=C(k+h);l=C(C(C(H-I)+l)-C(k*C(.1989123672246933)));k=C(k+C(l*C(.3826834261417389)));z[n+28>>2]=C(i-k)*C(2.562915563583374);z[n+4>>2]=C(i+k)*C(.509795606136322);h=C(h-t);i=C(l-C(k*C(.1989123672246933)));z[n+20>>2]=C(h+i)*C(.8999761939048767);z[n+12>>2]=C(h-i)*C(.601344883441925);n=n+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;l=z[s+32>>2];h=z[s+96>>2];k=z[s+64>>2];while(1){z[m>>2]=z[s+(o<<2)>>2];n=m;o=o+1|0;m=s+(o<<2)|0;i=z[m+96>>2];z[n+72>>2]=C(h+k)+i;k=l;l=z[m+32>>2];z[n+144>>2]=k+l;k=z[m- -64>>2];z[n+216>>2]=i+C(h+k);m=n+288|0;h=i;if((o|0)!=7){continue}break}z[n+288>>2]=z[s+28>>2];h=z[s+124>>2];z[n+360>>2]=z[s+92>>2]+h;i=z[s+60>>2];z[n+504>>2]=h;z[n+432>>2]=i;x=x+1|0;if((p|0)!=(x|0)){continue}break}v=v+1|0;if((v|0)!=(d|0)){continue}break}}F=hc(f,a,3840);P=d<<5;v=0;while(1){m=gb-32|0;gb=m;o=(v<<8)+F|0;x=(v<<2)+b|0;z[o+4080>>2]=z[x+1152>>2];n=d;f=n-1|0;w=x+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[x>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[x+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[x+4>>2];z[o+4348>>2]=z[w+4>>2];D=(B(v,P)<<1)+e|0;E=D+(f<<1)|0;rt(E,n,o+244|0);f=n<<6;rt(f+E|0,n,o+500|0);rt(D,n,o+240|0);rt(f+D|0,n,o+496|0);O=o+3840|0;p=68384;f=14;while(1){s=f;q=f<<4;j=q+O|0;g=B(31-f|0,72);l=z[g+x>>2];z[j>>2]=l;z[j+4>>2]=z[g+w>>2];g=g|4;z[j+8>>2]=z[g+x>>2];z[j+12>>2]=z[g+w>>2];g=B(f,72);r=g+76|0;z[j+256>>2]=z[r+x>>2];z[j+260>>2]=z[r+w>>2];g=g+72|0;z[j-248>>2]=z[g+x>>2];z[j-244>>2]=z[g+w>>2];h=z[p>>2];i=z[p+4>>2];q=o+q|0;t=z[q>>2];k=C(C(l*h)-C(i*t));z[m+16>>2]=k;l=C(C(i*l)+C(h*t));z[m>>2]=l;r=f<<2;f=1;while(1){g=f<<2;t=z[g+j>>2];A=z[g+q>>2];z[g+(m+16|0)>>2]=C(h*t)-C(i*A);z[g+m>>2]=C(i*t)+C(h*A);f=f+1|0;if((f|0)!=4){continue}break}j=(r<<2)+O|0;q=j-3584|0;r=j-256|0;h=z[p+12>>2];i=z[p+8>>2];f=0;while(1){g=f<<2;t=z[g+q>>2];A=z[g+r>>2];z[g+(m+16|0)>>2]=C(C(h*t)-C(i*A))+k;z[g+m>>2]=l+C(C(h*A)+C(i*t));f=f+1|0;if((f|0)!=4){g=f<<2;k=z[g+(m+16|0)>>2];l=z[g+m>>2];continue}break}q=j-3328|0;r=j-512|0;h=z[p+20>>2];i=z[p+16>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3072|0;r=j-768|0;h=z[p+28>>2];i=z[p+24>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(h*k)-C(i*l))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2816|0;r=j-1024|0;h=z[p+36>>2];i=z[p+32>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2560|0;r=j-1280|0;h=z[p+44>>2];i=z[p+40>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(h*k)-C(i*l))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2304|0;r=j-1536|0;h=z[p+52>>2];i=z[p+48>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=j-2048|0;q=j-1792|0;h=z[p+60>>2];i=z[p+56>>2];f=0;while(1){j=f<<2;r=j+m|0;l=z[j+q>>2];k=z[g+j>>2];z[r>>2]=z[r>>2]+C(C(h*l)+C(i*k));j=j+(m+16|0)|0;z[j>>2]=C(C(h*k)-C(i*l))+z[j>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(n,15-s|0)<<1;Q=f+E|0,R=Aj(z[m+20>>2]),u[Q>>1]=R;j=B(n,s+17|0)<<1;Q=j+E|0,R=Aj(z[m+4>>2]),u[Q>>1]=R;Q=f+D|0,R=Aj(z[m+16>>2]),u[Q>>1]=R;Q=j+D|0,R=Aj(z[m>>2]),u[Q>>1]=R;f=B(n,47-s|0)<<1;Q=f+E|0,R=Aj(z[m+28>>2]),u[Q>>1]=R;j=B(n,s+49|0)<<1;Q=j+E|0,R=Aj(z[m+12>>2]),u[Q>>1]=R;Q=f+D|0,R=Aj(z[m+24>>2]),u[Q>>1]=R;Q=j+D|0,R=Aj(z[m+8>>2]),u[Q>>1]=R;f=s-1|0;p=p- -64|0;if(s){continue}break}gb=m+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+F>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}hc(a,(b<<2)+F|0,3840)}}function qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=gb-752|0;gb=e;vc(b);f=gb-32|0;gb=f;d=f+24|0;j=e+144|0;vU(d,j);h=yb(d);d=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;g=f+16|0;d=b;cc(g,d,f);g=yb(g);if((g|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(h|0);if(!d){uU(j)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!d){break m}if(!yU(e+144|0)){break m}if(!Pb(b,Qc(xU(e+144|0),jb))){break m}if(!c){o=1;break m}Hd(a,262144);f=e+104|0;Mk(f,2,e+144|0);d=e+24|0;Bc(d,f);Eb(a+1298268|0,d);vb(d);h=Tb(d,5450);Eb(a+1298304|0,h);vb(h);d=Tb(d,7395);Eb(a+1298316|0,d);vb(d);d=gb-16|0;gb=d;g=f;f=Tb(d,1302);Dc(g,f);vb(f);gb=d+16|0;t[e+8|0]=w[e+174|0];d=w[e+173|0];v[22708]=0;t[e+127|0]=d;R(874,e+128|0,e+127|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;Y(372,e+24|0,e+104|0,e+8|0,e+128|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}d=e+24|0;Eb(a+1298328|0,d);vb(d);vb(e+128|0);f=e+104|0;Hb(f);v[a+480208>>2]=12;v[a+1298364>>2]=5;u[a+480188>>1]=w[e+182|0]|w[e+183|0]<<8;u[e+24>>1]=w[e+178|0]|w[e+179|0]<<8;u[e+104>>1]=3999;C=a,D=x[Pc(d,f)>>1],u[C+480190>>1]=D;KX(Sb(a+484360|0),e+240|0,w[e+176|0]|w[e+177|0]<<8);if(x[a+480188>>1]){d=0;while(1){f=(d<<5)+a|0;We(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}d=e+24|0;Sd(d,b,B(w[e+178|0]|w[e+179|0]<<8,80));l=kc(e+104|0,d);xb(d);if(x[a+480190>>1]){h=c&2;j=e+72|0;d=0;while(1){v[22708]=0;R(875,l|0,e+24|0);f=v[22708];v[22708]=0;if((f|0)==1){break l}v[22708]=0;Mk(e+8|0,2,j);f=v[22708];v[22708]=0;n:{o:{p:{if((f|0)==1){break p}v[22708]=0;R(324,e+128|0,e+8|0);f=v[22708];v[22708]=0;if((f|0)==1){break p}v[22708]=0;d=d+1|0;Q(301,((d<<5)+a|0)+946304|0,e+128|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}f=e+128|0;vb(f);v[22708]=0;g=f;f=(B(d,104)+a|0)+484380|0;U(876,g|0,e+24|0,f|0);g=v[22708];v[22708]=0;q:{if((g|0)==1){break q}if(!h|!v[f>>2]){break n}g=w[e+42|0]|w[e+43|0]<<8|(w[e+44|0]<<16|w[e+45|0]<<24);v[22708]=0;g=Q(190,b|0,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}if(!g){break n}v[22708]=0;W(329,e+128|0,f|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break n}}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+128|0);break e}if(x[a+480190>>1]>d>>>0){continue}break}}o=1;r:{if(!(c&1)){break r}c=w[e+180|0]|w[e+181|0]<<8;j=0;v[22708]=0;m=a+484344|0;R(330,m|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break k}if(!(w[e+180|0]|w[e+181|0]<<8)){break r}c=e+24|0;p=c|4;q=c|2;r=c|5;s=c|3;y=c|1;while(1){v[22708]=0;c=W(331,m|0,j&65535,64)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}s:{if(!c){break s}c=(j<<1)+e|0;d=c+496|0;if(!(w[d|0]|w[d+1|0]<<8)){break s}c=w[c+496|0]|w[c+497|0]<<8;v[22708]=0;c=Q(190,b|0,c<<4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}if(!c){break s}n=0;c=_b(m,j);v[22708]=0;c=Yc(c,0,0);d=v[22708];v[22708]=0;if((d|0)==1){break f}while(1){v[22708]=0;d=Q(191,b|0,1)|0;f=v[22708];v[22708]=0;t:{u:{v:{if((f|0)!=1){if(!d){break s}v[22708]=0;g=T(374,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break v}if(g){break u}n=n+1|0;c=B(x[a+480188>>1],6)+c|0;break t}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}u[e+28>>1]=0;v[e+24>>2]=0;d=g&31;f=B(d,6)+c|0;z=cj(e+24|0);h=d>>>0<x[a+480188>>1];w:{if(!(g&32)){break w}v[22708]=0;R(403,e+128|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}d=e+128|0;i=qd(d);k=h?f:e+24|0;d=w[d|0];t[k|0]=d;t[(h?f+1|0:y)|0]=w[i|0];x:{if(d){if((d|0)==254){break x}if(d>>>0<121){break w}}d=0}t[k|0]=d}y:{if(!(g&64)){break y}v[22708]=0;R(403,e+128|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}d=e+128|0;A=qd(d);i=h?f+3|0:s;d=w[d|0];t[i|0]=d;k=h?f+5|0:r;t[k|0]=w[A|0];z:{A:{B:{if(d>>>0<=15){v[22708]=0;Of(h?f:z);d=v[22708];v[22708]=0;if((d|0)!=1){break B}a=P()|0;O()|0;break e}if(d>>>0>23){break z}d=w[d+33319|0];t[i|0]=d;break A}d=w[i|0]}if((d|0)!=23){if((d|0)!=9){break y}t[i|0]=20;t[e+8|0]=w[k|0]>>>3;v[22708]=0;t[e+127|0]=1;d=qf(e+8|0,e+127|0);i=v[22708];v[22708]=0;if((i|0)!=1){t[k|0]=w[d|0]-1&15|128;break y}a=P()|0;O()|0;break e}v[22708]=0;t[e+8|0]=64;d=ac(k,e+8|0);i=v[22708];v[22708]=0;if((i|0)!=1){t[k|0]=w[d|0]<<1;break y}a=P()|0;O()|0;break e}t[i|0]=0}if(!(g&128)){break t}t[(h?f+2|0:q)|0]=1;v[22708]=0;d=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break g}t[(h?f+4|0:p)|0]=d}if(n>>>0<64){continue}break}}j=j+1|0;if(j>>>0<(w[e+180|0]|w[e+181|0]<<8)>>>0){continue}break}}xb(l)}gb=e+752|0;return o|0}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}xb(l);break a}a=P()|0;O()|0;vb(e+128|0);break b}a=P()|0;O()|0}Hb(e+104|0)}S(a|0);L()}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-112|0;gb=f;vc(b);a:{b:{c:{d:{e:{if(!YU(b,11403)){break e}i=mc(f+96|0);j=mc(f+80|0);v[22708]=0;v[f+72>>2]=0;v[f+76>>2]=0;R(367,a|0,32768);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;d=Q(2,f+40|0,5302)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}Eb(a+1298304|0,d);vb(d);v[22708]=0;d=Q(2,f+40|0,3152)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=2;k=a+484360|0;h=f- -64|4;while(1){v[22708]=0;d=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((e|0)!=1){n:{o:{p:{q:{r:{s:{if(!d){break s}v[22708]=0;d=Q(827,b|0,f- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break r}if(!d){break s}d=h;d=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[22708]=0;U(288,f+16|0,b|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break q}d=f+40|0;g=f+16|0;e=kc(d,g);xb(g);v[22708]=0;d=T(275,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}if(d){break p}xb(f+40|0)}if(x[a+480188>>1]){break n}d=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}t:{u:{v:{w:{d=f- -64|0;d=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)<=1396788559){if((d|0)<=1346522947){if((d|0)==1129140036){break w}if((d|0)!=1346458708){break t}d=Sb(k);v[22708]=0;g=T(195,f+40|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break o}v[22708]=0;fa(521,d|0,e|0,g|0,255,254)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break f}break o}if((d|0)==1346522948){break u}if((d|0)!=1347175758){break t}v[22708]=0;d=T(195,f+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}if(d>>>0<2){break f}v[22708]=0;m=T(416,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break f}break o}if((d|0)<=1397507405){if((d|0)==1396788560){break v}if((d|0)!=1396854596){break t}if(Ie(j)>>>0>3998){break f}v[22708]=0;d=T(195,f+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}if(!d){break f}v[22708]=0;R(828,j|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}break f}if((d|0)==1397507406){break f}if((d|0)!=1397769541){break t}v[22708]=0;d=T(195,f+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}if(d>>>0<2){break f}v[22708]=0;d=T(416,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break o}n=a,o=Fd(d,1,255),v[n+480196>>2]=o;break f}if(x[a+480188>>1]){break f}v[22708]=0;d=T(195,f+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}if(d>>>0<8){break f}d=0;v[22708]=0;R(829,f+16|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}while(1){e=vd(f+16|0,d);g=Ib(w[e|0]|w[e+1|0]<<8);e=x[a+480188>>1];if(g){g=f+72|0;n=ic(g,e),o=1,t[n|0]=o;n=ic(g,x[a+480188>>1]+1|0),o=255,t[n|0]=o;e=x[a+480188>>1];v[22708]=0;We(((e<<5)+a|0)+480280|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}g=x[a+480188>>1];e=g+1|0;u[a+480188>>1]=e;u[((g<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64}v[22708]=0;We((((e&65535)<<5)+a|0)+480280|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}e=x[a+480188>>1];u[a+480188>>1]=e+1;u[((e<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64;d=d+1|0;if((d|0)!=4){continue}break}break i}if(x[a+480190>>1]){break f}v[22708]=0;R(830,e|0,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){break f}break o}if(Ie(i)>>>0>255){break f}v[22708]=0;R(828,i|0,e|0);d=v[22708];v[22708]=0;if((d|0)!=1){break f}break o}d=f- -64|0;if(!(Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))&-2139062144)){break f}d=0;break h}a=P()|0;O()|0;xb(f+40|0);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Sb(k);v[22708]=0;R(502,b|0,m&65535);b=v[22708];v[22708]=0;if((b|0)==1){break b}x:{if(!(c&1)){break x}d=0;b=Ie(i);v[22708]=0;R(330,a+484344|0,b&65535);b=v[22708];v[22708]=0;if((b|0)==1){break b}if(!Ie(i)){break x}b=0;while(1){h=Kg(i,d);v[22708]=0;d=v[f+76>>2];e=v[f+72>>2];v[f+8>>2]=e;v[f+12>>2]=d;v[f>>2]=e;v[f+4>>2]=d;Y(831,h|0,b&65535,a|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}b=b+1|0;d=b&65535;if(Ie(i)>>>0>d>>>0){continue}break}}e=1;if(x[a+480190>>1]<2){break j}h=c&2;b=0;while(1){if(!h|Ie(j)>>>0<=b>>>0){break j}v[22708]=0;c=(B(e,104)+a|0)+484380|0;Iu(c);d=v[22708];v[22708]=0;if((d|0)==1){break l}if(v[c>>2]){d=Kg(j,b);v[22708]=0;d=T(195,d|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break l}qc(c,d);d=Rc(f+40|0,8,1,1,0);k=Kg(j,b);v[22708]=0;W(329,d|0,c|0,k|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}b=b+1|0}d=1;e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=1;break g}if(c){break f}d=1}xb(f+40|0)}jd(j);jd(i);break e}xb(f+40|0);continue}}gb=f+112|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}jd(j);jd(i);S(a|0);L()}function vma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-240|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!zr(b,d+224|0)){break h}if(!rV(d+224|0)){break h}j=Jh(d+200|0);k=Kb(d+184|0);iD(d+120|0);v[22708]=0;e=Q(783,b|0,d+112|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}i:{if(!e){break i}e=d+112|4;h=Xb(Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-4|0);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=0;while(1){f=Xb(Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-8|0);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;j:{if(c){break j}f=d+112|0;if((Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)!=1347699796){break j}h=1;break i}f=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22708]=0;U(288,d+88|0,b|0,f|0);f=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((f|0)!=1){g=d+8|0;i=d+88|0;f=kc(g,i);xb(i);v[22708]=0;g=T(275,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}if(g){break o}xb(d+8|0);break k}a=P()|0;O()|0;break a}g=d+112|0;g=Xb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((g|0)<=1347699795){if((g|0)==1129139796){break m}if((g|0)!=1229866575){break l}v[22708]=0;l=Q(784,f|0,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}break l}if((g|0)!=1347699796){if((g|0)!=1447383635){break l}v[22708]=0;Q(318,d+8|0,4)|0;g=v[22708];v[22708]=0;if((g|0)==1){break n}v[22708]=0;g=T(785,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}if(!g){break l}if(Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0<7){break l}g=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22708]=0;U(786,f|0,k|0,g-6|0);f=v[22708];v[22708]=0;if((f|0)==1){break n}break l}v[22708]=0;h=W(787,a|0,f|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break l}}a=P()|0;O()|0;xb(d+8|0);break a}Ew(j,f)}xb(d+8|0);v[22708]=0;f=Q(783,b|0,d+112|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(f){continue}}break}if(gd(k)){v[22708]=0;b=Q(2,d+8|0,12081)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}Eb(k,b);vb(b)}p:{if(!(h&l&1)){break p}b=d+162|0;b=Ib(w[b|0]|w[b+1|0]<<8);v[22708]=0;c=b&256;W(409,a+1074312|0,5,!c|0)|0;b=v[22708];v[22708]=0;q:{r:{if((b|0)!=1){b=d+158|0;if(Ib(w[b|0]|w[b+1|0]<<8)){u[d+8>>1]=64;b=Ib(w[b|0]|w[b+1|0]<<8);v[22708]=0;u[d+88>>1]=b;b=Pc(d+8|0,d+88|0);e=v[22708];v[22708]=0;if((e|0)==1){break r}v[a+480228>>2]=x[b>>1]}b=d+160|0;if(!(!Ib(w[b|0]|w[b+1|0]<<8)|!c)){m=a,n=B(Ib(w[b|0]|w[b+1|0]<<8),1e4),v[m+480204>>2]=n}if(w[d+120|0]){v[22708]=0;Je(d+88|0,2,d+120|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;R(324,d+8|0,d+88|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}b=d+8|0;Eb(a+1298268|0,b);vb(b)}v[d+8>>2]=1;v[d+88>>2]=12;c=d+166|0;if(!er(c,d+8|0,d+88|0)){break p}v[d+80>>2]=31;v[d+84>>2]=1;e=d+164|0;if(!er(e,d+84|0,d+80|0)){break p}v[d+72>>2]=23;v[d+76>>2]=0;f=d+170|0;if(!er(f,d+76|0,d+72|0)){break p}v[d+64>>2]=59;v[d+68>>2]=0;g=d+172|0;if(!er(g,d+68|0,d- -64|0)){break p}v[d+56>>2]=59;v[d+60>>2]=0;i=d+174|0;if(!er(i,d+60|0,d+56|0)){break p}b=Cr(d+8|0);l=d+168|0;m=b,n=Ib(w[l|0]|w[l+1|0]<<8),v[m+20>>2]=n;m=b,n=Ib(w[c|0]|w[c+1|0]<<8)-1|0,v[m+16>>2]=n;m=b,n=Ib(w[e|0]|w[e+1|0]<<8),v[m+12>>2]=n;m=b,n=Ib(w[f|0]|w[f+1|0]<<8),v[m+8>>2]=n;m=b,n=Ib(w[g|0]|w[g+1|0]<<8),v[m+4>>2]=n;m=b,n=Ib(w[i|0]|w[i+1|0]<<8),v[m>>2]=n;v[22708]=0;R(601,a+1298368|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(h&1){v[22708]=0;b=T(275,j|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}if(b){b=Kb(d+8|0);v[22708]=0;W(413,j|0,b|0,32)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(wr(b,11063)){v[22708]=0;U(13,d+88|0,2,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=d+88|0;Eb(a+1298280|0,c);vb(c)}v[22708]=0;c=T(788,j|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!c){v[22708]=0;c=T(467,j|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;fa(473,a+1298292|0,j|0,c|0,40,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}}vb(b)}v[22708]=0;b=Q(2,d+88|0,14633)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;U(652,d+8|0,b|0,k|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}c=d+8|0;Eb(a+1298328|0,c);vb(c);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22708]=0;a=a+1074312|0;W(409,a|0,84,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;W(409,a|0,83,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(410,a|0,85)|0;a=v[22708];v[22708]=0;if((a|0)==1){break d}}vb(k);xb(j)}gb=d+240|0;return h&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b)}vb(k);xb(j);S(a|0);L()}function Ed(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=gb-96|0;gb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;Lf(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;Lf(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=nqa(d,0,b,s);b=jb;G=b;e=f;A=e<<15&-32768;k=p;g=nqa(A,0,k,0);f=g+q|0;e=jb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=nqa(c,s,A,B);f=i+g|0;b=j;j=j+jb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=nqa(d,r,k,H);K=jb;p=m;f=nqa(A,B,m,0);b=f+N|0;j=jb+K|0;O=b;m=nqa(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+jb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=nqa(d,r,p,P);G=jb;f=A;I=y|65536;A=o;i=nqa(f,B,I,o);f=i+Q|0;j=jb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=nqa(C,S,k,H);i=f+B|0;o=j;f=j+jb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=nqa(c,s,D,0);c=L+i|0;s=f;j=f+jb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=nqa(p,P,C,S);e=jb;r=nqa(d,r,I,A);d=r+f|0;j=jb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=nqa(D,T,k,H);d=f+d|0;j=jb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=nqa(D,T,I,A);b=e+b|0;j=jb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=nqa(D,T,p,P);f=jb;p=nqa(C,S,I,A);b=p+k|0;j=jb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;Lf(l+48|0,u,g,h,i,j);Lf(l+32|0,d,e,b,c,j);om(l+16|0,u,g,h,i,f);om(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;gb=l+96|0}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;g=gb-208|0;gb=g;vc(b);a:{b:{c:{d:{e:{if(!_C(b,g+160|0)){break e}if(!pT(g+160|0)){break e}if(!c){i=1;break e}if(!Pb(b,Qc(oT(g+160|0),jb))){break e}Hd(a,128);e=g+144|0;Je(e,2,g+175|0);d=g+72|0;Bc(d,e);Eb(a+1298268|0,d);vb(d);h=Tb(d,5600);Eb(a+1298304|0,h);vb(h);h=Tb(d,3148);Eb(a+1298316|0,h);vb(h);e=Tb(e,14645);v[22708]=0;U(946,d|0,e|0,v[(w[g+174|0]<<2)+33180>>2]);d=v[22708];v[22708]=0;i=1;if((d|0)==1){break b}d=g+72|0;Eb(a+1298328|0,d);vb(d);vb(e);v[a+480208>>2]=12;v[a+1298364>>2]=5;oB(a+1298292|0,b,w[g+207|0]<<5,32,0);z=a,A=Ae(b),u[z+480190>>1]=A;if(x[a+480190>>1]){k=1;while(1){f:{if(w[g+174|0]>=52){d=g+72|0;if(!mY(b,d)){lD(d)}break f}e=gb-48|0;gb=e;v[e+44>>2]=64;v[e+24>>2]=66;d=b;h=v[Fb(e+44|0,e+24|0)>>2];if(!Pb(d,h)){h=nf(d)}f=e+24|0;j=g+72|0;Iv(f,j);m=wd(e+32|0,v[f>>2],h);n=v[m+4>>2];v[e+8>>2]=v[m>>2];v[e+12>>2]=n;cc(e+16|0,d,e+8|0);Iv(f,j);Qb(v[e+24>>2]+h|0,0,66-h|0);Rb(d,v[e+44>>2]);gb=e+48|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}h=gb-32|0;gb=h;e=(B(i,104)+a|0)+484380|0;ud(e,0);j=g+72|0;d=j;Lk(h,2,d+32|0);f=h+16|0;Bc(f,h);v[22708]=0;Q(303,e+43|0,f|0)|0;f=v[22708];v[22708]=0;g:{if((f|0)!=1){vb(h+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[h+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);z=e,A=v[Fb(h+16|0,e)>>2],v[z+16>>2]=A;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Po(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)/393216)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}gb=h+32|0;break g}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}d=g+56|0;Je(d,2,j);e=g+144|0;Bc(e,d);v[22708]=0;Q(301,((i<<5)+a|0)+946304|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}vb(g+144|0);k=k+1|0;i=k&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}jp(Sb(a+484360|0),b,256,255,254);i=0;d=Ae(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Ae(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(i<<5)+a|0;We(e+480280|0);h=e+480284|0;i:{if(w[g+174|0]>=51){e=(Ae(b)<<4|8)&248;break i}e=i&1?192:64}u[h>>1]=e;i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}m=a+484344|0;zg(m,r);i=0;k=0;while(1){e=k&65535;if(!wh(m,e,64)){break e}k=k+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){h=cj(g+72|0);n=0;while(1){if(Pb(b,5)){k=0;i=Yc(_b(m,n),0,p&65535);while(1){s=64-k|0;l=w[g+174|0];f=gb-16|0;gb=f;q=1;d=h;o=d;e=b;j=Ae(e);if((j|0)==252){q=Ae(e);j=Ae(e)}t[o|0]=(j-1&255)>>>0<60?j+36|0:0;j=f+8|0;wn(j,e);e=qd(j);o=Ve(j);y=fj(j);t[d+1|0]=w[j|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[o|0];t[f+4|0]=w[y|0];mT(f+7|0,f+5|0,l);mT(f+6|0,f+4|0,l);j=w[f+7|0];l=(j|0)!=10;e=w[f+6|0];j:{if(!(l|(e|0)!=10)){t[f+7|0]=0;z=f,A=fm((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[z+5|0]=A;break j}k:{l:{m:{if(!l){z=f,A=fm(w[f+5|0]<<2),t[z+5|0]=A;break m}if((e|0)==10){z=f,A=fm(w[f+4|0]<<2),t[z+4|0]=A;break j}if((e|0)!=(j|0)){break m}e=0;t[f+6|0]=0;break l}if((e|0)==13){break k}}if((j|0)==13|e){break j}}gi(f+7|0,f+6|0);gi(f+5|0,f+4|0)}e=f+6|0;j=f+4|0;l=f+7|0;o=f+5|0;qz(e,j,l,o);to(f,l,o,e,j);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];gb=f+16|0;e=k+q|0;k=e>>>0>64?s:q;if(k){while(1){d=v[g+72>>2];t[i|0]=d;t[i+1|0]=d>>>8;t[i+2|0]=d>>>16;t[i+3|0]=d>>>24;d=x[g+76>>1];t[i+4|0]=d;t[i+5|0]=d>>>8;i=B(x[a+480188>>1],6)+i|0;k=k-1|0;if(k){continue}break}d=e>>>0<64;k=d?e:64;if(d){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}p=p+1|0;if(x[a+480188>>1]>(p&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;h=xB(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[22708]=0;U(948,h|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){a=P()|0;O()|0;Ye(h);S(a|0);L()}v[22708]=0;U(947,g+32|0,m|0,d|0);e=v[22708];v[22708]=0;i=1;if((e|0)==1){break d}Ye(g+32|0);Ye(d);if(!(c&2)|!x[a+480190>>1]){break e}k=1;while(1){c=B(k&65535,104)+a|0;Cg(Rc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);k=k+1|0;if(x[a+480190>>1]>=(k&65535)>>>0){continue}break}}gb=g+208|0;return i|0}i=P()|0;O()|0;Ye(d);break a}i=P()|0;O()|0;vb(g+144|0);break a}i=P()|0;O()|0;vb(e)}S(i|0);L()}function EZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-128|0;gb=g;vc(b);a:{if(!Sr(b,9028)){break a}if(!cw(b,g+112|0)){break a}if(!aE(g+112|0)){break a}if(!Pb(b,Qc($D(g+112|0),jb))){break a}if(!Rb(b,w[g+121|0]|w[g+122|0]<<8)){break a}b:{if(!c){break b}Hd(a,4096);v[a+480208>>2]=12;d=1;h=g+112|0;u[a+480188>>1]=(w[h|2]&31)+1;i=h|3;u[a+480190>>1]=w[i|0];xh(a,1);j=g+32|0;e=Tb(j,5623);Eb(a+1298304|0,e);vb(e);e=Tb(j,4107);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=g+8|0;k=Tb(e,1356);Dc(f,k);vb(k);gb=e+16|0;v[22708]=0;Y(349,j|0,f|0,h|1,h|0);h=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){h=g+32|0;Eb(a+1298328|0,h);vb(h);Hb(g+8|0);v[a+1298364>>2]=5;e=w[i|0];h=gb-16|0;gb=h;j=g+96|0;v[j>>2]=0;v[j+4>>2]=0;v[h+12>>2]=0;ef(j+8|0,h+12|0,h+8|0);if(e){Xr(j,e);WE(j,e,0)}gb=h+16|0;k:{if(x[a+480190>>1]){h=1;while(1){v[22708]=0;R(350,b|0,g+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}v[22708]=0;R(351,g+32|0,(B(d,104)+a|0)+484380|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}e=w[g+48|0];i=g+8|0;Ce(i,j,d-1|0);Uf(i,(e&3)!=0);h=h+1|0;d=h&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22708]=0;W(352,b|0,a+1298268|0,-1)|0;h=v[22708];v[22708]=0;d=1;l:{m:{if((h|0)!=1){if(x[a+480190>>1]){while(1){v[22708]=0;W(353,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[22708]=0;h=(d<<5)+a|0;We(h+480280|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;U(355,b|0,h+480289|0,-1);h=v[22708];v[22708]=0;if((h|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}h=g+112|4;e=w[h|0]|w[h+1|0]<<8;d=0;v[22708]=0;i=a+484344|0;R(330,i|0,e|0);e=v[22708];v[22708]=0;if((e|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(w[h|0]|w[h+1|0]<<8){while(1){v[22708]=0;U(356,b|0,g+32|0,-1);e=v[22708];v[22708]=0;n:{o:{if((e|0)==1){break o}v[22708]=0;e=W(331,i|0,d&65535,64)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}if(!e){break n}e=_b(i,d);v[22708]=0;R(357,e|0,g+32|0);e=v[22708];v[22708]=0;if((e|0)!=1){break n}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}}v[22708]=0;f=T(287,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}p:{if(!f){break p}v[22708]=0;d=Q(191,b|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}if(!d){break p}e=mc(g+32|0);v[22708]=0;W(358,b|0,e|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break h}d=Kb(g+8|0);v[22708]=0;R(60,d|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}m=g,n=Vb(e),v[m+56>>2]=n;m=g,n=Zb(e),v[m+88>>2]=n;if(Gb(g+56|0,g+88|0)){while(1){q:{f=w[v[g+56>>2]];if(f&128){m=g,n=ff(d),v[m+72>>2]=n;Gd(g+80|0,g+72|0);v[22708]=0;da(359,d|0,v[g+80>>2],f&127,32)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break q}break i}v[22708]=0;R(61,d|0,f<<24>>24);f=v[22708];v[22708]=0;if((f|0)!=1){break q}break i}f=g+56|0;Oe(f);if(Gb(f,g+88|0)){continue}break}}v[22708]=0;Y(360,g+56|0,5,6,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}f=g+56|0;Eb(d,f);vb(f);f=zb(Jb(d));k=Ab(d);v[22708]=0;fa(361,a+1298292|0,f|0,k|0,76,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}vb(d);gc(e)}e=Sb(a+484360|0);d=g+112|6;f=w[d|0]|w[d+1|0]<<8;d=0;v[22708]=0;fa(362,e|0,b|0,f|0,65535,65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}r:{s:{t:{u:{if(!(w[h|0]|w[h+1|0]<<8)){break u}e=c&1;while(1){v[22708]=0;f=Q(191,b|0,4)|0;k=v[22708];v[22708]=0;v:{if((k|0)!=1){if(f){break v}break u}b=P()|0;O()|0;break d}v[22708]=0;f=T(192,b|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break s}v[22708]=0;U(288,g+8|0,b|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break r}f=g+8|0;k=kc(g+32|0,f);xb(f);w:{if(!e){break w}v[22708]=0;f=me(i,d&65535);l=v[22708];v[22708]=0;if((l|0)==1){break t}if(!f){break w}f=_b(i,d);v[22708]=0;U(364,f|0,0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break t}}xb(g+32|0);d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){d=1;c=1;while(1){h=B(d,104)+a|0;e=x[h+484414>>1];i=g+32|0;Ce(i,j,d-1|0);d=Rc(g+8|0,e&1?16:8,1,0,Cb(i)?6:0);v[22708]=0;W(329,d|0,h+484380|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}Ye(j);break b}b=P()|0;O()|0;xb(g+32|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Hb(g+8|0);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(d);break g}b=P()|0;O()|0}gc(e);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ye(j)}S(b|0);L()}d=1}gb=g+128|0;return d|0}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-3056|0;gb=g;vc(b);h=gb-32|0;gb=h;e=h+24|0;f=g+1096|0;FD(e,f);l=yb(e);e=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=e;j=h+16|0;e=b;cc(j,e,h);j=yb(j);if((j|0)==(l|0)){Rb(e,yb(h+24|0))}gb=h+32|0;e=(j|0)==(l|0);if(!e){ED(f)}a:{if(!e){break a}if(!ID(g+1096|0)){break a}if(!c){d=1;break a}if(!Pb(b,Qc(1024,0))){break a}HD(b,g+576|0);HD(b,g- -64|0);while(1){e=i<<2;h=e+(g+576|0)|0;if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0>16777215){break a}e=e+(g- -64|0)|0;f=w[e+1|0]<<8;j=w[e+2|0]<<16|w[e+3|0]<<24;if((w[e|0]|f|j)>>>0<3|(j|(f|w[e|0]))>>>0>4096){break a}if(!qs(b,((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)+2978|0)){break a}i=i+1|0;if((i|0)!=128){continue}break}Hd(a,2);Ag(a);d=g+40|0;e=Tb(d,11144);Eb(a+1298304|0,e);vb(e);e=Tb(d,11962);Eb(a+1298316|0,e);vb(e);d=Tb(d,12607);Eb(a+1298328|0,d);vb(d);v[a+1298364>>2]=5;d=w[g+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;l=a+484360|0;cf(Sb(l),w[g+1097|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){e=d+1|0;i=B(e,104)+a|0;h=i+484380|0;ud(h,2);f=g+16|0;li(f,1,(B(d,13)+g|0)+1098|0);j=g+40|0;Bc(j,f);v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,j|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}vb(g+40|0);f=h;d=(g+1096|0)+(d<<4)|0;h=d+422|0;v[f>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[i+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[i+484414>>1]=2;v[i+484388>>2]=d}v[i+484404>>2]=8287;d=e;if((d|0)!=32){continue}break}i=0;while(1){d=i+33|0;h=(B(d,104)+a|0)+484380|0;ud(h,2);e=g+16|0;li(e,1,(B(i,13)+g|0)+2026|0);f=g+40|0;Bc(f,e);v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}d=g+40|0;vb(d);v[g+48>>2]=0;v[g+40>>2]=0;v[g+44>>2]=0;e=(g+1096|0)+B(i,11)|0;f=w[e+1347|0];p=ic(d,0),q=f,t[p|0]=q;f=w[e+1352|0];p=ic(d,1),q=f,t[p|0]=q;f=w[e+1348|0];p=ic(d,2),q=f,t[p|0]=q;f=w[e+1353|0];p=ic(d,3),q=f,t[p|0]=q;f=w[e+1349|0];p=ic(d,4),q=f,t[p|0]=q;f=w[e+1354|0];p=ic(d,5),q=f,t[p|0]=q;f=w[e+1350|0];p=ic(d,6),q=f,t[p|0]=q;f=w[e+1355|0];p=ic(d,7),q=f,t[p|0]=q;f=w[e+1351|0];p=ic(d,8),q=f,t[p|0]=q;f=w[e+1356|0];p=ic(d,9),q=f,t[p|0]=q;e=w[e+1346|0];p=ic(d,10),q=e,t[p|0]=q;v[g+8>>2]=v[g+48>>2];d=v[g+44>>2];v[g>>2]=v[g+40>>2];v[g+4>>2]=d;Ro(h,1,g);i=i+1|0;if((i|0)!=32){continue}break}Tr(Sb(l),g+2794|0,256,255,65535);j=a+484344|0;zg(j,128);o=c&1;i=0;f:{while(1){h=i<<2;d=h+(g+576|0)|0;Wc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);e=g+16|0;d=h+(g- -64|0)|0;Sd(e,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));h=kc(g+40|0,e);xb(e);g:{if(!o){break g}v[22708]=0;d=W(331,j|0,i&65535,64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!d){break g}d=0;l=_b(j,i);while(1){v[22708]=0;e=Q(191,g+40|0,1)|0;f=v[22708];v[22708]=0;h:{i:{if((f|0)!=1){if(!e){break g}v[22708]=0;e=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}if(e>>>0>12){break i}v[22708]=0;f=Yc(l,d,e);k=v[22708];v[22708]=0;if((k|0)==1){break c}v[22708]=0;R(403,g+16|0,h|0);k=v[22708];v[22708]=0;if((k|0)==1){break c}k=g+16|0;m=qd(k);n=w[k|0];e=e>>>0>3;t[f|0]=((n&15)+(e?13:37)|0)+B(n>>>4&7,12);t[f+1|0]=((w[m|0]>>>4|0)+(e?33:1)|0)+(w[k|0]>>>3&16);GD(f,w[m|0],e);break h}break c}f=e-32|0;if((f&255)>>>0<=12){v[22708]=0;f=Yc(l,d,f&65535);k=v[22708];v[22708]=0;if((k|0)==1){break c}v[22708]=0;k=T(374,h|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break c}GD(f,k,e>>>0>35);break h}if((e|0)!=64){if((e|0)!=96){break f}if(!d){break g}v[22708]=0;d=Yc(l,d-1|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}t[d+3|0]=14;break g}v[22708]=0;e=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}d=d+e|0}if(d>>>0<64){continue}break}}xb(g+40|0);i=i+1|0;if((i|0)!=128){continue}break}d=1;if(!(c&2)){break a}i=1;while(1){Cg(Rc(g+40|0,8,1,0,1),(B(i,104)+a|0)+484380|0,b);i=i+1|0;if((i|0)!=33){continue}break}break a}xb(g+40|0);d=0;break a}d=P()|0;O()|0;vb(g+40|0);break b}d=P()|0;O()|0;vb(g+40|0);break b}d=P()|0;O()|0;xb(g+40|0)}S(d|0);L()}gb=g+3056|0;return d|0}function Dpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-336|0;gb=d;vc(b);a:{if(!zr(b,d+320|0)){break a}if(!cY(d+320|0)){break a}if(v[d+320>>2]==1179472708){Rb(b,4)}if(!Ih(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}l=d+312|4;f=l;UD(b,d+120|0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Hd(a,8192);e=d+32|0;f=Tb(e,3596);Eb(a+1298304|0,f);vb(f);f=Tb(e,7411);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;f=d+96|0;Mk(f,2,d+120|0);Bc(e,f);Eb(a+1298268|0,e);vb(e);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;q=a,r=x[Ke(e,f)>>1],u[q+480188>>1]=r;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[ac(e,f)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+32>>2]=256/x[a+480188>>1];v[d+96>>2]=128;f=v[Fb(d+32|0,d+96|0)>>2];break b}f=w[d+165|0]&127}v[e+480228>>2]=f;e=0;while(1){f=(e<<5)+a|0;We(f+480280|0);h=d+e|0;if(w[h+168|0]<=128){u[f+480284>>1]=w[h+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}k=a+484360|0;g=Sb(k);i=d+184|0;e=gb-16|0;gb=e;v[e+12>>2]=w[d+156|0]|w[d+157|0]<<8;f=e+12|0;qc(f,128);qc(f,65535);j=x[e+12>>1];Bf(g,j);if(j){h=0;while(1){f=w[h+i|0];c:{if((f|0)==255){f=65535;break c}if((f|0)!=254){break c}f=65534}q=gj(g,h),r=f,u[q>>1]=r;h=h+1|0;if((j|0)!=(h|0)){continue}break}}gb=e+16|0;if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){cf(Sb(k),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Ih(b,d+312|0)){break a}n=c&2;k=a+484344|0;o=c&1;p=d+68|0;j=0;while(1){e=d+32|0;c=l;Sd(e,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));h=kc(d+96|0,e);xb(e);d:{e:{f:{if(!(!o|v[d+312>>2]!=1414807888)){v[22708]=0;m=j&65535;c=W(331,k|0,m|0,64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}if(!c){break d}v[22708]=0;Q(318,d+96|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}hi(d+32|0);f=0;g:{while(1){v[22708]=0;c=Q(191,d+96|0,1)|0;e=v[22708];v[22708]=0;h:{i:{if((e|0)!=1){if(!(c&f>>>0<64)){break g}v[22708]=0;e=T(374,h|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}if(e){break h}f=f+1|0;continue}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}c=d+32|0;j:{k:{l:{g=e&15;m:{if(g>>>0<x[a+480188>>1]){c=_b(k,m);v[22708]=0;c=Yc(c,f,g);g=v[22708];v[22708]=0;if((g|0)==1){break m}}n:{if(!(e&128)){break n}v[22708]=0;g=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break l}if(!g){break n}t[c|0]=g>>>0<109?g+12|0:g}if(!(e&64)){break j}v[22708]=0;g=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break k}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}t[c+1|0]=g}o:{p:{q:{r:{s:{t:{u:{v:{if(e&32){t[c+2|0]=1;v[22708]=0;g=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break v}t[d+16|0]=g;v[22708]=0;t[d|0]=64;g=ac(d+16|0,d);i=v[22708];v[22708]=0;if((i|0)==1){break u}t[c+4|0]=w[g|0]}if(!(e&16)){continue}v[22708]=0;R(403,d+16|0,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break t}e=d+16|0;g=e;i=qd(e);e=w[e|0];switch(e-17|0){case 2:break r;case 0:case 1:break s;default:break q}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}e=e&15;break p}t[g|0]=33;t[i|0]=145;e=w[g|0];break o}if(e>>>0<17){break o}e=(e&240)==32?9:-1}t[g|0]=e}t[c+3|0]=e;t[c+5|0]=w[i|0];v[22708]=0;Of(c);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break e}j=j+1|0;break d}if(v[d+312>>2]!=1414745673){break d}if(!fi(a)){break d}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22708]=0;R(495,h|0,d+32|0);e=v[22708];v[22708]=0;w:{x:{y:{if((e|0)==1){break y}v[22708]=0;g=(B(c&65535,104)+a|0)+484380|0;R(496,d+32|0,g|0);c=v[22708];v[22708]=0;if((c|0)==1){break y}v[22708]=0;Mk(d,2,p);c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;R(324,d+16|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break x}c=x[a+480190>>1];v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,d+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}vb(d+16|0);if(!n){break d}i=d+16|0;c=Rc(i,8,1,0,1);e=2;f=d+45|0;z:{if(!(w[f|0]&64)){e=0;if(!(w[f|0]&2)){break z}}Cf(c,e)}if(w[f|0]&4){Zi(c,16)}v[22708]=0;W(329,i|0,g|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(d+16|0);break e}b=P()|0;O()|0}xb(d+96|0);S(b|0);L()}xb(d+96|0);e=1;if(Ih(b,d+312|0)){continue}break}}gb=d+336|0;return e|0}function Xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=gb-320|0;gb=d;vc(b);g=gb-32|0;gb=g;f=g+24|0;BX(f,d+96|0);i=yb(f);f=v[g+28>>2];h=v[g+24>>2];v[g+8>>2]=h;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=f;h=g+16|0;f=b;cc(h,f,g);h=yb(h);if((h|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;a:{b:{c:{d:{if((i|0)!=(h|0)){break d}if(!FX(d+96|0)){break d}if(!Pb(b,Qc(EX(d+96|0),jb))){break d}if(!c){e=1;break d}Hd(a,2);Ag(a);v[a+480204>>2]=455e3;v[a+480188>>2]=524296;Ob(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;e=d- -64|0;Je(e,2,d+127|0);f=d+80|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);e=0;e:{f:{g:{h:{i:{while(1){g=d+80|0;f=(d+96|0)+B(e,19)|0;ZC(g,f+63|0);i=d- -64|0;Bc(i,g);v[22708]=0;Q(399,((e<<5)+a|0)+480289|0,i|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}g=d- -64|0;vb(g);e=e+1|0;h=B(e,104)+a|0;j=h+484380|0;ud(j,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;i=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[g+7|0]=i;t[g+8|0]=i>>>8;t[g+9|0]=i>>>16;t[g+10|0]=i>>>24;i=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24;t[g+4|0]=i;t[g+5|0]=i>>>8;t[g+6|0]=i>>>16;t[g+7|0]=i>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;Ro(j,1,d);v[h+484404>>2]=8215;f=d+48|0;Bc(f,d+80|0);v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}vb(d+48|0);if((e|0)!=8){continue}break}o=w[d+312|0];m=o+1|0;j=a+484360|0;jp(Sb(j),b,m,65535,65535);f=mc(d+80|0);v[22708]=0;W(358,b|0,f|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}z=d,A=Vb(f),v[z+64>>2]=A;z=d,A=Zb(f),v[z+48>>2]=A;if(Gb(d- -64|0,d+48|0)){while(1){if((w[v[d- -64>>2]]-1&255)>>>0>7){break f}e=d- -64|0;Oe(e);if(Gb(e,d+48|0)){continue}break}}z=a,A=w[lc(f,0)|0],v[z+480196>>2]=A;e=w[d+311|0];p=w[d+313|0];g=mc(d- -64|0);v[22708]=0;h=p+1|0;W(358,b|0,g|0,h|0)|0;i=v[22708];v[22708]=0;j:{if((i|0)==1){break j}v[22708]=0;i=a+484344|0;R(330,i|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break j}q=e+1|0;k:{l:{if(!(c&1)){break l}h=0;while(1){c=w[lc(g,h)|0];v[22708]=0;c=W(331,i|0,c|0,q|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break k}if(!c){break l}c=0;n=_b(i,w[lc(g,h)|0]);k=0;while(1){if(v[n+12>>2]){r=c+1|0;e=0;while(1){v[22708]=0;c=T(374,b|0)|0;l=v[22708];v[22708]=0;m:{n:{if((l|0)!=1){if(!(c&128)){break n}e=(c&127)+e|0;break m}e=P()|0;O()|0;break c}v[22708]=0;l=Yc(n,e,k&65535);s=v[22708];v[22708]=0;o:{if((s|0)!=1){if((c|0)!=1){break o}t[l|0]=254;break m}e=P()|0;O()|0;break c}if((c-1&255)>>>0>96){break m}t[l+1|0]=r;t[l|0]=c+12}e=e+1|0;if(e>>>0<y[n+12>>2]){continue}break}}e=k&65535;c=k+1|0;k=c;if(e>>>0<7){continue}break}c=(h|0)==(p|0);h=h+1|0;if(!c){continue}break}}c=0;e=0;p:{q:{r:{s:{t:{u:{v:{while(1){b=Sb(j);v[22708]=0;h=e&65535;b=Q(472,b|0,h|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break v}w:{if(!b){v[22708]=0;b=W(544,i|0,q|0,0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break u}if((b|0)==65535){break w}z=sc(Sb(j),c),A=b,u[z>>1]=A}z=d,A=Zb(_b(i,x[sc(Sb(j),c)>>1])),v[z+32>>2]=A;z=d,A=YC(d+32|0,1),v[z+48>>2]=A;b=w[lc(f,(c+1>>>0)%(m>>>0)|0)|0];if((b|0)==w[v[d+48>>2]+5|0]){break w}x:{if(w[v[d+48>>2]+3|0]!=16){break x}c=Sb(j);v[22708]=0;c=Q(545,c|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break p}if((c|0)==65535){break x}z=d,A=Zb(_b(i,c)),v[z+32>>2]=A;z=d,A=YC(d+32|0,1),v[z+48>>2]=A}t[v[d+48>>2]+3|0]=16;t[v[d+48>>2]+5|0]=b}e=e+1|0;c=e&65535;if(o>>>0>=c>>>0){continue}break}v[22708]=0;b=Q(2,d+48|0,5747)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+48|0,3141)|0;c=v[22708];v[22708]=0;if((c|0)==1){break s}Eb(a+1298316|0,b);vb(b);v[22708]=0;Yj(d+16|0,2,d+107|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}v[22708]=0;R(324,d+32|0,d+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}v[22708]=0;U(13,d+48|0,5,d+32|0);b=v[22708];v[22708]=0;e=1;if((b|0)==1){break q}b=d+48|0;Eb(a+1298328|0,b);vb(b);vb(d+32|0);v[a+1298364>>2]=5;gc(g);break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+32|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;vb(d- -64|0);break a}e=P()|0;O()|0;break b}e=0}gc(f)}gb=d+320|0;return e|0}gc(g)}gc(f)}S(e|0);L()}function fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-176|0;gb=d;vc(b);a:{if(!_C(b,d+128|0)){break a}if(!mU(d+128|0)){break a}if(!Pb(b,Qc(lU(d+128|0),jb))){break a}b:{if(!c){break b}Hd(a,256);h=d+16|0;Yj(h,2,d+128|0);g=d+48|0;Bc(g,h);Eb(a+1298268|0,g);vb(g);e=Tb(g,12467);Eb(a+1298304|0,e);vb(e);e=Tb(g,7390);Eb(a+1298316|0,e);vb(e);Ef(h,1380);v[22708]=0;R(371,d+112|0,d+159|0);e=v[22708];v[22708]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[22708]=0;Y(885,d+48|0,d+16|0,d+158|0,d+112|0);e=v[22708];v[22708]=0;if((e|0)==1){break g}e=d+48|0;Eb(a+1298328|0,e);vb(e);vb(d+112|0);Hb(d+16|0);v[a+1298364>>2]=5;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+160|0];if(w[d+159|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}h=(f&255?f:96)&255;e=FP(h);v[a+480196>>2]=h>>>4;v[a+480204>>2]=e;if(w[d+159|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+112|0)}Hb(d+16|0);break c}t[d+48|0]=64;p=a,q=w[ac(d+162|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;We(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;h:{i:{while(1){dv(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break i}j=gb-32|0;gb=j;i=(B(f,104)+a|0)+484380|0;ud(i,0);g=d+16|0;k=g;Lk(j,2,g);e=j+16|0;Bc(e,j);v[22708]=0;Q(303,i+43|0,e|0)|0;e=v[22708];v[22708]=0;j:{k:{if((e|0)!=1){h=j+16|0;vb(h);e=k+24|0;v[i+24>>2]=w[e|0]|w[e+1|0]<<8;t[j+16|0]=w[k+22|0];t[j|0]=64;p=i,q=w[ac(h,j)|0]<<2,u[p+30>>1]=q;e=k+16|0;v[i>>2]=w[e|0]|w[e+1|0]<<8;e=k+18|0;v[i+4>>2]=w[e|0]|w[e+1|0]<<8;e=k+20|0;k=w[e|0]|w[e+1|0]<<8;v[i+8>>2]=k;h=v[i>>2];if(h>>>0>1){break k}v[i>>2]=0;break j}a=P()|0;O()|0;vb(j+16|0);S(a|0);L()}e=v[i+4>>2];if((k|0)==65535|h>>>0<=e>>>0|e>>>0>=k>>>0){break j}u[i+34>>1]=2;p=i,q=v[Fb(i+8|0,i)>>2],v[p+8>>2]=q}gb=j+32|0;Lk(d,2,g);e=d+112|0;Bc(e,d);v[22708]=0;Q(301,((f<<5)+a|0)+946304|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}vb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;jp(Sb(e),b,w[d+159|0]?128:64,65535,65535);e=Sb(e);p=d,q=Vb(e),v[p+16>>2]=q;p=d,q=Zb(e),v[p+112>>2]=q;if(Gb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];h=x[e>>1];l:{if(!((h|0)!=255&(h|0)!=99)){u[e>>1]=65535;break l}if(h>>>0>63){break i}}e=d+16|0;of(e);if(Gb(e,d+112|0)){continue}break}}k=c&1;if(k){zg(a+484344|0,w[d+161|0])}if(w[d+161|0]){o=a+484344|0;while(1){m:{n:{if(k){if(wh(o,m&65535,64)){break n}}f=0;while(1){if((Ae(b)+5&255)>>>0>=3){Rb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}p=d,q=Vb(_b(o,m)),v[p+112>>2]=q;v[d>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;o:{p:{q:{r:{s:{t:{e=Ae(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}t[v[d+112>>2]]=254;break o}g=d+16|0;Ur(g,b);f=w[ic(g,0)|0];i=w[ic(g,1)|0];j=w[ic(g,2)|0];g=254;if((e|0)==254){break q}g=e;if(e>>>0>95){break p}}g=(B(g>>>4|0,12)+(g&15)|0)+37|0}e=g;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(i&15)+33344|0];t[v[d+112>>2]+5|0]=j;u:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:g=v[d+112>>2];e=w[g+5|0];if(w[v[d+112>>2]+5|0]&15){t[g+5|0]=e&15;break o}t[g+5|0]=e&240;break o;case 3:e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=B(e&240,10)|e&15;v:{if((l|0)!=65535){if(w[v[d+112>>2]+5|0]){break v}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=l}l=65535}qc(d,n);break o;case 1:l=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break o;case 5:if(w[d+159|0]<=20){e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0}$j(d+112|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break m}Jm(_b(o,m),pp(Ue(Be(d+16|0,12,l&255),v[d>>2])))}m=m+1|0;if(m>>>0<w[d+161|0]){continue}break}}f=1;if(!(c&2)){break a}h=Rc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;w:{if(!v[e>>2]|!x[c+484410>>1]){break w}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Wc(b,c<<4)){break w}Cg(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;vb(d+112|0)}S(f|0);L()}f=1}gb=d+176|0;return f|0}function Poa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=gb-736|0;gb=m;a:{b:{if(d>>>0<=511){d=0;a=gb-32|0;gb=a;e=a+24|0;g=m+56|0;bc(e,g,554);e=yb(e);k=v[a+28>>2];j=v[a+24>>2];v[a+8>>2]=j;v[a+12>>2]=k;v[a>>2]=j;v[a+4>>2]=k;k=a+16|0;cc(k,b,a);k=yb(k);if((k|0)==(e|0)){Rb(b,yb(a+24|0))}gb=a+32|0;a=(e|0)==(k|0);if(!a){Qb(g,0,554)}if(!a){break b}b=gb-32|0;gb=b;c:{d:{a=m+56|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}Cp(b,3,a+32|0);d=b+16|0;Bc(d,b);v[22708]=0;Q(301,c+492|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}d=b+16|0;vb(d);li(b,1,a+4|0);Bc(d,b);v[22708]=0;Q(301,c+524|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}vb(b+16|0);d=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=d<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];e=c+108|0;k=c+236|0;while(1){g=a+(h<<1)|0;d=w[g- -64|0];g=w[g+65|0];o=vd(k,h),p=g,u[o>>1]=p;o=ic(e,h),p=(d>>>0<120?d:h)+1|0,t[o|0]=p;h=h+1|0;if((h|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;k=c+61|0;t[k|0]=w[a+18|0];g=c+62|0;t[g|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];i=c- -64|0;t[i|0]=w[a+21|0];d=c+48|0;kh(d,25);h=0;while(1){f:{f=h<<1;e=w[(f+a|0)+504|0];o=Mb(d,h),p=e,u[o>>1]=p;if((e|0)==255){kh(d,h);break f}e=w[(a+(f|1)|0)+504|0];o=Mb(d,h),p=e,t[o+2|0]=p;h=h+1|0;if((h|0)!=25){continue}}break}a=w[qf(k,g)|0];if(Nb(d)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[qf(j,i)|0];if(Nb(d)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}gb=b+32|0;break c}a=P()|0;O()|0;vb(b+16|0);S(a|0);L()}d=554;break b}k=v[b+8>>2];h=m+56|0;i=h;g=gb-48|0;gb=g;v[g+44>>2]=674;v[g+24>>2]=674;d=b;j=v[Fb(g+44|0,g+24|0)>>2];if(!Pb(d,j)){j=nf(d)}f=g+24|0;VW(f,i);n=wd(g+32|0,v[f>>2],j);l=v[n+4>>2];v[g+8>>2]=v[n>>2];v[g+12>>2]=l;cc(g+16|0,d,g+8|0);VW(f,i);Qb(v[g+24>>2]+j|0,0,674-j|0);Rb(d,v[g+44>>2]);gb=g+48|0;g=b;j=c;d=c;n=v[a+480180>>2];i=gb-32|0;gb=i;g:{h:{a=h;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1229999433){Cp(i,3,a+32|0);f=i+16|0;Bc(f,i);v[22708]=0;Q(301,d+492|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}f=i+16|0;vb(f);li(i,1,a+4|0);Bc(f,i);v[22708]=0;Q(301,d+524|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}f=i+16|0;vb(f);v[d>>2]=(w[a+20|0]|w[a+21|0]<<8)<<5;v[d+4>>2]=w[a+24|0]>>>1;qc(d+4|0,64);l=w[a+25|0]&127;v[d+8>>2]=l>>>0>64?128:l<<2;t[d+15|0]=w[d+15|0]&254|((w[a+25|0]^-1)&128)>>>7;t[i+16|0]=w[a+26|0];t[i|0]=100;o=d,p=w[ac(f,i)|0],t[o+20|0]=p;t[i+16|0]=w[a+27|0];t[i|0]=64;o=d,p=w[ac(f,i)|0],t[o+19|0]=p;t[d+16|0]=w[a+17|0];t[d+17|0]=w[a+18|0];t[d+18|0]=w[a+19|0];t[d+26|0]=w[a+22|0];t[d+27|0]=w[a+23|0];hm(d,w[a+58|0]&127,w[a+58|0]>>>7|0);gm(d,w[a+59|0]&127,w[a+59|0]>>>7|0);i:{j:{k:{f=w[a+28|0]|w[a+29|0]<<8;if(!((f|0)==514|(f|0)==529|(w[a+28|0]|w[a+29|0]<<8)==544)){if((w[a+28|0]|w[a+29|0]<<8)!=532){break k}}if(w[a+61|0]==255){break k}if(w[a+61|0]<=128){t[d+30|0]=w[a+61|0]}e=w[a+62|0]|w[a+63|0]<<8;if(e>>>0<129){break j}break i}if(t[a+61|0]>=0){t[d+30|0]=w[a+61|0]+1}e=t[a+62|0]>=0?w[a+62|0]+1|0:e;if(t[a+63|0]<0){break j}e=(w[a+63|0]<<7)+e|0}u[d+28>>1]=e}e=t[a+60|0];t[d+31|0]=e;if((e|0)<=-1){t[d+31|0]=0;t[d+34|0]=e^128}e=0;f=n&16777216?240:25;xw(a+304|0,d+48|0,0,f);xw(a+386|0,d+68|0,32,f);xw(a+468|0,d+88|0,32,f);t[d+100|0]=w[d+100|0]&239|w[a+468|0]>>>3&16;f=d+108|0;n=d+236|0;while(1){l=a+(e<<1)|0;d=w[l- -64|0];l=w[l+65|0];o=vd(n,e),p=l,u[o>>1]=p;o=ic(f,e),p=(d>>>0<120?d:e)+1|0,t[o|0]=p;e=e+1|0;if((e|0)!=120){continue}break}e=554}gb=i+32|0;a=e;break g}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}if(a){d=w[h+550|0]|w[h+551|0]<<8|(w[h+552|0]<<16|w[h+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){d=j+236|0;a=0;while(1){e=w[(a+h|0)+554|0];j=vd(d,a);u[j>>1]=x[j>>1]|e<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Wc(g,k+d|0);if(!Gh(b,11287)){break b}e=m+8|0;Sd(e,b,sg(b));a=kc(m+32|0,e);xb(e);v[22708]=0;e=T(195,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;b=Q(555,a|0,11078)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}if(b){v[22708]=0;b=T(374,a|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}d=(d+e|0)+8|0;xb(a)}gb=m+736|0;return d|0}b=P()|0;O()|0;xb(a);S(b|0);L()}function nL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-416|0;gb=e;t[e+415|0]=c;a:{if(pk(b)){break a}f=w[ul(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}f=e+160|0;Ld(f);g=v[e+160>>2];Ld(e+376|0);h=tl(g,v[e+380>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=uc(e+392|0,18726);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Gc(e+8|0,e)){a=ba(8)|0;v[22708]=0;R(2058,e+376|0,e+415|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+160|0,14728,e+376|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}rc(a,e+160|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);vb(e+376|0);break c}b=P()|0;O()|0;break d}if(!d){break h}a=ba(8)|0;v[22708]=0;c=Q(2059,e+344|0,b|0)|0;b=v[22708];v[22708]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[22708]=0;U(2039,e+360|0,14764,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break p}v[22708]=0;R(2056,e+376|0,e+360|0);b=v[22708];v[22708]=0;d=1;if((b|0)==1){break o}v[22708]=0;R(2058,e+328|0,e+415|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}v[22708]=0;U(2060,e+160|0,e+376|0,e+328|0);b=v[22708];v[22708]=0;if((b|0)==1){break m}rc(a,e+160|0);v[22708]=0;U(186,a|0,54936,1938);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);d=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;vb(c);break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}vb(e+328|0)}vb(e+376|0)}vb(e+360|0);vb(c);if(!d){break c}}ca(a|0);break c}v[e+320>>2]=f;v[e+324>>2]=g;d=uc(e+312|0,18726);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Gc(e+152|0,e+144|0)){a=ba(8)|0;v[22708]=0;R(2058,e+376|0,e+415|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+160|0,14728,e+376|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,e+160|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);vb(e+376|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=uc(e+296|0,4506);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;q:{if(!Gc(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=uc(e+280|0,4488);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Gc(e+120|0,e+112|0)){break q}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=uc(e+264|0,3991);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;r:{if(!Gc(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=uc(e+248|0,3972);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Gc(e+88|0,e+80|0)){break r}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=uc(e+232|0,4075);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Gc(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=uc(e+216|0,3156);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=uc(e+200|0,4555);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=uc(e+184|0,10720);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Gc(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;b=e;if(c){a=AK(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!Ny(e+160|0,v[d>>2]+24648|0)){break h}Wz(v[d>>2],e+160|0)}gb=e+416|0;return}b=P()|0;O()|0;vb(e+376|0);break d}b=P()|0;O()|0;vb(e+376|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function Zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-192|0;gb=e;a:{if(!Pb(c,8)){break a}Rb(c,4);while(1){n=tv(c);if(n){break a}p=gb-288|0;gb=p;f=PR(p);g=gb-384|0;gb=g;i=g+96|0;PR(i);j=hc(f,i,282);f=0;b:{c:{d:{e:{f:{g:{h:{h=c;if(Gh(h,10979)){pg(h,4);l=le(g+72|0,h);v[22708]=0;i=Q(1105,l|0,j|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}i:{if(!i){break i}i=w[j+26|0];v[22708]=0;i=Q(191,l|0,i|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}if(!i){break i}k=0;j:{k:{l:{if(w[j+26|0]){while(1){v[22708]=0;i=T(309,l|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break l}t[(j+k|0)+27|0]=i;f=f+i|0;k=k+1|0;if(k>>>0<w[j+26|0]){continue}break}k=f&65535}f=0;v[22708]=0;i=Q(191,l|0,k|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break d}if(!i){break i}v[22708]=0;Q(318,l|0,k|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}pg(l,QR(j));i=Wi(g- -64|0);f=g+96|0;WA(f);v[22708]=0;R(1106,l|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break k}u[g+118>>1]=0;u[g+120>>1]=0;OR(i,g+96|0,g+123|0);f=w[j+26|0];v[22708]=0;Q(318,l|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=j+27|0;OR(i,f,f+w[j+26|0]|0);v[22708]=0;U(288,g+16|0,l|0,k|0);f=v[22708];v[22708]=0;if((f|0)!=1){break j}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=g+16|0;k=kc(g+40|0,f);xb(f);v[22708]=0;R(757,f|0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break h}v[22708]=0;Vv(g+8|0,g+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break g}f=i;o=g+8|0;m=v[o>>2];o=v[o+4>>2];if((m|0)!=(o|0)){while(1){MR(f,zb(w[m|0]));m=m+1|0;if((o|0)!=(m|0)){continue}break}}zc(g+16|0);xb(k);f=0;if(v[i>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break i}f=QR(j);v[22708]=0;Q(318,h|0,f|0)|0;i=v[22708];v[22708]=0;f=1;if((i|0)==1){break d}}xb(l)}gb=g+384|0;break b}f=P()|0;O()|0;break f}f=P()|0;O()|0;zc(g+16|0)}xb(k);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}xb(l);S(f|0);L()}gb=p+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|n;vc(c);m:{n:{o:{p:{q:{r:{if(n){i=sg(c);d=e+144|0;Sd(d,c,nf(c));f=kc(e+168|0,d);xb(d);u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=i>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[22708]=0;R(757,d|0,f|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}v[22708]=0;b=Rd(e+144|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=v[e+144>>2];d=zb(b);i=Vi(c);v[22708]=0;i=fa(756,d|0,i|0,e+140|0,e+136|0,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}v[22708]=0;Q(318,f|0,v[e+140>>2])|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!i){break p}h=v[e+140>>2];v[22708]=0;T(386,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}d=c-h|0;b=b+h|0;n=v[e+136>>2];c=0;while(1){s:{if(n){if(!d|(n|0)!=1){break q}if(y[a>>2]>c>>>0){break s}break q}if(y[a>>2]<=c>>>0){break q}}if(!Md(a)){break q}v[e+132>>2]=0;v[e+128>>2]=0;h=zb(b);g=Vi(d);v[22708]=0;h=la(758,i|0,h|0,g|0,e+132|0,e+124|0,e+128|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}v[22708]=0;v[e+140>>2]=h;Q(318,f|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}j=v[e+140>>2];bk(e+128|0,Vi(v[a>>2]-c|0));t:{if(v[e+128>>2]<1){break t}if(v[e+132>>2]!=(fd(a)|0)){break t}if(t[a+34|0]&1){h=mg(e+112|0,v[a+20>>2]+(B(fd(a),c)<<1)|0,fd(a),v[e+128>>2]);g=mg(e+96|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22708]=0;v[e+56>>2]=v[h+8>>2];l=v[h+4>>2];v[e+48>>2]=v[h>>2];v[e+52>>2]=l;v[e+40>>2]=v[g+8>>2];h=v[g+4>>2];v[e+32>>2]=v[g>>2];v[e+36>>2]=h;R(759,e+48|0,e+32|0);h=v[22708];v[22708]=0;if((h|0)!=1){break t}break o}h=mg(e+80|0,v[a+20>>2]+B(fd(a),c)|0,fd(a),v[e+128>>2]);g=mg(e- -64|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22708]=0;v[e+24>>2]=v[h+8>>2];l=v[h+4>>2];v[e+16>>2]=v[h>>2];v[e+20>>2]=l;v[e+8>>2]=v[g+8>>2];h=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=h;R(760,e+16|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break o}}v[22708]=0;h=v[e+128>>2];n=ly(i);g=v[22708];v[22708]=0;if((g|0)==1){break o}d=d-j|0;b=b+j|0;v[e+136>>2]=n;c=c+h|0;continue}}break o}Cg(b,a,c);a=1;break m}a=P()|0;O()|0;break n}v[22708]=0;my(i);a=v[22708];v[22708]=0;if((a|0)!=1){break p}break o}a=(i|0)!=0;zc(e+144|0);xb(f);break m}a=P()|0;O()|0;zc(e+144|0)}xb(f);S(a|0);L()}gb=e+192|0;return a|0}function bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-256|0;gb=g;vc(b);a:{if(!wY(b,g+184|0)){break a}if(!cV(g+184|0)){break a}if(!Pb(b,Qc(bV(g+184|0),jb))){break a}b:{if(!c){break b}Hd(a,16);e=g+24|0;f=g+184|0;Yj(e,2,f|4);d=g+48|0;Bc(d,e);Eb(a+1298268|0,d);vb(d);u[a+480190>>1]=w[g+214|0];u[a+480188>>1]=w[g+217|0];i=Tb(d,5512);Eb(a+1298304|0,i);vb(i);i=Tb(d,7399);Eb(a+1298316|0,i);vb(i);Ef(e,1320);f=f|3;v[g>>2]=w[f|0]>>>4;f=w[f|0];v[22708]=0;v[g+180>>2]=f&15;Y(460,d|0,e|0,g|0,g+180|0);e=v[22708];v[22708]=0;d=1;c:{d:{e:{if((e|0)!=1){e=g+48|0;Eb(a+1298328|0,e);vb(e);Hb(g+24|0);v[a+1298364>>2]=5;if(x[a+480190>>1]){e=1;while(1){i=g+48|0;zE(b,i);j=gb-16|0;gb=j;h=(B(d,104)+a|0)+484380|0;ud(h,0);f=i;u[j+14>>1]=w[f+35|0]<<2;u[j+12>>1]=256;q=h,r=x[Pc(j+14|0,j+12|0)>>1],u[q+30>>1]=r;f:{if((w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24))>>>0<3){break f}v[h>>2]=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);v[h+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[j+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[j+4>>2]=1;q=h,r=v[Mc(j+8|0,j+4|0)>>2]-1|0,v[q+8>>2]=r;qc(h+8|0,v[h>>2]);g:{if(y[h+8>>2]<=v[h+4>>2]+4>>>0){v[h+4>>2]=0;v[h+8>>2]=0;break g}u[h+34>>1]=x[h+34>>1]|2}t[h+37|0]=w[f+34|0];q=h,r=Ju(0,t[f+34|0]<<4),v[q+24>>2]=r;if(!(t[f+36|0]&1)){break f}u[h+34>>1]=x[h+34>>1]|1;v[h>>2]=v[h>>2]>>>1;v[h+4>>2]=v[h+4>>2]>>>1;v[h+8>>2]=v[h+8>>2]>>>1}gb=j+16|0;Qk(g,2,i);f=g+24|0;Bc(f,g);v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}vb(g+24|0);e=e+1|0;d=e&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){d=0;while(1){e=(d<<5)+a|0;We(e+480280|0);u[e+480284>>1]=(w[(d+g|0)+218|0]<<4|8)&248;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}i=g+48|0;e=i;f=gb-32|0;gb=f;d=b;h:{if(!Pb(d,128)){d=gb-16|0;gb=d;h=e+128|0;while(1){If(e);e=e+1|0;if((h|0)!=(e|0)){continue}break}gb=d+16|0;break h}DW(f+24|0,e);e=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=e;kd(f+16|0,d,f+8|0)}gb=f+32|0;JE(Sb(a+484360|0),i,w[g+211|0]+1|0);h=w[g+216|0]?w[g+216|0]:64;Sd(g,b,B(w[g+208|0]|w[g+209|0]<<8,192));l=kc(g+24|0,g);xb(g);i:{j:{if(!(c&1)){break j}d=w[g+210|0];v[22708]=0;o=a+484344|0;R(330,o|0,d+1|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}while(1){v[22708]=0;e=W(331,o|0,m&65535,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break i}d=0;if(!e){break j}while(1){v[22708]=0;e=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}j=d;k:{if(!e|e>>>0>(w[g+208|0]|w[g+209|0]<<8)>>>0){break k}d=j&65535;if(d>>>0>=x[a+480188>>1]){break k}v[22708]=0;Q(190,l|0,B(e,192)-192|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}e=_b(o,m);v[22708]=0;d=Yc(e,0,d);e=v[22708];v[22708]=0;if((e|0)==1){break d}p=0;if(!h){break k}while(1){v[22708]=0;R(723,g|0,l|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}k=qd(g);n=Ve(g);f=d;i=g;e=w[g|0];if(e>>>0>=4){t[d|0]=(e>>>2|0)+37;e=w[i|0]}t[f+1|0]=e<<4&48|w[k|0]>>>4;e=w[n|0];f=0;i=0;l:{m:{n:{o:{p:{q:{k=w[k|0]&15;switch(k-8|0){case 0:break n;case 6:break p;case 2:break q;default:break o}}e=(e&240?-16:15)&e;k=10;break m}k=14;n=(e+16&240)>>>4|0;if(n>>>0>8){break m}if(1<<n&435){break n}break m}f=k;i=e}k=f;e=i;if(!((f|e)&255)){break l}}t[d+5|0]=e;t[d+3|0]=k;v[22708]=0;Of(d);e=v[22708];v[22708]=0;if((e|0)!=1){break l}break d}d=B(x[a+480188>>1],6)+d|0;p=p+1|0;if((p|0)!=(h|0)){continue}break}}d=j+1|0;if((j&65535)>>>0<31){continue}break}d=w[g+210|0]>m>>>0;m=m+1|0;if(d){continue}break}}if(w[g+212|0]|w[g+213|0]<<8){d=w[g+212|0]|w[g+213|0]<<8;v[22708]=0;fa(473,a+1298292|0,b|0,d|0,39,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;e=Rc(g,u[c+484414>>1]&1?16:8,1,0,1);v[22708]=0;W(329,e|0,c+484380|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;xb(l);break b}break d}d=P()|0;O()|0;Hb(g+24|0);break c}d=P()|0;O()|0;vb(g+24|0);break c}d=P()|0;O()|0;xb(l)}S(d|0);L()}d=1}gb=g+256|0;return d|0}function CP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=gb-16|0;gb=i;a:{if(!ve(d&255)){break a}j=(B(b,872)+a|0)+1074992|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(sk(j)){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1298260|0;if(!Dd(c)){break c}Qi(v[c>>2],b,0);break a}c=sA(a,b);if((c|0)==65535){break a}m=B(c,872);c=a+1074992|0;a=m+c|0;ou(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;$o(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;n=v[e+1075096>>2];c=x[a+480192>>1]<c>>>0?0:c;h=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!h){break d}f=d-1|0;c=x[vd(h+236|0,f)>>1];k=i+8|0;g=a+1074312|0;Db(k,g,104);e:{if(Cb(k)){Db(i,g,34);if(Cb(i)){break e}}d=w[ic(h+108|0,f)|0]}if((c-1&65535)>>>0<=3998){n=(B(c,104)+a|0)+484380|0;break d}c=i+8|0;Db(c,g,43);if(!Cb(c)){break d}if(!Ij(h)){break a}}if(w[e+1075081|0]&4){break a}g=a+1298260|0;k=a+1074312|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)&x[a+480188>>1]>c>>>0){break f}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(q|0)&(b|0)!=(c|0)){break f}p=e+1075648|0;f=v[p>>2];if(!f){break f}l=e+1074992|0;g:{h:{i:{j:{k:{l:{m:{switch(w[f+17|0]-1|0){case 0:if(!d){break f}m=w[e+1075789|0]==(d|0)&(f|0)==(h|0);o=m;if(!h){break l}if(m){break i}break f;case 1:if(!n|v[e+1075096>>2]!=(n|0)){break f}if((f|0)==(h|0)){break g}f=i+8|0;Db(f,k,104);if(!Cb(f)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(h){break j}o=(f|0)==(h|0)}if(o){break g}break f}if(!h){break f}m=w[h+34|0];if(!m){break f}if((m|0)==w[f+34|0]){break h}break f}if((f|0)!=(h|0)){break f}}if(!w[h+34|0]){break g}}if(!w[e+1075789|0]|w[f+18|0]>2){break g}f=i+8|0;Db(f,k,34);Mm(a,c&65535,JS(l,Cb(f))+255|0,0);t[e+1075792|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:Co(a,l);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break n}if(!Dd(g)){break n}Qi(v[g>>2],c&65535,1);break n;case 1:Co(a,l);if(!(w[e+1075081|0]&2)){break n}if(!Dd(g)){break n}uk(v[g>>2],c&65535);break n;case 2:break o;default:break n}}l=e+1075080|0;f=v[l>>2];v[l>>2]=f|4096;if(!(f&512)){break n}if(!Dd(g)){break n}f=i+8|0;Db(f,k,105);if(Cb(f)){break n}uk(v[g>>2],c&65535)}if(v[e+1075680>>2]){break f}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;c=0;p:{if(!sk(j)){break p}c=0;if(!ve(w[(B(b,872)+a|0)+1075789|0])){break p}d=Lm(a,b,2,1);c=0;if((d-1&255)>>>0>249){break p}e=v[(B(d,160)+a|0)+906140>>2];if(!e){e=0;c=0;break p}c=i+8|0;Db(c,k,34);c=(s=e,y=JS(j,Cb(c)),z=b,r=v[v[e>>2]+100>>2],kb[r](s|0,y|0,z|0)|0)}if(!(r=1,z=Oi(j),y=c,y?r:z)){break a}h=sA(a,b);if((h|0)==65535){break a}f=B(h,872)+a|0;d=f+1075080|0;n=f+1074992|0;q:{if(!(w[f+1075081|0]&2)){break q}if(!Dd(g)){break q}Qi(v[g>>2],h,1)}ou(n,j);v[d>>2]=v[d>>2]&-917505;t[f+1075823|0]=0;l=x[a+480188>>1];t[f+1075797|0]=0;u[f+1075778>>1]=b>>>0<l>>>0?b+1|0:0;r:{if(!(c&(e|0)!=0)){break r}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}Mm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}s:{t:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Co(a,n);if(!(w[d+1|0]&2)){break s}if(!Dd(g)){break s}uk(v[g>>2],b);c=i+8|0;Db(c,k,105);if(!Cb(c)){break s}ZA(v[g>>2],b,h);break s;case 0:v[(B(h,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break s}if(!Dd(g)){break s}Qi(v[g>>2],b,1);break s;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break s}if(!Dd(g)){break s}c=i+8|0;Db(c,k,105);e=Cb(c);c=v[g>>2];if(e){ZA(c,b,h);break s}uk(c,b);break s;case 1:break t;default:break s}}if(!(w[d+1|0]&2)){break s}if(!Dd(g)){break s}ZA(v[g>>2],b,h)}if(!v[(B(h,872)+a|0)+1075680>>2]){v[(B(h,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}gb=i+16|0}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-112|0;gb=e;f=e+88|0;g=a+140|0;Tm(f,g,1296125513);v[22708]=0;f=T(275,f|0)|0;h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((h|0)!=1){if(f){f=Kb(e+32|0);v[22708]=0;h=T(195,e+88|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break o}v[22708]=0;U(1439,e+88|0,f|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break o}h=x[a+174>>1];v[22708]=0;Y(1440,e+72|0,h|0,8,f|0);h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;U(9,e+8|0,c|0,e+72|0);c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;Q(301,d|0,e+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break l}vb(e+8|0);vb(e+72|0);vb(f)}if(w[a+176|0]){v[22708]=0;R(1441,e+32|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;Q(303,b+43|0,e+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break h}vb(e+32|0)}v[22708]=0;U(1431,e+32|0,g|0,1413894985);c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;f=T(1442,e+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}g=e+32|0;xb(g);c=a+40|0;vc(c);v[22708]=0;g=Q(1443,c|0,g|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(!g){break d}if((w[e+60|0]|w[e+61|0]<<8|(w[e+62|0]<<16|w[e+63|0]<<24))>>>0<2){break e}v[22708]=0;g=Q(1444,c|0,e+8|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!g){break e}g=v[b>>2];v[22708]=0;yz(e+8|0,b+12|0,b+16|0,g,b+34|0,8,16,f);g=v[22708];v[22708]=0;if((g|0)!=1){break e}break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;vb(e+8|0)}vb(e+72|0)}vb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+32|0);break a}v[22708]=0;c=Q(1444,c|0,e+8|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(c){c=v[b>>2];v[22708]=0;yz(e+8|0,b+4|0,b+8|0,c,b+34|0,2,4,f);c=v[22708];v[22708]=0;if((c|0)==1){break b}}c=w[e+44|0]|w[e+45|0]<<8|(w[e+46|0]<<16|w[e+47|0]<<24);t[b+42|0]=c&128?0:c+1|0;v[22708]=0;wk(b);c=v[22708];v[22708]=0;if((c|0)==1){break b}}p:{q:{if(w[b+42|0]){break q}v[22708]=0;c=a+60|0;f=Q(861,c|0,7)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!f){break q}vc(c);v[22708]=0;c=Q(1446,c|0,e+8|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}if(!c){break q}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22708]=0;h=a+120|0;c=T(275,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}r:{if(!c){break r}c=0;v[22708]=0;f=T(192,h|0)|0;g=v[22708];v[22708]=0;s:{if((g|0)!=1){v[e+72>>2]=f;g=b+68|0;qc(e+72|0,9);if(v[e+72>>2]){f=e+8|4;while(1){v[22708]=0;R(1447,h|0,e+8|0);i=v[22708];v[22708]=0;if((i|0)==1){break s}i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Pe(g,c),k=i,v[j>>2]=k;c=c+1|0;if(c>>>0<y[e+72>>2]){continue}break}}c=v[e+72>>2];f=mX(g);v[22708]=0;UB(g+(c<<2)|0,f,36536);c=v[22708];v[22708]=0;if((c|0)!=1){break r}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+80|0;vc(a);v[22708]=0;c=Q(1449,a|0,e+8|0)|0;f=v[22708];v[22708]=0;t:{u:{v:{w:{x:{if((f|0)==1){break x}if(!c){break u}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|4;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22708]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22708];v[22708]=0;if((f|0)==1){break t}u[b+28>>1]=x[c>>1];c=e+8|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22708]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}u[b+30>>1]=x[c>>1];u[e+72>>1]=w[e+16|0]|w[e+17|0]<<8;v[22708]=0;u[e+6>>1]=64;c=Pc(e+72|0,e+6|0);f=v[22708];v[22708]=0;if((f|0)==1){break v}u[b+32>>1]=x[c>>1];t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22708]=0;c=Q(191,a|0,32)|0;f=v[22708];v[22708]=0;if((f|0)==1){break x}if(!c){break u}v[22708]=0;W(1450,a|0,d|0,32)|0;c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;c=T(467,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}v[22708]=0;U(1451,a|0,b+43|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break u}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}xb(e+88|0);gb=e+112|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(e+88|0);S(a|0);L()}function KO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;a:{b:{if(!ve(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}e=v[d+44>>2];if(!e){break b}u[i+14>>1]=c-61;d=gb-80|0;gb=d;c=u[e+28>>1];g=i+14|0;b=u[g>>1];f=e+4|0;Nb(f);c:{d:{if((b|0)>=(c|0)){if((b|0)<=(x[e+28>>1]+Nb(f)<<16)-65536>>16){break d}}Kb(a);break c}e:{b=x[e+30>>1];if(!b){b=e+52|0;k=d,l=iz(b,g),v[k+56>>2]=l;k=d,l=Dh(b),v[k+40>>2]=l;if(!og(d+56|0,d+40|0)){break e}gg(a,ue(d+56|0)+4|0);break c}c=ro(u[g>>1],b<<16>>16);u[d+78>>1]=c;b=Kb(a);a=e+52|0;k=d,l=iz(a,d+78|0),v[k+72>>2]=l;k=d,l=Dh(a),v[k+56>>2]=l;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(og(d+72|0,d+56|0)){a=ue(d+72|0);v[22708]=0;Q(156,b|0,a+4|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break v}a=u[e+30>>1];c=u[g>>1];v[22708]=0;k=d,l=hz(c,a)+5|0,v[k+40>>2]=l;R(153,d+56|0,d+40|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;Q(113,b|0,d+56|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(d+56|0);break c}a=P()|0;O()|0;vb(d+56|0);break f}if(u[e+30>>1]>26){break s}v[22708]=0;c=W(716,d+40|0,1,(c<<24)+1090519040>>24)|0;a=v[22708];v[22708]=0;if((a|0)==1){break u}v[22708]=0;U(13,d+56|0,0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break t}a=d+56|0;Eb(b,a);vb(a);vb(c);v[22708]=0;Q(154,b|0,11846)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break r}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22708]=0;a=(c<<16>>16)/16|0;v[d+36>>2]=c-(a<<4)<<16>>16;R(1505,d+40|0,d+36|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}v[22708]=0;v[d+20>>2]=(a<<16>>16)%16;R(1505,d+24|0,d+20|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;U(3,d+56|0,d+40|0,d+24|0);a=v[22708];v[22708]=0;if((a|0)==1){break o}a=d+56|0;Eb(b,a);vb(a);vb(d+24|0);vb(d+40|0);if(c<<16>>16<256){break r}v[22708]=0;U(9,d+8|0,0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;ZS(d+40|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;U(13,d+56|0,0,d+40|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}a=d+56|0;Eb(b,a);vb(a);vb(d+40|0);vb(d+8|0)}a=u[e+30>>1];c=u[g>>1];v[22708]=0;k=d,l=hz(c,a)+5|0,v[k+40>>2]=l;R(153,d+56|0,d+40|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;Q(113,b|0,d+56|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break h}vb(d+56|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(d+24|0)}vb(d+40|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+40|0)}vb(d+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+56|0);break f}a=P()|0;O()|0}vb(b);S(a|0);L()}b=a;a=gb-16|0;gb=a;c=a;f=gb-32|0;gb=f;e=Ge(f+16|0,1,0);QP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);w:{x:{if(v[f+12>>2]){while(1){h=Ab(e);v[22708]=0;v[f+4>>2]=h;h=yf(f+4|0);j=v[22708];v[22708]=0;if((j|0)==1){break x}v[22708]=0;U(75,e|0,h|0,0);h=v[22708];v[22708]=0;if((h|0)==1){break x}QP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);if(v[f+12>>2]){continue}break}}g=v[f+8>>2];h=Jb(e);v[22708]=0;R(76,e|0,g-h|0);g=v[22708];v[22708]=0;if((g|0)==1){break x}v[22708]=0;R(86,c|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break w}}a=P()|0;O()|0;vb(e);S(a|0);L()}vb(e);gb=f+32|0;v[22708]=0;R(85,b|0,a|0);b=v[22708];v[22708]=0;y:{if((b|0)!=1){vb(a);gb=a+16|0;break y}b=P()|0;O()|0;vb(a);S(b|0);L()}}gb=d+80|0;break a}e=v[b>>2];b=gb-32|0;gb=b;d=gb-16|0;gb=d;t[d+15|0]=c;t[d+14|0]=251;t[d+13|0]=255;f=Jv(d+15|0,d+14|0,d+13|0);gb=d+16|0;z:{if(f){v[b+16>>2]=v[9588];d=v[9587];v[b+8>>2]=v[9586];v[b+12>>2]=d;d=v[9585];v[b>>2]=v[9584];v[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break z}if(ve(c)){d=Kb(b);v[22708]=0;f=c-1|0;c=(f<<16>>16)/12|0;e=Q(1323,d|0,e+(f-B(c,12)<<16>>16<<2)|0)|0;f=v[22708];v[22708]=0;A:{if((f|0)==1){break A}v[22708]=0;c=Q(1324,e|0,c+48&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;Q(4,a|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break A}vb(d);break z}a=P()|0;O()|0;vb(d);S(a|0);L()}if(!c){Tb(a,13839);break z}Tb(a,11817)}gb=b+32|0}gb=i+16|0}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-144|0;gb=e;d=-1;a:{b:{c:{d:{if(!El(v[v[b>>2]-12>>2]+b|0)){b=Hm(e+40|0,b);v[22708]=0;d=Q(620,e+24|0,11257)|0;f=v[22708];v[22708]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){v[22708]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(621,b|0,d|0,e+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break E}Hb(d);t[e+15|0]=0;v[22708]=0;d=Q(620,e+24|0,11945)|0;f=v[22708];v[22708]=0;if((f|0)==1){break D}v[22708]=0;W(622,b|0,e+15|0,d|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break C}Hb(d);v[22708]=0;f=w[e+15|0];d=Q(620,e+24|0,12908)|0;g=v[22708];v[22708]=0;if((g|0)==1){break B}v[22708]=0;f=f?0:c;Y(1508,b|0,a+40|0,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break A}Hb(d);u[e+12>>1]=65535;v[22708]=0;c=Q(620,e+24|0,12589)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;W(1094,b|0,e+12|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break y}Hb(c);u[e+10>>1]=0;v[22708]=0;c=Q(620,e+24|0,12482)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}v[22708]=0;W(1094,b|0,e+10|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break w}Hb(c);u[a>>1]=x[e+10>>1];v[22708]=0;c=Q(620,e+24|0,12244)|0;d=v[22708];v[22708]=0;if((d|0)==1){break v}v[22708]=0;Y(1509,b|0,a+52|0,c|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break u}Hb(c);v[22708]=0;c=Q(620,e+24|0,12193)|0;d=v[22708];v[22708]=0;if((d|0)==1){break t}v[22708]=0;W(1481,b|0,a+36|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break s}Hb(c);v[22708]=0;c=Q(620,e+24|0,12591)|0;d=v[22708];v[22708]=0;if((d|0)==1){break r}v[22708]=0;f=a+4|0;U(1510,b|0,f|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break q}Hb(c);v[22708]=0;c=Q(620,e+24|0,12484)|0;d=v[22708];v[22708]=0;if((d|0)==1){break p}v[22708]=0;g=a+28|0;U(1511,b|0,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}Hb(c);v[22708]=0;c=Q(620,e+24|0,12345)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;U(1511,b|0,a+30|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}Hb(c);v[22708]=0;c=Q(620,e+24|0,12217)|0;d=v[22708];v[22708]=0;if((d|0)==1){break l}v[22708]=0;U(1512,b|0,a+32|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break k}Hb(c);u[e+8>>1]=0;v[22708]=0;c=Q(620,e+24|0,12172)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;W(1094,b|0,e+8|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}Hb(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break e}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break e}i=e,j=Vi(v[a+36>>2]),v[i+24>>2]=j;v[22708]=0;v[e+16>>2]=0;c=ej(e+24|0,e+16|0,49656);h=v[22708];v[22708]=0;if((h|0)==1){break c}v[a+36>>2]=v[c>>2];if(Nb(f)>>>0>32767){break e}switch(x[a>>1]-1|0){case 2:break i;case 0:break h;default:break g}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;Hb(c);break a}c=u[e+8>>1];if((c|0)<1){break e}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];f=x[a+28>>1];u[e+16>>1]=f;v[22708]=0;u[e+18>>1]=(c+f|0)-1;a=da(1513,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}c=u[e+8>>1];if((c|0)<1){break e}z[e+24>>2]=z[a+32>>2];h=x[a+28>>1];u[e+16>>1]=h;v[22708]=0;u[e+18>>1]=(c+h|0)-1;a=fa(1514,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}v[22708]=0;_(1515,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}}d=1}gh(b)}gb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}gh(b);S(a|0);L()}function LL(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=gb-48|0;gb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Yb(k);v[j>>2]=0}v[22708]=0;X(2029);k=v[22708];v[22708]=0;b:{c:{if((k|0)==1){m=Ta(89104,54720,54776,54936,89280,89384,89332,89224,89212,89528,89496,89464,89452,89080,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(89104)|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=277;if((j|0)==1){break e}break b}if((ea(54720)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(54776)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(54936)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89280)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89384)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89332)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89224)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89212)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89528)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89496)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89464)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89452)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2030,j|0,k|0);j=v[22708];v[22708]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}o=ea(89080)|0;k=257;m=Z(m|0)|0;if((n|0)!=(o|0)){break b}v[22708]=0;R(2030,j|0,m|0);j=v[22708];v[22708]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}$()}o=!g;if(d){j=kb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=ie(m);break f}o=ie(18726)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=ie(g);break g}g=ie(18726)}v[i>>2]=g}g=v[l+44>>2];if(g){Yb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[22708]=0;R(1914,l+32|0,a|0);g=v[22708];v[22708]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22708]=0;R(1915,f|0,l+32|0);g=v[22708];v[22708]=0;if((g|0)!=1){break k}break j}g=Jb(l+32|0);if(b){v[22708]=0;R(b|0,g|0,c|0);g=v[22708];v[22708]=0;if((g|0)==1){break j}break k}Kt(g,l)}vb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;vb(l+32|0)}Z(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:18726;v[l+4>>2]=250;v[l>>2]=6331;XI(14942,l);lt(90144);$()}gb=l+48|0}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=gb-128|0;gb=d;i=-1;a:{b:{c:{d:{if(!_f(v[v[b>>2]-12>>2]+b|0)){break d}se(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];h=d+104|0;jm(h);kl(b,h,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=sh(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;jk(b,d+8|0);break d}u[d+86>>1]=0;ag(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}e=d+78|0;jm(e);kl(b,e,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;ag(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Kb(d+112|0);v[22708]=0;f=W(653,b|0,e|0,65535)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!f){break j}v[22708]=0;U(13,d- -64|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)!=1){break k}break b}e=Kb(d+112|0);v[22708]=0;f=W(655,b|0,e|0,255)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(!f){break i}v[22708]=0;U(13,d- -64|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}}f=d- -64|0;Eb(a+40|0,f);vb(f);vb(e);u[d+62>>1]=0;ag(b,d+62|0);u[d+60>>1]=0;ag(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Hk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=Nv(e);u[d+58>>1]=e;break l}ag(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){h=a+52|0;f=0;while(1){e=Kb(d+112|0);v[22708]=0;u[d+40>>1]=0;Q(1516,b|0,d+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[22708]=0;g=W(653,b|0,e|0,65535)|0;j=v[22708];v[22708]=0;if((j|0)==1){break g}if(g){break q}break e}v[22708]=0;g=W(655,b|0,e|0,255)|0;j=v[22708];v[22708]=0;if((j|0)==1){break g}if(!g){break e}}v[22708]=0;U(13,d- -64|0,c|0,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break p}v[22708]=0;g=Q(1517,h|0,d+40|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break o}j=g;g=d- -64|0;Eb(j,g);vb(g);vb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}c=d- -64|0;jm(c);kl(b,c,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(lN(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d- -64|0);break f}if(!kN(b,c)){break d}}e=a+16|0;r:{if(u[d+86>>1]<=2){if(lN(b,e)){break r}break d}if(!kN(b,e)){break d}}l=a,m=Nb(e),v[l+36>>2]=m;u[d+56>>1]=0;ag(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e+200&65535)>>>0>400){break d}u[d+54>>1]=0;ag(b,d+54|0);e=u[d+54>>1];u[a+30>>1]=e;if((e|0)<0){break d}v[d+48>>2]=0;lq(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}e=d+40|0;jm(e);kl(b,e,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}if(Nb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?!(z[a+32>>2]<=C(0))&u[a+30>>1]>0:1)){break d}s:{switch(b-1|0){case 0:case 2:if(Nb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=Vi(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[ej(d+112|0,d+32|0,49656)>>2],v[l+36>>2]=m;mq(a);i=1;if(x[a>>1]!=3){break d}if((qN(Nb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=mc(d+112|0);b=0;if(u[a+30>>1]>0){while(1){i=Mb(c,b-u[a+28>>1]|0);v[22708]=0;R(1518,e|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}b=b+1|0;if((b|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;l=d,m=(Nb(c)+b|0)-1|0,u[l+34>>1]=m;v[22708]=0;u[d+30>>1]=0;fa(1514,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[22708];v[22708]=0;i=1;if((a|0)!=1){Lc(e);break d}break h}vb(e);break d}vb(e);break d}b=P()|0;O()|0;Lc(e);break a}b=P()|0;O()|0}vb(e);break a}vb(e)}gb=d+128|0;return i|0}b=P()|0;O()|0;vb(e);break a}b=P()|0;O()|0;vb(e)}S(b|0);L()}function OI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=gb-560|0;gb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+B(s,-24)|0;n=v[(e<<2)+71248>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=s-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+71264>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=l-24|0;i=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;while(1){f=A[(g<<3)+h>>3];c=0;i=g;o=(g|0)<1;if(!o){while(1){k=(h+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;a:{if(D(f)<2147483648){j=~~f;break a}j=-2147483648}f=+(j|0);m=m+f*-16777216;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}v[k>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=ji(f,q);f=f+H(f*.125)*-8;c:{if(D(f)<2147483648){k=~~f;break c}k=-2147483648}f=f-+(k|0);d:{e:{f:{u=(q|0)<1;g:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;v[r+476>>2]=i;k=c+k|0;j=i>>y;break g}if(q){break f}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<1){break d}break e}j=2;if(f>=.5){break e}j=0;break d}c=0;i=0;if(!o){while(1){r=(h+480|0)+(c<<2)|0;o=v[r>>2];w=16777215;h:{i:{if(i){break i}w=16777216;if(o){break i}i=0;break h}v[r>>2]=w-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}j:{if(u){break j}c=8388607;k:{switch(z|0){case 1:c=4194303;break;case 0:break k;default:break j}}o=(g<<2)+h|0;v[o+476>>2]=v[o+476>>2]&c}k=k+1|0;if((j|0)!=2){break d}f=1-f;j=2;if(!i){break d}f=f-ji(1,q)}l:{m:{if(f==0){i=0;c=g;if((n|0)>=(c|0)){break l}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break l}l=q;while(1){l=l-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break m}f=ji(f,24-l|0);n:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=q}v[(h+480|0)+(g<<2)>>2]=c}f=ji(1,l);if((g|0)>=0){c=g;while(1){A[(c<<3)+h>>3]=f*+v[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){q:{f=f+A[(c<<3)+74032>>3]*A[(a+c<<3)+h>>3];if((c|0)>=(n|0)){break q}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<1){break u}d=(h+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=h+160|0;a=c-1|0;i=e+(a<<3)|0;x=A[i>>3];f=f+x;A[e+(c<<3)>>3]=m+(x-f);A[i>>3]=f;e=(c|0)>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=f+p;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break s}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}gb=h+560|0;return k&7}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(s+g<<2)+71264>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}}function Zoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-976|0;gb=g;vc(b);f=gb-32|0;gb=f;d=f+24|0;j=g+872|0;JX(d,j);h=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){IX(j)}a:{if(!d){break a}if(!MX(g+872|0)){break a}if(!Pb(b,Qc(LX(g+872|0),jb))){break a}b:{if(!c){break b}Hd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[g+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Ob(a+1074312|0,7,1);d=g+96|0;e=Tb(d,5357);Eb(a+1298304|0,e);vb(e);e=Tb(d,6043);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;e=g+16|0;$C(e,2,g+872|4);Bc(d,e);Eb(a+1298268|0,d);vb(d);e=0;while(1){d=(e<<5)+a|0;f=d+480280|0;We(f);h=f;f=(g+872|0)+e|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;e=e+1|0;if((e|0)!=16){continue}break}if(w[g+968|0]|w[g+969|0]<<8){oB(a+1298292|0,b,w[g+968|0]|w[g+969|0]<<8,132,0)}e=0;f=gb-32|0;gb=f;d=f+24|0;j=g+96|0;bc(d,j,771);h=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){Qb(j,0,771)}if(!d){break a}d=a+484360|0;KX(Sb(d),g+96|0,w[g+353|0]);cf(Sb(d),w[g+354|0]);Wc(b,w[g+919|0]|w[g+920|0]<<8);i=a+484344|0;r=c&1;f=0;c:{d:{while(1){d=(f<<1)+g|0;if(w[d+355|0]|w[d+356|0]<<8){e=g+72|0;Sd(e,b,w[d+355|0]|w[d+356|0]<<8);p=kc(g+16|0,e);xb(e);d=w[d+355|0]|w[d+356|0]<<8;j=(d-2|0)/64|0;e:{if(!r){break e}v[22708]=0;e=W(331,i|0,f&65535,j|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!e){break e}v[22708]=0;m=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(318,g+16|0,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0>=66){s=j>>>0>1?j:1;k=0;while(1){d=_b(i,f);v[22708]=0;n=Tf(d,k);d=v[22708];v[22708]=0;e=0;if((d|0)==1){break d}f:{while(1){g:{v[22708]=0;R(531,g+72|0,p|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}d=g+72|0;l=qd(d);h=Ve(d);o=fj(d);d=w[d|0];if((d-1&255)>>>0<=71){q=B(e,6)+n|0;t[q|0]=d+36;t[q+1|0]=w[l|0]+1}if((w[h|0]-1&255)>>>0<=15){d=B(e,6)+n|0;t[d+2|0]=1;t[d+4|0]=((w[h|0]<<6)+-64>>>0)/15}d=B(e,6)+n|0;l=w[o|0];h=l&15;t[d+5|0]=h;h:{i:{switch((w[o|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=l|240;break h;case 2:t[d+5|0]=h<<2;break h;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=h<<3;break h;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=h|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[o|0]>>>4|0)+28608|0];e=e+1|0;if((e|0)!=16){continue}break f}break}break d}k=k+1|0;if((s|0)!=(k|0)){continue}break}}d=_b(i,f);v[22708]=0;e=Be(g+72|0,14,0);h=v[22708];v[22708]=0;if((h|0)==1){break d}e=Fh(Ue(e,m?j-2>>>0>m>>>0?m+1|0:-1:-1));v[22708]=0;Q(431,d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}}xb(g+16|0)}f=f+1|0;if((f|0)!=256){continue}break}e=1;if(!(c&2)){break a}QY(b,g- -64|0);e=0;while(1){j:{k:{if(!(w[g- -64+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;break k}if(!_C(b,g+16|0)){break b}e=e+1|0;u[a+480190>>1]=e;Je(g,1,g+16|0);c=g+72|0;Bc(c,g);d=x[a+480190>>1];v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break j}f=g+72|0;vb(f);h=(B(e,104)+a|0)+484380|0;c=h;ud(c,0);j=g+16|0;d=j;v[c>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[c+4>>2]=w[d+38|0]|w[d+39|0]<<8|(w[d+40|0]<<16|w[d+41|0]<<24);i=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=i;u[c+30>>1]=w[d+37|0]<<4;if(t[d+46|0]&1){v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}if(!(!(w[d+47|0]&8)|y[c+8>>2]<=y[c+4>>2])){u[c+34>>1]=x[c+34>>1]|2}Rc(f,t[j+46|0]&1?16:8,1,0,0);Cg(f,h,b)}if((e|0)!=64){continue}break b}break}e=P()|0;O()|0;vb(g+72|0);break c}e=P()|0;O()|0;xb(g+16|0)}S(e|0);L()}e=1}gb=g+976|0;return e|0}function S2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb+-64|0;gb=h;v[h+56>>2]=b;v[e>>2]=0;Fc(h,d);v[22708]=0;i=T(2482,h|0)|0;j=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h);S(a|0);L()}_G(a,f+24|0,h+56|0,c,e,i);break b}ZG(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=hk(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}a=e;b=pj(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[20875];v[h+24>>2]=v[20874];v[h+28>>2]=g;g=v[20873];v[h+16>>2]=v[20872];v[h+20>>2]=g;g=v[20871];v[h+8>>2]=v[20870];v[h+12>>2]=g;g=v[20869];v[h>>2]=v[20868];v[h+4>>2]=g;k=h,l=hk(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20883];v[h+24>>2]=v[20882];v[h+28>>2]=g;g=v[20881];v[h+16>>2]=v[20880];v[h+20>>2]=g;g=v[20879];v[h+8>>2]=v[20878];v[h+12>>2]=g;g=v[20877];v[h>>2]=v[20876];v[h+4>>2]=g;k=h,l=hk(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=pj(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=pj(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=pj(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=pj(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=pj(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+56|0;H:{if(!wm(b,a+8|0)){break H}while(1){if(!jl(i,8192,vm(b))){break H}um(b);if(wm(b,a+8|0)){continue}break}}if(il(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+56|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ms(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=hc(h,83536,44);k=g,l=hk(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20900];g=v[20899];v[h+8>>2]=v[20898];v[h+12>>2]=g;g=v[20897];v[h>>2]=v[20896];v[h+4>>2]=g;k=h,l=hk(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=pj(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[20911];v[h+24>>2]=v[20910];v[h+28>>2]=g;g=v[20909];v[h+16>>2]=v[20908];v[h+20>>2]=g;g=v[20907];v[h+8>>2]=v[20906];v[h+12>>2]=g;g=v[20905];v[h>>2]=v[20904];v[h+4>>2]=g;k=h,l=hk(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=pj(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=hk(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}YG(f+20|0,h+56|0,c,e,i);break b}a=pj(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(il(c,a+8|0)){break M}b=4;if((Qn(i,vm(c))|0)!=37){break M}b=2;if(!il(um(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+56>>2]}gb=h- -64|0;return a|0}function V8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-128|0;gb=f;a:{if(gd(b)){break a}e=w[pL(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+112|0;Ns(e,b,0,Ab(b)-1|0);Eb(b,e);vb(e)}g=f+112|0;Ld(g);e=v[f+112>>2];Ld(f+96|0);e=oL(e,v[f+100>>2],b);Ld(g);b:{c:{d:{e:{if((e|0)==v[f+116>>2]){if(qe(b,18726)){a=ba(8)|0;v[22708]=0;U(2055,f+112|0,14728,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,f+112|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+112|0);break c}if(!d){break e}a=ba(8)|0;v[22708]=0;U(2055,f+80|0,14764,b|0);b=v[22708];v[22708]=0;f:{g:{h:{i:{if((b|0)!=1){v[22708]=0;R(2056,f+96|0,f+80|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}v[22708]=0;U(718,f+112|0,f+96|0,c|0);b=v[22708];v[22708]=0;d=1;if((b|0)==1){break h}rc(a,f+112|0);v[22708]=0;U(186,a|0,54936,1938);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+112|0);d=0;break g}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(f+80|0);break f}b=P()|0;O()|0}vb(f+96|0);vb(f+80|0);if(!d){break c}}ca(a|0);break c}j:{switch(v[e+4>>2]){case 0:Dg(f+72|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22708]=0;R(99,b+32|0,e|0);c=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((c|0)!=1){v[22708]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break o}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22708]=0;g=ga(79)|0;h=v[22708];v[22708]=0;if((h|0)==1){break m}v[22708]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break m}Wb(b+8|0);v[22708]=0;e=Q(2057,c|0,b+32|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break m}g=v[v[e>>2]-12>>2];v[22708]=0;e=El(e+g|0);g=v[22708];v[22708]=0;if((g|0)==1){break m}g=w[b+32|0];wf(c);gb=b+192|0;b=(e^-1)&(g|0)!=0;break k}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break l}a=P()|0;O()|0;wf(c)}S(a|0);L()}c=v[f+76>>2];v[f>>2]=v[f+72>>2];v[f+4>>2]=c;nL(a,f,b,d);break e;case 1:Dg(f- -64|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22708]=0;R(99,b+32|0,e|0);c=v[22708];v[22708]=0;p:{q:{r:{s:{t:{if((c|0)!=1){v[22708]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22708]=0;g=ga(79)|0;h=v[22708];v[22708]=0;if((h|0)==1){break r}v[22708]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break r}Wb(b+8|0);v[22708]=0;e=Q(110,c|0,b+32|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break r}g=v[v[e>>2]-12>>2];v[22708]=0;e=El(e+g|0);g=v[22708];v[22708]=0;if((g|0)==1){break r}g=v[b+32>>2];h=v[b+36>>2];wf(c);gb=b+192|0;b=e?0:g;c=e?0:h;break p}a=P()|0;O()|0;break s}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break q}a=P()|0;O()|0;wf(c)}S(a|0);L()}e=v[f+68>>2];v[f+8>>2]=v[f+64>>2];v[f+12>>2]=e;mL(a,f+8|0,b,c,d);break e;case 2:Dg(f+56|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22708]=0;R(99,b+32|0,e|0);c=v[22708];v[22708]=0;u:{v:{w:{x:{y:{if((c|0)!=1){v[22708]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break y}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22708]=0;g=ga(79)|0;h=v[22708];v[22708]=0;if((h|0)==1){break w}v[22708]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break w}Wb(b+8|0);v[22708]=0;e=Q(111,c|0,b+32|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break w}g=v[v[e>>2]-12>>2];v[22708]=0;e=El(e+g|0);g=v[22708];v[22708]=0;if((g|0)==1){break w}i=A[b+32>>3];wf(c);gb=b+192|0;i=e?0:i;break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break v}a=P()|0;O()|0;wf(c)}S(a|0);L()}b=v[f+60>>2];v[f+16>>2]=v[f+56>>2];v[f+20>>2]=b;lL(a,f+16|0,i,d);break e;case 3:break j;default:break e}}Dg(f+48|0,b);Dg(f+40|0,c);b=v[f+52>>2];v[f+32>>2]=v[f+48>>2];v[f+36>>2]=b;b=v[f+44>>2];v[f+24>>2]=v[f+40>>2];v[f+28>>2]=b;kL(a,f+32|0,f+24|0,d)}gb=f+128|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Jo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-112|0;gb=d;p=TA(a);q=Ti(p);f=q;c=a;e=Ec(c);a:{if(f>>>0>e>>>0){m=gb-32|0;gb=m;b:{i=f-e|0;c:{if(i>>>0<=(v[wb(c)>>2]-v[c+4>>2]|0)/12>>>0){f=gb-16|0;gb=f;i=Mp(f,c,i);h=v[i+4>>2];e=v[i+8>>2];if((h|0)!=(e|0)){while(1){wb(c);gR(h);h=h+12|0;v[i+4>>2]=h;if((e|0)!=(h|0)){continue}break}}$b(i);gb=f+16|0;break c}e=wb(c);j=Wu(m+8|0,PB(c,Ec(c)+i|0),Ec(c),e);v[22708]=0;R(1132,j|0,i|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}Zp(c);wb(c);f=j+4|0;l=f;k=v[c+4>>2];e=v[c>>2];if((k|0)!=(e|0)){i=v[l>>2];while(1){k=k-12|0;TB(i-12|0,k);i=v[l>>2]-12|0;v[l>>2]=i;if((e|0)!=(k|0)){continue}break}}wc(c,f);wc(c+4|0,j+8|0);wc(wb(c),dc(j));v[j>>2]=v[j+4>>2];Zw(c,Ec(c));hR(j)}gb=m+32|0;break a}a=P()|0;O()|0;hR(j);S(a|0);L()}if(e>>>0>f>>>0){f=v[c>>2]+B(f,12)|0;Ec(c);lR(c,f);iR(c)}}if(b){c=a+12|0;Jq(c,Xd(c));r=wb(c),s=0,v[r>>2]=s;r=c,s=fc(c),v[r>>2]=s;r=fc(c),s=0,v[r>>2]=s;v[a+28>>2]=0}n=mc(d+96|0);c=v[a+24>>2];v[22708]=0;e=nq(c+484344|0);c=v[22708];v[22708]=0;d:{e:{f:{g:{if((c|0)==1){break g}v[22708]=0;j=W(796,d+80|0,e|0,36524)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}h=0;u[d+78>>1]=0;if(q){o=a+12|0;while(1){l=x[sc(p,h&65535)>>1];c=wR(a,l);v[d+72>>2]=c;f=Ad(a,x[d+78>>1]);h:{if(b){v[22708]=0;t[d+32|0]=0;U(1126,f|0,c|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)!=1){break h}g=P()|0;O()|0;break e}v[22708]=0;U(948,f|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break f}}v[22708]=0;e=Q(472,p|0,x[d+78>>1])|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}i:{if(!e){break i}g=0;g=b?g:v[f+4>>2];v[22708]=0;v[d+32>>2]=g;e=Fb(d+32|0,d+72|0);c=v[22708];v[22708]=0;j:{k:{if((c|0)!=1){v[d+68>>2]=v[e>>2];i=Dh(o);if(x[sc(j,l)>>1]!=65535){e=uR(o,Um(d+32|0,sc(j,l),d+68|0));v[d+64>>2]=e;r=d,s=Dh(o),v[r+8>>2]=s;f=d;l:{if(og(d- -64|0,d+8|0)){c=uR(o,Um(d+32|0,sc(j,l),d+72|0));break l}c=Dh(o)}v[f+56>>2]=c;v[d+48>>2]=e;if(!og(d+48|0,d+56|0)){break i}while(1){m:{f=dd(d+32|0);c=tg(ue(d+48|0)+8|0);v[22708]=0;R(1127,f|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break m}yB(d+16|0,i);c=Um(d+8|0,d+78|0,ue(d+48|0)+4|0);v[22708]=0;e=da(1128,o|0,v[d+16>>2],c|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[d+24>>2]=e;tR(d+24|0);i=v[d+24>>2];Kq(f);if(og(tR(d+48|0),d+56|0)){continue}break i}break}g=P()|0;O()|0;Kq(f);break e}f=_b(v[a+24>>2]+484344|0,l);v[22708]=0;e=Li(f);c=v[22708];v[22708]=0;n:{o:{if((c|0)!=1){v[22708]=0;t[d+32|0]=0;U(1130,n|0,e|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break o}k=v[d+72>>2];if((k|0)!=v[d+68>>2]){break n}break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}p:while(1){q:{h=0;v[22708]=0;k=k-1|0;v[d+64>>2]=k;g=Tf(f,k);c=v[22708];v[22708]=0;m=1;if((c|0)==1){break k}while(1){r:{v[22708]=0;e=Li(f);c=v[22708];v[22708]=0;s:{if((c|0)!=1){if(m>>>0<16&e>>>0>h>>>0){break s}if(m>>>0>1){e=dd(d+32|0);v[22708]=0;R(1127,e|0,m|0);c=v[22708];v[22708]=0;if((c|0)==1){break r}yB(d,i);c=Um(d+8|0,d+78|0,d- -64|0);v[22708]=0;i=da(1128,o|0,v[d>>2],c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}Kq(e)}if(v[d+68>>2]==(k|0)){break j}continue p}g=P()|0;O()|0;break e}e=w[lc(n,h)|0];t:{u:{v:{switch(w[g+3|0]-19|0){case 1:c=w[g+5|0];if((c&240)==176){break u}break t;case 0:break v;default:break t}}c=w[g+5|0];if((c&240)!=96){break t}}r=lc(n,h),s=c&15,t[r|0]=s;if(!w[lc(n,h)|0]){break t}e=w[lc(n,h)|0]}m=B(e?e+1|0:1,m);g=g+6|0;h=h+1|0;continue}break}}break}g=P()|0;O()|0;Kq(e);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}if(k){break i}c=x[d+78>>1];r=sc(j,l),s=c,u[r>>1]=s}h=x[d+78>>1]+1|0;u[d+78>>1]=h;if((h&65535)>>>0<q>>>0){continue}break}}Ze(j);gc(n);gb=d+112|0;return}g=P()|0;O()|0;break d}g=P()|0;O()|0}Ze(j)}gc(n);S(g|0);L()}function Z2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;Fc(i,d);v[22708]=0;i=T(21,i|0)|0;j=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h+8|0);S(a|0);L()}bH(a,f+24|0,h+24|0,c,e,i);break b}aH(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=ik(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}a=e;b=qj(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=ik(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=ik(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=qj(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=qj(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=qj(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=qj(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=qj(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+24|0;H:{if(!lk(b,a+8|0)){break H}while(1){if(!nh(i,8192,nl(b))){break H}ml(b);if(lk(b,a+8|0)){continue}break}}if(kk(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+24|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Os(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[83460]|w[83461]<<8|(w[83462]<<16|w[83463]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[83457]|w[83458]<<8|(w[83459]<<16|w[83460]<<24);v[h+8>>2]=w[83453]|w[83454]<<8|(w[83455]<<16|w[83456]<<24);v[h+12>>2]=g;k=h,l=ik(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[83468];v[h+8>>2]=w[83464]|w[83465]<<8|(w[83466]<<16|w[83467]<<24);k=h,l=ik(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=qj(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=ik(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=qj(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=ik(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}$G(f+20|0,h+24|0,c,e,i);break b}a=qj(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(kk(c,a+8|0)){break M}b=4;if((Rn(i,nl(c))|0)!=37){break M}b=2;if(!kk(ml(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+24>>2]}gb=h+32|0;return a|0}function oe(a,b){var c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),n=C(0),o=0,r=0,s=C(0),t=C(0),u=C(0);i=C(1);a:{b:{c:{k=(p(b),j(2));d=k&2147483647;d:{if(!d){break d}h=(p(a),j(2));if((h|0)==1065353216){break d}e=h&2147483647;c=C(a+b);if(!(d>>>0<2139095041&e>>>0<=2139095040)){break a}e:{f:{if((h|0)>-1){break f}o=2;if(d>>>0>1266679807){break e}if(d>>>0<1065353216){break f}g=150-(d>>>23|0)|0;r=d>>>g|0;o=0;if((d|0)!=r<<g){break e}o=2-(r&1)|0;break e}o=0}g=o;g:{if((d|0)!=1065353216){if((d|0)!=2139095040){break g}if((e|0)==1065353216){break d}c=(k|0)>-1?b:C(0);if(e>>>0>=1065353217){break a}c=(k|0)>-1?C(0):C(-b);break a}c=(k|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((k|0)==1073741824){break a}c=C(K(a));if(!((k|0)!=1056964608|(h|0)<0)){break a}f=C(D(a));if(!(e?(h&1073741823)!=1065353216:0)){i=(k|0)<0?C(C(1)/f):f;if((h|0)>-1){break d}if(!(g|e-1065353216)){a=C(i-i);c=C(a/a);break a}c=(g|0)==1?C(-i):i;break a}h:{if((h|0)>-1){break h}i:{switch(g|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}i=C(-1)}j:{if(d>>>0>=1291845633){c=(k|0)<0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0<=1065353207){break a}c=(k|0)>0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0>=1065353224){break a}a=C(f+C(-1));c=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));f=c;a=C(a*C(1.44268798828125));c=(l(2,(p(C(c+a)),j(2))&-4096),q());f=C(f-C(c-a));break j}d=e>>>0<8388608;e=d?(p(C(f*C(16777216))),j(2)):e;h=e&8388607;g=h|1065353216;d=(e>>23)+(d?-151:-127)|0;e=0;k:{if(h>>>0<1885298){break k}if(h>>>0<6140887){e=1;break k}g=h|1056964608;d=d+1|0}h=e<<2;a=z[h+90048>>2];n=(l(2,g),q());m=C(C(1)/C(a+n));s=C(n-a);f=C(s*m);c=(l(2,(p(f),j(2))&-4096),q());t=C(c*c);u=m;m=(l(2,((g>>>1&536866816)+(e<<21)|0)+541065216|0),q());n=C(u*C(C(s-C(m*c))-C(C(n-C(m-a))*c)));a=C(f*f);m=C(C(n*C(f+c))+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(t+C(3))+m)),j(2))&-4096),q());f=C(C(n*a)+C(f*C(m-C(C(a+C(-3))-t))));c=C(c*a);a=(l(2,(p(C(f+c)),j(2))&-4096),q());n=z[h+90064>>2];f=C(z[h+90056>>2]+C(C(C(f-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(a*C(.9619140625));m=C(d|0);c=(l(2,(p(C(C(n+C(f+a))+m)),j(2))&-4096),q());f=C(f-C(C(C(c-m)-n)-a))}n=(l(2,k&-4096),q());a=C(c*n);b=C(C(f*b)+C(C(b-n)*c));c=C(a+b);g=(p(c),j(2));if((g|0)>=1124073473){break c}e=1124073472;l:{m:{if((g|0)==1124073472){if(!(C(b+C(4.299566569443414e-8))>C(c-a))){break m}break c}e=g&2147483647;if(!(!(b<=C(c-a))|(g|0)!=-1021968384)|e>>>0>=1125515265){break b}d=0;if(e>>>0<1056964609){break l}}k=(8388608>>>(e>>>23|0)-126|0)+g|0;e=k>>>23&255;d=(k&8388607|8388608)>>>150-e|0;d=(g|0)<0?0-d|0:d;a=C(a-(l(2,k&-8388608>>e-127),q()));g=(p(C(b+a)),j(2))}c=(l(2,g&-32768),q());f=C(c*C(.693145751953125));c=C(C(c*C(14286065379565116e-22))+C(C(b-C(c-a))*C(.6931471824645996)));a=C(f+c);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));m=C(C(a*b)/C(b+C(-2)));b=C(c-C(a-f));a=C(C(a-C(m-C(b+C(a*b))))+C(1));g=(p(a),j(2))+(d<<23)|0;n:{if((g|0)<=8388607){a=RI(a,d);break n}a=(l(2,g),q())}i=C(i*a)}c=i;break a}c=C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function iha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-11360|0;gb=g;vc(c);a:{b:{if(!Pb(c,4)){break b}c:{while(1){d:{j=g+16|0;d=j;f=gb-32|0;gb=f;h=c;e:{if(!Pb(c,3)){k=gb-16|0;gb=k;i=d+3|0;while(1){If(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}gb=k+16|0;break e}fY(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,h,f+8|0)}gb=f+32|0;f:{if(!sd(j,12222,3)){d=g+4648|0;f=gb-32|0;gb=f;g:{if(!Pb(c,7)){h=gb-16|0;gb=h;j=d+7|0;while(1){If(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=h+16|0;break g}tn(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,h,f+8|0)}gb=f+32|0;f=3;d=0;while(1){h=w[(g+4648|0)+f|0];if(h&128){break c}d=h|d<<7;f=f+1|0;if((f|0)!=7){continue}break}Rb(c,d);break f}h:{if(sd(g+16|0,11433,3)){break h}if(!yV(c,10883)){break h}Rb(c,sg(c)+16|0);break f}if(!sd(g+16|0,36527,3)){break f}if(!sd(g+16|0,36531,3)){break f}if(w[g+16|0]){break d}pg(c,2)}if(Pb(c,4)){continue}break b}break}if(SS(g+16|0)){break b}}f=0;break a}vc(c);d=g+11336|0;OC(d,c);k=v[d>>2];v[22708]=0;c=Rd(d);d=v[22708];v[22708]=0;i:{j:{k:{l:{if((d|0)!=1){c=zb(c);i=mc(g+11320|0);d=g+4648|0;Qb(d,0,6668);v[22708]=0;st(d);d=v[22708];v[22708]=0;if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;h=0;d=0;while(1){f=Ac(k,l);v[22708]=0;m=fa(1137,g+4648|0,c|0,f|0,g+16|0,g+4624|0)|0;f=v[22708];v[22708]=0;m:{n:{if((f|0)!=1){if((m|0)<0){break k}f=v[g+4624>>2];if((f|0)<0){break k}n=(m|0)<1;if(!(f?1:n)|!(f|m)){break k}if((f|0)<1){break m}j=v[g+4636>>2];if((j|0)!=(h|0)?h:0){break k}f=v[g+4632>>2];if((f|0)!=(d|0)?d:0){break k}if((j|0)<1|f-1>>>0>1){break l}v[g+12>>2]=0;d=Ac(k,l);v[22708]=0;v[g+8>>2]=d;d=ej(g+4624|0,g+12|0,g+8|0);h=v[22708];v[22708]=0;o:{if((h|0)!=1){d=v[d>>2];v[g+12>>2]=0;h=Ac(k,l);v[22708]=0;v[g+8>>2]=h;h=ej(g+4624|0,g+12|0,g+8|0);o=v[22708];v[22708]=0;if((o|0)==1){break o}c=c+d|0;d=k;h=v[h>>2];k=d-h|0;l=l-((h>>31)+(d>>>0<h>>>0)|0)|0;if(n){break n}v[22708]=0;d=g+16|0;U(1139,i|0,d|0,d+(B(f,m)<<1)|0);d=v[22708];v[22708]=0;if((d|0)!=1){break n}d=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break j}Z(d|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;h=j;d=f;if((c|0)!=1){break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}h=j;d=f}if((tc(i)>>>0)/(d>>>0)>>>0>268435456){break k}if(!!k&(l|0)>=0|(l|0)>0){continue}break}break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break i}h=j;d=f}f=0;p:{q:{r:{s:{t:{if(!h|!d){break t}if(cd(i)){break t}if((tc(i)>>>0)/(d>>>0)>>>0>268435456){break t}v[22708]=0;Q(1140,a|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}if(!e){v[22708]=0;c=Q(70,g+16|0,18726)|0;f=v[22708];v[22708]=0;if((f|0)==1){break s}v[22708]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}vb(c);v[22708]=0;c=B(b,104)+a|0;R(424,c+484380|0,0);f=v[22708];v[22708]=0;if((f|0)==1){break p}v[c+484404>>2]=h}h=B(b,104)+a|0;c=h+484380|0;p=c,q=(tc(i)>>>0)/(d>>>0)|0,v[p>>2]=q;f=h+484414|0;h=x[f>>1];u[f>>1]=(d|0)==2?h|65:h&65470|1;v[22708]=0;T(386,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break p}if(Md(c)){d=Vb(i);h=Zb(i);b=v[(B(b,104)+a|0)+484400>>2];v[22708]=0;W(1141,d|0,h|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}}if(!e){b=v[a+480180>>2];v[22708]=0;U(1142,c|0,32,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;_h(c,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break p}}f=Md(c)}Ze(i);zc(g+11336|0);break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;vb(c);break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Ze(i)}zc(g+11336|0);S(d|0);L()}gb=g+11360|0;return f|0}function b_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-576|0;gb=g;vc(b);f=gb-32|0;gb=f;d=f+24|0;i=g+72|0;FE(d,i);e=yb(d);d=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=d;v[f>>2]=h;v[f+4>>2]=d;h=f+16|0;d=b;cc(h,d,f);h=yb(h);if((h|0)==(e|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(e|0)==(h|0);if(!d){EE(i)}a:{if(!d){break a}if(!LE(g+72|0)){break a}b:{if(!c){break b}if(!Pb(b,Qc(KE(g+72|0),jb))){break a}Hd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;f=1;Ob(a+1074312|0,7,1);d=g+40|0;e=Tb(d,11859);Eb(a+1298304|0,e);vb(e);d=Tb(d,11892);Eb(a+1298316|0,d);vb(d);Xc(a+1298328|0,x[g+72>>1]==26217?11859:11887);v[a+1298364>>2]=5;d=w[g+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){i=1;while(1){h=gb-32|0;gb=h;d=h+24|0;e=g+40|0;bc(d,e,25);k=yb(d);d=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=d;v[h>>2]=j;v[h+4>>2]=d;j=h+16|0;d=b;cc(j,d,h);j=yb(j);if((j|0)==(k|0)){Rb(d,yb(h+24|0))}gb=h+32|0;if((j|0)!=(k|0)){t[e|0]=0;t[e+1|0]=0;t[e+2|0]=0;t[e+3|0]=0;t[e+4|0]=0;t[e+5|0]=0;t[e+6|0]=0;t[e+7|0]=0;t[e+24|0]=0;t[e+16|0]=0;t[e+17|0]=0;t[e+18|0]=0;t[e+19|0]=0;t[e+20|0]=0;t[e+21|0]=0;t[e+22|0]=0;t[e+23|0]=0;t[e+8|0]=0;t[e+9|0]=0;t[e+10|0]=0;t[e+11|0]=0;t[e+12|0]=0;t[e+13|0]=0;t[e+14|0]=0;t[e+15|0]=0}if((w[g+53|0]|w[g+54|0]<<8|(w[g+55|0]<<16|w[g+56|0]<<24))>>>0>67108863){break a}e=(B(f,104)+a|0)+484380|0;ud(e,0);v[e+24>>2]=8363;h=g+40|0;d=h;v[e>>2]=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[e+4>>2]=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>y[e>>2]?v[e+4>>2]?d:0:d;v[e+8>>2]=d;if(d){u[e+34>>1]=2;wk(e)}d=g+8|0;li(d,2,h);e=g+24|0;Bc(e,d);v[22708]=0;Q(301,((f<<5)+a|0)+946304|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}vb(g+24|0);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}f=g+24|0;e=g+72|2;Xe(f,3,e,36);d=g+40|0;Bc(d,f);Eb(a+1298268|0,d);vb(d);f=0;RS(a+1298292|0,zb(e),108,36,0);d=a+484360|0;JE(Sb(d),g+185|0,128);if(x[sc(Sb(d),w[g+184|0])>>1]<w[g+183|0]){break d}break c}a=P()|0;O()|0;vb(g+24|0);S(a|0);L()}cf(Sb(d),w[g+184|0])}while(1){d=(f<<5)+a|0;We(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;zg(h,w[g+183|0]);n=1;if(w[g+183|0]){o=c&1;e=0;while(1){f:{g:{if(o){if(wh(h,e&65535,64)){break g}}Rb(b,1536);break f}v[g+24>>2]=-1;v[g+28>>2]=-1;j=0;while(1){f=Tf(_b(h,e),j);k=0;while(1){i=g+40|0;Ur(i,b);d=qd(i);m=Ve(i);l=w[d|0];d=w[i|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|l>>>4)+1;t[(g+24|0)+k|0]=255;d=w[i|0]}if((d&255)!=255){t[f+2|0]=1;t[f+4|0]=(((l&15)<<6|8)>>>0)/15}l=(g+24|0)+k|0;h:{i:{i=w[m|0];j:{if((i|0)!=255){t[l|0]=i;d=i&15;if(d|(i|0)==48){break j}break i}i=w[l|0];if((i|0)==255){break h}d=i&15}t[f+5|0]=d;k:{if(i<<24>>24<0){break k}m=i>>>4|0;t[f+3|0]=w[m+28392|0];l:{switch(m-3|0){case 0:t[f+5|0]=d|32;break i;case 1:t[f+5|0]=B(d,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(i&15){case 0:t[f+5|0]=79;break h;case 1:break m;default:break k}}t[f+5|0]=244;break h}t[f+3|0]=0;break h}t[l|0]=255}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}j=j+1|0;if((j|0)!=64){continue}break}d=(g+72|0)+e|0;f=d;if(w[d+369|0]<63){Jm(_b(h,e),Fh(Ue(Be(g+40|0,14,0),w[f+369|0])))}Jm(_b(h,e),Fh(Be(g+40|0,16,w[d+241|0])))}e=e+1|0;if(e>>>0<w[g+183|0]){continue}break}}if(!(c&2)){break a}f=1;c=Rc(g+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){Cg(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=1}gb=g+576|0;return n|0}function lL(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=gb-256|0;gb=e;A[e+248>>3]=c;a:{if(pk(b)){break a}f=w[ul(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}f=e+216|0;Ld(f);g=v[e+216>>2];Ld(e+200|0);h=tl(g,v[e+204>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=uc(e+232|0,18726);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){a=ba(8)|0;v[22708]=0;R(2062,e+200|0,e+248|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+216|0,14728,e+200|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}rc(a,e+216|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);vb(e+200|0);break c}b=P()|0;O()|0;break d}if(!d){break i}a=ba(8)|0;v[22708]=0;f=Q(2059,e+168|0,b|0)|0;b=v[22708];v[22708]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22708]=0;U(2039,e+184|0,14764,f|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;R(2056,e+200|0,e+184|0);b=v[22708];v[22708]=0;d=1;if((b|0)==1){break p}v[22708]=0;R(2062,e+152|0,e+248|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[22708]=0;U(2060,e+216|0,e+200|0,e+152|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}rc(a,e+216|0);v[22708]=0;U(186,a|0,54936,1938);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);d=0;break m}b=P()|0;O()|0;break j}b=P()|0;O()|0;vb(f);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}vb(e+152|0)}vb(e+200|0)}vb(e+184|0);vb(f);if(!d){break c}}ca(a|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=uc(e+136|0,18726);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Gc(e+80|0,e+72|0)){a=ba(8)|0;v[22708]=0;R(2062,e+200|0,e+248|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,e+216|0,14728,e+200|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,e+216|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);vb(e+200|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=uc(e+120|0,4823);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Gc(e- -64|0,e+56|0)){if(!w[a+28|0]){break i}if(c<=0|c>4){a=ba(8)|0;v[22708]=0;d=Q(70,e+216|0,4918)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}rc(a,d);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=Ah(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;xq(v[a>>2]);break i}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=uc(e+104|0,4875);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Gc(e+48|0,e+40|0)){if(!w[a+28|0]){break i}if(c<=0|c>4){a=ba(8)|0;v[22708]=0;d=Q(70,e+216|0,4939)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,d);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=P()|0;O()|0;ca(a|0);break c}b=Ah(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;xq(v[a>>2]);break i}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=uc(e+88|0,4893);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Gc(e+32|0,e+24|0)){break i}b=Qo(c*65536);v[v[a+24>>2]+480236>>2]=b}gb=e+256|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(e+200|0);break d}b=P()|0;O()|0;vb(e+200|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function ana(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0,C=0;e=gb-48|0;gb=e;a:{b:{c:{d:{if(!c){break d}B=e,C=Ae(a),t[B+32|0]=C;k=e+32|0;d=b;e:{if(y[d+4>>2]<y[wb(d)>>2]){h=gb-16|0;gb=h;f=Bi(h,d,1);wb(d);Bd(v[f+4>>2],k);v[f+4>>2]=v[f+4>>2]+1;$b(f);gb=h+16|0;break e}f=gb-32|0;gb=f;h=wb(d);h=Zg(f+8|0,qh(d,oc(d)+1|0),oc(d),h);Bd(v[h+8>>2],k);v[h+8>>2]=v[h+8>>2]+1;v[22708]=0;R(296,d|0,h|0);d=v[22708];v[22708]=0;f:{if((d|0)!=1){ae(h);gb=f+32|0;break f}a=P()|0;O()|0;ae(h);S(a|0);L()}}h=c-1|0;if(!h){break c}while(1){g:{h:{c=i<<1;i=c&254;i:{if(!i){if(!lf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0<256){break i}break h}if((c&65535)>>>0>255){break h}}if(!lf(a,e+32|0)){break d}g=e+32|0;c=b;j:{if(v[c+4>>2]!=v[wb(c)>>2]){lM(c,g);break j}k=gb-32|0;gb=k;f=wb(c);j=Zg(k+8|0,qh(c,oc(c)+1|0),oc(c),f);d=v[j+8>>2];v[22708]=0;ql(f,d,g);d=v[22708];v[22708]=0;k:{if((d|0)==1){break a}v[j+8>>2]=v[j+8>>2]+1;v[22708]=0;R(296,c|0,j|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}ae(j);gb=k+32|0;break k}}h=h-1|0;break g}d=1;while(1){l:{m:{n:{c=i<<1&254;o:{if(c){g=i>>>0>127}else{if(!lf(a,e+32|0)){break o}f=w[e+32|0]<<1|1;c=f&255;g=f>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break m}if(lf(a,e+32|0)){break n}}i=0;break l}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break l}if(c>>>0>127){continue}}break}p:{if((d|0)<=2){f=0;g=d-2|0;break p}c=lf(a,e+32|0);if(!c){break d}c=c?(w[e+32|0]|d<<8)-768|0:s;f=((c|0)>1279?2:1)+((c|0)>31999)|0;s=c^-1;g=0}c=i<<1&254;if(c){d=i>>>0>127}else{if(!lf(a,e+32|0)){break d}d=w[e+32|0]<<1|1;c=d&255;d=d>>>0>255}k=h;i=c<<1&254;if(i){c=c>>>0>127}else{if(!lf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(g<<2|(d?2:0));if(!c){d=1;while(1){q:{r:{s:{c=i<<1&254;t:{if(c){g=i>>>0>127}else{if(!lf(a,e+32|0)){break t}g=w[e+32|0]<<1|1;c=g&255;g=g>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break r}if(lf(a,e+32|0)){break s}}i=0;break q}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break q}if(c>>>0>127){continue}}break}c=d+2|0}g=k;k=c+f|0;d=0;if(g>>>0<k>>>0|(k|0)<1|(s|0)>-1){break b}d=0;if((0-oc(b)|0)>(s|0)){break b}B=e,C=Zb(b),v[B+32>>2]=C;Gd(e+40|0,e+32|0);t[e+24|0]=0;A=e+24|0;q=A;m=gb-32|0;gb=m;v[m+24>>2]=v[e+40>>2];c=b;d=v[c>>2];B=m,C=Vb(c),v[B>>2]=C;d=ak(m+24|0,m)+d|0;u:{g=k;f=v[wb(c)>>2];l=v[c+4>>2];v:{if(g>>>0<=f-l>>>0){f=g;j=l-d|0;if(f>>>0>j>>>0){Dn(c,g-j|0,q);f=j;if(!f){break v}}x=gb-16|0;gb=x;n=c;r=l;j=d;p=v[c+4>>2];o=(p-(d+g|0)|0)+d|0;z=Bi(x,c,l-o|0);if(l>>>0>o>>>0){u=v[z+4>>2];l=o;while(1){wb(n);Bd(u,l);u=u+1|0;v[z+4>>2]=u;l=l+1|0;if(r>>>0>l>>>0){continue}break}}$b(z);yr(j,o,p);gb=x+16|0;oi(d,f,q+(d>>>0<=q>>>0?q>>>0<y[c+4>>2]?g:0:0)|0);break v}f=wb(c);j=Zg(m,qh(c,oc(c)+g|0),d-v[c>>2]|0,f);v[22708]=0;U(638,j|0,g|0,q|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}n=c;ut(c);r=j;f=v[j+4>>2];g=d;o=j+4|0;Ck(wb(c),v[c>>2],d,o);wb(c);l=j+8|0;p=l;d=v[c+4>>2];if((g|0)!=(d|0)){c=v[p>>2];while(1){Bd(c,g);c=v[p>>2]+1|0;v[p>>2]=c;g=g+1|0;if((d|0)!=(g|0)){continue}break}}xc(n,o);xc(n+4|0,l);xc(wb(n),dc(r));v[r>>2]=v[r+4>>2];tt(n,oc(n));d=f;ae(j)}Gg(d);gb=m+32|0;break u}B=e,C=Zb(b),v[B+16>>2]=C;B=e,C=NV(e+16|0,k),v[B+24>>2]=C;B=e,C=we(A,s),v[B+32>>2]=C;B=e,C=Zb(b),v[B+16>>2]=C;B=e,C=NV(e+16|0,k),v[B+24>>2]=C;c=k;while(1){B=e,C=MV(e+32|0),v[B+16>>2]=C;d=w[v[e+16>>2]];B=e,C=MV(e+24|0),v[B+8>>2]=C;t[v[e+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}h=h-k|0}if(h){continue}break}break c}d=0;break b}d=1}gb=e+48|0;return d|0}a=P()|0;O()|0;ae(j);S(a|0);L()}function fk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c=1;o(+b);e=j(1)|0;f=j(0)|0;h=e;a:{b:{v=e;m=e&2147483647;e=f;c:{if(!(m|e)){break c}o(+a);i=j(1)|0;f=j(0)|0;k=i;x=i;s=f;if(f?0:(i|0)==1072693248){break c}i=x&2147483647;if(!(!(i>>>0>2146435072|(i|0)==2146435072&(s|0)!=0|m>>>0>2146435072)&(!e|(m|0)!=2146435072))){return a+b}d:{e:{f:{g:{if((k|0)>-1){break g}t=2;if(m>>>0>1128267775){break f}if(m>>>0<1072693248){break g}f=m>>>20|0;if(m>>>0>=1094713344){d=1075-f|0;f=e>>>d|0;t=0;if((e|0)!=f<<d){break f}t=2-(f&1)|0;break f}if(e){break d}f=1043-f|0;e=m>>>f|0;if((m|0)!=e<<f){break e}d=2-(e&1)|0;break e}t=0}d=t;if(e){break d}}if((m|0)==2146435072){if(!(i-1072693248|s)){break c}if(i>>>0>=1072693248){return(h|0)>-1?b:0}return(h|0)>-1?0:-b}if((m|0)==1072693248){if((h|0)>-1){return a}return 1/a}if((v|0)==1073741824){return a*a}if((v|0)!=1071644672|(k|0)<0){break d}return K(a)}c=D(a);if(!((i?(x&1073741823)!=1072693248:0)|s)){c=(h|0)<0?1/c:c;if((k|0)>-1){break c}if(!(i-1072693248|d)){a=c-c;return a/a}return(d|0)==1?-c:c}q=1;h:{if((k|0)>-1){break h}i:{switch(d|0){case 0:a=a-a;return a/a;case 1:break i;default:break h}}q=-1}j:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(i>>>0<=1072693247){return(h|0)<0?N:0}return(v|0)>0?N:0}if(i>>>0<=1072693246){return(h|0)<0?q*1e300*1e300:q*1e-300*1e-300}if(i>>>0>=1072693249){return(v|0)>0?q*1e300*1e300:q*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;g=c;c=a*1.4426950216293335;o(+(g+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=g-(a-c);break j}a=c*9007199254740992;e=i>>>0<1048576;c=e?a:c;o(+a);d=j(1)|0;j(0)|0;k=e?d:i;f=k&1048575;d=f|1072693248;k=(k>>20)+(e?-1076:-1023)|0;e=0;k:{if(f>>>0<235663){break k}if(f>>>0<767610){e=1;break k}d=f|1071644672;k=k+1|0}s=e<<3;y=A[s+90096>>3];a=A[s+90080>>3];o(+c);j(1)|0;f=0;l(0,j(0)|f);l(1,d|0);p=+n();c=1/(a+p);r=c;g=p-a;w=g;l(0,f|0);l(1,((e<<18)+(d>>>1|0)|0)+537395200|0);u=+n();g=g*c;o(+g);d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);c=+n();a=r*(w-u*c-(p-(u-a))*c);r=a;p=c*c;w=a*(g+c);a=g*g;u=w+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(p+3+u));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=r*a+g*(u-(a+-3-p));c=c*a;o(+(g+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=y+((g-(a-c))*.9617966939259756+a*-7.028461650952758e-9);r=c;g=A[s+90112>>3];c=a*.9617967009544373;p=+(k|0);o(+(g+(r+c)+p));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=r-(a-p-g-c)}l(0,0);l(1,h|0);p=+n();c=a*p;a=g*b+(b-p)*a;b=c+a;o(+b);h=j(1)|0;d=j(0)|0;f=h;e=d;l:{if((f|0)>=1083179008){if(e|h-1083179008){break b}if(!(a+8.008566259537294e-17>b-c)){break l}break b}if((h&2147482624)>>>0<1083231232){break l}if(e|h+1064252416){break a}if(!(a<=b-c)){break l}break a}e=0;k=h&2147483647;if(k>>>0>=1071644673){d=h+(1048576>>>(k>>>20|0)-1022|0)|0;h=d>>>20&2047;e=(d&1048575|1048576)>>>1043-h|0;e=(f|0)<0?0-e|0:e;l(0,0);l(1,d&-1048576>>h-1023);c=c-+n();o(+(a+c));f=j(1)|0;j(0)|0}l(0,0);l(1,f|0);b=+n();g=b*.6931471824645996;c=(a-(b-c))*.6931471805599453+b*-1.904654299957768e-9;a=g+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);r=a*b/(b+-2);b=c-(a-g);a=a-(r-(b+a*b))+1;o(+a);d=j(1)|0;f=j(0)|0;d=(e<<20)+d|0;m:{if((d|0)<=1048575){a=ji(a,e);break m}l(0,f|0);l(1,d|0);a=+n()}c=q*a}return c}return q*1e300*1e300}return q*1e-300*1e-300}function T7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-352|0;gb=d;a:{if(pk(b)){break a}e=w[ul(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Jl(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}f=d+320|0;Ld(f);e=v[d+320>>2];Ld(d+304|0);e=tl(e,v[d+308>>2],b);Ld(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=uc(d+336|0,18726);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22708]=0;c=Q(70,d+320|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;if(!c){break g}a=ba(8)|0;v[22708]=0;c=Q(2059,d+304|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,d+320|0,14764,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}rc(a,d+320|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d+320|0);vb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]){a=ba(8)|0;v[22708]=0;c=Q(70,d+320|0,8874)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=uc(d+288|0,18726);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Gc(d+152|0,d+144|0)){a=ba(8)|0;v[22708]=0;c=Q(70,d+320|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=uc(d+272|0,4506);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;h:{if(!Gc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=uc(d+256|0,4488);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Gc(d+120|0,d+112|0)){break h}}e=w[a+60|0]!=0;break g}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=uc(d+240|0,3991);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;i:{if(!Gc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=uc(d+224|0,3972);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Gc(d+88|0,d+80|0)){break i}}e=w[a+61|0]!=0;break g}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=uc(d+208|0,4075);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break g}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=uc(d+192|0,3156);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break g}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=uc(d+176|0,4555);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break g}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=uc(d+160|0,10720);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Gc(d+24|0,d+16|0)){break g}e=v[v[a+24>>2]+24668>>2]!=0}gb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c)}ca(a|0)}S(b|0)}L()}function vP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;f=a+1074376|0;g=B(b,872);d=(f+g|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(Kj(d)){a=B(b,872)+a|0;u[a+1075764>>1]=e-8;a=a+1075843|0;t[a|0]=w[a|0]|32;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=e<<28>>24;c=x[(e<<1)+39728>>1];v[b+1075696>>2]=c;d=b+1075692|0;if(!v[d>>2]){break a}k=d,l=_g(a,w[b+1075789|0],e<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){t[(B(b,872)+a|0)+1075814|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){t[(B(b,872)+a|0)+1075817|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1298260|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,872)+a|0;c:{if((i|0)!=x[c+1075778>>1]){break c}d:{e:{switch(j|0){case 0:Co(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!Dd(d)){break d}uk(v[d>>2],e&65535);break d;case 1:g=c+1075080|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!Dd(d)){break d}uk(v[d>>2],e&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!Dd(d)){break d}Qi(v[d>>2],e&65535,1)}f=v[c+1075648>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}kb[v[v[g>>2]+92>>2]](g,f,w[c+1075789|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}kB(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Pm(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=ce(d+788|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=d;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=e;f=h+8|0;Db(f,a+1074312|0,35);if(Cb(f)){break a}if(!ce(c+1075780|0)){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}su(a,f,d,e);break a;case 11:i:{if(e){break i}e=1;if(v[a+480180>>2]&16777248){break i}e=0;if(v[a+480180>>2]==2){break a}}d=h+8|0;Db(d,a+1074312|0,30);c=a;if(Cb(d)){a=1}else{a=v[a+480180>>2]==2}rA(c,b,e,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=e}gb=h+16|0}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-288|0;gb=e;d=e+128|0;f=d;g=gb-48|0;gb=g;h=g+24|0;OC(h,b);v[22708]=0;Nr(g+16|0,h);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[22708]=0;b=v[g+20>>2];v[g+8>>2]=v[g+16>>2];v[g+12>>2]=b;R(640,f|0,g+8|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}zc(g+24|0);gb=g+48|0;break a}a=P()|0;O()|0;zc(g+24|0);S(a|0);L()}v[22708]=0;R(610,e+24|0,d|0);b=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((b|0)!=1){v[22708]=0;g=W(100,e+144|0,e+24|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break D}vb(e+24|0);gc(e+128|0);if(c>>>0<2189){break i}v[22708]=0;b=Q(619,e+24|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break e}v[22708]=0;c=Q(620,e+8|0,7394)|0;d=v[22708];v[22708]=0;if((d|0)==1){break B}v[22708]=0;v[e>>2]=19923026;v[e+4>>2]=0;U(621,b|0,c|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break A}Hb(c);t[e|0]=0;v[22708]=0;c=Q(620,e+8|0,8280)|0;d=v[22708];v[22708]=0;if((d|0)==1){break k}d=0;v[22708]=0;W(622,b|0,e|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break z}Hb(c);if(!w[e|0]){v[22708]=0;d=Jk(a);c=v[22708];v[22708]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[22708]=0;c=Q(620,e+8|0,12908)|0;h=v[22708];v[22708]=0;if((h|0)==1){break x}v[22708]=0;Y(624,b|0,f|0,c|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}Hb(c);v[22708]=0;c=Q(620,e+8|0,12589)|0;f=v[22708];v[22708]=0;if((f|0)==1){break v}v[22708]=0;Y(625,b|0,a|0,c|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break u}Hb(c);v[22708]=0;c=Q(620,e+8|0,12482)|0;d=v[22708];v[22708]=0;if((d|0)==1){break t}v[22708]=0;d=a+484360|0;U(626,b|0,d|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break s}Hb(c);v[22708]=0;c=Q(620,e+8|0,28870)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;U(627,b|0,a+484344|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}Hb(c);v[22708]=0;f=Jk(a);c=v[22708];v[22708]=0;if((c|0)==1){break p}v[22708]=0;c=Q(620,e+8|0,28876)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}v[22708]=0;Y(628,b|0,d|0,c|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}Hb(c);if(v[b>>2]&1073741824){v[22708]=0;c=Q(2,e+8|0,13382)|0;d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;U(560,a|0,1,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}vb(c)}gh(b);break h}a=P()|0;O()|0;break C}a=P()|0;O()|0;vb(e+24|0)}gc(e+128|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0}gh(b);break d}b=Kb(e+24|0);d=v[a+4>>2];v[22708]=0;f=Jk(a);h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;d=da(629,d|0,g|0,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break g}E:{if((d|0)!=1){v[22708]=0;c=Q(2,e+8|0,13688)|0;d=v[22708];v[22708]=0;F:{if((d|0)!=1){v[22708]=0;U(560,a|0,1,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break F}vb(c);break E}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22708]=0;d=Jk(a);f=v[22708];v[22708]=0;if((f|0)==1){break g}v[22708]=0;Y(630,g|0,a|0,d|0,c>>>0<2188|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}}vb(b)}wf(g);gb=e+288|0;return}a=P()|0;O()|0}vb(b);break d}a=P()|0;O()|0}wf(g)}S(a|0);L()}function xg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=gb-112|0;gb=k;l=h;o=i&2147483647;n=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(n|0)==-1;r=d;p=(c|0)==(n|0)&b>>>0>j>>>0|c>>>0>n>>>0;m=d+p|0;n=e&2147483647;j=n;j=m>>>0<p>>>0?j+1|0:j;p=m-1|0;a:{b:{j=j-(m>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;m=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(m|0)!=-1;p=(g|0)==(m|0)&f>>>0>j>>>0|g>>>0>m>>>0;m=p+l|0;j=o;j=m>>>0<p>>>0?j+1|0:j;p=m;m=m-1|0;j=j-(p>>>0<1)|0;if((m|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(m|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(n|0)==2147418112?!(b|c):n>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(n^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|n))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}j=(n|0)==(o|0);q=j&(l|0)==(r|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:j&l>>>0>r>>>0|n>>>0<o>>>0;j=q;m=j?f:b;o=j?g:c;l=j?i:e;r=l;n=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|n);i=d<<6;l=E(d?m:n)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;Lf(k+96|0,m,o,n,j,d-15|0);n=v[k+104>>2];m=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Lf(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=n;d=j<<3|b>>>29;n=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}Lf(k- -64|0,b,c,h,i,128-d|0);om(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=n;p=s|524288;b=m;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1|(q|0)<=-1){o=e;b=c-e|0;n=h;m=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=m-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<n>>>0)+i|0)|0)-(e>>>0>m>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;Lf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=e>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);e=h;c=e<<31|c>>>1;l=l+1|0;h=(i&1)<<31|e>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}e=0;e:{if((l|0)>0){e=l;break e}Lf(k+16|0,b,c,h,i,l+127|0);om(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2]}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;f:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;gb=k+112|0}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-176|0;gb=e;se(e+160|0,b);m=a;l=c;h=d;j=gb-48|0;gb=j;v[j+44>>2]=0;f=b;Hk(f,j+44|0);a:{b:{c:{if(v[j+44>>2]!=(An(11379)|0)){break c}v[j+40>>2]=0;g=gb-32|0;gb=g;v[g+28>>2]=0;cX(g+8|0,g+28|0);i=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=i;i=g+16|0;nt(i,f,g);yb(i);v[g+16>>2]=v[g+28>>2];v[j+40>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);gb=g+32|0;g=-1;i=v[j+40>>2];if(i-1>>>0>1){break c}d:{e:{f:{if((i|0)<=1){i=Kb(j+24|0);v[22708]=0;k=W(653,f|0,i|0,256)|0;n=v[22708];v[22708]=0;if((n|0)==1){break b}if(!k){break e}v[22708]=0;U(13,j+8|0,h|0,i|0);k=v[22708];v[22708]=0;if((k|0)!=1){break f}break b}i=Kb(j+24|0);v[22708]=0;k=W(655,f|0,i|0,255)|0;n=v[22708];v[22708]=0;if((n|0)==1){break b}if(!k){break d}v[22708]=0;U(13,j+8|0,h|0,i|0);k=v[22708];v[22708]=0;if((k|0)==1){break b}}k=l;l=j+8|0;Eb(k,l);vb(l);vb(i);i=0;u[j+8>>1]=0;ag(f,l);v[j+24>>2]=0;Hk(f,j+24|0);l=v[j+24>>2];if(l>>>0>50){break c}if(l){while(1){if(!aN(m,f,h)){break c}i=i+1|0;if(i>>>0<y[j+24>>2]){continue}break}}v[j+24>>2]=0;Hk(f,j+24|0);g=v[j+24>>2]==(An(11417)|0)?1:-1;break c}vb(i);break c}vb(i)}gb=j+48|0;f=g;break a}a=P()|0;O()|0;vb(i);S(a|0);L()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!f){no(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;jk(b,e);b=Hm(e+56|0,b);v[22708]=0;f=Q(620,e+40|0,11505)|0;h=v[22708];v[22708]=0;if((h|0)==1){break h}v[22708]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(621,b|0,f|0,e+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break i}Hb(f);t[e+31|0]=0;v[22708]=0;f=Q(620,e+40|0,11945)|0;h=v[22708];v[22708]=0;if((h|0)==1){break j}v[22708]=0;W(622,b|0,e+31|0,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break k}Hb(f);v[22708]=0;f=w[e+31|0];h=T(1522,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}v[22708]=0;g=T(1523,b|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break m}v[e+32>>2]=g;v[e+24>>2]=h;if(Gb(e+24|0,e+32|0)){f=f?0:d;while(1){u[e+22>>1]=65535;v[22708]=0;d=Q(620,e+40|0,12908)|0;h=v[22708];v[22708]=0;if((h|0)==1){break p}v[22708]=0;h=W(1524,b|0,e+24|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}Hb(d);s:{if(!h){v[22708]=0;Y(1525,b|0,e+24|0,c|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}break s}v[22708]=0;d=Q(620,e+40|0,12589)|0;h=v[22708];v[22708]=0;t:{u:{if((h|0)!=1){v[22708]=0;h=W(1524,b|0,e+24|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break u}Hb(d);if(h){break t}v[22708]=0;U(1526,b|0,e+24|0,e+22|0);d=v[22708];v[22708]=0;if((d|0)!=1){break s}break n}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}v[22708]=0;d=Q(620,e+40|0,12482)|0;h=v[22708];v[22708]=0;if((h|0)==1){break r}v[22708]=0;h=W(1524,b|0,e+24|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break q}Hb(d);if(h){break s}v[22708]=0;Y(1527,b|0,e+24|0,a|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}}d=e+24|0;Zo(d);if(Gb(d,e+32|0)){continue}break}}a=v[b>>2];gh(b);f=a&1073741824?-1:1}gb=e+176|0;return f|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0}gh(b);S(a|0);L()}function y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-160|0;gb=d;vc(b);rs(a);f=gb-32|0;gb=f;e=f+24|0;j=d+120|0;pF(e,j);h=yb(e);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;g=f+16|0;e=b;cc(g,e,f);g=yb(g);if((g|0)==(h|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(h|0);if(!e){qF(j)}a:{if(!e){break a}if(!YN(d+120|0)){break a}h=b;g=0;k=Nf(10441);if(k){p=v[h+8>>2];if(Wc(h,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){b:{if(!(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))){break b}while(1){if(!Pb(h,5)){break b}c:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((Mi(h)|0)<1){break c}}g=0;f=1;while(1){e=Ae(h);if(e){q=Yq(e<<24>>24);m=g>>>0>=k>>>0;j=m&f;e=j;d:{if(m){break d}e=j;if(!(f&1)){break d}e=w[g+10441|0]==(q&255)}f=e;g=g+1|0;continue}break}Rb(h,4);i=(g|0)==(k|0)?f?1:i:i}n=n+1|0;if(n>>>0<(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0){continue}break}}g=i&1}Wc(h,p)}if(!g){break a}if(!Pb(b,XN(d+120|0))){break a}if(!c){l=1;break a}f=gb-16|0;gb=f;c=b;j=d+120|0;e=j;Wc(c,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));g=d+104|0;h=mc(g);i=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[22708]=0;R(1422,h|0,i|0);i=v[22708];v[22708]=0;e:{f:{g:{if((i|0)!=1){h:{i:{j:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break j}while(1){v[22708]=0;i=Q(191,c|0,5)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}if(!i){break j}i=w[e+4|0]|w[e+5|0]<<8;v[22708]=0;U(1423,f|0,c|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break i}v[22708]=0;R(1424,h|0,f|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}vb(f);o=o+1|0;if(o>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}gb=f+16|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(f);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}yd(h);S(a|0);L()}v[22708]=0;Y(273,d+88|0,b|0,j|0,g|0);c=v[22708];v[22708]=0;k:{l:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22708]=0;Q(190,b|0,c|0)|0;c=v[22708];v[22708]=0;m:{if((c|0)!=1){if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break k}h=d+36|0;n:{o:{p:{q:{while(1){v[22708]=0;c=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;r:{if((e|0)!=1){if(c){break r}break k}b=P()|0;O()|0;break m}v[22708]=0;ka(274,d- -64|0,b|0,d+120|0,d+88|0,d+104|0,10441);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=d- -64|0;f=T(275,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}e=c;if(f){v[22708]=0;f=T(276,d+24|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break p}j=v[c+20>>2];s:{if((j|0)<0){break s}if(Ec(d+104|0)>>>0<=j>>>0){break s}c=Ad(d+104|0,v[c+20>>2]);v[22708]=0;U(13,d+8|0,2,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break o}c=d+8|0;Eb(d+24|0,c);vb(c)}Ew(h,e);v[22708]=0;R(277,a|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break o}Lw(f)}xb(d- -64|0);l=l+1|0;if(l>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break k}break}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break n}b=P()|0;O()|0;Lw(f)}xb(d- -64|0);break m}b=P()|0;O()|0}Lc(d+88|0);break l}b=P()|0;O()|0}yd(d+104|0);S(b|0);L()}l=cd(a)^1;Lc(d+88|0);yd(d+104|0)}gb=d+160|0;return l|0}function I1(){var a=0,b=0,c=0;Wd(465832);v[116458]=83656;v[22708]=0;X(2528);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;Q(70,465984,11509)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}Od(465840);Wd(465520);v[116380]=84980;v[22708]=0;X(2529);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465528);v[116382]=85012;v[22708]=0;X(2530);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465536);v[116384]=83676;t[465548]=0;v[116386]=0;b=465544,c=Xp(),v[b>>2]=c;v[22708]=0;X(2531);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465552);v[116388]=84160;v[22708]=0;X(2532);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465560);v[116390]=84308;v[22708]=0;X(2533);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2534);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2535);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465584);v[116396]=84456;v[22708]=0;X(2536);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465592);v[116398]=84572;v[22708]=0;X(2537);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465600);u[232804]=11310;v[116400]=83776;Kb(465612);v[22708]=0;X(2538);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465624);v[116408]=46;v[116409]=44;v[116406]=83816;Kb(465640);v[22708]=0;X(2539);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465656);v[116414]=85044;v[22708]=0;X(2540);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465664);v[116416]=85288;v[22708]=0;X(2541);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465672);v[116418]=85500;v[22708]=0;X(2542);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465680);v[116420]=85732;v[22708]=0;X(2543);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465688);v[116422]=86716;v[22708]=0;X(2544);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465696);v[116424]=86864;v[22708]=0;X(2545);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465704);v[116426]=86980;v[22708]=0;X(2546);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465712);v[116428]=87096;v[22708]=0;X(2547);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465720);v[116430]=87212;v[22708]=0;X(2548);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465728);v[116432]=87376;v[22708]=0;X(2549);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465736);v[116434]=87540;v[22708]=0;X(2550);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465744);v[116436]=87704;v[22708]=0;X(2551);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465752);v[116440]=88960;v[116440]=85980;v[116438]=85932;v[22708]=0;X(2552);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465768);v[116444]=88996;v[116444]=86244;v[116442]=86196;v[22708]=0;X(2553);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2554);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2555);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2556);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2557);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465816);v[116454]=87868;v[22708]=0;X(2558);a=v[22708];v[22708]=0;if((a|0)==1){break d}Wd(465824);v[116456]=87988;v[22708]=0;X(2559);a=v[22708];v[22708]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(465984)}px(465840)}S(a|0);L()}v[116058]=465832}function $L(a){var b=C(0),c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=C(0),j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=C(0),u=C(0),w=0,x=0,y=C(0);m=gb-16|0;gb=m;w=a,x=Jj(C(z[a+4256>>2]*C(3))),v[w+4264>>2]=x;w=a,y=C(xf(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[w+4268>>2]=y;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);w=m,y=oe(C(10),C(C(_L(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[w+12>>2]=y;v[m+8>>2]=1065353216;w=a,y=C(z[Gm(m+12|0,m+8|0)>>2]*C(.7609999775886536)),z[w+4280>>2]=y;h=a;b=oe(C(10),C(C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(b!=C(1)){c=Pp(C(C(ZL(a)*C(6.2831854820251465))/z[a+4268>>2]));j=C(b*b);k=C(K(C(C(C(C(b*C(8))+C(c*C(C(c*j)*C(4))))-C(j*C(4)))-C(C(b*c)*C(8)))));b=C(b+b);k=Go(C(C(k+C(C(c*b)+C(-2)))/C(b+C(-2))),C(0),C(1))}else{k=C(0)}z[h+4276>>2]=k;l=gb-16|0;gb=l;e=a;b=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[l+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[l+8>>2]=1000593162;h=a;j=z[az(l+12|0,l+8|0)>>2];i=C(b*C(C(c+j)+C(.007000000216066837)));a:{if(C(D(i))<C(2147483648)){f=~~i;break a}f=-2147483648}v[h+4352>>2]=f;d=1;while(1){h=((B(d&1,24)+e|0)+(d<<1&-4)|0)+4352|0;i=C(b*C(c+C(j*z[(d<<2)+52736>>2])));b:{if(C(D(i))<C(2147483648)){f=~~i;break b}f=-2147483648}v[h>>2]=f;d=d+1|0;if((d|0)!=12){continue}break}z[l+12>>2]=C(C(C(z[e+4248>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353);v[l+8>>2]=1065353216;c=z[Gm(l+12|0,l+8|0)>>2];j=C(b*C(C(c*C(75))/C(1e3)));c=C(b*C(C(c*C(67))/C(1e3)));d=0;while(1){p=(d<<2)+e|0;h=p+4316|0;q=d+q|0;i=oe(C(.9300000071525574),C(q|0));g=C(j*i);c:{if(C(D(g))<C(2147483648)){f=~~g;break c}f=-2147483648}v[h>>2]=f;h=p+4292|0;i=C(c*i);d:{if(C(D(i))<C(2147483648)){f=~~i;break d}f=-2147483648}v[h>>2]=f;d=d+1|0;if((d|0)!=6){continue}break}h=e+4348|0;c=C(b*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){f=~~c;break e}f=-2147483648}v[h>>2]=f;h=e+4344|0;c=C(b*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){f=~~c;break f}f=-2147483648}v[h>>2]=f;h=e+4340|0;b=C(b*C(.009999999776482582));g:{if(C(D(b))<C(2147483648)){f=~~b;break g}f=-2147483648}v[h>>2]=f;d=0;while(1){aM((B(d,24)+e|0)+4504|0,v[((d<<2)+e|0)+4292>>2]);d=d+1|0;if((d|0)!=15){continue}break}gb=l+16|0;d=gb-16|0;gb=d;b=th(a,5);c=th(a,11);k=C(C(b*C(.02250000089406967))+C(0));b=C(b*th(a,4));j=C(k+C(b*C(.03999999910593033)));k=C(C(c*C(.02250000089406967))+C(0));c=C(c*th(a,10));i=C(k+C(c*C(.03999999910593033)));if(t[a+4264|0]&1){g=th(e,3);n=th(e,9);g=C(b*g);b=C(g*th(e,2));j=C(C(j+C(g*C(.12250000238418579)))+C(b*C(.1444000005722046)));g=C(c*n);c=C(g*th(e,8));i=C(C(i+C(g*C(.12250000238418579)))+C(c*C(.1444000005722046)))}th(e,12);g=z[e+4496>>2];n=th(e,1);o=th(e,7);s=th(e,0);u=th(e,6);w=d,y=oe(C(10),C(C(_L(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[w+12>>2]=y;v[d+8>>2]=1065353216;r=z[Gm(d+12|0,d+8|0)>>2];k=b;b=C(g*g);g=C(n*C(k*b));n=C(s*g);b=C(o*C(c*b));c=C(u*b);o=C(C(C(n+c)*C(-.5))+C(1));z[e+4284>>2]=r*C(K(C(o/C(C(j+C(b*C(.1444000005722046)))+C(n*C(.1444000005722046))))));z[e+4288>>2]=r*C(K(C(o/C(C(i+C(g*C(.1444000005722046)))+C(c*C(.1444000005722046))))));gb=d+16|0;t[a+5046|0]=0;gb=m+16|0}function bO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{b:{if(b){f=a+327720|0;b=gb-400|0;gb=b;LR(b+384|0,8);v[22708]=0;ta(1108,b+368|0,9);g=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((g|0)!=1){v[22708]=0;g=Q(1109,b+352|0,14)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;R(1110,b+384|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;R(1110,b+368|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}KR(b+280|0,4900);KR(b+208|0,32e3);GR(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22708]=0;d=Q(1111,b+104|0,b+384|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break l}Du(b+120|0,b+280|0,d);Mf(d);v[22708]=0;d=Q(1111,b+72|0,b+368|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break k}Du(b+88|0,b+208|0,d);Mf(d);v[22708]=0;d=Q(1111,b+40|0,b+120|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}Du(b+56|0,b+136|0,d);Mf(d);v[22708]=0;e=Q(1111,b+8|0,b+88|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break i}d=b+24|0;Du(d,b+136|0,e);Mf(e);e=b+120|0;Oq(e);j=b+56|0;Oq(j);k=b+88|0;Oq(k);Oq(d);m=b+368|0;Oq(m);Nq(e,Hj(f,0));Nq(j,Hj(f,1));Nq(k,Hj(f,2));Nq(d,Hj(f,3));Nq(m,Hj(f,4));Mf(d);Mf(j);Mf(k);Mf(e);Mq(g);Mf(m);Mf(b+384|0);gb=b+400|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;Mf(b+56|0)}Mf(b+88|0)}Mf(b+120|0)}Mq(g)}Mf(b+368|0)}Mf(b+384|0);S(a|0);L()}Iz(a+131112|0,9.6377,.97);Iz(a+196648|0,8.5,.5);Iz(a+262184|0,2.7625,.425);Hz(a+368680|0,a);break b}if(Hz(a+368680|0,a)){break a}}e=a+24|0;p=A[a+8>>3];f=w[a+16|0];d=gb+-64|0;gb=d;while(1){q=+(l-4096|0)*.0001220703125;n=0;b=0;while(1){i=p;g=f;h=1;c=+(b|0)-q;o=c+-3.5;if(!(D(o)<1e-8)){o:{p:{switch(g|0){case 0:h=.5-Le(c*.8975979010256552)*.5;break o;case 1:h=Le(c*.8975979010256552)*-.46+.54;break o;case 2:h=Le(c*1.7951958020513104)*.08+(Le(c*.8975979010256552)*-.5+.42);break o;case 3:h=Le(c*1.7951958020513104)*.05677+(Le(c*.8975979010256552)*-.49364+.44959);break o;case 4:h=Le(c*1.7951958020513104)*.07922+(Le(c*.8975979010256552)*-.49755+.42323);break o;case 5:h=Le(c*1.7951958020513104)*.14128+(Le(c*.8975979010256552)*-.48829+.35875)+Le(c*2.6927937030769655)*-.01168;break o;case 6:h=Le(c*1.7951958020513104)*.09392+(Le(c*.8975979010256552)*-.49703+.40217)+Le(c*2.6927937030769655)*-.00183;break o;case 7:break p;default:break o}}h=Le(c*1.7951958020513104)*.09831+(Le(c*.8975979010256552)*-.49804+.40243)+Le(c*2.6927937030769655)*-.00122}c=o*3.141592653589793;i=si(c*i)/c}i=h*i;A[d+(b<<3)>>3]=i;n=n+i;b=b+1|0;if((b|0)!=8){continue}break}i=1/n;j=l<<3;b=0;while(1){k=e+(b+j<<1)|0;c=H(i*(A[d+(b<<3)>>3]*32768)+.5);c=c<-32768?-32768:F(c,32768);q:{if(D(c)<2147483648){g=~~c;break q}g=-2147483648}u[k>>1]=g;b=b+1|0;if((b|0)!=8){continue}break}l=l+1|0;if((l|0)!=8193){continue}break}gb=d- -64|0;f=v[a+20>>2];b=a+368696|0;v[b>>2]=v[a+16>>2];v[b+4>>2]=f;f=v[a+12>>2];b=a+368688|0;v[b>>2]=v[a+8>>2];v[b+4>>2]=f;b=v[a+4>>2];v[a+368680>>2]=v[a>>2];v[a+368684>>2]=b}}function aqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-736|0;gb=e;vc(b);g=gb-32|0;gb=g;f=g+24|0;k=e+120|0;AY(f,k);i=yb(f);f=v[g+28>>2];j=v[g+24>>2];v[g+8>>2]=j;v[g+12>>2]=f;v[g>>2]=j;v[g+4>>2]=f;j=g+16|0;f=b;cc(j,f,g);j=yb(j);if((j|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){zY(k)}a:{if(!f){break a}if(!CY(e+120|0)){break a}b:{if(!c){break b}Hd(a,67108864);Ag(a);d=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Tb(e,5312);Eb(a+1298304|0,d);vb(d);d=Tb(e,8058);Eb(a+1298316|0,d);vb(d);d=e+96|0;Ef(d,1283);v[e+72>>2]=w[e+144|0]>>>4;f=w[e+144|0];v[22708]=0;v[e+116>>2]=f&15;Y(460,e|0,d|0,e+72|0,e+116|0);d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){Eb(a+1298328|0,e);vb(e);Hb(e+96|0);v[a+1298364>>2]=2;Dr(Sb(a+484360|0),e+168|0,w[e+167|0]+1|0);while(1){d=h+1|0;g=B(d,104)+a|0;i=g+484380|0;ud(i,1);f=(e+120|0)+(h<<2)|0;o=i,p=Xb(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[o>>2]=p;k=Xb(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=k;o=g+484388|0,p=Xb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))+k|0,v[o>>2]=p;if(Xb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))){f=g+484414|0;u[f>>1]=x[f>>1]|2}wk(i);h=(e+120|0)+h|0;t[e|0]=w[h+548|0];t[e+96|0]=64;o=g+484410|0,p=w[ac(e,e+96|0)|0]<<2,u[o>>1]=p;t[g+484417|0]=w[h+579|0]<<4;h=d;if((d|0)!=31){continue}break}Rv(b,a+1298268|0,32);d=1;while(1){BY(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}j=c&1;if(j){zg(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;d=0;e:{while(1){f=d;g=Jh(e+96|0);f:{if(w[e+146|0]){v[22708]=0;d=T(416,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break e}v[22708]=0;U(288,e+72|0,b|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}break f}d=x[a+480188>>1];v[22708]=0;U(288,e+72|0,b|0,d<<8);d=v[22708];v[22708]=0;if((d|0)==1){break d}}d=e+72|0;Vc(g,kc(e,d));xb(e);xb(d);g:{if(!j){break g}v[22708]=0;d=W(331,k|0,f&65535,64)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!d){break g}if(!w[e+146|0]){h=0;if(!x[a+480188>>1]){break g}while(1){d=0;while(1){i=_b(k,f);v[22708]=0;i=Yc(i,d,h&65535);l=v[22708];v[22708]=0;if((l|0)==1){break d}v[22708]=0;R(461,g|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break d}d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break g}i=0;v[22708]=0;R(462,g|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}while(1){d=_b(k,f);v[22708]=0;l=Tf(d,i);d=v[22708];v[22708]=0;if((d|0)==1){break d}if(x[a+480188>>1]){m=e+i|0;d=128;h=0;while(1){h:{if(!(w[m|0]&d)){break h}v[22708]=0;R(461,g|0,l+B(h,6)|0);n=v[22708];v[22708]=0;if((n|0)!=1){break h}break d}d=d>>>1|0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}d=f+1|0;xb(e+96|0);if(f>>>0<w[e+166|0]){continue}break}d=1;if(!(c&2)){break a}c=Rc(e,8,1,1,0);while(1){Cg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}break d}d=P()|0;O()|0;Hb(e+96|0);break c}d=P()|0;O()|0;xb(e+96|0)}S(d|0);L()}d=1}gb=e+736|0;return d|0}function Yb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116507]){break a}a=a+b|0;if(v[116508]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=466012,j=v[116503]&rqa(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+466316|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=466016,j=v[116504]&rqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116505]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116509]==(f|0)){v[116509]=d;a=v[116506]+a|0;v[116506]=a;v[d+4>>2]=a|1;if(v[116508]!=(d|0)){break a}v[116505]=0;v[116508]=0;return}if(v[116508]==(f|0)){v[116508]=d;a=v[116505]+a|0;v[116505]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=466012,j=v[116503]&rqa(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+466316|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=466016,j=v[116504]&rqa(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116508]!=(d|0)){break f}v[116505]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;k:{if(!(c&a)){v[116503]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+466316|0;l:{m:{c=v[116504];b=1<<e;n:{if(!(c&b)){v[116504]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116511]-1|0;v[116511]=a?a:-1}}function iX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-128|0;gb=g;j=Ik(g+112|0);a:{b:{c:{if(d){v[22708]=0;U(645,a|0,j|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}break b}v[22708]=0;U(646,a|0,j|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}}k=mc(g+96|0);if(x[b+480192>>1]){d=1;c=1;while(1){v[22708]=0;u[g+94>>1]=0;Q(647,a|0,g+94|0)|0;f=v[22708];v[22708]=0;d:{e:{f:{if((f|0)!=1){l=gb-16|0;gb=l;p=l+8|0;i=gb-16|0;gb=i;f=j;m=f;o=g+94|0;q=o;e=Xd(f);h=fc(f);n=gb-16|0;gb=n;if(e){wb(m);while(1){m=MC(e+16|0,q);h=m?h:e;e=v[(m?4:0)+e>>2];if(e){continue}break}}e=v[yc(n+8|0,h)>>2];gb=n+16|0;v[i+8>>2]=e;r=i,s=Ch(f),v[r>>2]=s;g:{if(Gb(i+8|0,i)){if(!NC(wb(f),o,ue(i+8|0))){break g}}e=Ch(f)}gb=i+16|0;f=v[yc(p,e)>>2];gb=l+16|0;v[g+88>>2]=f;i=((d<<2)+b|0)+900380|0;if(!v[i>>2]){break d}r=g,s=Dh(j),v[r+72>>2]=s;if(og(g+88|0,g+72|0)){d=ue(g+88|0);v[22708]=0;d=Q(4,g+72|0,d+4|0)|0;f=v[22708];v[22708]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)!=1){v[22708]=0;f=Q(2,g+56|0,13855)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}e=ur(d,f);vb(f);if(e){break r}f=v[b+4>>2];v[22708]=0;f=Q(648,f|0,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break x}v[v[i>>2]+44>>2]=f;if(!v[v[i>>2]+44>>2]){break y}break e}b=P()|0;O()|0;break f}v[22708]=0;f=Q(2,g+56|0,10751)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}z:{A:{if(ur(d,f)){vb(f);break A}v[22708]=0;e=Q(2,g+40|0,10963)|0;h=v[22708];v[22708]=0;if((h|0)==1){break v}h=ur(d,e);vb(e);vb(f);if(!h){break z}}v[22708]=0;f=T(649,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}v[g+56>>2]=f;f=v[b+4>>2];qi(g+32|0,g+56|0);v[22708]=0;f=Q(650,f|0,v[g+32>>2])|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}Ig(g+56|0);if(f){break e}}h=Vb(k);l=Zb(k);f=d;e=gb-16|0;gb=e;v[e>>2]=l;v[e+8>>2]=h;if(Gb(e+8|0,e)){while(1){if(!ur(v[e+8>>2],f)){h=e+8|0;rr(h);if(Gb(h,e)){continue}}break}h=v[e+8>>2]}gb=e+16|0;v[g+56>>2]=h;r=g,s=Zb(k),v[r+40>>2]=s;if(Gb(g+56|0,g+40|0)){break r}v[22708]=0;R(651,k|0,d|0);f=v[22708];v[22708]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(f);break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;Ig(g+56|0);break h}v[22708]=0;f=Q(2,g+16|0,14557)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}v[22708]=0;U(652,g+40|0,f|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break p}v[22708]=0;e=Q(2,g|0,13431)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}v[22708]=0;U(3,g+56|0,g+40|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;U(560,b|0,2,g+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break m}vb(g+56|0);vb(e);vb(g+40|0);vb(f)}v[v[i>>2]+44>>2]=0;break e}b=P()|0;O()|0;break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(g+56|0)}vb(e)}vb(g+40|0)}vb(f);break h}b=P()|0;O()|0}vb(d);break f}if(!v[i>>2]){break d}v[v[i>>2]+44>>2]=0;break d}b=P()|0;O()|0}sm(k);break a}vb(d)}c=c+1|0;d=c&65535;if(d>>>0<=x[b+480192>>1]){continue}break}}sm(k);dX(j);gb=g+128|0;return}b=P()|0;O()|0}dX(j);S(b|0);L()}function pA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0;h=gb-16|0;gb=h;i=B(b,872)+a|0;l=i+1075800|0;j=w[l|0];e=h+8|0;k=a+1074312|0;Db(e,k,23);g=c&15;a:{b:{c:{if(Cb(e)){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[l|0]=g;e=0;break c}e=w[l|0];if(e){f=e-1|0;t[l|0]=f;e=0;if(f&255){break c}}t[l|0]=g;e=1;break c}e=h+8|0;Db(e,k,52);f=c&256;if(!(!Cb(e)|!f)){d:{if(!(w[a+480209|0]&16)){break d}e=B(b,872)+a|0;if(w[e+1075781|0]){j=XC(e+1075780|0)?1:j}if(w[e+1075782|0]!=1){break d}if(w[(B(b,872)+a|0)+1075784|0]){break b}}e=0;if((j&255)>>>0<g>>>0){break c}if(w[a+480209|0]&16){if(ce((B(b,872)+a|0)+1075780|0)){break c}}j=0;e=1;break c}if(v[a+480180>>2]&16777250){e=j&255;if(e){e=(e>>>0)%((g?g:1)>>>0)|0}else{e=1}e=!e;j=j+1|0;break c}if(v[a+480180>>2]==1){f=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!f){if(ce((B(b,872)+a|0)+1075780|0)){break a}}e=0;e=g?!((f>>>0)%(g>>>0)|0):e;break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}e:{f:{g:{h:{i:{if(f){e=B(b,872)+a|0;if(w[e+1075782|0]==1){g=(w[e+1075785|0]>15)+g|0}g=g?g:1;break i}if(w[a+480209|0]&16){break f}g=g?g:1;if(v[a+1074416>>2]){break h}}e=0;break g}e=!(y[a+1074392>>2]%(g>>>0)|0)}j=j+1|0;break e}e=0;j=v[a+480180>>2]&1048580?0:j}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!f?v[a+1074392>>2]:1)|(j&255)<(g|0))){e=1}g=h+8|0;Db(g,k,52);if(!Cb(g)|c){break c}e=!v[a+1074392>>2]}g=i+1074992|0;i=(B(b,872)+a|0)+1075068|0;j:{if(v[i>>2]){break j}f=h+8|0;Db(f,k,38);if(!Cb(f)){break j}if(!sk(g)){break a}}f=h+8|0;Db(f,k,106);if(z=0,A=Cb(f),C=v[(B(b,872)+a|0)+1075688>>2],C?z:A){break a}if(e){f=B(b,872)+a|0;p=f+1075680|0;v[h+4>>2]=v[p>>2];e=c>>>4&15;if(e){m=h+8|0;Db(m,k,52);k:{if(z=Cb(m),A=0,C=w[(B(b,872)+a|0)+1075782|0]==1,C?z:A){break k}if(!(16191>>>e&1)){v[h+4>>2]=(B(v[h+4>>2],t[e+40144|0])|0)/16;break k}v[h+4>>2]=v[h+4>>2]+(t[e+40160|0]<<2)}Yd(h+4|0,0,256);e=(B(b,872)+a|0)+1075080|0;v[e>>2]=v[e>>2]|2097152}q=f+1075692|0;m=v[q>>2];e=w[f+1075794|0];l:{if(!v[i>>2]|(e-1&255)>>>0>119){break l}if(!(!(w[(B(b,872)+a|0)+1075081|0]&2)|v[a+480180>>2]!=2)){f=h+8|0;Db(f,k,108);if(!Cb(f)){break l}}CP(a,b,0,e,1)}f=0;m:{if(!(v[a+480180>>2]&1048580)){break m}i=w[(B(b,872)+a|0)+1075781|0];f=(c|0)<256;if(!i|(c|0)>255){break m}Eo(a,g,i,0,0,1);f=1}i=B(b,872)+a|0;n=i+1075652|0;s=v[n>>2];v[n>>2]=0;o=i+1075080|0;u=v[o>>2];r=h+8|0;Db(r,k,23);ru(a,g,e,Cb(r),f,0,b);if(!w[i+1075781|0]){v[n>>2]=s}if(!(!(u&4096)|v[a+480180>>2]!=4)){v[o>>2]=v[o>>2]|4096}f=i+1075780|0;v[p>>2]=v[h+4>>2];if(x[a+480192>>1]){t[f|0]=e;kO(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[f|0]|!m))){v[q>>2]=m}e=v[a+480180>>2];f=h+8|0;Db(f,k,23);if(Cb(f)){v[g>>2]=0;v[g+4>>2]=0}e=e&16777250;f=(B(b,872)+a|0)+1075096|0;n:{if(!v[f>>2]|(d|0)<1){break n}i=d-1|0;if((i|0)>9){break n}o:{if(!i){b=v[(B(b,872)+a|0)+1075656>>2];break o}i=(B(b,872)+a|0)+1075656|0;b=v[Pe(v[f>>2]+68|0,d-2|0)>>2];v[i>>2]=b}Om(a,g,b)}j=e?j:0}a=h+8|0;Db(a,k,52);b=Cb(a);Db(a,k,23);if(Cb(a)){break a}j=(b&(c&256)>>>8)+j|0}t[l|0]=j}gb=h+16|0}function Kka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=gb-4144|0;gb=f;a:{b:{if(!Ib(w[a+14|0]|w[a+15|0]<<8)){break b}i=a;if(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0>20|x[b+480190>>1]<=w[a+23|0]){break b}ud(d,32);u[d+34>>1]=1;h=f+24|0;g=h;a=a+20|0;td(g,a,a+80|0);a=f+4136|0;OT(a,g,Ib(w[i+14|0]|w[i+15|0]<<8));j=Ak(b,w[Mb(a,0)+3|0]+1|0);v[f+24>>2]=1;n=1/+y[Mc(j+24|0,g)>>2];if(c){j=ar(f+4136|0)}else{j=1}OT(g,a,j);a=v[h>>2];g=v[h+4>>2];if((a|0)!=(g|0)){while(1){if(!(t[a+1|0]<0|x[b+480190>>1]<=w[a+3|0])){h=Ak(b,w[a+3|0]+1|0);j=v[h>>2];s=d,z=Ah(n*(Dk(+(t[a+1|0]-t[Mb(f+4136|0,0)+1|0]|0)/-12)*+(j>>>0)*+y[h+24>>2]))+v[d>>2]|0,v[s>>2]=z}a=a+4|0;if((g|0)!=(a|0)){continue}break}}q=Pl(d);if(q){j=(e<<12>>>0)/1e4|0;e=ar(f+4136|0);a=f+4120|0;h=vh(a);c:{if(!e){break c}v[22708]=0;R(939,a|0,e|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;R(940,a|0,e|0);e=v[22708];v[22708]=0;if((e|0)!=1){break c}}break a}h=a;d:{if(!ar(f+4136|0)){break d}a=0;while(1){e:{e=Mb(f+4136|0,a);g=NT(h,a);if(!(t[e+1|0]<0|x[b+480190>>1]<=w[e+3|0])){k=0;k=w[e+2|0]<242|w[e+2|0]>247?k:t[w[e+2|0]+33118|0];l=Ak(b,w[e+3|0]+1|0);e=t[e+1|0];m=Mb(f+4136|0,0);o=v[l+24>>2];m=t[m+1|0];v[22708]=0;k=Oa(934,+(n*(Dk(+(k<<24>>24)/96+ +(e-m|0)/12)*+(o>>>0))))|0;e=O()|0;m=k|0;o=v[22708];v[22708]=0;k=g;f:{g:{if((o|0)!=1){v[g+8>>2]=m;v[g+12>>2]=e;v[g+16>>2]=v[l+20>>2];e=v[l>>2];v[g+76>>2]=e;v[g+88>>2]=x[l+34>>1]&1023;if(!c){break g}v[g+664>>2]=r;p=MB(g+8|0);v[22708]=0;e=Ah(+(e>>>0)/p);l=v[22708];v[22708]=0;if((l|0)==1){break e}r=e+r|0;e=j;break f}break a}e=(j>>>0)/(Ib(w[i+14|0]|w[i+15|0]<<8)>>>0)|0}v[k+20>>2]=e;v[g+24>>2]=e}a=a+1|0;if(ar(f+4136|0)>>>0>a>>>0){continue}break d}break}break a}a=v[d>>2];if(a){k=b+24648|0;c=0;while(1){Qb(f+24|0,0,4096);v[f+16>>2]=512;v[22708]=0;v[f+8>>2]=a-c;a=Fb(f+16|0,f+8|0);b=v[22708];v[22708]=0;h:{i:{if((b|0)!=1){g=v[a>>2];s=f,z=Vb(h),v[s+16>>2]=z;s=f,z=Zb(h),v[s+8>>2]=z;if(Gb(f+16|0,f+8|0)){break i}break h}break a}while(1){j:{a=v[f+16>>2];if(!v[a+16>>2]){break j}b=v[a+664>>2];if(b>>>0>=g>>>0){v[a+664>>2]=b-g;break j}e=v[a+88>>2];v[f+4>>2]=g-b;b=v[a+76>>2];n=MB(a);p=MB(a+8|0);v[22708]=0;b=Ah((+(b>>>0)-n)/p);i=v[22708];v[22708]=0;if((i|0)==1){break a}v[22708]=0;v[f>>2]=b;b=Fb(f+4|0,f);i=v[22708];v[22708]=0;if((i|0)==1){break a}b=v[b>>2];i=v[a+664>>2];v[22708]=0;Y(v[((e&1|(e&64?18:16))<<2)+33696>>2],a|0,k|0,(f+24|0)+(i<<3)|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break j}v[a+16>>2]=0;break j}break a}a=f+16|0;v[a>>2]=v[a>>2]+872;if(Gb(a,f+8|0)){continue}break}}e=v[d+20>>2]+(c<<1)|0;i=f+24|0;b=gb-16|0;gb=b;v[b+12>>2]=g;qc(b+12|0,512);a=v[b+12>>2];v[b+12>>2]=a-1;if(a){while(1){a=e;j=id(v[i>>2]+2048|0,12);if((j|0)<-32768){j=-32768}u[a>>1]=(j|0)>32767?32767:j;a=v[b+12>>2];v[b+12>>2]=a-1;i=i+8|0;e=e+2|0;if(a){continue}break}}gb=b+16|0;a=v[d>>2];c=c+g|0;if(a>>>0>c>>>0){continue}break}}GT(h)}h=(q|0)!=0}gb=f+4144|0;return h|0}a=P()|0;O()|0;GT(h);S(a|0);L()}function mL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-224|0;gb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(pk(b)){break a}g=w[ul(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Jl(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}g=f+184|0;Ld(g);h=v[f+184>>2];Ld(f+168|0);i=tl(h,v[f+172>>2],b);Ld(g);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=uc(f+200|0,18726);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Gc(f+16|0,f+8|0)){a=ba(8)|0;v[22708]=0;R(2061,f+168|0,f+216|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,f+184|0,14728,f+168|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}rc(a,f+184|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);vb(f+168|0);break c}b=P()|0;O()|0;break d}if(!e){break h}c=ba(8)|0;v[22708]=0;d=Q(2059,f+136|0,b|0)|0;a=v[22708];v[22708]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22708]=0;U(2039,f+152|0,14764,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;R(2056,f+168|0,f+152|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break o}v[22708]=0;R(2061,f+120|0,f+216|0);a=v[22708];v[22708]=0;if((a|0)==1){break n}v[22708]=0;U(2060,f+184|0,f+168|0,f+120|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break m}rc(c,f+184|0);v[22708]=0;U(186,c|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);a=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;vb(d);break i}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0}vb(f+120|0)}vb(f+168|0)}vb(f+152|0);vb(d);if(!a){break c}}ca(c|0);break c}v[f+112>>2]=g;v[f+116>>2]=h;e=uc(f+104|0,18726);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Gc(f- -64|0,f+56|0)){a=ba(8)|0;v[22708]=0;R(2061,f+168|0,f+216|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,f+184|0,14728,f+168|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,f+184|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);vb(f+168|0);break c}b=P()|0;O()|0;break e}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=uc(f+88|0,8207);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Gc(f+48|0,f+40|0)){_K(a,Ac(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=uc(f+72|0,5758);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Gc(f+32|0,f+24|0)){break h}b=KA(c,d);c=gb-16|0;gb=c;a=v[a+32>>2];b=b>>>0<4?b:1;q:{if((Hy(a)|0)==(b|0)){d=a+120|0;Ci(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[14910];v[a+8>>2]=v[14909];v[a+12>>2]=e;e=v[14908];v[a>>2]=v[14907];v[a+4>>2]=e;kb[v[Rh(a,Yg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break q}yK(a,b,zK(a))}gb=c+16|0}gb=f+224|0;return}b=P()|0;O()|0;vb(f+168|0);break d}b=P()|0;O()|0;vb(f+168|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function VL(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);VP(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=xf(v[a+16>>2]);o=oe(C(10),C(C(C(z[a+4216>>2]+C(-.5))*C(30))/C(40)));b=C(C(c/C(d>>>0))*C(6.2831854820251465));c=vG(b);r=Pp(b);s=a;t=c;k=C(C(b*C(C(C(z[a+4212>>2]*C(35))+C(1))*C(.02888113260269165)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());c=C(((d|0)<=22?C(C(C(1)-g)+C(c-e)):C(C(c-C(e+g))+C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+71232>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=RI(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(o*b);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function As(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116508]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=466012,j=v[116503]&rqa(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+466316|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=466016,j=v[116504]&rqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116505]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116509]==(f|0)){v[116509]=a;b=v[116506]+b|0;v[116506]=b;v[a+4>>2]=b|1;if(v[116508]!=(a|0)){break a}v[116505]=0;v[116508]=0;return}if(v[116508]==(f|0)){v[116508]=a;b=v[116505]+b|0;v[116505]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=466012,j=v[116503]&rqa(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+466316|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=466016,j=v[116504]&rqa(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116508]!=(a|0)){break g}v[116505]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+466052|0;d=v[116503];b=1<<b;l:{if(!(d&b)){v[116503]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+466316|0;m:{d=v[116504];c=1<<e;n:{if(!(d&c)){v[116504]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function P8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;v[d+184>>2]=c;a:{b:{c:{d:{if(b>=.8){v[22708]=0;c=ga(2072)|0;e=v[22708];v[22708]=0;e:{f:{g:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22708]=0;c=T(2073,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+72>>2]=c;mo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+160|0,a);v[22708]=0;e=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=e;v[d- -64>>2]=v[a+16>>2];e=v[a+4>>2];v[d+48>>2]=v[a>>2];v[d+52>>2]=e;a=W(2063,c|0,d+48|0,15)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}if(a){a=v[d+88>>2];v[22708]=0;T(1292,a|0)|0;a=v[22708];v[22708]=0;f=1;if((a|0)==1){break g}}Ei(d+72|0);Fi(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ei(d+72|0);break e}c=V(0)|0;O()|0}Fi(d+88|0);break d}if(b>=.6){v[22708]=0;c=ga(2072)|0;e=v[22708];v[22708]=0;h:{i:{j:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22708]=0;c=T(2073,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}v[d+72>>2]=c;mo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+136|0,a);v[22708]=0;e=v[a+12>>2];v[d+32>>2]=v[a+8>>2];v[d+36>>2]=e;v[d+40>>2]=v[a+16>>2];e=v[a+4>>2];v[d+24>>2]=v[a>>2];v[d+28>>2]=e;a=W(2063,c|0,d+24|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break j}if(a){a=v[d+88>>2];v[22708]=0;T(1292,a|0)|0;a=v[22708];v[22708]=0;f=.8;if((a|0)==1){break j}}Ei(d+72|0);Fi(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ei(d+72|0);break h}c=V(0)|0;O()|0}Fi(d+88|0);break d}f=.2;if(b>=.2){v[22708]=0;c=ga(2072)|0;e=v[22708];v[22708]=0;k:{l:{m:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22708]=0;c=T(2073,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break l}v[d+72>>2]=c;mo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+112|0,a);v[22708]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;v[d+16>>2]=v[a+16>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2063,c|0,d|0,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}f=0;if(a){a=v[d+88>>2];v[22708]=0;T(1292,a|0)|0;a=v[22708];v[22708]=0;f=.6;if((a|0)==1){break m}}Ei(d+72|0);Fi(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ei(d+72|0);break k}c=V(0)|0;O()|0}Fi(d+88|0);break d}if(!(b>=.1)){break c}v[22708]=0;U(755,d+88|0,a|0,2048);c=v[22708];v[22708]=0;n:{o:{p:{if((c|0)!=1){v[22708]=0;c=Rd(d+88|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}e=v[d+88>>2];v[22708]=0;a=T(195,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}v[22708]=0;a=rG(2074,3,0,c,e,a,0);c=v[22708];v[22708]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+59648>>3];zc(d+88|0);break c}c=V(0)|0;O()|0;break d}a=ba(8)|0;v[22708]=0;e=Q(70,d+72|0,18726)|0;c=v[22708];v[22708]=0;if((c|0)!=1){rc(a,e);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;vb(e);break n}c=V(0)|0;O()|0;ca(a|0);break n}c=V(0)|0;O()|0}zc(d+88|0)}Z(c|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;f=0;if((a|0)==1){break a}}eg(d+184|0);gb=d+192|0;return+f}L()}a=P()|0;O()|0;eg(d+184|0);S(a|0);L()}function hga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=49424;v[a+4>>2]=0;v[a>>2]=38432;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Vq(a+24604|0);cP(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Qb(b+28|0,0,40);Qb(b+68|0,0,49824);Qb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Ho(a+480248|0);v[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){v[22708]=0;c=bP(c);e=v[22708];v[22708]=0;if((e|0)==1){break k}c=c+32|0;if((b|0)!=(c|0)){continue}break}e=a+484344|0;dd(e);v[e+12>>2]=a;v[22708]=0;l=Q(1283,a+484360|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break j}b=a+900380|0;c=a+484380|0;while(1){v[22708]=0;c=Q(895,c|0,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}c=c+104|0;if((b|0)!=(c|0)){continue}break}v[22708]=0;T(1284,a+901404|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}c=a+946300|0;f=a+906300|0;b=f;while(1){b=aP(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;d=a+1074304|0;g=a+946304|0;b=g;while(1){v[22708]=0;b=Tq(b);h=v[22708];v[22708]=0;if((h|0)==1){break g}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;oA(a+1074312|0);v[22708]=0;b=ga(1285)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}v[22708]=0;b=T(1286,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}v[a+1074328>>2]=b;v[22708]=0;iO(a+1074332|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;T(1288,a+1074376|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;d=W(1248,a+1298224|0,a|0,255)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}h=zh(a+1298260|0);b=gb-16|0;gb=b;v[b+12>>2]=0;i=a+1298264|0;wq(i,b+12|0);gb=b+16|0;m=Kb(a+1298268|0);n=Kb(a+1298280|0);j=a+1298292|0;Kb(j);o=$O(a+1298304|0);p=dd(a+1298368|0);t[a+1298380|0]=0;b=a+1298384|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298424>>2]=0;zq(a+12|0);Xo(a+8204|0);v[22708]=0;Xo(a+12300|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[a+480216>>2]=4;v[a+480220>>2]=16;b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;ZO(a+900380|0);v[22708]=0;mA(g);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=T(1291,12)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;hh(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;nA(p);ku(o);vb(j);vb(n);vb(m);ju(i);iu(h);Dq(d)}while(1){c=Aq(c-160|0);if((f|0)!=(c|0)){continue}break}}Hu(l)}lA(e)}Lc(k);S(b|0);L()}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){vq(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;LO(a)}sO(a+24648|0);s=v[a+24620>>2];g=gb-144|0;gb=g;f=a+397456|0;c=v[f+4>>2];if(c>>>0>=29){v[f+4>>2]=0;c=0}j=B(c,44)+53296|0;if(!(b?0:(j|0)==v[f+8>>2])){v[f+8>>2]=j;r=C(s>>>0);h=r;c=g+8|0;d=v[j+24>>2];v[c>>2]=d;e=v[j+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[j+4>>2];m=(d|0)>(e|0)?d:e;if((m|0)<=-601){i=e;e=m+600|0;v[c+4>>2]=i-e;v[c>>2]=d-e}e=c;k=C(z[j+36>>2]*C(79.30999755859375));a:{if(C(D(k))<C(2147483648)){d=~~k;break a}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(C(z[j+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(k))<C(2147483648)){e=~~k;break b}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;m=0;k=z[j+8>>2];e=c;o=C(C(F(z[j+20>>2],C(.10000000149011612)))*h);c:{if(C(D(o))<C(2147483648)){d=~~o;break c}d=-2147483648}i=(d|0)<96;p=i?96:d;l=(p|0)>7500;o=C(z[j+28>>2]*h);d:{if(C(D(o))<C(2147483648)){n=~~o;break d}n=-2147483648}d=(n+(i?d-96|0:0)|0)+(l?p-7500|0:0)|0;i=(d|0)<128;n=i?128:d;t=(n|0)>3800;w=t?3800:n;v[e+24>>2]=w;i=i?d-128|0:0;e=c;h=C(k*h);e:{if(C(D(h))<C(2147483648)){d=~~h;break e}d=-2147483648}i=(d+i|0)+(t?n-3800|0:0)|0;v[e+32>>2]=i;p=l?7500:p;while(1){d=B(m,12);e=d+c|0;u[e+42>>1]=x[d+54586>>1];u[e+36>>1]=x[d+54580>>1];l=d+54582|0;l=x[l>>1]|x[l+2>>1]<<16;u[e+38>>1]=l;u[e+40>>1]=l>>>16;v[e+44>>2]=p+((B(v[d+54576>>2],w)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}e=c;h=C(i|0);k=C(oe(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/h))*C(32768));f:{if(C(D(k))<C(2147483648)){d=~~k;break f}d=-2147483648}v[e+12>>2]=d;h=C(z[j+12>>2]*h);A=c,E=oe(C(.0010000000474974513),h<=C(4720)?C(1):C(C(4720)/h)),z[A+28>>2]=E;v[f+20>>2]=v[g+40>>2];c=NL(OL(v[g+16>>2]),r);u[f+86>>1]=c;u[f+84>>1]=c;c=x[g+24>>1]<<1;u[f+94>>1]=c;u[f+92>>1]=c;while(1){c=(q<<4)+f|0;d=(g+8|0)+B(q,12)|0;e=v[d+44>>2];v[c+100>>2]=e;v[c+104>>2]=e;u[c+108>>1]=x[d+36>>1];u[c+110>>1]=x[d+42>>1];u[c+112>>1]=x[d+40>>1];u[c+114>>1]=x[d+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+49892>>2]=v[g+32>>2];c=f;d=v[g+12>>2];if((d|0)>-9e3){e=ML(d)}else{e=0}v[c+80>>2]=e;e=f+49948|0;c=v[g+8>>2];if((c|0)>=-8999){c=ML(c)}else{c=0}v[e>>2]=c;c=v[g+28>>2];d=f+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+49906>>1]=c;u[f+49904>>1]=c;u[f+49902>>1]=c;u[f+49900>>1]=c;v[g+4>>2]=v[g+20>>2];Yd(g+4|0,0,32752);c=x[g+4>>1];u[f+49914>>1]=c;d=f+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[f+49908>>1]=c;h=z[g+36>>2];A=g,G=NL(C(h*h),r),v[A>>2]=G;Yd(g,256,32512);c=x[g>>1];u[f+49922>>1]=c;d=f+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[f+49916>>1]=c}c=a+397448|0;d=a+397452|0;if(b){v[f+16>>2]=0;QL(f,c,d)}b=B(s,5);if(b>>>0>y[f+20>>2]){v[f+20>>2]=b}gb=g+144|0;b=a+1298260|0;if(Dd(b)){TR(v[b>>2],v[a+24620>>2])}}function u_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-32|0;gb=e;v[e+28>>2]=b;a:{b:{if((d|0)<1){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Fb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Mt(c,v[Fb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){c:{b=e+8|0;f=lh(b,a);i=lh(b,a+4|0);o=lh(b,a+5|0);r=e,s=lh(b,a+6|0)<<8|lh(b,a+7|0),v[r+24>>2]=s;b=o|i<<8;p=a+8|0;d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break d}a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}break b}while(1){r=e,s=lh(e+8|0,i+p|0),t[r+20|0]=s;jq(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break d;case 1:break e;default:break c}}bk(e+24|0,d);i=v[e+24>>2];m=lh(e+8|0,a+10|0);t[e+20|0]=m;jq(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break d}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=qg(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!qg(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!qg(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!qg(h,a,1,e+8|0)){break n}f=qg(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;f=((k<<3)+f|0)-17|0;if((f|0)<=-1){a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}break b}if(f>>>0>=56){a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}break b}k=w[f+28336|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];o:{if((g|0)<1){break o}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=lh(f,g);m=m-((lh(f,g+1|0)<<8|q<<16|lh(f,g+2|0))<<(b-(l<<3)|0)+8>>32-k)|0;t[e+20|0]=m;jq(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if((a|0)<1){break o}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}p:{q:{r:{a=f+1|0;if(!qg(h,a,1,e+8|0)){f=2;break r}a=f+2|0;if(!qg(h,a,1,e+8|0)){f=4;break r}a=f+3|0;if(!qg(h,a,1,e+8|0)){f=6;break r}a=f+5|0;if(!qg(h,f+4|0,1,e+8|0)){b=f+8|0;a=qg(h,a,3,e+8|0)+8|0;break p}b=f+10|0;f=16;a=qg(h,a,5,e+8|0);break q}b=a+2|0;a=qg(h,a+1|0,1,e+8|0)}a=a+f|0}s:{if(qg(h,b,1,e+8|0)){f=-256;g=12;break s}b=b+1|0;g=qg(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=qg(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=((j|0)>1?j:1)-1|0}f=oc(c)+((l^-1)+f|0)|0;if(f>>>0<oc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<1|(g|0)<=0){break g}while(1){m=w[lc(c,f)|0];t[e+20|0]=m;jq(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if((a|0)<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}break a}n=n-(n>>3)|0;if((g|0)>0){continue}break}}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=cd(c)^1}gb=e+32|0;return a|0}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ia(a|0,28304,206);L()}function Ifa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=gb-144|0;gb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){xz(a+96|0,c);v[22708]=0;c=Q(2,a+80|0,14864)|0;d=v[22708];v[22708]=0;if((d|0)==1){break E}v[22708]=0;U(3,a+112|0,a+96|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break D}v[22708]=0;d=Q(4,a+48|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}v[22708]=0;e=Q(2,a+32|0,16669)|0;f=v[22708];v[22708]=0;if((f|0)==1){break B}v[22708]=0;U(5,a- -64|0,d|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break A}v[22708]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[22708];v[22708]=0;if((f|0)==1){break z}vb(a- -64|0);vb(e);vb(d);d=a+112|0;vb(d);vb(c);vb(a+96|0);c=v[b>>2];v[22708]=0;U(6,d|0,1,(c?c:18726)|0);c=v[22708];v[22708]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22708]=0;U(6,a+96|0,1,(c?c:18726)|0);c=v[22708];v[22708]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22708]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}v[22708]=0;b=Q(8,463432,14743)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;U(9,a- -64|0,0,a+112|0);c=v[22708];v[22708]=0;if((c|0)==1){break p}v[22708]=0;b=Q(10,b|0,a- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break o}v[22708]=0;b=Q(8,b|0,14517)|0;c=v[22708];v[22708]=0;if((c|0)==1){break o}v[22708]=0;U(9,a+32|0,0,a+80|0);c=v[22708];v[22708]=0;if((c|0)==1){break n}v[22708]=0;b=Q(10,b|0,a+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;b=Q(8,b|0,14514)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;b=Q(8,b|0,14864)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;U(9,a+16|0,0,a+128|0);c=v[22708];v[22708]=0;if((c|0)==1){break l}v[22708]=0;b=Q(10,b|0,a+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;b=Q(8,b|0,10777)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(9,a|0,0,a+96|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[22708]=0;b=Q(10,b|0,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;b=Q(8,b|0,10775)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;Q(11,b|0,12)|0;b=v[22708];v[22708]=0;if((b|0)==1){break i}vb(a);vb(a+16|0);vb(a+32|0);vb(a- -64|0);vb(a+80|0);vb(a+96|0);vb(a+112|0);vb(a+128|0)}gb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a- -64|0)}vb(e)}vb(d)}vb(a+112|0)}vb(c)}vb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a)}vb(a+16|0)}vb(a+32|0)}vb(a- -64|0)}vb(a+80|0)}vb(a+96|0)}vb(a+112|0)}vb(a+128|0)}S(b|0);L()}function an(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-96|0;gb=d;g=mc(a);v[22708]=0;e=T(426,b|0)|0;a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)==1){break e}v[22708]=0;a=Q(191,b|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}if(a){break d}v[22708]=0;a=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}v[22708]=0;Q(318,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[22708]=0;U(288,d+48|0,b|0,e|0);b=v[22708];v[22708]=0;a=d;f:{g:{h:{i:{if((b|0)!=1){b=d+48|0;f=kc(d+72|0,b);xb(b);if(e>>>0<10){break g}v[22708]=0;b=T(930,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break g}v[22708]=0;b=T(426,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[d+44>>2]=b;v[d+40>>2]=e-10;b=v[d+40>>2];if(b>>>0>25264513){break i}b=B(b,170);break h}a=P()|0;O()|0;break a}b=-1}v[a+40>>2]=b;qc(d+44|0,b);v[22708]=0;R(440,g|0,v[d+44>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break b}e=v[d+44>>2];b=0;while(1){j:{v[22708]=0;a=T(931,f|0)|0;c=v[22708];v[22708]=0;k:{l:{m:{n:{if((c|0)!=1){if(a){break j}v[22708]=0;a=T(707,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}switch(a|0){case 3:break k;case 2:break l;case 1:break m;case 0:break n;default:break j}}break b}v[22708]=0;a=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(a>>>0>e>>>0){break j}v[22708]=0;c=Q(191,f|0,a|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!c){break j}v[22708]=0;Ud(d+48|0,g);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;Y(932,d+24|0,d+48|0,b|0,a|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;c=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=c;U(633,d+16|0,f|0,d+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){e=e-a|0;b=a+b|0;continue}break b}v[22708]=0;a=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}c=a<<2;if(c>>>0>e>>>0){break j}v[22708]=0;h=Q(933,f|0,d+32|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break b}if(!h){break j}e=e-c|0;if(!a){continue}while(1){c=d+32|0;h=fc(c);j=d,k=Vb(g),v[j+48>>2]=k;Tu(c,h,we(d+48|0,b));b=b+4|0;a=a-1|0;if(a&255){continue}break}continue}if(e>>>0<8){break j}v[22708]=0;a=Q(933,f|0,d+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!a){break j}a=d+32|0;c=fc(a);j=d,k=Vb(g),v[j+48>>2]=k;i=c;c=d+48|0;Tu(a,i,we(c,b));h=fc(a);j=d,k=Vb(g),v[j+16>>2]=k;j=d,k=we(d+16|0,b),v[j+48>>2]=k;Tu(a,h,we(c,4));e=e-8|0;b=b+8|0;continue}v[22708]=0;a=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(a>>>0>e>>>0){break j}e=e-a|0;b=a+b|0;continue}break}if(!e){break f}a=mc(d+48|0);xc(a,g);xc(a+4|0,g+4|0);xc(wb(a),wb(g));wb(a);wb(g);gc(a);break f}v[22708]=0;W(505,f|0,g|0,e|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}}xb(f)}gb=d+96|0;return}a=P()|0;O()|0;xb(f)}gc(g);S(a|0);L()}function Eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-96|0;gb=d;a:{b:{c:{d:{if(w[a|0]==23){e=t[a+1|0];f=d,g=BA(c,+w[a+2|0]*1e4/240),t[f+8|0]=g;v[d+80>>2]=127;v[d+64>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[pd(d+80|0,d- -64|0)>>2],t[f+95|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Ef(d- -64|0,12700);v[22708]=0;R(737,d+48|0,d+8|0);a=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[22708]=0;R(737,d+32|0,d+95|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}v[22708]=0;Y(738,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break j}v[22708]=0;R(444,d+16|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;Q(401,d+16|0,d+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;case 1:Ef(d- -64|0,12640);v[22708]=0;R(737,d+48|0,d+8|0);a=v[22708];v[22708]=0;l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22708]=0;R(737,d+32|0,d+95|0);a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;Y(738,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;R(444,d+16|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break o}v[22708]=0;Q(401,d+16|0,d+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break o}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;default:break e}}a=Tb(d+80|0,12727);v[22708]=0;R(444,d- -64|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(401,d- -64|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}vb(a);break b}if(w[a|0]==24){t[d+95|0]=t[a+1|0]<=4?w[a+1|0]:0;t[d+31|0]=t[a+2|0]>=0?w[a+2|0]:127;t[d+30|0]=t[a+3|0]>=0?w[a+3|0]:127;a=gb-16|0;gb=a;c=Tb(a,1157);Dc(d- -64|0,c);vb(c);gb=a+16|0;v[22708]=0;R(737,d+48|0,d+95|0);a=v[22708];v[22708]=0;r:{s:{t:{u:{v:{w:{x:{y:{if((a|0)!=1){v[22708]=0;R(737,d+32|0,d+31|0);a=v[22708];v[22708]=0;if((a|0)==1){break y}v[22708]=0;R(737,d+16|0,d+30|0);a=v[22708];v[22708]=0;if((a|0)==1){break x}v[22708]=0;ha(937,d+80|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break w}v[22708]=0;R(444,d+8|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break v}v[22708]=0;Q(401,d+8|0,d+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break v}vb(d+80|0);vb(d+16|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;break u}b=P()|0;O()|0;vb(d+80|0)}vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c}a=0;break a}b=P()|0;O()|0;vb(a)}S(b|0);L()}a=1}gb=d+96|0;return a|0}function Ry(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-96|0;gb=e;a:{b:{c:{if(j=1,k=nd(a,11),l=v[a+4>>2],l?j:k){g=v[a+28>>2];b=e;d=v[a+12>>2];f=v[a+64>>2];c=f+v[a+8>>2]|0;d=sh(b+80|0,c,c>>>0<f>>>0?d+1|0:d);c=v[d+12>>2];v[b+32>>2]=v[d+8>>2];v[b+36>>2]=c;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;jk(g,e+24|0);b=v[a+28>>2];if(El(v[v[b>>2]-12>>2]+b|0)){uh(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=g;c=vf(b);d:{if(d>>>0>c>>>0){f=gb-32|0;gb=f;e:{c=d-c|0;f:{if(c>>>0<=v[wb(b)>>2]-v[b+4>>2]>>4>>>0){h=gb-16|0;gb=h;c=bq(h,b,c);d=v[c+4>>2];i=v[c+8>>2];if((d|0)!=(i|0)){while(1){wb(b);_H(d);d=d+16|0;v[c+4>>2]=d;if((d|0)!=(i|0)){continue}break}}$b(c);gb=h+16|0;break f}d=wb(b);d=TI(f+8|0,ey(b,vf(b)+c|0),vf(b),d);v[22708]=0;QI(d,c);c=v[22708];v[22708]=0;if((c|0)==1){break e}Tx(b);wb(b);c=d+4|0;ol(v[b>>2],v[b+4>>2],c);wc(b,c);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];dI(b,vf(b));LI(d)}gb=f+32|0;break d}a=P()|0;O()|0;LI(d);S(a|0);L()}if(c>>>0>d>>>0){d=v[b>>2]+(d<<4)|0;vf(b);II(b,d);xi(b);vf(b)}}h=a+32|0;Mt(h,v[a+92>>2]<<2);if(v[a+92>>2]){c=0;while(1){b=v[a+28>>2];if(El(v[v[b>>2]-12>>2]+b|0)){uh(a,1073741828);break a}b=x[a+16>>1];u[e+78>>1]=b;if((b|0)==65535){Sy(v[a+28>>2],e+78|0);b=x[e+78>>1]}f=oc(h);v[e+72>>2]=f;g:{if(!b){break g}d=b;f=v[e+72>>2];if(b>>>0>-1-f>>>0){break g}Qy(h,d+f|0);kl(v[a+28>>2],lc(h,v[e+72>>2]),d);f=v[e+72>>2]}j=Tc(g,c),k=b,u[j+12>>1]=k;j=Tc(g,c),k=f,v[j>>2]=k;if(nd(a,6)){yl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break c}j=Tc(g,c),k=v[e+56>>2],v[j+4>>2]=k}b=v[a+4>>2];h:{if(b){j=Tc(g,c),k=b,v[j+8>>2]=k;break h}if(!nd(a,7)){break h}yl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break b}j=Tc(g,c),k=v[e+56>>2],v[j+8>>2]=k}i:{if(v[Tc(g,c)+8>>2]==-1){break i}if(nd(a,6)){break i}if(c){b=Tc(g,c-1|0);b=v[b+8>>2]+v[b+4>>2]|0}else{b=0}j=Tc(g,c),k=b,v[j+4>>2]=k}if(nd(a,8)){u[e+56>>1]=0;Sy(v[a+28>>2],e+56|0);b=nd(a,9);xm(v[a+28>>2],x[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<y[a+92>>2]){continue}break}}se(e+56|0,v[a+28>>2]);b=v[e+68>>2];v[a+72>>2]=v[e+64>>2];v[a+76>>2]=b}zl(a,4,1);g=v[a+76>>2];f=v[a+88>>2];c=f+v[a+8>>2]|0;d=v[a+12>>2];d=c>>>0<f>>>0?d+1|0:d;b=c;c=(f|0)==v[a+64>>2];f=c?v[a+72>>2]:b;v[a+80>>2]=f;b=c?g:d;v[a+84>>2]=b;d=v[a+28>>2];b=sh(e+40|0,f,b);c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;jk(d,e+8|0);if(nd(a,6)){break a}if(!(j=1,k=nd(a,7),l=v[a+4>>2],l?j:k)){break a}b=v[a+92>>2];if(!b){break a}d=a+44|0;c=v[a+80>>2];a=v[a+8>>2];c=c-a|0;a=0;while(1){g=Tc(d,a);v[g+4>>2]=c+v[g+4>>2];a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}uh(a,1073741829);break a}uh(a,1073741829)}gb=e+96|0}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-48|0;gb=c;if(ii(b)){h=Li(b);j=v[b+12>>2];f=c+32|0;e=Hg(f);a:{d=h;if(!d){break a}v[22708]=0;R(617,f|0,d|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;GN(f,d);d=v[22708];v[22708]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;wv(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[22708]=0;d=_f(a+d|0);e=v[22708];v[22708]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[22708]=0;t[c+31|0]=0;Q(1485,a|0,c+31|0)|0;d=v[22708];v[22708]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[22708]=0;Q(1485,a|0,c+30|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;hi(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[22708]=0;g=Yc(b,i,d);e=v[22708];v[22708]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[22708]=0;Q(1485,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=ad(f,d),m=e,t[l|0]=m}l=g,m=w[ad(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[22708]=0;Q(1485,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=ad(f,d),m=e,t[l+1|0]=m}l=g,m=w[ad(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[22708]=0;Q(1485,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=ad(f,d),m=e,t[l+2|0]=m}l=g,m=w[ad(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[22708]=0;Q(1485,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=ad(f,d),m=e,t[l+4|0]=m}l=g,m=w[ad(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[22708]=0;Q(1485,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+3|0]=m}l=g,m=w[ad(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[22708]=0;Q(1485,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+5|0]=m}l=g,m=w[ad(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[22708]=0;Q(1485,a|0,c+15|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){d=w[c+15|0];v[22708]=0;W(1486,a|0,d|0,-1)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;jn(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}jn(f)}gb=c+48|0}function ena(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[ac(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[ac(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=gn(+(dW(e,b,c,d)>>>0)/1e4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[ac(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[ac(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=ac(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[ac(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[ac(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[ac(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[ac(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[ac(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=44;h=a,i=fm(Qc(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=ei(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){Of(a);break a}t[a+3|0]=0}gb=f+16|0}function R7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;a:{if(pk(b)){break a}e=w[ul(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Jl(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}g=d+160|0;Ld(g);e=v[d+160>>2];Ld(d+144|0);e=tl(e,v[d+148>>2],b);Ld(g);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=uc(d+176|0,18726);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22708]=0;c=Q(70,d+160|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}f=0;if(!c){break g}a=ba(8)|0;v[22708]=0;c=Q(2059,d+144|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,d+160|0,14764,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}rc(a,d+160|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d+160|0);vb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=2){a=ba(8)|0;v[22708]=0;c=Q(70,d+160|0,8874)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=uc(d+128|0,18726);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){a=ba(8)|0;v[22708]=0;c=Q(70,d+160|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=uc(d+112|0,4823);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break g}f=65536/+y[v[a+24>>2]+480244>>2];break g}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,4875);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break g}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break g}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=uc(d+80|0,4893);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Gc(d+24|0,d+16|0)){break g}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}gb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c)}ca(a|0)}S(b|0)}L()}function nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=gb-32|0;gb=f;r=a+4|0;p=v[r>>2];m=a+20|0;A=v[ye(m,b)>>2];a:{if(A+1>>>0<2){break a}h=(B(b,872)+p|0)+616|0;if(!Oi(h)){if(!w[ye(m,b)+4|0]){break a}}i=B(b,872)+p|0;if(!v[i+720>>2]){break a}j=v[i+704>>2]&2;g=v[(j?i+700|0:i+692|0)>>2];s=v[i+700>>2];u=v[i+696>>2];Db(f,v[a>>2]+1074312|0,31);D=Cb(f);E=i+1362|0;k=w[E|0];F=i+624|0;e=Cw(F,c);y=jb;n=y;v[f+24>>2]=e;v[f+28>>2]=n;if(w[i+704|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+n|0)}e=0;H=e;n=g;G=j?e:0;e=u;q=j?e:0;l=s-e|0;s=l<<1;e=B(b,872)+p|0;y=e+1316|0;o=e+1467|0;u=(k&17)!=1;b:{while(1){c:{if(d>>>0>z>>>0){g=(w[E|0]&17)==1;break c}t[o|0]=w[o|0]&254;k=Yc(_b(v[a>>2]+484344|0,x[v[r>>2]+70>>1]),v[v[r>>2]+48>>2],b);j=w[k+3|0];if(w[k+2|0]==11){zA(f,v[a>>2],k,0);e=Ve(f);Ao(v[a>>2],h,x[f>>1]);g=1;if(w[e|0]){break c}}g=1;d:{switch(j-4|0){case 0:Ao(v[a>>2],h,w[k+5|0]);break c;case 2:break d;default:break c}}Ao(v[a>>2],h,0)}v[f+20>>2]=v[y>>2];if(D){bu(v[a>>2],h)}if(!u){pO(v[a>>2],h,f+20|0);g=1}if(!D){bu(v[a>>2],h)}v[f+16>>2]=0;qO(h,f+16|0);e:{f:{if(w[i+705|0]&2){break f}g:{if(!g){if(!w[ye(m,b)+4|0]){break g}}if(w[o|0]&48){IS(h,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&32?-33:-17)&e}Tz(f,v[a>>2],h,v[f+20>>2],0);g=v[f+4>>2];e=F;v[e>>2]=v[f>>2];v[e+4>>2]=g;I=ye(m,b),J=0,t[I+4|0]=J;e=Cw(e,c);j=jb;g=j;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+704|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+g|0)}Ub(h,f+24|0);k=v[h>>2];e=v[h+4>>2];if((k>>>0<H>>>0&(e|0)<=(n|0)|(e|0)<(n|0))&((e|0)>=(q|0)&k>>>0>=G>>>0|(e|0)>(q|0)|v[f+28>>2]>-1)){break f}g=v[i+704>>2];if(!(g&2)){break e}if(g&4){if(k>>>0<G>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){g=v[i+696>>2]<<1;v[f>>2]=0;v[f+4>>2]=g;I=h,J=Pg(f,h),v[I>>2]=J;v[h+4>>2]=jb;v[i+704>>2]=v[i+704>>2]^128;g=v[f+24>>2];e=0-(v[f+28>>2]+((g|0)!=0)|0)|0;v[f+24>>2]=0-g;v[f+28>>2]=e;e=v[h+4>>2]}g=v[i+696>>2];Db(f,v[a>>2]+1074312|0,33);e=(e-g>>>0)%(s-Cb(f)>>>0)|0;h:{if(e>>>0>=l>>>0){v[h+4>>2]=v[i+700>>2]+(l-e|0);g=v[i+704>>2];if(!(g&128)){break h}break f}v[h+4>>2]=e+v[i+696>>2];g=v[i+704>>2];if(!(g&128)){break f}}v[i+704>>2]=g^128;g=v[f+24>>2];e=0-(v[f+28>>2]+((g|0)!=0)|0)|0;v[f+24>>2]=0-g;v[f+28>>2]=e;break f}g=e;j=v[i+700>>2];if(e>>>0>=j+l>>>0){g=j+((g-j>>>0)%(l>>>0)|0)|0}while(1){e=g;g=e-l|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=k;v[h+4>>2]=e}z=z+1|0;if((A|0)!=(z|0)){continue}break b}break}lB(h);v[(B(b,872)+p|0)+1324>>2]=0}I=ye(m,b),J=0,v[I>>2]=J}gb=f+32|0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-192|0;gb=d;g=d+176|0;iL(g);v[g>>2]=55124;dd(g+4|0);h=a;mo(v[a+24>>2],g);e=w[a+62|0];f=w[a+61|0];j=w[a+60|0];k=v[a+24>>2];b=le(d+152|0,b);v[22708]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=f?b&14:b;b=W(2063,k|0,d|0,(e?b&3:b)|0)|0;e=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)==1){break p}if(!b){b=ba(8)|0;v[22708]=0;c=Q(70,d+136|0,9264)|0;a=v[22708];v[22708]=0;if((a|0)!=1){rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;ca(b|0);break b}if(!w[a+63|0]){v[22708]=0;R(2064,a|0,a+36|0);b=v[22708];v[22708]=0;if((b|0)==1){break p}}t[a+28|0]=1;mo(v[h+24>>2],v[a+4>>2]);v[22708]=0;R(2065,d+136|0,g|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=d+136|0;l=d,m=Vb(b),v[l+128>>2]=m;l=d,m=Zb(b),v[l+120>>2]=m;if(Gb(d+128|0,d+120|0)){h=a+68|0;while(1){b=v[d+128>>2];e=v[b>>2];v[22708]=0;f=e;e=b+4|0;U(2066,a|0,f|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}b=v[b>>2];v[22708]=0;R(2067,d+56|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;R(2041,d+72|0,d+56|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;b=Q(70,d+40|0,14864)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}v[22708]=0;U(2060,d+88|0,d+72|0,b|0);f=v[22708];v[22708]=0;if((f|0)==1){break k}v[22708]=0;U(718,d+104|0,d+88|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break m}v[22708]=0;R(1424,h|0,d+104|0);e=v[22708];v[22708]=0;if((e|0)==1){break n}vb(d+104|0);vb(d+88|0);vb(b);vb(d+72|0);vb(d+56|0);b=d+128|0;Zo(b);if(Gb(b,d+120|0)){continue}break}}l=d,m=nr(c),v[l+104>>2]=m;l=d,m=Dh(c),v[l+88>>2]=m;q:{while(1){v[22708]=0;b=og(d+104|0,d+88|0);c=v[22708];v[22708]=0;r:{if((c|0)!=1){if(b){break r}Jt(d+136|0);Ht(g);gb=d+192|0;return}a=P()|0;O()|0;break c}v[22708]=0;c=ue(d+104|0);b=v[22708];v[22708]=0;s:{if((b|0)==1){break s}v[22708]=0;b=Q(69,d+24|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break s}v[22708]=0;Y(2002,a|0,b|0,c+12|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break q}vb(b);Sj(d+104|0);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(b);break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+104|0);break l}a=P()|0;O()|0}vb(d+88|0);break j}a=P()|0;O()|0}vb(b);break h}a=P()|0;O()|0}vb(d+72|0);break f}a=P()|0;O()|0}vb(d+56|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Jt(d+136|0)}Ht(g);S(a|0)}L()}function xma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=gb-560|0;gb=f;a:{if(!Wc(b,1464)){break a}if(!hp(b,f+556|0)){break a}Hd(a,1);d=a+1074312|0;Rf(d,83);Ob(d,84,1);Ob(d,85,1);b:{if(je(f+556|0,33202)){d=f+32|0;e=Tb(d,5577);Eb(a+1298304|0,e);vb(e);e=Tb(d,12020);Eb(a+1298316|0,e);vb(e);d=Tb(d,12085);Eb(a+1298328|0,d);break b}if(!je(f+556|0,12635)){break a}d=f+32|0;e=Tb(d,5735);Eb(a+1298304|0,e);vb(e);e=Tb(d,9516);Eb(a+1298316|0,e);vb(e);d=Tb(d,12552);Eb(a+1298328|0,d)}vb(d);v[a+1298364>>2]=2;d=0;Wc(b,0);TC(b,a+1298268|0,20);u[a+480190>>1]=31;e=1;while(1){d=fC(b,f+32|0,(B(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+552|0;jw(i,b);m=qd(i);if(w[i|0]>128){break a}e=f+32|0;h=e;g=gb-32|0;gb=g;d=b;c:{if(!Pb(d,512)){jV(h);break c}Sv(g+24|0,h);h=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=h;kd(g+16|0,d,g+8|0)}gb=g+32|0;d=f+544|0;g=w[m|0];d:{while(1){if(g>>>0>=w[e|0]){e=e+1|0;if((d|0)!=(e|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;xh(a,0);n=a+484360|0;Bf(Sb(n),w[i|0]);u[f+30>>1]=0;j=a+484344|0;zg(j,w[i|0]);if(w[i|0]){g=0;while(1){s=sc(Sb(n),g),x=g,u[s>>1]=x;if(wh(j,g&65535,64)){p=g<<2;h=0;while(1){Wc(b,(w[f+32+(h+p)|0]<<8)+1468|0);e=Yc(_b(j,g),0,h&65535);d=0;while(1){gv(b,e);e:{f:{l=w[e+3|0];g:{if((l|0)!=14){if(!l){if(w[e+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[e+5|0]<=15){break f}}t[e+3|0]=0;break e}Of(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=f,x=Vb(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){e=d;d=w[v[f+24>>2]+3|0];h:{if((d|0)!=16&(d|0)!=17){break h}t[v[f+24>>2]+3|0]=16;k=0;if(w[v[f+24>>2]+5|0]<16){break h}d=w[v[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=w[v[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=v[f+24>>2];t[d+5|0]=w[d+5|0]>>>4}$j(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}t[f+31|0]=r;t[f+30|0]=q;d=k&255;if(d){Jm(_b(j,g),Ue(Be(f+8|0,16,w[(d+f|0)+29|0]),h));d=k+1|0;k=(d&255)==3?1:d}else{k=0}h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Wc(b,(w[m|0]<<8)+1468|0);e=1;while(1){c=(B(e,104)+a|0)+484380|0;if(v[c>>2]){Cg(Rc(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}gb=f+560|0;return o|0}function _Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-384|0;gb=f;vc(b);d=gb-32|0;gb=d;e=d+24|0;h=f+344|0;oE(e,h);k=yb(e);e=v[d+28>>2];g=v[d+24>>2];v[d+8>>2]=g;v[d+12>>2]=e;v[d>>2]=g;v[d+4>>2]=e;g=d+16|0;e=b;cc(g,e,d);g=yb(g);if((g|0)==(k|0)){Rb(e,yb(d+24|0))}gb=d+32|0;e=(g|0)==(k|0);if(!e){nE(h)}a:{b:{if(!e){break b}if(!BE(f+344|0)){break b}if(!Pb(b,Qc(AE(f+344|0),jb))){break b}c:{if(!c){break c}Hd(a,2097152);Ag(a);i=1;xh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);u[a+480190>>1]=w[f+378|0];if(w[f+381|0]<w[f+380|0]){cf(Sb(a+484360|0),w[f+381|0])}e=f+80|0;d=Tb(e,3576);Eb(a+1298304|0,d);vb(d);d=Tb(e,8337);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;kw(b,e);Tr(Sb(a+484360|0),e,w[f+380|0],65535,65535);if(x[a+480190>>1]){j=1;while(1){e=f+40|0;zE(b,e);l=gb-16|0;gb=l;g=(B(i,104)+a|0)+484380|0;ud(g,0);k=e;t[g+37|0]=w[e+22|0]<<4;t[l+15|0]=w[e+23|0];t[l+14|0]=64;n=g,o=w[ac(l+15|0,l+14|0)|0]<<2,u[n+30>>1]=o;t[g+36|0]=w[e+24|0];d=e+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e+33|0;d:{if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0<3){break d}m=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(m>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))}gb=l+16|0;d=f+8|0;Qk(d,2,e);e=f+24|0;Bc(e,d);v[22708]=0;Q(301,((i<<5)+a|0)+946304|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}vb(f+24|0);j=j+1|0;i=j&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Rb(b,B(64-w[f+378|0]|0,37));k=a+484344|0;zg(k,w[f+379|0]);if(w[f+379|0]){h=c&1;j=0;while(1){e:{f:{if(h){if(wh(k,j&65535,64)){break f}}Rb(b,2048);break e}e=_b(k,j);n=f,o=Vb(e),v[n+40>>2]=o;n=f,o=Zb(e),v[n+24>>2]=o;if(!Gb(f+40|0,f+24|0)){break e}while(1){e=v[f+40>>2];d=f+8|0;wn(d,b);i=qd(d);g=Ve(d);l=fj(d);d=w[d|0];if((d-1&255)>>>0<=106){t[e|0]=d+13}t[e+1|0]=w[i|0];t[e+3|0]=w[g|0];t[e+5|0]=w[l|0];Of(e);e=f+40|0;$j(e);if(Gb(e,f+24|0)){continue}break}}j=j+1|0;if(j>>>0<w[f+379|0]){continue}break}}if(!(c&2)){break c}i=1;c=Rc(f+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){Cg(c,(B(i&65535,104)+a|0)+484380|0,b);i=i+1|0;if(x[a+480190>>1]>=(i&65535)>>>0){continue}break}}i=1}gb=f+384|0;return i|0}a=P()|0;O()|0;vb(f+24|0);S(a|0);L()}function uG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;g=gb-48|0;gb=g;o(+a);d=j(1)|0;f=j(0)|0;a:{b:{e=d;d=e;h=e&2147483647;c:{if(h>>>0<=1074752122){if((d&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;e=h>>>20|0;f=(e-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(f){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;f=e;o(+a);e=j(1)|0;j(0)|0;if((f-(e>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(h>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,f|0);l(1,e&1048575|1096810496);a=+n();d=0;f=1;while(1){m=(g+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=f&1;f=0;if(m){continue}break}A[g+32>>3]=a;e:{if(a!=0){d=2;break e}f=1;while(1){d=f;f=d-1|0;if(A[(g+16|0)+(d<<3)>>3]==0){continue}break}}d=OI(g+16|0,g,(h>>>20|0)-1046|0,d+1|0,1);a=A[g>>3];if((e|0)<-1|(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}gb=g+48|0;return d}function g3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;n=Px(g);o=vx(g);Ug(l,o);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22708]=0;g=Q(2504,n|0,g<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22708]=0;j=Q(2504,n|0,48)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=t[h+1|0];v[22708]=0;j=Q(2504,n|0,j|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=h+2|0;if(j>>>0>=c>>>0){g=j;break d}h=g+h|0;g=j;e:{while(1){i=t[g|0];v[22708]=0;k=ga(2478)|0;m=v[22708];v[22708]=0;if((m|0)==1){break e}v[22708]=0;i=Fx(i,k);k=v[22708];v[22708]=0;if((k|0)==1){break e}if(!i){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}j=g+h|0;g=h;while(1){i=t[g|0];v[22708]=0;ga(2478)|0;k=v[22708];v[22708]=0;if((k|0)==1){break a}v[22708]=0;i=Qh(i);k=v[22708];v[22708]=0;if((k|0)==1){break a}if(!i){break f}g=g+1|0;if((j|0)!=(g|0)){continue}break}g=j}j=h}g:{if(gd(l)){h=v[f>>2];v[22708]=0;Y(2494,n|0,j|0,g|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-j<<2);break g}pm(j,g);v[22708]=0;p=T(2492,o|0)|0;h=v[22708];v[22708]=0;h:{i:{if((h|0)!=1){if(g>>>0>j>>>0){break i}h=v[f>>2];break h}break a}h=j;i=0;k=0;j:{while(1){k:{if(t[pc(l,i)|0]<1){break k}if(t[pc(l,i)|0]!=(k|0)){break k}k=v[f>>2];v[f>>2]=k+4;v[k>>2]=p;i=(Ab(l)-1>>>0>i>>>0)+i|0;k=0}m=t[h|0];v[22708]=0;q=Q(2504,n|0,m|0)|0;m=v[22708];v[22708]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;k=k+1|0;h=h+1|0;if((h|0)==(g|0)){break j}continue}break}break a}h=m+4|0}rx((j-a<<2)+d|0,h)}l:{if(c>>>0<=g>>>0){h=v[f>>2];break l}while(1){h=w[g|0];if((h|0)==46){v[22708]=0;j=T(2495,o|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}i=v[f>>2];h=i+4|0;v[f>>2]=h;v[i>>2]=j;g=g+1|0;break l}v[22708]=0;j=Q(2504,n|0,h<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;g=g+1|0;if((g|0)!=(c|0)){continue}break}h=h+4|0;g=c}v[22708]=0;Y(2494,n|0,g|0,c|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g<<2)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-320|0;gb=d;e=gb-16|0;gb=e;v[a>>2]=0;f=a+32|0;Mt(f,32);t[e+15|0]=0;jq(f,e+15|0);gb=e+16|0;e=v[a+28>>2];a:{if(!_f(v[v[e>>2]-12>>2]+e|0)){uh(a,1073741825);break a}f=d+56|0;se(f,v[a+28>>2]);e=f;g=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=g;v[e>>2]=3;i=v[a+28>>2];h=d+16|0;j=h;g=0;if(v[e>>2]){while(1){Vh(i,g+j|0);g=g+1|0;if(g>>>0<y[f>>2]){continue}break}}if(sd(h,27248,3)){uh(a,1073741827);break a}g=0;t[d+319|0]=0;Vh(v[a+28>>2],d+319|0);Qb(d+56|0,0,256);e=w[d+319|0];b:{if(!e){f=d+56|0;break b}f=d+56|0;kl(v[a+28>>2],f,e);g=w[d+319|0]}e=b;b=po(d+16|0,f,g);e=Uy(e,b);Hb(b);if(!e){uh(a,1073741830)}if(w[a+3|0]&64){break a}Vh(v[a+28>>2],d+55|0);e=w[d+55|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(Ej(e,6)){zl(a,9,1)}v[d+48>>2]=0;AL(v[a+28>>2],d+48|0);b=v[d+48>>2];t[d+47|0]=0;if(b>>>0>=2){Vh(v[a+28>>2],d+55|0);f=w[d+55|0];if(!f){Vh(v[a+28>>2],d+47|0);f=w[d+55|0]}xm(v[a+28>>2],b+(f&255?-1:-2)|0,-1)}v[d+32>>2]=0;v[d+36>>2]=0;c:{if(!Ej(e,4)){break c}yl(v[a+28>>2],d+32|0);b=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break c}uh(a,536871424)}if(Ej(e,5)){Vh(v[a+28>>2],d+55|0);xm(v[a+28>>2],w[d+55|0],-1)}d:{if(!Ej(w[d+47|0],0)){break d}Vh(v[a+28>>2],d+55|0);b=w[d+55|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break d}uh(a,536871168)}v[a+4>>2]=0;b=1;if(Ej(w[d+47|0],1)){AL(v[a+28>>2],a+4|0)}zl(a,6,Ej(e,2));zl(a,7,Ej(e,3));zl(a,5,x[a+16>>1]!=0);zl(a,8,Ej(e,7));e:{if(nd(a,5)){break e}if(nd(a,6)){break e}if(nd(a,7)){break e}b=nd(a,8)}zl(a,11,b);nd(a,11);b=w[d+47|0];if(Ej(b,2)){u[d+16>>1]=0;Sy(v[a+28>>2],d+16|0);xm(v[a+28>>2],B(x[d+16>>1],nd(a,9)?2:1),-1);b=w[d+47|0]}if(Ej(b,3)){xm(v[a+28>>2],5,-1)}yl(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){uh(a,1073741831);break a}v[a+92>>2]=b;if(!b){uh(a,536871040)}f:{if(!nd(a,11)){break f}yl(v[a+28>>2],d+32|0);b=v[d+36>>2];if((b|0)==2147483647|b>>>0<2147483647){break f}uh(a,1073741829);break a}se(d,v[a+28>>2]);WL(d+16|0,d,v[a+8>>2],v[a+12>>2]);b=v[d+28>>2];e=v[d+24>>2];if(!(!b&((b|0)>0|(b|0)>=0))){uh(a,1073741832);break a}v[a+88>>2]=e;k=a,l=v[(nd(a,11)?d+32|0:a+88|0)>>2],v[k+64>>2]=l;if(!nd(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}zl(a,10,1)}gb=d+320|0}function CU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=ne(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=gb-16|0;gb=b;d=Pj(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[pd(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}h=c;d=(d|0)/32|0;c=d<<2;yh(h,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}ne(a,f);gb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=ne(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=gb-16|0;gb=f;d=Pj(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;d=f+8|0;b=v[pd(d,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;h=v[g+4>>2];j=v[v[e+24>>2]>>2];k=v[e+28>>2];v[f+8>>2]=b;h=32-h|0;v[f+4>>2]=h;l=Fb(d,f+4|0);i=v[g>>2];j=j&(-1<<k&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];k=h;h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=pd(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}ne(a,g);gb=f+16|0}gb=e+80|0}function noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=gb-128|0;gb=c;f=gb-32|0;gb=f;d=f+24|0;h=b+16|0;DW(d,h);e=yb(d);d=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;d=a;g=f+16|0;cc(g,d,f);g=yb(g);if((g|0)==(e|0)){Rb(d,yb(f+24|0))}gb=f+32|0;if((e|0)!=(g|0)){Qb(h,0,128)}gX(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;d=c+80|0;Sd(d,a,sg(a));f=kc(c+104|0,d);xb(d);v[22708]=0;d=T(467,f|0)|0;e=v[22708];v[22708]=0;a:{b:{if((e|0)==1){break b}v[22708]=0;e=b+4|0;R(440,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;Ud(c+72|0,e);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;d=v[c+76>>2];v[c+8>>2]=v[c+72>>2];v[c+12>>2]=d;U(633,c+80|0,f|0,c+8|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;d=T(192,a|0)|0;e=v[22708];v[22708]=0;c:{if((e|0)==1){break c}v[22708]=0;U(288,c+48|0,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=c+48|0;d=kc(c+80|0,a);xb(a);v[22708]=0;a=T(275,d|0)|0;e=v[22708];v[22708]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[22708]=0;a=Q(191,d|0,5)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(!a){break f}v[22708]=0;Q(634,d|0,c+44|0)|0;a=v[22708];v[22708]=0;h:{if((a|0)!=1){a=4;e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);if((e|0)==1414682436|(e|0)==1196380752){break h}v[22708]=0;a=T(192,d|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22708]=0;U(288,c+24|0,d|0,a|0);a=v[22708];v[22708]=0;i:{j:{k:{if((a|0)!=1){e=c+24|0;a=kc(c+48|0,e);xb(e);if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1414682436){break k}v[22708]=0;i=C(Ba(635,a|0));a=v[22708];v[22708]=0;if((a|0)==1){break g}z[c+24>>2]=i;v[c+20>>2]=0;v[22708]=0;v[c+16>>2]=1065353216;a=Af(c+24|0,c+20|0,c+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break g}e=v[a>>2];z[b+144>>2]=z[a>>2];if(e+8388608&2130706432){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1196380752){break j}v[22708]=0;a=T(192,a|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}v[b+148>>2]=a}xb(c+48|0);continue}}break}a=P()|0;O()|0;xb(c+48|0);break d}xb(d);xb(f);gb=c+128|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}xb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);S(a|0);L()}function Qla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=gb-16|0;gb=h;a:{if(!Pb(a,2)){wh(c+484344|0,b,64);break a}m=c+484344|0;k=Fd(Lr(a),1,1024);if(!wh(m,b,k)|!k){break a}n=x[c+480188>>1];while(1){o=Tf(_b(m,b),l);i=0;if(n){while(1){g=h+8|0;wn(g,a);e=B(i,6)+o|0;j=qd(g);p=Ve(g);f=fj(g);g=w[g|0];b:{if((g-1&255)>>>0>35){break b}t[e|0]=g+48;g=w[j|0]+1|0;t[e+1|0]=g;j=g;g=g&255;if((j|0)!=(g|0)|g>>>0>x[c+480190>>1]){break b}g=Ak(c,w[e+1|0]);j=ic(d,i);if(!(!w[j|0]|x[g+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}g=g+68|0;if(!(q=v[Pe(g,0)>>2]==1,r=0,s=w[j|0],s?q:r)){if(v[Pe(g,0)>>2]|w[j|0]){break b}}t[e+1|0]=w[e+1|0]+100}c:{d:{switch(w[p|0]){case 1:if(!w[f|0]){break c}t[e+3|0]=2;t[e+5|0]=w[f|0];break c;case 2:if(!w[f|0]){break c}t[e+3|0]=3;t[e+5|0]=w[f|0];break c;case 12:if(!w[f|0]){break c}t[e+3|0]=1;t[e+5|0]=w[f|0];break c;case 13:if(!w[f|0]){break c}t[e+3|0]=39;t[h+7|0]=15;q=e,r=w[ac(h+7|0,f)|0]|16,t[q+5|0]=r;break c;case 30:if(!w[f|0]){break c}t[e+3|0]=38;t[h+6|0]=15;q=e,r=w[ac(h+6|0,f)|0]|16,t[q+5|0]=r;break c;case 21:if(!w[f|0]){break c}t[e+3|0]=39;t[h+5|0]=15;q=e,r=w[ac(h+5|0,f)|0]|80,t[q+5|0]=r;break c;case 17:if(!w[f|0]){break c}t[e+3|0]=38;t[h+4|0]=15;q=e,r=w[ac(h+4|0,f)|0]|80,t[q+5|0]=r;break c;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break c;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break c;case 27:$o(e);t[e|0]=255;break c;case 28:if(w[f|0]>31){break c}t[e+3|0]=16;t[e+5|0]=w[f|0];break c;case 31:g=w[f|0];if(g&15){q=e,r=w[ic(d,i)|0]?22:11,t[q+3|0]=r;t[e+5|0]=w[f|0]&15;g=w[f|0]}e:{f:{switch(g>>>4|0){case 4:if((g|0)!=64){break e}case 0:case 1:case 2:case 3:if(w[ic(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break e}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break e;case 5:t[e+5|0]=w[e+5|0]<<4;break e;case 6:t[h+3|0]=w[e+5|0];t[h+2|0]=14;q=e,r=w[ac(h+3|0,h+2|0)|0]|240,t[q+5|0]=r;break e;case 7:t[h+1|0]=w[e+5|0];t[h|0]=14;q=e,r=w[ac(h+1|0,h)|0]<<4|15,t[q+5|0]=r;break e;default:break f}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break c}f=B(t[ic(d,i)|0]+i|0,6)+o|0;g=f;if(Xt(f+3|0,f+5|0,1)){t[f+2|0]=w[g+3|0];t[f+4|0]=w[f+5|0]}t[g+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break c;case 0:break c;default:break d}}t[e+3|0]=0}i=i+1|0;if((n|0)!=(i|0)){continue}break}}l=l+1|0;if((l|0)!=(k|0)){continue}break}}gb=h+16|0}function q3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;m=zD(g);q=zx(g);Ug(l,q);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22708]=0;g=Q(22,m|0,g<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22708]=0;i=Q(22,m|0,48)|0;j=v[22708];v[22708]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=t[h+1|0];v[22708]=0;i=Q(22,m|0,i|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=h+2|0;if(i>>>0>=c>>>0){g=i;break d}h=g+h|0;g=i;e:{while(1){j=t[g|0];v[22708]=0;k=ga(2478)|0;n=v[22708];v[22708]=0;if((n|0)==1){break e}v[22708]=0;j=Fx(j,k);k=v[22708];v[22708]=0;if((k|0)==1){break e}if(!j){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}i=g+h|0;g=h;while(1){j=t[g|0];v[22708]=0;ga(2478)|0;k=v[22708];v[22708]=0;if((k|0)==1){break a}v[22708]=0;j=Qh(j);k=v[22708];v[22708]=0;if((k|0)==1){break a}if(!j){break f}g=g+1|0;if((i|0)!=(g|0)){continue}break}g=i}i=h}g:{if(gd(l)){h=v[f>>2];v[22708]=0;Y(2474,m|0,i|0,g|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break g}pm(i,g);v[22708]=0;j=T(2466,q|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}if(g>>>0>i>>>0){h=i;while(1){h:{if(t[pc(l,p)|0]<1){break h}if(t[pc(l,p)|0]!=(o|0)){break h}o=v[f>>2];v[f>>2]=o+1;t[o|0]=j;p=(Ab(l)-1>>>0>p>>>0)+p|0;o=0}k=t[h|0];v[22708]=0;k=Q(22,m|0,k|0)|0;n=v[22708];v[22708]=0;if((n|0)==1){break a}n=v[f>>2];v[f>>2]=n+1;t[n|0]=k;o=o+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}}pm((i-a|0)+d|0,v[f>>2])}i:{if(c>>>0<=g>>>0){break i}while(1){h=w[g|0];if((h|0)==46){v[22708]=0;h=T(2475,q|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;break i}v[22708]=0;h=Q(22,m|0,h<<24>>24)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=c}h=v[f>>2];v[22708]=0;Y(2474,m|0,g|0,c|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g|0)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function Hpa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;a:{b:{c:{d:{i=a+24|0;e:{if(Dd(i)){break e}h=a+4|0;j=Ab(h);a=gb-48|0;gb=a;c=a+40|0;b=c;v[b>>2]=-1;v[b+4>>2]=-1;v[22708]=0;b=pG(2292);d=v[22708];v[22708]=0;if((d|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;g=a+16|0;d=g;k=b,l=nqa(v[d>>2],v[d+4>>2],1e3,0),v[k>>2]=l;v[b+4>>2]=jb;d=Yl(b+8|0,b);f=v[d+4>>2];gb=b+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;d=a+24|0;b=d;b=PC(v[b>>2],v[b+4>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;hX(c,d,wb(d));v[22708]=0;b=pG(2293);f=v[22708];v[22708]=0;if((f|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;f=v[g+4>>2];v[b>>2]=v[g>>2];v[b+4>>2]=f;g=Yl(b+8|0,b);f=v[g+4>>2];gb=b+16|0;v[a+24>>2]=v[g>>2];v[a+28>>2]=f;b=PC(v[d>>2],v[d+4>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;hX(c,d,wb(d));d=v[c>>2];c=v[c+4>>2];gb=a+48|0;if(j){b=mc(e+32|0);v[22708]=0;v[e+16>>2]=c;R(40,b|0,e+16|0);a=v[22708];v[22708]=0;f:{g:{h:{if((a|0)!=1){v[22708]=0;v[e+16>>2]=d;R(40,b|0,e+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}if(Ab(h)){a=0;while(1){c=w[pc(h,a)|0];v[22708]=0;v[e+16>>2]=c;R(40,b|0,e+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}a=a+1|0;if(Ab(h)>>>0>a>>>0){continue}break}}a=Vb(b);c=Zb(b);v[22708]=0;c=W(41,e+16|0,a|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;a=T(42,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}v[e+8>>2]=a;a=e+8|0;VC(i,a);ln(a);Lc(c);Lc(b);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Lc(c);break b}jb=d;v[e+16>>2]=c;v[e+20>>2]=jb;b=e+32|0;a=mc(b);v[22708]=0;U(49,b|0,e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){b=P()|0;O()|0;Lc(a);S(b|0);L()}v[22708]=0;a=T(42,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[e+8>>2]=a;a=e+8|0;VC(i,a);ln(a);Lc(b)}gb=e+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(b);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-48|0;gb=l;f=v[a+4>>2];e=ne(l+40|0,b);j=ne(l+32|0,c);d=gb-16|0;gb=d;e=BU(ne(d+8|0,e),ne(d,j));gb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}v[v[a>>2]+((d>>>0<33?0:e>>>5|0)<<2)>>2]=0}d=ne(l+24|0,b);g=ne(l+16|0,c);c=l+8|0;yp(c,a,f);b=l;j=gb-48|0;gb=j;c:{if(v[d+4>>2]==v[c+4>>2]){d=ne(j+40|0,d);e=ne(j+32|0,g);f=ne(j+24|0,c);a=gb-16|0;gb=a;c=Pj(e,d);v[a+12>>2]=c;d:{if((c|0)<1){break d}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[pd(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;yh(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break d}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];i=d;n=v[d>>2];d=-1>>>32-e|0;v[i>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}ne(b,f);gb=a+16|0;break c}e=ne(j+16|0,d);a=ne(j+8|0,g);d=ne(j,c);f=gb-16|0;gb=f;a=Pj(a,e);v[f+12>>2]=a;e:{if((a|0)<1){break e}c=v[e+4>>2];f:{if(!c){c=v[d+4>>2];break f}c=32-c|0;v[f+8>>2]=c;g=f+8|0;a=v[pd(g,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;h=v[d+4>>2];k=v[v[e>>2]>>2];i=v[e+4>>2];v[f+8>>2]=a;m=32-h|0;v[f+4>>2]=m;n=Fb(g,f+4|0);h=v[d>>2];k=k&(-1<<i&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];i=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=i|v[h>>2]&(-1<<c&-1>>>m-g^-1);i=c+g|0;c=i&31;v[d+4>>2]=c;h=h+(i>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;i=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=i&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break e}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=pd(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];i=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=i|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break e}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}ne(b,d);gb=f+16|0}gb=j+48|0;gb=l+48|0}function oR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-96|0;gb=g;t[g+95|0]=d;n=TA(a);o=Ti(n);u[b>>1]=0;a:{if(o){while(1){b:{if(!Oo(n,h&65535)){break b}h=x[b>>1];if(Ec(a)>>>0<=h>>>0){v[c>>2]=0;a=1;break a}m=Ad(a,x[b>>1]);zk(g+72|0,m);Ul(g- -64|0,m);h=v[g+76>>2];v[g+32>>2]=v[g+72>>2];v[g+36>>2]=h;h=v[g+68>>2];v[g+24>>2]=v[g+64>>2];v[g+28>>2]=h;l=g+80|0;e=g+32|0;j=g+24|0;h=gb-32|0;gb=h;c:{if(w[g+95|0]){f=v[e+4>>2];v[h+24>>2]=v[e>>2];v[h+28>>2]=f;e=Pj(j,e);j=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=j;j=gb-16|0;gb=j;v[j+12>>2]=e;i=h+8|0;f=v[i+4>>2];d:{if(f){v[j+8>>2]=32-f;e=Fb(j+8|0,j+12|0);k=v[i>>2];e=v[e>>2];f=v[k>>2]&(-1<<f&-1>>>v[j+8>>2]-e);if(f){td(l,k,mqa(f));break d}f=v[j+12>>2];if((f|0)==(e|0)){_Q(l,i,e);break d}e=f-e|0;v[j+12>>2]=e;v[i>>2]=k+4}if(e>>>0>=32){f=v[i>>2];while(1){k=v[f>>2];if(k){td(l,f,mqa(k));break d}f=f+4|0;v[i>>2]=f;e=e-32|0;v[j+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){f=v[i>>2];break e}f=v[i>>2];i=v[f>>2]&-1>>>32-e;if(!i){break e}td(l,f,mqa(i));break d}td(l,f,e)}gb=j+16|0;break c}f=v[e+4>>2];v[h+16>>2]=v[e>>2];v[h+20>>2]=f;e=Pj(j,e);j=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=j;f=gb-16|0;gb=f;v[f+12>>2]=e;j=h;i=v[h+4>>2];f:{if(i){v[f+8>>2]=32-i;e=v[Fb(f+8|0,f+12|0)>>2];k=-1<<i&-1>>>v[f+8>>2]-e;i=v[j>>2];k=k&(v[i>>2]^-1);if(k){td(l,i,mqa(k));break f}k=v[f+12>>2];if((k|0)==(e|0)){_Q(l,j,e);break f}e=k-e|0;v[f+12>>2]=e;v[j>>2]=i+4}if(e>>>0>=32){i=v[j>>2];while(1){k=v[i>>2];if((k|0)!=-1){td(l,i,mqa(k^-1));break f}i=i+4|0;v[j>>2]=i;e=e-32|0;v[f+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){i=v[j>>2];break g}i=v[j>>2];j=(v[i>>2]^-1)&-1>>>32-e;if(!j){break g}td(l,i,mqa(j));break f}td(l,i,e)}gb=f+16|0}gb=h+32|0;if(d){h=g+56|0;Ul(h,m);if(!nR(g+80|0,h)){break b}v[c>>2]=0;a=1;break a}h=g+56|0;Ul(h,m);if(nR(g+80|0,h)^1){zk(g+48|0,m);a=v[g+84>>2];b=v[g+80>>2];v[g+40>>2]=b;v[g+44>>2]=a;d=v[g+52>>2];v[g+16>>2]=v[g+48>>2];v[g+20>>2]=d;v[g+8>>2]=b;v[g+12>>2]=a;p=c,q=DU(g+16|0,g+8|0),v[p>>2]=q;a=1;break a}if(y[m+4>>2]>=y[_b(v[a+24>>2]+484344|0,x[sc(n,x[b>>1])>>1])+12>>2]){break b}v[c>>2]=v[m+4>>2];a=1;break a}h=x[b>>1]+1|0;u[b>>1]=h;if((h&65535)>>>0<o>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}gb=g+96|0;return a|0}function Sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-1184|0;gb=d;vc(b);a:{if(!Yw(b,d+1160|0)){break a}if(!ON(d+1160|0)){break a}e=d+1168|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(lm(b)|0)){break a}f=d+1176|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=(nf(b)|0)){break a}if(!c){g=1;break a}e=d+1104|0;Qb(e,0,56);i=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;h=v[e+32>>2];if(!h){v[e+32>>2]=2283;h=2283}if(!v[e+36>>2]){v[e+36>>2]=2284}h=kb[h|0](v[e+40>>2],1,43784)|0;i=-4;if(!h){break b}v[e+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;i=0}if(i){break a}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+1100>>2]=e;g=d+1180|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=(g|0)!=0;h=pX(d+1088|0,g);c:{d:{e:{f:{g:{h:{i:{j:{if(!e|!g){break j}while(1){v[22708]=0;v[d+48>>2]=1024;e=Fb(d+48|0,d+1100|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}e=v[e>>2];f=wd(d+56|0,d- -64|0,e);v[22708]=0;i=v[f+4>>2];v[d+24>>2]=v[f>>2];v[d+28>>2]=i;U(201,d+48|0,b|0,d+24|0);f=v[22708];v[22708]=0;if((f|0)==1){break h}v[22708]=0;j=sJ(j,d- -64|0,e);f=v[22708];v[22708]=0;if((f|0)==1){break i}v[d+1120>>2]=g;v[d+1108>>2]=e;v[d+1104>>2]=d- -64;f=v[h>>2];v[22708]=0;v[d+1116>>2]=f+k;l=Q(1471,d+1104|0,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}i=v[d+1100>>2]-e|0;v[d+1100>>2]=i;e=v[d+1120>>2];f=(e|0)!=0;if(!i|!e){break j}k=(g+k|0)-e|0;g=e;if((l|0)!=1){continue}break}}v[22708]=0;T(1472,d+1104|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}g=0;b=d+1172|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|f|(l|0)!=1)){v[22708]=0;Ud(d+40|0,h);b=v[22708];v[22708]=0;if((b|0)==1){break f}b=Td(d+32|0);v[22708]=0;g=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=g;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=W(732,d- -64|0,d+16|0,d+8|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[22708]=0;g=W(1385,a|0,b|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}xb(b)}gc(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;xb(b);break c}a=P()|0;O()|0}gc(h);S(a|0);L()}gb=d+1184|0;return g|0}function afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;v[22708]=0;e=T(788,a|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){a:{b:{if(e){break b}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}i=Fd(e+1|0,1,1024);v[22708]=0;k=d+484344|0;e=W(331,k|0,b|0,i|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}if(!e){break b}d=x[d+480188>>1];if(!d|!i){break b}l=d-1|0;while(1){v[22708]=0;d=Q(191,a|0,1)|0;e=v[22708];v[22708]=0;c:{d:{if((e|0)!=1){if(!d){break b}v[22708]=0;g=T(374,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}if(g){break d}j=j+1|0;break c}break a}d=_b(k,b);u[h+14>>1]=g&31;v[22708]=0;u[h+12>>1]=l;e=Pc(h+14|0,h+12|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}e=x[e>>1];v[22708]=0;d=Yc(d,j,e);e=v[22708];v[22708]=0;if((e|0)==1){break a}if(!(g&224)){break c}e:{if(!(g&128)){break e}v[22708]=0;e=T(374,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[d+5|0]=e;v[22708]=0;e=T(374,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+49024|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Fd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){n=d,o=ei(e<<1),t[n+5|0]=o;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[22708]=0;Zt(d);e=v[22708];v[22708]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}m=d;e=w[d+5|0];f=e&240;h:{if((f|0)==16){f=2}else{if((f|0)!=32){break h}f=3}t[m+3|0]=f}t[d+5|0]=e&15|224;break e}t[d+3|0]=0}i:{if(!(g&64)){break i}v[22708]=0;R(403,h+8|0,a|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}e=h+8|0;f=qd(e);t[d+1|0]=w[e|0];e=w[f|0];t[d|0]=e;f=255;if((e|0)!=128){f=253;if(e>>>0<129){break i}}t[d|0]=f}if(!(g&32)){break c}t[d+2|0]=1;v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}t[d+4|0]=e;if(!c){break c}t[d+4|0]=(e<<6>>>0)/127}if(i>>>0>j>>>0){continue}break}}xb(a);gb=h+16|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-160|0;gb=d;a:{if(pk(b)){break a}e=w[ul(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Jl(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}f=d+128|0;Ld(f);e=v[d+128>>2];Ld(d+112|0);e=tl(e,v[d+116>>2],b);Ld(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=uc(d+144|0,18726);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22708]=0;c=Q(70,d+128|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;f=0;if(!c){break g}a=ba(8)|0;v[22708]=0;c=Q(2059,d+112|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(2039,d+128|0,14764,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}rc(a,d+128|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d+128|0);vb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=1){a=ba(8)|0;v[22708]=0;c=Q(70,d+128|0,8874)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,18726);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){a=ba(8)|0;v[22708]=0;c=Q(70,d+128|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=uc(d+80|0,8207);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break g}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=uc(d- -64|0,5758);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Gc(d+24|0,d+16|0)){break g}e=Hy(v[a+32>>2]);f=0}gb=d+160|0;jb=f;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c)}ca(a|0)}S(b|0)}L()}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[22708]=0;X(2029);c=v[22708];v[22708]=0;a:{b:{if((c|0)==1){c=Sa(54936,89104,89080,0)|0;c:{d:{e:{d=O()|0;if((d|0)==(ea(54936)|0)){c=Z(c|0)|0;v[22708]=0;Q(1919,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Q(1919,a|0,14864)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Q(1919,a|0,14840)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22708]=0;Q(1919,a|0,(b?b:18726)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(89104)|0)==(d|0)){c=Z(c|0)|0;v[22708]=0;Q(1919,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;Q(1919,a|0,14864)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;Q(1919,a|0,14815)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22708]=0;Q(1919,a|0,(b?b:18726)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(89080)|0;c=Z(c|0)|0;g:{if((d|0)==(e|0)){v[22708]=0;Q(1919,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;Q(1919,a|0,14864)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;Q(1919,a|0,14831)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22708]=0;Q(1919,a|0,(b?b:18726)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22708]=0;Q(1919,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(1919,a|0,14864)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(1919,a|0,11040)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Bb()}L()}return}vb(a);S(b|0);L()}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;a:{if(pk(c)){break a}f=w[ul(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}f=e+128|0;Ld(f);g=v[e+128>>2];Ld(e+112|0);h=tl(g,v[e+116>>2],c);Ld(f);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{f:{g:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=uc(e+144|0,18726);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Gc(e+8|0,e)){a=ba(8)|0;v[22708]=0;b=Q(70,e+128|0,7752)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(d){a=ba(8)|0;v[22708]=0;b=Q(2059,e+112|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;U(2039,e+128|0,14764,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break e}rc(a,e+128|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+128|0);vb(b);break c}c=P()|0;O()|0;break d}Kb(a);break g}v[e+104>>2]=f;v[e+108>>2]=g;d=uc(e+96|0,18726);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){a=ba(8)|0;v[22708]=0;b=Q(70,e+128|0,7752)|0;c=v[22708];v[22708]=0;if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=uc(e+80|0,9597);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){h:{switch(v[b+52>>2]){case 0:Tb(a,2693);break g;case 1:Tb(a,8575);break g;case 2:Tb(a,6363);break g;default:break h}}Kb(a);break g}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=uc(e- -64|0,8812);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Gc(e+24|0,e+16|0)){i:{switch(v[b+56>>2]){case 0:Tb(a,12689);break g;case 1:Tb(a,12694);break g;case 2:Tb(a,9902);break g;case 3:Tb(a,6427);break g;default:break i}}Kb(a);break g}Kb(a)}gb=e+160|0;return}c=P()|0;O()|0;ca(a|0);break c}c=P()|0;O()|0;vb(b)}ca(a|0)}S(c|0)}L()}function uZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=gb-32|0;gb=e;j=cj(e+24|0);if(v[a+12>>2]){q=b^1;r=j+3|0;s=j+5|0;x=j+4|0;z=j+2|0;A=j+1|0;d=e+16|0;C=d|5;D=d|3;while(1){E=Tf(a,n);while(1){a:{if(!Pb(c,1)){break a}k=Ae(c);if((k|0)==255){break a}h=k&31;d=Li(a)>>>0>h>>>0;h=B(h,6)+E|0;if(k&64){l=1}else{f=Ae(c);i=f<<24>>24;g=255;f=f&127;b:{c:{if((f|0)==1){break c}g=f-1|0;if(((g&255)>>>0>120|q)!=1){break c}if((f-12&255)>>>0>96|b){break b}g=f+13|0}t[(d?h:e+24|0)|0]=g}F=d?h+1|0:A,G=Ae(c),t[F|0]=G;l=(i|0)<0}if(l){p=d?h:j;f=d?h+3|0:r;g=d?h+5|0:s;o=d?h+4|0:x;m=d?h+2|0:z;h=d?h:e+24|0;while(1){d=h;v[e+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Ae(c);l=d&128;i=d&63;d:{if(d&64){t[m|0]=1;t[o|0]=i;break d}d=Ae(c);t[g|0]=d;e:{f:{if(i>>>0<=15){t[f|0]=i;Of(p);g:{h:{i:{d=w[f|0];switch(d-9|0){case 1:case 2:case 3:break e;case 4:break h;case 0:break i;default:break g}}t[f|0]=9;t[g|0]=B(w[g|0]&15,17);break e}t[f|0]=0;t[m|0]=1;v[e+12>>2]=w[g|0]+1>>>1;v[e+8>>2]=64;F=o,G=v[pd(e+12|0,e+8|0)>>2],t[F|0]=G;break e}if((d|0)!=19){break e}if(w[g|0]==128){break f}Zt(p);break e}if(i>>>0>44){break e}t[f|0]=w[i+28448|0];j:{switch(i-16|0){case 0:if(d>>>0>1){break f}t[g|0]=d|158;break e;case 1:case 2:t[e+12|0]=15;F=g,G=w[ac(e+12|0,g)|0]|224,t[F|0]=G;break e;case 5:case 6:v[e+12>>2]=16;v[e+8>>2]=d+1;F=g,G=v[pd(e+12|0,e+8|0)>>2]/2|240,t[F|0]=G;break e;case 14:k:{l:{m:{n:{o:{i=d>>>4|0;switch(i-1|0){case 1:break m;case 0:break n;default:break o}}switch(i-10|0){case 1:break k;case 0:break l;default:break f}}t[f|0]=2;t[g|0]=d|240;break e}t[f|0]=3;t[g|0]=d|240;break e}t[f|0]=11;t[g|0]=(d<<3&120)+8|15;break e}t[f|0]=11;t[g|0]=(d&15)+1>>>1|240;break e;case 12:break j;default:break e}}v[e+12>>2]=d+1>>>1;v[e+8>>2]=64;F=g,G=v[pd(e+12|0,e+8|0)>>2],t[F|0]=G;break e}t[f|0]=0}qz(f,g,D,C);if(uo(w[e+19|0])>>>0<=uo(w[f|0])>>>0){break d}p:{if(w[m|0]){break p}if(!Xt(f,g,1)){break p}t[m|0]=w[f|0];t[o|0]=w[g|0]}t[f|0]=w[e+19|0];t[g|0]=w[e+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}gb=e+32|0}function tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=gb-1120|0;gb=d;v[d+1116>>2]=c;j=nD(d+56|0,b);v[22708]=0;p=nn(j);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){f=mc(a);v[22708]=0;a=T(467,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break h}v[d+16>>2]=a;v[22708]=0;v[d+48>>2]=85899345;a=Fb(d+16|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}a=v[a>>2];v[22708]=0;v[d+32>>2]=B(a,50);a=Fb(d+1116|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}a=v[a>>2];v[22708]=0;R(499,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;e=T(512,d+32|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}a=0;v[22708]=0;g=Q(513,d+16|0,8192)|0;c=v[22708];v[22708]=0;if((c|0)==1){break e}while(1){s=Mb(e,a),z=8192,u[s>>1]=z;s=Mb(e,a),z=a,t[s+2|0]=z;a=a+1|0;if((a|0)!=256){continue}break}m=9;break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}i:{j:while(1){c=0;n=257;while(1){q=m&255;k:{while(1){i=n&65535;while(1){v[22708]=0;h=Q(200,j|0,q|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}k=h&65535;if((k|0)==257|i>>>0<k>>>0){break k}if(oc(f)>>>0>=y[d+1116>>2]){break k}if((k|0)==256){m=9;continue j}a=i>>>0>k>>>0?h:c;l=8192;while(1){a=a&65535;r=w[Mb(e,a)+2|0];l=l-1|0;o=l&65535;s=lc(g,o),z=r,t[s|0]=z;a=x[Mb(e,a)>>1];if(a>>>0<8192){continue}break}s=d,z=Zb(f),v[s+48>>2]=z;Gd(d+8|0,d+48|0);s=d,z=Vb(g),v[s>>2]=z;a=we(d,o);l=Zb(g);v[22708]=0;Y(500,f|0,v[d+8>>2],a|0,l|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}l:{if((i|0)!=(k|0)){break l}a=lc(g,o);v[22708]=0;R(514,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break l}break i}if(i>>>0>=8192){c=h;continue}if(oc(f)>>>0>=y[d+1116>>2]){continue}break}a=lc(g,o);s=Mb(e,i),z=w[a|0],t[s+2|0]=z;s=Mb(e,i),z=c,u[s>>1]=z;a=n+1|0;n=8192;c=h;h=a&65535;if((h|0)==8192){continue}break}m=((h|0)==1<<q)+m|0;n=a;continue}break}break}v[22708]=0;a=nn(j);c=v[22708];v[22708]=0;m:{if((c|0)!=1){v[22708]=0;Q(190,b|0,((a-p|0)+3&-4)+p|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break m}}break i}gc(g);hD(e);xb(j);gb=d+1120|0;return}a=P()|0;O()|0;gc(g)}hD(e)}gc(f)}xb(j);S(a|0);L()}function Bu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-48|0;gb=f;v[f+32>>2]=c;u[f+38>>1]=b;i=TA(a);a:{if(tc(i)>>>0<=b>>>0){break a}if(wR(a,x[sc(i,b)>>1])>>>0<=c>>>0){break a}b:{if(Ec(a)>>>0>b>>>0){if(y[Ad(a,b)+4>>2]>c>>>0){break b}}Jo(a,0);if(Ec(a)>>>0<=b>>>0){break a}}g=x[v[a+24>>2]+480188>>1];c=f+16|0;b=v[d>>2];v[c>>2]=b;v[c+4>>2]=b+B(g,872);d=f+24|0;b=d;v[b>>2]=-2078137563;v[b+4>>2]=-873292572;g=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;b=c;if(yR(b)){while(1){e=w[NT(b,h)+841|0];l=e^nqa(g^h,i^j,435,256);e=!e;g=(o=g,p=nqa(l,jb,435,256),q=e,q?o:p);i=e?i:jb;e=h+1|0;j=e>>>0<1?j+1|0:j;h=e;if(!j&yR(b)>>>0>e>>>0){continue}break}}v[d>>2]=g;v[d+4>>2]=i;i=Um(c,f+38|0,f+32|0);j=gb-16|0;gb=j;e=j+8|0;h=gb-16|0;gb=h;l=a+12|0;g=l;b=Xd(g);m=fR(g,i,b,fc(g));v[h+8>>2]=m;o=h,p=Ch(g),v[o>>2]=p;c:{if(Gb(h+8|0,h)){if(!Ml(wb(g),i,ue(h+8|0))){break c}}m=Ch(g)}gb=h+16|0;b=v[yc(e,m)>>2];gb=j+16|0;v[f+8>>2]=b;o=f,p=Dh(l),v[o+16>>2]=p;b=0;if(og(f+8|0,c)){b=cd(ue(f+8|0)+8|0)^1}h=v[d>>2]!=-2078137563|v[d+4>>2]!=-873292572;c=f+16|0;Ce(c,Ad(a,x[f+38>>1]),v[f+32>>2]);m=1;i=b|h;j=Cb(c)^1;if(!(j?1:i)){break a}if(b){g=ue(f+8|0)+8|0;n=Vb(g);e=Zb(g);c=d;k=gb-16|0;gb=k;v[k>>2]=e;v[k+8>>2]=n;if(Gb(k+8|0,k)){while(1){e=v[k+8>>2];if(v[e>>2]!=v[c>>2]|v[e+4>>2]!=v[c+4>>2]){e=k+8|0;Cu(e);if(Gb(e,k)){continue}}break}n=v[k+8>>2]}gb=k+16|0;v[f+16>>2]=n;o=f,p=Zb(g),v[o+40>>2]=p;if(Gb(f+16|0,f+40|0)){break a}}if(h){v[a+28>>2]=v[a+28>>2]+1}if(i){if(!(b|j)){d:{e=pR(l,Um(f+16|0,f+38|0,f+32|0));if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=bR(b,e);wb(e);aR(v[c+4>>2]);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break d}c=gb-32|0;gb=c;b=wb(e);b=SA(c+8|0,gs(e,sf(e)+1|0),sf(e),b);aR(v[b+8>>2]);v[b+8>>2]=v[b+8>>2]+8;RA(e,b);QA(b);gb=c+32|0}}e=pR(l,Um(f+16|0,f+38|0,f+32|0));e:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=bR(b,e);wb(e);$Q(v[c+4>>2],d);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break e}c=gb-32|0;gb=c;b=wb(e);b=SA(c+8|0,gs(e,sf(e)+1|0),sf(e),b);$Q(v[b+8>>2],d);v[b+8>>2]=v[b+8>>2]+8;RA(e,b);QA(b);gb=c+32|0}}b=f+16|0;Ce(b,Ad(a,x[f+38>>1]),v[f+32>>2]);Uf(b,1);m=0}gb=f+48|0;return m|0}function N9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{k=Vp(1,32);d:{e:{if(!k){a=ba(4)|0;nm(a);v[22708]=0;U(186,a|0,89104,1930);a=v[22708];v[22708]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1921;d=Au(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,j+48|0,c|0)|0;f=v[22708];v[22708]=0;i:{if((f|0)!=1){v[22708]=0;f=Q(1931,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break i}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22708]=0;c=Q(70,j+48|0,c|0)|0;e=v[22708];v[22708]=0;j:{if((e|0)!=1){v[22708]=0;R(1932,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22708]=0;a=T(1291,96)|0;i=v[22708];v[22708]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22708]=0;b=Q(1933,k|0,k+4|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[j+48>>2]=b;b=v[iq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22708]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;da(2007,a|0,j+8|0,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}v[k+28>>2]=a;Dj(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Kl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Dj(j+48|0)}Yb(a)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1913,8630,k|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){a=v[k+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Yb(a);v[k+20>>2]=0}Yb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}Z(i|0)|0;k=0;v[22708]=0;Y(1913,8630,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=j+80|0;return k|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=d;k=fg(a,c);se(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}f=v[h+24>>2];d=gb-160|0;gb=d;i=Hm(d+56|0,v[a+28>>2]);v[22708]=0;g=Q(620,d+40|0,34104)|0;e=v[22708];v[22708]=0;b:{c:{d:{e:{if((e|0)!=1){v[22708]=0;v[d+24>>2]=19923026;v[d+28>>2]=0;U(621,i|0,g|0,d+24|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}Hb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}t[d+39|0]=0;v[22708]=0;g=Q(620,d+40|0,2597)|0;e=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[22708]=0;W(622,i|0,d+39|0,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}Hb(g);g=Kb(d+40|0);v[22708]=0;e=Q(620,d+24|0,7364)|0;j=v[22708];v[22708]=0;if((j|0)==1){break p}v[22708]=0;U(1093,i|0,g|0,e|0);j=v[22708];v[22708]=0;if((j|0)==1){break o}Hb(e);v[22708]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break n}v[22708]=0;R(418,b|0,d+24|0);e=v[22708];v[22708]=0;if((e|0)==1){break m}e=d+24|0;vb(e);u[d+22>>1]=0;v[22708]=0;e=Q(620,e|0,8041)|0;f=v[22708];v[22708]=0;if((f|0)==1){break g}v[22708]=0;W(1094,i|0,d+22|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}Hb(e);yg(d+22|0,4e3);v[22708]=0;e=Q(620,d+24|0,10749)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=v[yc(d+16|0,x[d+22>>1])>>2];v[22708]=0;Y(1095,i|0,b|0,e|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}Hb(e);u[d+14>>1]=65535;v[22708]=0;e=Q(620,d+24|0,6095)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}v[22708]=0;f=W(1094,i|0,d+14|0,e|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Hb(e);if(!((f|0)==1|j>>>0<=l>>>0)){cf(b,x[d+14>>1])}vb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+24|0);break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0}vb(g)}gh(i);S(a|0);L()}gh(i);gb=d+160|0}Zf(a,k,c,h+16|0);gb=h+32|0}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Td(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=lg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Jd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);p=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=nqa(l,s,f,f>>31);l=jb;p=nqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Vy(a){a=a|0;var b=0,c=0,d=C(0),e=0;Qb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22708]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ha(1840,e|0,67,5,c|0,b|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22708]=0;ha(1840,a+4528|0,62,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22708]=0;ha(1840,a+4552|0,53,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22708]=0;ha(1840,a+4576|0,43,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22708]=0;ha(1840,a+4600|0,32,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22708]=0;ha(1840,a+4624|0,22,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22708]=0;ha(1840,a+4648|0,75,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22708]=0;ha(1840,a+4672|0,69,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22708]=0;ha(1840,a+4696|0,60,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22708]=0;ha(1840,a+4720|0,48,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22708]=0;ha(1840,a+4744|0,36,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22708]=0;ha(1840,a+4768|0,25,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1840,a+4792|0,0,0,0,0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22708]=0;ha(1840,a+4816|0,3,0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22708]=0;ha(1840,a+4840|0,3,0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1840,a+4864|0,407,1,c|0,0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1840,a+4888|0,400,1,c|0,0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1840,a+4912|0,10,0,c|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1840,a+4936|0,10,0,c|0,-1);c=v[22708];v[22708]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(89104)|0;if((O()|0)==(ea(89104)|0)){Z(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=C(0),k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,t=0,u=0,x=C(0),y=0,A=0,B=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=C(0);a:{if(!v[a+4316>>2]){break a}k=a+44|0;if(!ni(k)){break a}p=Nd(k,0);q=Nd(k,1);r=od(k,0);s=od(k,1);H=kb[v[v[a>>2]+192>>2]](a)|0;e=C(kb[v[v[a>>2]+200>>2]](a));B=C(kb[v[v[a>>2]+188>>2]](a));t=kb[v[v[a>>2]+212>>2]](a)|0;b:{if(!d){break b}u=a+4276|0;l=a+4264|0;h=w[a+4260|0];E=h?u:l;F=a+4300|0;G=a+4288|0;x=C(e/C(100));I=t&1;m=v[a+4256>>2];n=v[a+4312>>2];y=d;while(1){j=z[q>>2];i=z[p>>2];f=qo(a,m+n|0);m=qo(a,n);c:{if(h){n=v[a+4328>>2];J=Pe(G,n),K=i,z[J>>2]=K;J=Pe(F,n),K=j,z[J>>2]=K;e=z[Mb(l,f)>>2];J=Mb(l,m),K=C(i+C(x*e)),z[J>>2]=K;e=C(j+C(x*z[Mb(u,f)>>2]));h=u;break c}e=C(C(C(i+j)*C(.5))+C(x*z[Mb(l,f)>>2]));h=l}J=Mb(h,m),K=e,z[J>>2]=K;d:{if(H){g=z[a+4244>>2];e=C(g+z[a+4236>>2]);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(e>C(1)){e=C(e+C(-2));z[a+4236>>2]=e}if(g>C(1)){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break d}g=z[a+4240>>2];o=z[a+4244>>2];e=C(C(g*o)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(g-C(o*e));z[a+4240>>2]=g}if(w[a+4260|0]){f=(v[a+4328>>2]+2|0)%3|0;i=z[Pe(G,f)>>2];j=z[Pe(F,f)>>2]}o=z[Mb(l,qo(a,v[a+4320>>2]+v[a+4312>>2]|0))>>2];J=r,K=C(i+C(B*C(C(o+C(C(z[Mb(l,qo(a,(v[a+4312>>2]+v[a+4320>>2]|0)+4096|0))>>2]-o)*C(C(v[a+4320>>2]&4095)*C(.000244140625))))-i))),z[J>>2]=K;i=z[Mb(E,qo(a,v[a+4324>>2]+v[a+4312>>2]|0))>>2];J=s,K=C(j+C(B*C(C(i+C(C(z[Mb(E,qo(a,(v[a+4312>>2]+v[a+4324>>2]|0)+4096|0))>>2]-i)*C(C(v[a+4324>>2]&4095)*C(.000244140625))))-j))),z[J>>2]=K;f=v[a+4328>>2];v[a+4328>>2]=((f|0)<1?f+3|0:f)-1;f=v[a+4312>>2];n=(((f|0)>0?0:v[a+4316>>2]<<12)+f|0)-4096|0;v[a+4312>>2]=n;A=a;m=v[a+4256>>2];f=m;j=z[a+4248>>2];i=C((I?g:e)*j);e:{if(C(D(i))<C(2147483648)){h=~~i;break e}h=-2147483648}v[A+4324>>2]=f+(t>>>0>1?h:0-h|0);f=t>>>0<4;A=a;e=C(e*j);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[A+4320>>2]=(f?h:0-h|0)+m;y=y-1|0;if(!y){break b}q=q+4|0;p=p+4|0;r=r+4|0;s=s+4|0;h=w[a+4260|0];continue}}Gi(a,b,c,od(k,0),od(k,1),d)}}function IE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=gb-128|0;gb=j;a:{b:{c:{if(!sn(f,g,h,i,0,0,0,0)){break c}m=f;n=g;l=h;o=i&65535;k=i>>>16&32767;d:{e:{if((k|0)!=32767){p=4;if(k){break e}m=l|m|(n|o)?3:2;break d}p=!(l|m|(n|o))}m=p}if(!m){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}Ed(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];bF(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=o<<16;p=d;q=l|e&65535;m=q;n=h;q=i>>>16&32767;k=i&65535|q<<16;if((sn(b,c,p,m,f,g,h,k)|0)<=0){if(sn(b,c,p,m,f,g,n,k)){h=b;i=c;break a}Ed(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Ed(j+96|0,b,c,p,m,0,0,0,1081540608);h=v[j+108>>2];m=h;p=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Ed(j+80|0,f,g,n,k,0,0,0,1081540608);f=v[j+92>>2];k=f;n=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((o|0)>(q|0)){while(1){k=p;l=n;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0|(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){Ed(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;p=k<<1|i>>>31;break f}l=m<<1|p>>>31;p=p<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}l=p;q=l-n|0;n=m-((l>>>0<n>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=n-(l>>>0>q>>>0)|0;n=q-l|0;g:{if((k|0)<0){n=p;k=m;break g}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|n|(i|k)){break g}Ed(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=n;k=k<<1|b>>>31;n=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Ed(j- -64|0,h,i,n,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=n;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;gb=j+128|0}function DL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{d:{e:{f:{k=Vp(1,28);if(!k){a=ba(4)|0;nm(a);v[22708]=0;U(186,a|0,89104,1930);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1921;d=Au(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,j+48|0,c|0)|0;f=v[22708];v[22708]=0;j:{if((f|0)!=1){v[22708]=0;f=Q(1931,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break j}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22708]=0;c=Q(70,j+48|0,c|0)|0;e=v[22708];v[22708]=0;k:{if((e|0)!=1){v[22708]=0;R(1932,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22708]=0;a=T(1291,80)|0;i=v[22708];v[22708]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22708]=0;b=Q(1933,k|0,k+4|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[iq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22708]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;da(1934,a|0,j+8|0,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}v[k+24>>2]=a;Dj(j+48|0);Kl(d);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Dj(j+48|0)}Yb(a)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1913,12322,k|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Yb(Ft(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Yb(a);v[k+20>>2]=0}Yb(k);break d}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22708]=0;Y(1913,12322,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=j+80|0;return i|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Jm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;a:{b:{if(cd(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=Li(a)>>>0;g=x[b+8>>1];if(c&(g|0)!=65535){break b}f=g;if((f&65535)==65535){g=Li(a)-1|0;f=0}d=Yc(a,v[b+4>>2],f&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=g&65535;if(l>>>0<(f&65535)>>>0){break d}j=w[b+10|0];e=f;c=d;while(1){e:{if(!k){if((j|0)!=w[c+3|0]){break e}break c}if((j|0)==w[c+2|0]){break c}}c=c+6|0;e=e+1|0;if((e&65535)>>>0<=l>>>0){continue}break}}j=g&65535;if(j>>>0>=(f&65535)>>>0){e=f;c=d;while(1){f:{if(!k){if(w[c+3|0]){break f}t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break c}if(w[c+2|0]){break f}t[c+2|0]=w[b+10|0];t[c+4|0]=w[b+11|0];break c}c=c+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[so(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}g=g&65535;if(g>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[d+3|0]-9|0){case 4:if(!uz(v[so(a)+8>>2],1)){break i}c=1;t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}c=d;k:{if(i){e=w[d+5|0];if(e>>>0>128){break i}t[d+2|0]=2;t[d+3|0]=w[b+10|0];a=1;break k}t[d+2|0]=2;t[d+3|0]=w[b+10|0];e=w[d+5|0];a=2}t[c+4|0]=a+e>>>a;t[d+5|0]=w[b+11|0];break c}d=d+6|0;f=f+1|0;if(g>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){c=w[b+11|0];d=13;m:{switch(w[b+10|0]-1|0){case 1:c=fm(B(i?2:4,c));e=w[b+12|0];d=9;break;case 0:break m;default:break l}}t[b+11|0]=c;t[b+10|0]=d;e=e&254;t[b+12|0]=e;break l}f=w[b+11|0];t[h+14|0]=f;d=b;c=w[b+10|0];n:{o:{if(!(!i|(c|0)!=9)){if(f>>>0>128){break n}c=2;f=(f&254)>>>1|0;break o}t[h+15|0]=c;if(!Xt(h+15|0,h+14|0,1)){break n}c=w[h+15|0];if(!c){break n}e=w[b+12|0];f=w[h+14|0]}t[d+11|0]=f;t[b+10|0]=c;t[b+12|0]=e&254}e=w[b+12|0]}c=1;if(e&1){break g}t[b+12|0]=e^4;if(Jm(a,b)){break a}}d=v[b>>2];p:{if((d|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){v[b+4>>2]=v[b+4>>2]+1;break p}d=v[b>>2]}if((d|0)!=2){break b}c=0;d=v[b+4>>2];if(!d){break a}v[b+4>>2]=d-1}t[b+12|0]=w[b+12|0]|1;c=Jm(a,b);break a}c=1;break a}c=0}gb=h+16|0;return c|0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;a:{b:{c:{f=v[a+12>>2];h=v[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<1){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if(h>>>0>2147483647&(f|0)>=-2|(f|0)>-2){break d}break b}if(h>>>0>2147483648&(f|0)>=1|(f|0)>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=h;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(j>>>16&65520)+r|0;j=u[e+14>>1];h=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];p=u[e+6>>1];t=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];i=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],w)+B(u[b+(e|-12)>>1],x)|0)+B(u[b+(e|-4)>>1],t)|0)+B(u[b+e>>1],p)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(h,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(i<<2)|0;j=v[k>>2];h=v[a+60>>2];l=h;e=(g+32|0)+(i<<3)|0;q=v[e>>2];b=Lb(q,-16777216,16776704);i=v[a+64>>2];f=Lb(v[e+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=nqa(l,p,h,h>>31);l=jb;p=h;h=nqa(i,i>>31,b,b>>31);i=p+h|0;b=jb+l|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=v[a+68>>2];i=nqa(i,i>>31,f,f>>31);f=h+i|0;b=jb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Jc(f,b,24);v[e+4>>2]=q;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[e>>2]=b-(f&j);i=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=g+48|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Td(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=lg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=(((i&2147483647)<<1|g>>>31)&-2)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Jd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);p=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=nqa(l,s,f,f>>31);l=jb;p=nqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;d=gb-48|0;gb=d;e=JR(d+32|0,1<<v[b+12>>2]);if(sf(a)){while(1){f=A[ye(a,c)>>3];IR(Tc(e,c),f);c=c+1|0;if(sf(a)>>>0>c>>>0){continue}break}}v[22708]=0;Dz(b,e);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}w=d,x=Vb(e),v[w>>2]=x;w=d,x=Zb(e),v[w+24>>2]=x;if(Gb(d,d+24|0)){while(1){c=v[d>>2];t=c;f=A[c+8>>3];i=gb-32|0;gb=i;o(+A[c>>3]);c=j(1)|0;g=j(0)|0;o(+f);k=j(1)|0;q=j(0)|0;p=c&2147483647;h=p;k=k&2147483647;r=(h|0)==(k|0)&g>>>0<q>>>0|h>>>0<k>>>0;c=r?g:q;h=r?h:k;r=h;l(0,c|0);l(1,h|0);f=+n();h=h>>>20|0;b:{if((h|0)==2047){break b}u=g;g=(k|0)==(p|0)&g>>>0>q>>>0|k>>>0<p>>>0;l(0,(g?u:q)|0);g=g?p:k;l(1,g|0);m=+n();p=!(c|r);c=g>>>20|0;if(!(p|(c|0)==2047)){if((c-h|0)>=65){f=m+f;break b}c:{if(c>>>0>=1534){f=f*1.90109156629516e-211;m=m*1.90109156629516e-211;s=5.260135901548374e210;break c}s=1;if(h>>>0>572){break c}f=f*5.260135901548374e210;m=m*5.260135901548374e210;s=1.90109156629516e-211}SI(i+24|0,i+16|0,m);SI(i+8|0,i,f);f=s*K(A[i>>3]+A[i+16>>3]+A[i+8>>3]+A[i+24>>3]);break b}f=m}gb=i+32|0;IR(t,Sp(f));Zo(d);if(Gb(d,d+24|0)){continue}break}}v[22708]=0;Bz(b,e);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;Az(e);c=v[22708];v[22708]=0;if((c|0)==1){break a}if(vf(e)>>>0>3){c=1;while(1){VA(Tc(e,c),2);VA(Tc(e,(vf(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<vf(e)>>>1>>>0){continue}break}}v[22708]=0;Dz(b,e);c=v[22708];v[22708]=0;if((c|0)==1){break a}w=d,x=Vb(e),v[w+24>>2]=x;w=d,x=Zb(e),v[w+16>>2]=x;d:{if(Gb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[22708]=0;UA(d,c);g=v[22708];v[22708]=0;if((g|0)==1){break d}g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;c=d+24|0;Zo(c);if(Gb(c,d+16|0)){continue}break}}v[22708]=0;Bz(b,e);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;Az(e);b=v[22708];v[22708]=0;if((b|0)==1){break a}if(sf(a)){c=0;while(1){f=A[Tc(e,c)>>3];w=ye(a,c),y=f,A[w>>3]=y;c=c+1|0;if(sf(a)>>>0>c>>>0){continue}break}}Mq(e);gb=d+48|0;return}}a=P()|0;O()|0;Mq(e);S(a|0);L()}function _h(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;a:{if(!Md(a)){break a}wk(a);if(c){c=b;o=gb-16|0;gb=o;g=a;if(Md(a)){s=c+1298224|0;d=c+1074992|0;c=x[g+34>>1];i=c&4;z=c&2;j=c&16;A=c&8;h=v[g+8>>2];p=v[g+4>>2];f=v[g+16>>2];q=v[g+12>>2];while(1){b:{if((g|0)!=v[d+104>>2]){break b}e=v[d+76>>2];if(!e){break b}m=d;c:{d:{e:{f:{n=v[g>>2];if(!A|(n>>>0<f>>>0|f>>>0<=q>>>0)){break f}l=v[d+88>>2];if(l&2048){break f}v[d+84>>2]=f;v[d+80>>2]=q;e=f;c=j;break e}if(!z|(h>>>0<=p>>>0|h>>>0>n>>>0)){break d}v[d+84>>2]=h;v[d+80>>2]=p;l=v[d+88>>2];e=h;c=i}v[m+76>>2]=e;k=l|2;r=d+88|0;l=(c|0)!=0;c=1;break c}r=d+88|0;k=v[d+88>>2]&-3;l=0;c=0}k=k&-5|(c?l?4:0:0);v[d+88>>2]=k;if(y[d+4>>2]>e>>>0){k=k&-129;v[d+88>>2]=k;m=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=m}if(!l){v[r>>2]=k&-129}if(c){break b}v[d+76>>2]=n}d=d+872|0;if((s|0)!=(d|0)){continue}break}}gb=o+16|0}if((jj(a)|0)==2){d=0;g=gb+-64|0;gb=g;e=fd(a);h=v[a+20>>2];f=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){i=B(d,e);j=B(e,d^-1);c=0;while(1){u[f+(c+i<<1)>>1]=x[f+(c-e<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];j=g+32|0;Db(j,b+1074312|0,33);xS(g+40|0,d,h+(B(e,f)<<1)|0,i-f|0,e,(c&4)>>>2|0,Cb(j));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];i=g+32|0;Db(i,b+1074312|0,33);xS(g+8|0,d+(e<<7)|0,h+(B(a,e)<<1)|0,f-a|0,e,(c&16)>>>4|0,Cb(i))}gb=g- -64|0;return}if((jj(a)|0)!=1){break a}d=0;g=gb+-64|0;gb=g;e=fd(a);h=v[a+20>>2];f=h+B(e,v[a>>2])|0;while(1){if(e){i=B(d,e);j=B(e,d^-1);c=0;while(1){t[f+(c+i|0)|0]=w[f+(c-e|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];j=g+32|0;Db(j,b+1074312|0,33);wS(g+40|0,d,h+B(e,f)|0,i-f|0,e,(c&4)>>>2|0,Cb(j));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];i=g+32|0;Db(i,b+1074312|0,33);wS(g+8|0,d+(e<<6)|0,h+B(a,e)|0,f-a|0,e,(c&16)>>>4|0,Cb(i))}gb=g- -64|0}}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<1){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if(g>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(g>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];h=v[a+44>>2];v[f+32>>2]=h;m=v[a+48>>2];v[f+36>>2]=m;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){i=(((i&2147483647)<<1|j>>>31)&-2)+s|0;b=(j>>>16&65520)+r|0;e=u[b+14>>1];j=u[b+12>>1];g=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];p=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];h=0;m=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[i+(b|-4)|0],w)+B(t[i+(b|-6)|0],x)|0)+B(t[i+(b|-2)|0],p)|0)+B(t[b+i|0],q)|0)+B(t[i+(b|2)|0],l)|0)+B(t[i+(b|4)|0],g)|0)+B(j,t[i+(b|6)|0])|0)+B(e,t[i+(b|8)|0])<<8)/32768;y=k&1;k=0;b=1;if(y){continue}break}while(1){k=(f+8|0)+(h<<2)|0;j=v[k>>2];g=v[a+60>>2];l=g;i=(f+32|0)+(h<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);h=v[a+64>>2];e=Lb(v[i+4>>2],-16777216,16776704);p=g>>31;j=j<<8;g=j;g=nqa(l,p,g,g>>31);l=jb;p=g;g=nqa(h,h>>31,b,b>>31);h=p+g|0;b=jb+l|0;b=h>>>0<g>>>0?b+1|0:b;g=h;h=v[a+68>>2];h=nqa(h,h>>31,e,e>>31);e=g+h|0;b=jb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Jc(e,b,24);v[i+4>>2]=q;e=v[a+72>>2];v[k>>2]=(b|0)/256;v[i>>2]=b-(e&j);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;e=o>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];i=v[f+28>>2];continue}break}j=v[f+24>>2];i=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];m=v[f+36>>2];h=v[f+32>>2];break e}b=n>>12;e=o>>12}v[a+40>>2]=n;v[a+20>>2]=e;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=i;gb=f+48|0}function u2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-1072|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=Xx(j,100,8345,a+16|0);v[a+48>>2]=2458;k=a+48|0;o=ge(a+536|0,0,k);v[a+48>>2]=2458;k=ge(a+528|0,0,k);m=a+544|0;a:{b:{c:{if(j>>>0>=100){v[22708]=0;j=ga(2478)|0;m=v[22708];v[22708]=0;if((m|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22708]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=da(2497,a+956|0,j|0,8345,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if((j|0)==-1){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+956>>2]);Ee(k,Cd(j<<2));if(vk(k)){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)==1){break b}break c}m=v[k>>2]}v[22708]=0;Fc(a+520|0,d);f=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22708]=0;q=T(2482,a+520|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;f=v[a+956>>2];Y(2494,q|0,f|0,f+j|0,m|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+956>>2]]==45:p;h=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[22708]=0;na(2526,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,f|0,g|0,a+452|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[a+36>>2]=2458;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Ab(g)+(j-n<<1)|0)+Ab(f)|0)+1|0;break k}l=(Ab(g)+Ab(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ee(c,Cd(l<<2));i=v[c>>2];if(i){break h}v[22708]=0;X(2459);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[22708]=0;qa(2527,i|0,a+36|0,a+32|0,l|0,m|0,(j<<2)+m|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,f|0,g|0,n|0);j=v[22708];v[22708]=0;if((j|0)!=1){v[22708]=0;b=la(2507,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}Ic(g);Ic(f);vb(h)}Wb(a+520|0);break a}Hc(c);Ic(g);Ic(f);vb(h);Wb(a+520|0);Hc(k);Hc(o);gb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Hc(k);Hc(o);S(j|0);L()}function Ql(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(60,a|0,d|0);d=v[22708];v[22708]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=v[xk(c,b)>>2];f:{if(d>>>0<=127){v[22708]=0;R(61,a|0,d<<24>>24);d=v[22708];v[22708]=0;if((d|0)!=1){break f}break e}v[22708]=0;R(61,a|0,63);d=v[22708];v[22708]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(60,a|0,d|0);d=v[22708];v[22708]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=v[xk(c,b)>>2];i:{if(d>>>0<=255){v[22708]=0;R(61,a|0,d<<24>>24);d=v[22708];v[22708]=0;if((d|0)!=1){break i}break h}v[22708]=0;R(61,a|0,63);d=v[22708];v[22708]=0;if((d|0)==1){break h}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Xq(a,c,20896);return;case 5:Xq(a,c,21920);return;case 4:Xq(a,c,22944);return;case 6:Xq(a,c,23968);return;default:a=ba(8)|0;v[22708]=0;Q(59,a|0,8299)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}e=gb-16|0;gb=e;f=Kb(a);j:{k:{if(Ab(c)){while(1){a=v[xk(c,h)>>2];l:{if(a>>>0>=2097152){v[22708]=0;R(61,f|0,63);a=v[22708];v[22708]=0;if((a|0)!=1){break l}break k}d=0;m:{n:{while(1){g=a&63;t[(e+10|0)+d|0]=g;if(a>>>0<64){break n}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break m}o:{if(!d){v[22708]=0;R(61,f|0,t[e+10|0]);break o}b=d+1|0;if((b|0)!=2){break m}d=1;b=2;if((g|0)!=1){break m}v[22708]=0;R(61,f|0,t[e+10|0]|64)}a=v[22708];v[22708]=0;if((a|0)!=1){break l}break k}g=(-1<<b^-1)<<7-d;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){p:{if((a|0)==(b|0)){a=w[j|0];v[22708]=0;R(61,f|0,(a|g)<<24>>24);i=v[22708];v[22708]=0;a=d;if((i|0)!=1){break p}break k}v[22708]=0;a=a-1|0;R(61,f|0,t[a+(e+10|0)|0]|-128);i=v[22708];v[22708]=0;if((i|0)==1){break k}}if(a){continue}break}}h=h+1|0;if(Ab(c)>>>0>h>>>0){continue}break}}gb=e+16|0;break j}a=P()|0;O()|0;vb(f);S(a|0);L()}return}ia(a|0,89224,24);L()}b=P()|0;O()|0;vb(a);S(b|0);L()}function Bx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[22614]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Nf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}h=e+1|0;f=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}h=e+2|0;f=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76800>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76800>>2];f=1;continue}h=w[e|0];f=h>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{i=e+1|0;f=h-128|g<<6;h=i;v:{if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=e+2|0;f=h|f<<6;h=i;if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[115189]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[115189]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function hA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-160|0;gb=h;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!c){break i}d=v[c+4>>2];if(!d&y[c>>2]>=yb(b)>>>0|d){break i}b=ba(8)|0;v[22708]=0;Q(126,b|0,18726)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break h}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[22708]=0;T(1293,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ca(b|0);break a}d=v[b+4>>2];g=v[b>>2];v[h>>2]=g;v[h+4>>2]=d;v[h+128>>2]=g;v[h+132>>2]=d;g=gb-16|0;gb=g;d=v[h+4>>2];e=v[h>>2];v[g>>2]=e;v[g+4>>2]=d;v[g+8>>2]=e;v[g+12>>2]=d;d=gb-32|0;gb=d;e=v[g+4>>2];f=v[g>>2];v[d+8>>2]=f;v[d+12>>2]=e;v[d+16>>2]=f;v[d+20>>2]=e;rh(d+24|0,d+8|0);e=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=e;e=gb-16|0;gb=e;f=v[d+4>>2];i=v[d>>2];v[e>>2]=i;v[e+4>>2]=f;v[e+8>>2]=i;v[e+12>>2]=f;f=gb-16|0;gb=f;i=v[e+4>>2];k=v[e>>2];v[f>>2]=k;v[f+4>>2]=i;v[f+8>>2]=k;v[f+12>>2]=i;i=h+136|0;YF(i,f);gb=f+16|0;gb=e+16|0;v[i+12>>2]=0;gb=d+32|0;gb=g+16|0;j:{k:{if(a&2){d=Jn(h+104|0,i);v[22708]=0;g=Q(1294,d|0,c|0)|0;e=v[22708];v[22708]=0;d=1;if((e|0)==1){break j}if((g|0)==1){break k}e=Jn(h+80|0,i);v[22708]=0;e=Q(1295,e|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}k=(e|0)==1;if(k){break k}f=Jn(h+56|0,i);v[22708]=0;f=Q(1296,f|0,c|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}l=(f|0)==1;if(l){break k}j=Jn(h+32|0,i);v[22708]=0;j=Q(1297,j|0,c|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break d}if((j|0)==1){break k}d=(g|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(j|0)==-1?-1:l?d:(f|0)==-1?-1:d}if(a&1){a=37824;while(1){d=v[a>>2];if(d){g=Jn(h+8|0,i);v[22708]=0;g=Q(d|0,g|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=1;if((g|0)==1){break k}j=(g|0)==-1?-1:j}a=a+12|0;if((a|0)!=38328){continue}break}}if(c){d=0;if((j|0)!=-1){break k}d=Qc(v[c>>2],v[c+4>>2])>>>0>yb(b)>>>0?-1:0;break k}d=0;if((j|0)!=-1){break k}d=yb(b)>>>0>2047?1:-1}gb=h+160|0;return d}a=P()|0;break b}ia(b|0,89384,24);L()}ia(b|0,89280,24);L()}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0}O()|0}S(a|0);L()}function y2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-464|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=Xx(j,100,8345,a+16|0);v[a+48>>2]=2458;k=a+48|0;o=ge(a+232|0,0,k);v[a+48>>2]=2458;k=ge(a+224|0,0,k);m=a+240|0;a:{b:{c:{if(j>>>0>=100){v[22708]=0;j=ga(2478)|0;m=v[22708];v[22708]=0;if((m|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22708]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=da(2497,a+348|0,j|0,8345,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if((j|0)==-1){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+348>>2]);Ee(k,Cd(j));if(vk(k)){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)==1){break b}break c}m=v[k>>2]}v[22708]=0;Fc(a+216|0,d);f=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22708]=0;q=T(21,a+216|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;f=v[a+348>>2];Y(2474,q|0,f|0,f+j|0,m|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+348>>2]]==45:p;h=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[22708]=0;na(2524,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,f|0,g|0,a+156|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[a+36>>2]=2458;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Ab(g)+(j-n<<1)|0)+Ab(f)|0)+1|0;break k}l=(Ab(g)+Ab(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ee(c,Cd(l));i=v[c>>2];if(i){break h}v[22708]=0;X(2459);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[22708]=0;qa(2525,i|0,a+36|0,a+32|0,l|0,m|0,j+m|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],h|0,f|0,g|0,n|0);j=v[22708];v[22708]=0;if((j|0)!=1){v[22708]=0;b=la(17,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}vb(g);vb(f);vb(h)}Wb(a+216|0);break a}Hc(c);vb(g);vb(f);vb(h);Wb(a+216|0);Hc(k);Hc(o);gb=a+464|0;return b|0}L()}j=P()|0;O()|0}Hc(k);Hc(o);S(j|0);L()}function Bz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=gb-208|0;gb=c;i=1;h=v[a+12>>2];k=1<<h;m=2;g=h;if(g>>>0>=2){f=k;while(1){l=f>>>2|0;if(f>>>0>=4){w=B(i,3);x=i<<1;y=l>>>0>1?l:1;g=0;while(1){e=c+192|0;ZN(e,Tc(a,g<<1));f=c+176|0;ZN(f,Tc(a,g));Ni(c+160|0,f,e);f=g<<m;u=i+f|0;if(f>>>0<u>>>0){while(1){d=Tc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;n=f+i|0;d=Tc(b,n);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;o=f+x|0;d=Tc(b,o);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;p=f+w|0;d=Tc(b,p);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;q=c+80|0;d=c+144|0;e=c+128|0;Fl(q,d,e);r=c- -64|0;Fj(r,d,e);s=c+48|0;d=c+112|0;e=c+96|0;Fl(s,d,e);j=c+16|0;Fj(j,d,e);t=c+32|0;Ni(t,48208,j);Fl(j,q,s);d=Tc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fl(c,r,t);Ni(j,c+192|0,c);n=Tc(b,n);d=n;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fj(c,q,s);Ni(j,c+176|0,c);o=Tc(b,o);d=o;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fj(c,r,t);Ni(j,c+160|0,c);p=Tc(b,p);d=p;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((u|0)!=(f|0)){continue}break}}g=g+1|0;if((y|0)!=(g|0)){continue}break}g=v[a+12>>2]}i=i<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){e=k>>>1|0;l=e>>>0>1?e:1;f=0;while(1){k=e+f|0;h=Tc(b,k);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;h=c+192|0;Fj(c+176|0,Tc(b,f),h);g=Tc(b,k);a=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=a;a=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=a;Cz(Tc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}gb=c+208|0}function Gi(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=C(0);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((kb[v[v[a>>2]+152>>2]](a)|0)<1){break a}if(!EM(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}m=z[a+4196>>2];k=C(k*m);j=C(j*m);l=a+44|0;n=Nd(l,0);l=Nd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;k=z[h>>2];q=h;r=k;m=z[g+n>>2];h=c+g|0;o=z[h>>2];p=z[g+l>>2];k=C(C(C(C(k+m)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(j*z[d+g>>2])))-m);z[h>>2]=o-C(C(k+C(k-C(j*z[e+g>>2])))-p);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]-C(z[d+g>>2]-C(j*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]-C(z[e+g>>2]-C(j*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(z[d+g>>2]-C(k*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(z[e+g>>2]-C(k*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(z[g+n>>2]-C(j*z[d+g>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(z[g+l>>2]-C(j*z[e+g>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(C(j*z[d+g>>2])+C(k*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(C(j*z[e+g>>2])+C(k*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=EM(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;m=C(z[d+g>>2]-z[g+n>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=z[h>>2]+C(C(j*m)+C(k*o));g=c+g|0;z[g>>2]=z[g>>2]+C(C(k*m)+C(j*o));i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(kb[v[v[a>>2]+136>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[a+n>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Td(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=lg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Jd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);n=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=nqa(m,s,f,f>>31);m=jb;n=nqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb+-64|0;gb=d;u[d+62>>1]=c;yg(d+62|0,32);f=mc(a);v[22708]=0;R(711,f|0,x[d+62>>1]);a=v[22708];v[22708]=0;a:{if((a|0)!=1){b:{if(!x[d+62>>1]){break b}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;c:{d:{if((a&65535)>>>0<4e3){break d}u[d+24>>1]=1;e:{if(!x[b+480190>>1]){break e}while(1){f:{if(Md(Ak(b,x[d+24>>1]))){break f}j=d,k=dC(Vb(f),Zb(f),d+24|0),v[j+48>>2]=k;j=d,k=Zb(f),v[j+40>>2]=k;if(Gb(d+48|0,d+40|0)){break f}u[d+60>>1]=x[d+24>>1];c=1;if(!x[b+480192>>1]){break e}while(1){a=v[(((c&65535)<<2)+b|0)+900380>>2];g:{if(!a){break g}a=a+236|0;e=Lu(a);if((a|0)==(e|0)){break g}while(1){if(x[a>>1]==x[d+60>>1]){u[a>>1]=0}a=a+2|0;if((e|0)!=(a|0)){continue}break}}c=c+1|0;if(x[b+480192>>1]>=(c&65535)>>>0){continue}break}break e}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break d}c=xB(d+48|0);v[22708]=0;a=Q(977,b|0,c|0)|0;e=v[22708];v[22708]=0;h:{i:{if((e|0)==1){break i}j:{if(a){v[22708]=0;Q(978,b|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}e=1;if(!x[b+480192>>1]){break j}while(1){a=v[(((e&65535)<<2)+b|0)+900380>>2];k:{if(!a){break k}a=a+236|0;g=Lu(a);if((a|0)==(g|0)){break k}while(1){l:{if(y[c+4>>2]<=x[a>>1]){break l}h=d+40|0;Ce(h,c,x[a>>1]);if(Cb(h)){break l}u[a>>1]=0}a=a+2|0;if((g|0)!=(a|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break j}Ye(c);break b}a=d+24|0;zk(a,c);e=d+32|0;sB(e,a,1);a=d+16|0;Ul(a,c);v[22708]=0;t[d+15|0]=0;bT(d+40|0,e,a,d+15|0);a=v[22708];v[22708]=0;if((a|0)!=1){break h}}a=P()|0;O()|0;Ye(c);break a}zk(d,c);j=d,k=Pj(d+40|0,d),u[j+60>>1]=k;Ye(c);if(x[d+60>>1]>=4e3){break c}}v[22708]=0;R(383,f|0,d+60|0);a=v[22708];v[22708]=0;if((a|0)!=1){if(x[b+480190>>1]>=x[d+60>>1]){break c}u[b+480190>>1]=x[d+60>>1];break c}a=P()|0;O()|0;break a}i=i+1|0;if(x[d+62>>1]>(i&65535)>>>0){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0}Ze(f);S(a|0);L()}function M9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{j=Vp(1,32);d:{e:{if(!j){a=ba(4)|0;nm(a);v[22708]=0;U(186,a|0,89104,1930);a=v[22708];v[22708]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1921;d=Au(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,k+16|0,c|0)|0;f=v[22708];v[22708]=0;i:{if((f|0)!=1){v[22708]=0;f=Q(1931,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break i}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22708]=0;c=Q(70,k+16|0,c|0)|0;e=v[22708];v[22708]=0;j:{if((e|0)!=1){v[22708]=0;R(1932,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22708]=0;c=T(1291,96)|0;e=v[22708];v[22708]=0;k:{l:{m:{if((e|0)!=1){v[22708]=0;e=Q(1933,j|0,j+4|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[iq(k+8|0,k+16|0)>>2];v[22708]=0;fa(2008,c|0,a|0,b|0,e|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}v[j+28>>2]=c;Dj(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Kl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Dj(k+16|0)}Yb(c)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1913,2069,j|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Yb(a);v[j+20>>2]=0}Yb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[22708]=0;Y(1913,2069,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=k+48|0;return j|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function E8(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;d=gb-16|0;gb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!(a>>>0>=8388608&(a|0)>-1)){f=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}f=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));e=C(k*k);m=C(e*e);f=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());e=C(C(C(f-c)-i)+C(k*C(i+C(C(e*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(e*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(e+c)*C(-3168997136526741e-20))))))}f=c}e=C(f*C(2e3));if(!(C(D(e))<C(2147483648))){break c}a=~~e;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=gb-16|0;gb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){d=ba(8)|0;v[22708]=0;b=Q(70,b|0,2219)|0;a=v[22708];v[22708]=0;if((a|0)==1){break k}rc(d,b);v[22708]=0;U(186,d|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break i}a=P()|0;O()|0;vb(b);break j}gb=b+16|0;a=v[(a<<24>>24<<2)+59672>>2];break h}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}break b;case 3:v[d>>2]=0;g=gb-80|0;gb=g;a=v[a+24>>2]+24604|0;v[g+40>>2]=v[a+32>>2];v[g>>2]=v[a+36>>2];b=g+40|0;h=v[Hf(b,g)>>2];o=d;l:{if(v[a+32>>2]==v[Vq(b)+32>>2]){b=-1;if(v[a+36>>2]==v[Vq(g)+36>>2]){break l}}b=0;if((h|0)<1){break l}b=(h+500>>>0)/1e3|0}v[o>>2]=b;gb=g+80|0;a=v[d>>2];break b;default:break d}}h=ba(8)|0;v[22708]=0;d=Q(70,d|0,7655)|0;a=v[22708];v[22708]=0;m:{if((a|0)!=1){rc(h,d);v[22708]=0;U(186,h|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break m}b=P()|0;O()|0;ca(h|0)}S(b|0);L()}a=-2147483648}gb=d+16|0;return a|0}L()}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Td(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=lg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=(((i&2147483647)<<1|g>>>31)&-2)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Jd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);n=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=nqa(m,s,f,f>>31);m=jb;n=nqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;a:{b:{c:{e=v[a+12>>2];i=v[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<1){if((e|0)>=-2&i>>>0>=3489660928|(e|0)>-2){break c}if(i>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(i>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){m=1;e=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];i=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];t=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];k=0;b=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((((B(u[e+(h|-8)>>1],w)+B(u[e+(h|-12)>>1],x)|0)+B(u[e+(h|-4)>>1],t)|0)+B(u[e+h>>1],o)|0)+B(u[e+(h|4)>>1],l)|0)+B(u[e+(h|8)>>1],n)|0)+B(u[e+(h|12)>>1],i)|0)+B(j,u[e+(h|16)>>1])|0)/32768;h=b;b=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];i=v[a+60>>2];n=i;h=(f+32|0)+(k<<3)|0;k=v[h>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];e=Lb(v[h+4>>2],-16777216,16776704);o=i>>31;i=g<<8;g=i;g=nqa(n,o,g,g>>31);n=jb;l=nqa(l,l>>31,b,b>>31);g=l+g|0;b=jb+n|0;b=g>>>0<l>>>0?b+1|0:b;o=g;g=v[a+68>>2];g=nqa(g,g>>31,e,e>>31);e=o+g|0;b=jb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Jc(e,b,24);v[h+4>>2]=k;e=v[a+72>>2];v[j>>2]=(b|0)/256;v[h>>2]=b-(e&i);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=0,u=C(0),w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(ni(m)){B=Nd(m,0);D=Nd(m,1);E=od(m,0);F=od(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){k=a+4304|0;j=q+1|0;w=j+v[a+4272>>2]&4095;l=k+(w<<4)|0;x=j+v[a+4276>>2]&4095;h=((x<<4)+k|0)+4|0;y=j+v[a+4280>>2]&4095;n=((y<<4)+k|0)+8|0;A=j+v[a+4284>>2]&4095;f=((A<<4)+k|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;H=a+69840|0;I=a+78032|0;G=d;while(1){w=w-1&4095;j=(w<<4)+k|0;e=z[j>>2];r=r&1023;t=(r<<3)+H|0;p=z[t+4>>2];J=z[f>>2];K=z[n>>2];L=z[h>>2];M=z[l>>2];N=z[D>>2];O=z[B>>2];x=x-1&4095;l=(x<<4)+k|0;i=z[l+4>>2];u=z[a+4232>>2];g=C(C(i*C(.6180340051651001))+C(z[t>>2]*u));f=o<<3;h=f+H|0;z[h+4>>2]=i-C(g*C(.6180340051651001));i=e;e=C(C(u*p)-C(e*C(.6180340051651001)));z[h>>2]=i+C(e*C(.6180340051651001));z[j>>2]=g;z[l+4>>2]=e;s=s&1023;t=(s<<3)+I|0;p=z[t+4>>2];y=y-1&4095;n=(y<<4)+k|0;g=z[n+8>>2];A=A-1&4095;h=(A<<4)+k|0;i=z[h+12>>2];u=z[a+4236>>2];e=C(C(i*C(.6180340051651001))+C(z[t>>2]*u));f=f+I|0;z[f+4>>2]=i-C(e*C(.6180340051651001));i=g;g=C(C(u*p)-C(g*C(.6180340051651001)));z[f>>2]=i+C(g*C(.6180340051651001));z[n+8>>2]=e;z[h+12>>2]=g;g=e;e=C(O+C(1.0000000031710769e-30));z[E>>2]=g+C(C(e*z[a+4224>>2])+z[j>>2]);g=C(N+C(1.0000000031710769e-30));z[F>>2]=C(C(g*z[a+4224>>2])+z[l+4>>2])+z[h+12>>2];f=(q<<4)+k|0;i=e;e=z[a+4228>>2];p=C(i*e);z[f>>2]=p+C(C(z[j>>2]*z[a+4240>>2])+C(M*z[a+4244>>2]));e=C(g*e);z[f+4>>2]=e+C(C(z[l+4>>2]*z[a+4248>>2])+C(L*z[a+4252>>2]));z[f+8>>2]=C(C(z[n+8>>2]*z[a+4256>>2])+C(K*z[a+4260>>2]))-e;z[f+12>>2]=p+C(C(z[h+12>>2]*z[a+4264>>2])+C(J*z[a+4268>>2]));f=h+12|0;n=n+8|0;h=l+4|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=j;G=G-1|0;if(G){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;Gi(a,b,c,od(m,0),od(m,1),d)}}function Up(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Cd(b)}if(b>>>0>=4294967232){v[115189]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116623]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;As(c,b);return a}if(v[116509]==(f|0)){c=c+v[116506]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116506]=c;v[116509]=b;return a}if(v[116508]==(f|0)){c=c+v[116505]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116508]=d;v[116505]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=466012,o=v[116503]&rqa(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+466316|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=466016,o=v[116504]&rqa(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;As(b,l);return a}c=Cd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;hc(c,a,b>>>0>d>>>0?d:b);Yb(a);a=c}return a}function CL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{d:{e:{f:{j=Vp(1,28);if(!j){a=ba(4)|0;nm(a);v[22708]=0;U(186,a|0,89104,1930);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1921;d=Au(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,k+16|0,c|0)|0;f=v[22708];v[22708]=0;j:{if((f|0)!=1){v[22708]=0;f=Q(1931,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break j}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22708]=0;c=Q(70,k+16|0,c|0)|0;e=v[22708];v[22708]=0;k:{if((e|0)!=1){v[22708]=0;R(1932,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22708]=0;c=T(1291,80)|0;e=v[22708];v[22708]=0;l:{m:{n:{if((e|0)!=1){v[22708]=0;e=Q(1933,j|0,j+4|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[iq(k+8|0,k+16|0)>>2];v[22708]=0;fa(1935,c|0,a|0,b|0,e|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}v[j+24>>2]=c;Dj(k+16|0);Kl(d);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Dj(k+16|0)}Yb(c)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1913,12278,j|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Yb(Ft(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Yb(a);v[j+20>>2]=0}Yb(j);break d}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22708]=0;Y(1913,12278,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=k+48|0;return i|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<1){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if(h>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(h>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){e=(((g&2147483647)<<1|j>>>31)&-2)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];k=0;m=1;i=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],x)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],w)|0)+B(t[b+e|0],o)|0)+B(t[e+(b|2)|0],l)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],h)|0)+B(j,t[e+(b|8)|0])<<8)/32768;g=i;i=0;b=1;if(g){continue}break}while(1){j=(f+8|0)+(k<<2)|0;e=v[j>>2];h=v[a+60>>2];n=h;i=(f+32|0)+(k<<3)|0;k=v[i>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);o=h>>31;h=e<<8;e=h;e=nqa(n,o,e,e>>31);n=jb;l=nqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+n|0;b=e>>>0<l>>>0?b+1|0:b;o=e;e=v[a+68>>2];e=nqa(e,e>>31,g,g>>31);g=o+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=k;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&h);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function US(a){a=a|0;var b=0,c=0,d=0,e=0;Qb(a,0,288);c=a+288|0;qB(c);d=a+800|0;Xo(d);t[a+2|0]=w[11432];b=w[11430]|w[11431]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[11510];b=w[11508]|w[11509]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[2591]|w[2592]<<8|(w[2593]<<16|w[2594]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[2588]|w[2589]<<8|(w[2590]<<16|w[2591]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[12799]|w[12800]<<8|(w[12801]<<16|w[12802]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[12802]|w[12803]<<8|(w[12804]<<16|w[12805]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[6426];b=w[6422]|w[6423]<<8|(w[6424]<<16|w[6425]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;a=gb-32|0;gb=a;b=Tb(a+16|0,2028);v[22708]=0;R(444,a+8|0,c|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)==1){break b}v[22708]=0;Q(401,a+8|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}vb(b);gb=a+32|0;break a}a=P()|0;O()|0;vb(b);S(a|0);L()}b=0;a=gb+-64|0;gb=a;c:{d:{e:{while(1){v[a+60>>2]=b<<3;f:{if(b>>>0<=15){Ef(a+32|0,1193);v[22708]=0;R(442,a+16|0,a+60|0);c=v[22708];v[22708]=0;g:{h:{i:{j:{if((c|0)!=1){v[22708]=0;U(443,a+48|0,a+32|0,a+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[22708]=0;R(444,a+8|0,(b<<5)+d|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;Q(401,a+8|0,a+48|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}vb(a+48|0);vb(a+16|0);Hb(a+32|0);break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a+48|0)}vb(a+16|0)}Hb(a+32|0);break d}c=Tb(a+48|0,18726);v[22708]=0;R(444,a+32|0,(b<<5)+d|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;Q(401,a+32|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}vb(c)}b=b+1|0;if((b|0)!=128){continue}break}gb=a- -64|0;break c}b=P()|0;O()|0;vb(c)}S(b|0);L()}}function yk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(62,a|0,d|0);d=v[22708];v[22708]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=t[pc(c,b)|0];f:{if((d|0)>=0){v[22708]=0;R(63,a|0,d&255);d=v[22708];v[22708]=0;if((d|0)!=1){break f}break e}v[22708]=0;R(63,a|0,65533);d=v[22708];v[22708]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(62,a|0,d|0);d=v[22708];v[22708]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=w[pc(c,b)|0];v[22708]=0;R(63,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Wq(a,c,20896);return;case 5:Wq(a,c,21920);return;case 4:Wq(a,c,22944);return;case 6:Wq(a,c,23968);return;default:a=ba(8)|0;v[22708]=0;Q(59,a|0,8299)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}d=gb-16|0;gb=d;e=Kb(a);f=d,g=zd(c),v[f+8>>2]=g;f=d,g=ff(c),v[f>>2]=g;i:{j:{k:{if(!Gb(d+8|0,d)){break k}c=0;a=0;while(1){b=w[v[d+8>>2]];l:{if(!c){if(!(b&128)){c=0;v[22708]=0;R(63,e|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break l}break j}if((b&224)==192){a=b&31;c=1;break l}if((b&240)==224){a=b&15;c=2;break l}if((b&248)==240){a=b&7;c=3;break l}a=0;v[22708]=0;R(63,e|0,65533);b=v[22708];v[22708]=0;c=0;if((b|0)==1){break j}break l}if((b&192)!=128){v[22708]=0;R(63,e|0,65533);a=v[22708];v[22708]=0;if((a|0)==1){break j}a=b&63;c=-1;break l}b=b&63|a<<6;c=c-1|0;if(c){a=b;break l}a=0;v[22708]=0;R(63,e|0,b|0);b=v[22708];v[22708]=0;c=0;if((b|0)==1){break j}}b=d+8|0;Oe(b);if(Gb(b,d)){continue}break}if(!c){break k}v[22708]=0;R(63,e|0,65533);a=v[22708];v[22708]=0;if((a|0)!=1){break k}break j}gb=d+16|0;break i}a=P()|0;O()|0;Ic(e);S(a|0);L()}return}ia(a|0,89224,24);L()}b=P()|0;O()|0;Ic(a);S(b|0);L()}function qma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;t[a|0]=0;d=w[b|0];if(d){t[a|0]=d>>>0>96?-1:d+12|0}t[a+1|0]=w[b+1|0];d=a;c=w[b+2|0];e=c-16|0;a:{b:{if((e&255)>>>0<=128){t[a+2|0]=1;c=(e&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[d+4|0]=c}e=w[b+4|0];c=w[b+5|0];d=w[b+6|0];d:{if(!(d?1:e|c)){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=d>>>3;t[f+15|0]=15;h=a,i=w[ac(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d}t[a+5|0]=c;t[a+3|0]=d;Of(a);g=w[b+6|0]==15;break d}t[a+3|0]=2;h=a,i=ei(d<<4|(c&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=3;h=a,i=ei(d<<4|(c&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=4;h=a,i=ei(d<<4|(c&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=5;t[a+5|0]=d&240|(c&240)>>>4;break d}if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((d-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=d>>>1;break d}if(d){t[a+5|0]=d;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=c&15;break d}t[a+5|0]=c;t[a+3|0]=d;Xu(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=c;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=d>>>1;break d}t[a+3|0]=31;t[a+5|0]=d>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=d>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}gb=f+16|0;return g|0}function Dz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=gb-208|0;gb=c;g=1;d=v[a+12>>2];i=1<<d;if(d&1){j=i>>>1|0;e=j>>>0>1?j:1;d=0;while(1){k=d+j|0;g=Tc(b,k);m=v[g+12>>2];v[c+200>>2]=v[g+8>>2];v[c+204>>2]=m;m=v[g+4>>2];v[c+192>>2]=v[g>>2];v[c+196>>2]=m;m=c+192|0;Fj(c+176|0,Tc(b,d),m);g=Tc(b,k);h=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=h;k=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=k;Cz(Tc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=v[a+12>>2];g=2;i=i>>>3|0}else{i=i>>>2|0}k=d&-2;if(k){while(1){if(g){t=B(i,3);u=i<<1;j=0;while(1){d=Tc(a,j<<1);e=v[d+12>>2];v[c+200>>2]=v[d+8>>2];v[c+204>>2]=e;e=v[d+4>>2];v[c+192>>2]=v[d>>2];v[c+196>>2]=e;d=Tc(a,j);e=v[d+12>>2];v[c+184>>2]=v[d+8>>2];v[c+188>>2]=e;e=v[d+4>>2];v[c+176>>2]=v[d>>2];v[c+180>>2]=e;Ni(c+160|0,c+176|0,c+192|0);d=j<<k;m=i+d|0;if(d>>>0<m>>>0){while(1){e=Tc(b,d);h=v[e+12>>2];v[c+152>>2]=v[e+8>>2];v[c+156>>2]=h;h=v[e+4>>2];v[c+144>>2]=v[e>>2];v[c+148>>2]=h;h=c+128|0;q=d+i|0;Ni(h,c+192|0,Tc(b,q));e=c+112|0;r=d+u|0;Ni(e,c+176|0,Tc(b,r));f=c+96|0;s=d+t|0;Ni(f,c+160|0,Tc(b,s));n=c+80|0;l=c+144|0;Fl(n,l,e);o=c- -64|0;Fj(o,l,e);l=c+48|0;Fl(l,h,f);e=c+16|0;Vm(e,-A[6026],-A[6027]);Fj(c,h,f);h=c+32|0;Ni(h,e,c);Fl(e,n,l);f=Tc(b,d);p=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=p;p=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=p;Fj(e,n,l);f=Tc(b,q);l=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=l;n=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=n;Fl(e,o,h);f=Tc(b,r);l=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=l;n=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=n;Fj(e,o,h);e=Tc(b,s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;h=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(g|0)){continue}break}}i=i>>>2|0;g=g<<2;k=k-2|0;if(k){continue}break}}gb=c+208|0}function U7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-96|0;gb=e;a:{if(gd(c)){break a}f=w[pL(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;Ns(f,c,0,Ab(c)-1|0);Eb(c,f);vb(f)}f=e+80|0;Ld(f);g=v[e+80>>2];Ld(e+72|0);g=oL(g,v[e+76>>2],c);Ld(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(qe(c,18726)){a=ba(8)|0;v[22708]=0;b=Q(70,e+80|0,7752)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(!d){break f}a=ba(8)|0;v[22708]=0;U(2055,e+80|0,14764,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,e+80|0);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+80|0);break c}c=P()|0;O()|0;ca(a|0);break c}f=Kb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Dg(e- -64|0,c);v[22708]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(1998,b|0,e+8|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;t[e+72|0]=b;R(2058,a|0,e+72|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}break i;case 1:Dg(e+56|0,c);v[22708]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=qG(b,e+16|0,d);c=jb;d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2061,a|0,e+72|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}break i;case 2:Dg(e+48|0,c);v[22708]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(2e3,b|0,e+24|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;A[e+72>>3]=h;R(2062,a|0,e+72|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Dg(e+40|0,c);v[22708]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;Y(2001,a|0,b|0,e+32|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;vb(f);break c}Dc(a,f)}vb(f);break e}Kb(a)}gb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;t=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){s=(g+8|0)+(f<<2)|0;f=f<<1;v[s>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],q)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],w)+B(u[e+(f|-12)>>1],x)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],m)|0)/2|0)|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Lb(q,-16777216,16776704);m=v[a+64>>2];i=Lb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=nqa(l,r,h,h>>31);l=jb;m=nqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=nqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=e+o|0;l=o>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}l=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb+-64|0;gb=d;u[d+62>>1]=b;e=Ti(a);b=e;f=d+48|0;g=Hg(f);a:{if(!b){break a}v[22708]=0;R(814,f|0,b|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;R(1087,f|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bs(g);S(a|0);L()}b:{c:{if(!e){break c}b=0;while(1){j=sc(f,b),k=b-c|0,u[j>>1]=k;v[22708]=0;g=Q(1086,a|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}c=(x[g>>1]==x[d+62>>1])+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}if(!(c&65535)){break c}e=Vb(a);c=Zb(a);b=gb-32|0;gb=b;v[b+16>>2]=c;j=b,k=dC(e,c,d+62|0),v[j+24>>2]=k;d:{if(!Gb(b+24|0,b+16|0)){break d}v[b+8>>2]=v[b+24>>2];if(!Gb(of(b+8|0),b+16|0)){break d}while(1){if(x[v[b+8>>2]>>1]!=x[d+62>>1]){c=b+24|0;u[v[c>>2]>>1]=x[v[b+8>>2]>>1];of(c)}if(Gb(of(b+8|0),b+16|0)){continue}break}}gb=b+32|0;v[d+32>>2]=v[b+24>>2];g=d+32|0;b=Gd(d+40|0,g);j=d,k=Zb(a),v[j+16>>2]=k;h=d+16|0;e=Gd(d+24|0,h);b=v[b>>2];c=gb-32|0;gb=c;v[c+16>>2]=v[e>>2];v[c+24>>2]=b;b=a;e=v[b>>2];j=c,k=Vb(b),v[j+8>>2]=k;i=c+24|0;e=e+(rp(i,c+8|0)<<1)|0;if(Gb(i,c+16|0)){yn(b,Rg(e+(rp(c+16|0,c+24|0)<<1)|0,v[b+4>>2],e))}Gg(e);gb=c+32|0;j=d,k=Vb(a),v[j+32>>2]=k;j=d,k=Zb(a),v[j+16>>2]=k;if(Gb(g,h)){while(1){b=x[v[d+32>>2]>>1];c=v[a+24>>2];v[22708]=0;c=me(c+484344|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break b}e:{if(!c){break e}b=_b(v[a+24>>2]+484344|0,b);j=d,k=Vb(b),v[j+8>>2]=k;j=d,k=Zb(b),v[j>>2]=k;if(!Gb(d+8|0,d)){break e}while(1){b=v[d+8>>2];f:{if(w[b+3|0]!=12){break f}c=w[b+5|0];if(tc(f)>>>0<=c>>>0){break f}j=b,k=w[sc(f,w[b+5|0])|0],t[j+5|0]=k}b=d+8|0;$j(b);if(Gb(b,d)){continue}break}}b=d+32|0;of(b);if(Gb(b,d+16|0)){continue}break}}b=x[a+28>>1];if(tc(f)>>>0<=b>>>0){break c}j=a,k=x[sc(f,x[a+28>>1])>>1],u[j+28>>1]=k}Ze(f);gb=d- -64|0;return}a=P()|0;O()|0;Ze(f);S(a|0);L()}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+s|0;n=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],q)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],w)+B(t[e+(f|-6)|0],x)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],m)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Lb(q,-16777216,16776704);m=v[a+64>>2];i=Lb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=nqa(l,r,h,h>>31);l=jb;m=nqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=nqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;l=p>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);o=e+o|0;f=o>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}f=o>>12;l=p>>12}v[a+40>>2]=o;v[a+20>>2]=l;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}j=a,k=Ju(t[a+36|0],t[a+37|0]),v[j+24>>2]=k;u[a+36>>1]=0;if((b|0)!=1){break a}e=nqa(v[a+24>>2],0,8272,0)+4181|0;d=jb;j=a,k=Qc(qqa(e,e>>>0<4181?d+1|0:d,8363,0),jb),v[j+24>>2]=k;break a}if(d){break a}if((c|0)==1){e=nqa(v[a+24>>2],0,8363,0)+4136|0;d=jb;j=a,k=Qc(qqa(e,e>>>0<4136?d+1|0:d,8272,0),jb),v[j+24>>2]=k}e=gb-16|0;gb=e;g=e+8|0;h=g;d=gb-16|0;gb=d;i=v[a+24>>2];b:{if(!i){t[h|0]=0;t[h+1|0]=0;break b}kt(d+8|0,Lb(Qo(Sp(+(i>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];hB(h,d+7|0,d+6|0)}gb=d+16|0;yc(e,a+36|0);d=e+4|0;yc(d,a+37|0);tS(e,g);tS(d,g+1|0);gb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}c:{d:{e:{if(c&4){d=x[a+34>>1];if(!(d&32)){u[a+28>>1]=128;u[a+34>>1]=d|32}zf(a+40|0,15);zf(a+41|0,63);if(c&16777248?b&4:0){break e}if(!(b&16777248)){break c}if(w[a+41|0]){break d}break c}if(!(b&4)|!(c&16777248)){break c}if(w[a+41|0]){break d}break c}if(!w[a+41|0]){break c}}e=w[a+40|0];if(!e){break c}b=a;d=w[a+39|0];if(d){g=fm(Qc(((e<<8|d>>>1)>>>0)/(d>>>0)|0,0))}else{g=255}t[b+39|0]=g}f:{g:{if((c|0)!=4){if((c|0)==16777216){break f}if((c|0)!=32|w[a+38|0]!=2){break g}t[a+38|0]=3;break g}if(w[a+38|0]!=4){break g}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}h:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Ro(a,0,f);break h}if(!(w[a+35|0]&2)|(c|0)!=2){break h}a=a+68|0;b=ic(a,8);t[b|0]=w[b|0]&3;a=ic(a,9);t[a|0]=w[a|0]&3}gb=f+32|0}function f3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-432|0;gb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Ks(i+424|1,11170,v[c+4>>2]);v[i+380>>2]=i+384;a=xe();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=Gf(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Gf(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2458;k=ge(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22708]=0;a=ga(2478)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[22708]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=da(2497,i+380|0,a|0,i+424|0,i|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break e}break c}v[22708]=0;a=ga(2478)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22708]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=da(2497,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Ee(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=Tg(j,f,c);v[i+116>>2]=2458;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=Cd(a<<3);if(!a){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+380>>2]}v[22708]=0;Fc(i+104|0,c);h=v[22708];v[22708]=0;h:{i:{if((h|0)!=1){v[22708]=0;ja(2506,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}Wb(i+104|0);v[22708]=0;a=la(2507,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(e);Hc(k);gb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function p3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-256|0;gb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Ks(i+248|1,11170,v[c+4>>2]);v[i+204>>2]=i+208;a=xe();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=Gf(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Gf(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2458;k=ge(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22708]=0;a=ga(2478)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[22708]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=da(2497,i+204|0,a|0,i+248|0,i|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break e}break c}v[22708]=0;a=ga(2478)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22708]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=da(2497,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Ee(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=Tg(j,f,c);v[i+116>>2]=2458;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=Cd(a<<1);if(!a){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+204>>2]}v[22708]=0;Fc(i+104|0,c);h=v[22708];v[22708]=0;h:{i:{if((h|0)!=1){v[22708]=0;ja(2498,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}Wb(i+104|0);v[22708]=0;a=la(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(e);Hc(k);gb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function Ni(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0;e=A[b+8>>3];f=A[c>>3];m=e*f;g=A[b>>3];h=A[c+8>>3];p=g*h;i=m+p;q=g*f;r=e*h;k=q-r;a:{if(!Pi(k)){break a}if(!Pi(i)){break a}b:{if(!$g(g)){b=0;if(!$g(e)){break b}}o(+($g(g)?1:0));b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=+n();o(+($g(e)?1:0));b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=+n();o(0);b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=(s=+n(),t=f,u=Pi(f),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=(s=+n(),t=h,u=Pi(h),u?s:t);b=1}c:{d:{if(!$g(f)){if(!$g(h)){break d}}o(+($g(f)?1:0));b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=+n();o(+($g(h)?1:0));b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=+n();o(0);b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=(s=+n(),t=g,u=Pi(g),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=(s=+n(),t=e,u=Pi(e),u?s:t);break c}if(b){break c}e:{if($g(q)){break e}if($g(r)){break e}if($g(p)){break e}if(!$g(m)){break a}}o(0);b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=(s=+n(),t=g,u=Pi(g),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=(s=+n(),t=e,u=Pi(e),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=(s=+n(),t=f,u=Pi(f),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=(s=+n(),t=h,u=Pi(h),u?s:t)}i=(f*e+h*g)*N;k=(f*g-h*e)*N}Vm(a,k,i)}function kg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>=1){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+34704>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+34704>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+34704>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+34704>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+34704>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+34704>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+34192>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function t6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=rJ(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=rJ(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;hc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;hc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}gb=e+16|0;return g|0}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb+-64|0;gb=g;k=c+484344|0;zg(k,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){h=v[a+8>>2];d=sg(a);Rb(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Ae(a)+1|0;break b}c=Ng(a)}e=Ng(a);Wc(a,d+h|0);d=g+16|0;Sd(d,a,e);h=kc(g+40|0,d);xb(d);v[22708]=0;c=W(331,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}c:{if(!c|!e){break c}c=_b(k,j);l=g,m=Vb(c),v[l+16>>2]=m;l=g,m=Zb(c),v[l+8>>2]=m;if(!Gb(g+16|0,g+8|0)){break c}while(1){e=v[g+16>>2];v[22708]=0;c=T(374,h|0)|0;d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){if(!(c&128)){break f}if(c&1){v[22708]=0;d=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e|0]=d}if(c&2){break e}break d}break a}t[e|0]=c;c=255}v[22708]=0;d=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e+1|0]=d}d=0;if(c&4){v[22708]=0;d=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}}if(c&8){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}t[e+3|0]=f}if(c&16){v[22708]=0;c=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e+5|0]=c}c=e;g:{h:{f=w[e|0];if(!f){break h}i=255;if((f|0)==97){break g}if(f>>>0>96){break h}i=f+12|0;break g}i=0}t[c|0]=i;i:{if(w[e+5|0]|w[e+3|0]){v[22708]=0;Of(e);c=v[22708];v[22708]=0;if((c|0)!=1){break i}break a}t[e+3|0]=0}if(w[e+1|0]==255){t[e+1|0]=0}c=d-16|0;j:{if((c&255)>>>0<=64){t[e+4|0]=c;t[e+2|0]=1;break j}if(d>>>0<96){break j}c=d&15;t[e+4|0]=c;d=d-96>>4;t[e+2|0]=w[d+33439|0];if((d|0)!=6){break j}t[e+4|0]=c<<2}c=g+16|0;$j(c);if(Gb(c,g+8|0)){continue}break}}xb(g+40|0);j=j+1|0;if(j>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}gb=g- -64|0;return}a=P()|0;O()|0;xb(g+40|0);S(a|0);L()}function Gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=gb-32|0;gb=i;o=i,p=$q(b),v[o+16>>2]=p;l=i+24|0;n=l;g=gb-32|0;gb=g;c=b;e=a;b=Xd(e);h=fc(e);a:{b:{if(b){wb(e);c:{while(1){d:{e=b+14|0;e:{if(Ou(c,e)){if(!v[b>>2]){break b}h=b;break e}if(!Ou(e,c)){break c}h=b+4|0;if(!v[b+4>>2]){break d}b=h;h=b}b=v[b>>2];continue}break}v[g+28>>2]=b;b=h;break a}v[g+28>>2]=b;b=h;break a}b=fc(e)}v[g+28>>2]=b}h=b;b=v[b>>2];t[g+27|0]=0;if(!b){k=gb-16|0;gb=k;b=fc(a);e=g+8|0;m=Tj(e,Nc(48,4),Uj(k+8|0,b));b=v[m>>2];j=gb-16|0;gb=j;v[j+8>>2]=v[i+16>>2];c=v[j+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+14|0]=f;t[b+15|0]=f>>>8;t[b+16|0]=f>>>16;t[b+17|0]=f>>>24;t[b+18|0]=d;t[b+19|0]=d>>>8;t[b+20|0]=d>>>16;t[b+21|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);f=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+38|0]=f;t[b+39|0]=f>>>8;t[b+40|0]=f>>>16;t[b+41|0]=f>>>24;t[b+42|0]=d;t[b+43|0]=d>>>8;t[b+44|0]=d>>>16;t[b+45|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);f=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+30|0]=f;t[b+31|0]=f>>>8;t[b+32|0]=f>>>16;t[b+33|0]=f>>>24;t[b+34|0]=d;t[b+35|0]=d>>>8;t[b+36|0]=d>>>16;t[b+37|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+22|0]=c;t[b+23|0]=c>>>8;t[b+24|0]=c>>>16;t[b+25|0]=c>>>24;t[b+26|0]=d;t[b+27|0]=d>>>8;t[b+28|0]=d>>>16;t[b+29|0]=d>>>24;u[b+46>>1]=0;gb=j+16|0;o=fc(m),p=1,t[o+4|0]=p;gb=k+16|0;Gk(a,v[g+28>>2],h,v[e>>2]);b=be(e);t[g+27|0]=1;a=v[e>>2];v[e>>2]=0;if(a){fc(e);if(a){uT(a)}}}Vj(n,yc(g+8|0,b),g+27|0);gb=g+32|0;a=Xl(l);gb=i+32|0;return a+32|0}function qk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{if(!v[c>>2]|!d){break a}j=c;f=v[c>>2]+B(d,20)|0;b:{c:{if(v[a+480180>>2]==64){break c}f=v[c>>2]+((B(d,36318)|0)/1024|0)|0;if(v[a+480180>>2]==512){break c}d:{e:{f:{f=v[a+480208>>2];if(f&16){if(v[a+480180>>2]!=4){break f}f=v[a+480208>>2]}if(f&16){break d}Db(i,a+1074312|0,7);if(!Cb(i)){break d}f=v[c>>2];if((d|0)>-1){break e}g=nqa(f,0,14317456,0);h=jb;f=nqa(f,0,0-d|0,0)+14317456|0;d=jb;f=lP(qqa(g,h,f,f>>>0<14317456?d+1|0:d),jb);break c}k=v[c>>2];f=d>>31;v[i+12>>2]=f+d^f;qc(i+12|0,1020);h=v[i+12>>2];f=c;l=f;g=v[f>>2];m=g;n=g>>31;g:{if((d|0)>=1){if(h>>>0<=15){g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h<<2)+(f?43456:43520)>>2];break g}g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h>>>2<<2)+(f?43584:44608)>>2];break g}if(h>>>0<=15){g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h<<2)+(f?43520:43456)>>2];break g}g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h>>>2<<2)+(f?44608:43584)>>2]}h=nqa(m,n,h,h>>31)+32768|0;f=jb;f=Ac(oqa(h,h>>>0<32768?f+1|0:f,65536,0),jb);v[l>>2]=f;if((f|0)!=(k|0)){break b}Db(i,a+1074312|0,7);h=Cb(i);f=v[c>>2];if(!(h^(d|0)>0)){d=(f|0)==2147483647;f=v[c>>2];if(d){break b}f=f+1|0;break c}if((f|0)<2){break b}f=f-1|0;break c}d=nqa(f,f>>31,d,0);h=jb;g=h;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=lP(qqa(nqa(f,0,14317456,0),jb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),jb);break c}f=v[c>>2]-d|0}v[j>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=i+16|0}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=gb-144|0;gb=c;e=Hm(c+40|0,a);v[22708]=0;d=Q(620,c+24|0,49645)|0;a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22708]=0;v[c>>2]=19923026;v[c+4>>2]=0;U(621,e|0,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break n}Hb(d);if(v[e>>2]&1073741824){break e}v[22708]=0;d=Q(620,c+24|0,10683)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;da(1479,e|0,b|0,d|0,1480)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}Hb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[22708]=0;d=Q(620,c+24|0,13824)|0;a=v[22708];v[22708]=0;if((a|0)==1){break k}v[22708]=0;W(1481,e|0,c+20|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break j}Hb(d);v[22708]=0;d=Q(620,c+24|0,13814)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;W(1481,e|0,c+16|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break h}Hb(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[so(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[so(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Ho(c+24|0);v[22708]=0;f=Q(620,c|0,11389)|0;a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;U(1482,e|0,d|0,f|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}Hb(f);if(cd(d)){break f}a=v[b+16>>2];v[22708]=0;U(1306,d|0,a|0,16777216);a=v[22708];v[22708]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;Hb(f);break b}v[22708]=0;R(1483,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Lc(d)}gh(e);gb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(d)}gh(e);S(a|0);L()}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;m=gb-16|0;gb=m;n=c;k=d;g=gb-32|0;gb=g;l=g+28|0;f=g+24|0;h=c;e=gb-32|0;gb=e;v[e+24>>2]=b;a:{b:{c:{d:{i=a;if(!Qj(e+24|0,yc(e+16|0,Ch(i)))){j=wb(i);if(!Ml(j,h,ue(e+24|0))){break d}}v[e+16>>2]=b;if(!Qj(e+16|0,yc(e+8|0,uC(i)))){o=wb(i);j=e+16|0;p=j;c=v[j>>2];f=v[c>>2];e:{if(f){c=f;while(1){f=c;c=v[c+4>>2];if(c){continue}break}break e}if(ng(c)){while(1){c=v[c+8>>2];if(ng(c)){continue}break}}f=v[c+8>>2]}v[p>>2]=f;if(!Ml(o,ue(j),h)){break c}}if(!v[b>>2]){v[l>>2]=b;break a}b=v[e+16>>2];v[l>>2]=b;b=b+4|0;break a}if(!Ml(j,ue(e+24|0),h)){break b}c=gb-16|0;gb=c;v[c+8>>2]=b;Sj(c+8|0);gb=c+16|0;c=v[c+8>>2];v[e+16>>2]=c;if(!Qj(e+16|0,yc(e+8|0,Ch(i)))){if(!Ml(j,h,ue(e+16|0))){break c}}if(!v[v[e+24>>2]+4>>2]){v[l>>2]=b;b=b+4|0;break a}v[l>>2]=c;b=c;break a}b=dR(i,l,h);break a}v[l>>2]=b;v[f>>2]=b;b=f}gb=e+32|0;c=b;b=v[b>>2];t[g+23|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);h=g+8|0;f=Tj(h,cR(),Uj(i+8|0,b));b=v[f>>2];v[22708]=0;b=b+16|0;e=v[22708];v[22708]=0;f:{if((e|0)!=1){e=v[n+4>>2];v[b>>2]=v[n>>2];v[b+4>>2]=e;wb(k);n=vh(b+8|0);v[b+8>>2]=v[k>>2];v[b+12>>2]=v[k+4>>2];b=wb(k);q=wb(n),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[k>>2]=0;v[k+4>>2]=0;q=fc(f),r=1,t[q+4|0]=r;gb=i+16|0;break f}a=P()|0;O()|0;OA(f);S(a|0);L()}Gk(a,v[g+28>>2],c,v[h>>2]);b=be(h);t[g+23|0]=1;OA(h)}Vj(m,yc(g+8|0,b),g+23|0);gb=g+32|0;a=m;if(!w[fc(a)|0]){c=ue(a)+8|0;b=c;if(v[b>>2]){sf(b);eR(b);tg(b);sf(b);PA(wb(b),v[b>>2],tg(b));q=wb(b),r=0,v[q>>2]=r;v[b>>2]=0;v[b+4>>2]=0}kp(c,d);v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];b=wb(d);q=wb(c),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[yc(m+8|0,v[a>>2])>>2];gb=m+16|0;return a|0}function boa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;v[g+24>>2]=d;k=fg(a,c);se(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}j=v[g+24>>2];d=gb-160|0;gb=d;h=Hm(d+56|0,v[a+28>>2]);v[22708]=0;e=Q(620,d+8|0,34111)|0;f=v[22708];v[22708]=0;b:{c:{d:{e:{if((f|0)!=1){v[22708]=0;v[d+48>>2]=19923026;v[d+52>>2]=0;U(621,h|0,e|0,d+48|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}Hb(e);if(!(v[h>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}t[d+48|0]=0;t[d+47|0]=0;v[22708]=0;e=Q(620,d+8|0,7364)|0;f=v[22708];v[22708]=0;f:{if((f|0)!=1){v[22708]=0;U(1097,h|0,d+48|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}Hb(e);if(!w[d+48|0]){break b}zf(d+48|0,50);v[22708]=0;e=Q(620,d+8|0,10564)|0;f=v[22708];v[22708]=0;g:{h:{i:{j:{if((f|0)!=1){v[22708]=0;U(1097,h|0,d+47|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}Hb(e);e=Ri(b);f=w[d+48|0];if(e>>>0<f>>>0){e=gB(d+8|0,v[b+12>>2]);v[22708]=0;U(1098,b|0,f|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}Zm(e)}e=0;f=x[Rj(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){i=e&255;cf(Rj(b,i),f);i=Rj(b,i);v[22708]=0;R(1099,d+8|0,d+7|0);l=v[22708];v[22708]=0;if((l|0)==1){break h}v[22708]=0;Y(1100,h|0,i|0,d+8|0,j|0);i=v[22708];v[22708]=0;if((i|0)==1){break g}Hb(d+8|0);e=e+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];j=Ri(b);t[b+16|0]=e>>>0<j>>>0?w[d+47|0]:0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}a=P()|0;O()|0;Zm(e);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(d+8|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e)}gh(h);S(a|0);L()}gh(h);gb=d+160|0}Zf(a,k,c,g+16|0);gb=g+32|0}function Iq(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);Yd(e+12|0,0,127);Yd(e+8|0,0,127);l=a+1074312|0;Db(e,l,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+780>>1]=0;t[b+837|0]=i;j=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=j}Db(e,l,36);i=B(i,d+256|0);j=(i|0)/256|0;k=Cb(e);m=v[e+8>>2];a:{if(!(m|!k|(i|0)<65024)){j=-1;a=b+788|0;if(!ce(a)){break a}if(uu(a)|x[b+786>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=oe(C(10),C(C(0-m|0)*C(.00937500037252903)));i=gb-16|0;gb=i;g=C(B(v[e+12>>2],d+256|0)>>>0);d=a;b:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Xh(C(h*oe(C(2),g))),v[n+12>>2]=o;Yd(i+12|0,120,2e4);k=v[i+12>>2];d=v[d+24620>>2];gb=i+16|0;Db(e,l,36);g=C(C(((d|0)<k<<1?d>>>1|0:k)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){h=f;f=C(C(y[a+24620>>2])/g);g=C(C(h+C(h*f))+C(-1));z[e>>2]=g;f=C(f*f);break c}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;VP(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(g+f))/h);f=C(C(-f)/h);h=C(C(1)/h);d:{if(w[b+845|0]==1){n=b,o=Xh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Xh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Xh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break d}n=b,o=Xh(C(h*C(16777216))),v[n+60>>2]=o;n=b,o=Xh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Xh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}gb=e+16|0;return j}function F2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-624|0;gb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2509;b=ge(a+200|0,a+208|0,a+16|0);v[22708]=0;Fc(a+192|0,e);h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22708]=0;h=T(2482,a+192|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}t[a+191|0]=0;e=v[e+4>>2];v[22708]=0;c=ra(2517,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(!c){break e}c=w[11855]|w[11856]<<8|(w[11857]<<16|w[11858]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[11852]|w[11853]<<8|(w[11854]<<16|w[11855]<<24);v[a+176>>2]=w[11848]|w[11849]<<8|(w[11850]<<16|w[11851]<<24);v[a+180>>2]=c;v[22708]=0;Y(2494,h|0,a+176|0,a+186|0,a+128|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[a+4>>2]=2458;d=ge(a+8|0,0,a+4|0);h=v[a+196>>2];c=h-v[b>>2]|0;e=a+16|0;if((c|0)<393){break h}Ee(d,Cd((c>>>2|0)+2|0));if(v[d>>2]){break i}v[22708]=0;X(2459);c=v[22708];v[22708]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+168|0;while(1){i=a+128|0;j=e,k=w[(a+176|0)+(sx(i,h,c)-i>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;if(c>>>0<y[a+196>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((sH(a+16|0,a)|0)==1){break f}v[22708]=0;_(2511,5133);c=v[22708];v[22708]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[22708]=0;c=Q(2488,a+616|0,a+608|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Wb(a+192|0);Hc(b);gb=a+624|0;return c|0}e=P()|0;O()|0}Wb(a+192|0)}Hc(b);S(e|0);L()}L()}function oO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;a:{b:{c:{h=B(b,872)+a|0;if(w[h+1075082|0]&2){f=v[a+480180>>2];d:{e:{f:{if(v[a+480208>>2]&4096){if(!(f&16777248)){break f}if(v[a+480180>>2]==64){break e}if(v[a+480208>>2]&4){break d}break c}if((f|0)!=64){break c}break e}if(v[a+480180>>2]!=64){break d}}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1;break a}break b}if(!(w[h+1075662|0]&2)){break a}a=nu(a,b);if(!a){break a}kb[v[v[a>>2]+88>>2]](a,0,0,b);break a}f=g+8|0;Db(f,a+1074312|0,21);k=1;if(!Cb(f)){break b}f=B(b,872)+a|0;e=f+1075811|0;t[e|0]=w[e|0]+(w[f+1075815|0]<<2)}e=B(b,872)+a|0;i=e+1075814|0;j=e+1075811|0;f=Qz(a,w[i|0],w[j|0]);h=h+1074992|0;g:{if(Kj(h)){z[d>>2]=z[d>>2]+C(C(C(B(w[e+1075816|0],f)|0)*C(.05000000074505806))/C(7680));c=e+1075843|0;d=w[c|0];t[c|0]=d&207|32;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break g}t[c|0]=d|48;break g}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}f=v[a+480180>>2]&5?(w[i|0]&3)==1?0-f|0:f:f;d=g+8|0;i=a+1074312|0;Db(d,i,21);d=Cb(d);e=v[a+480208>>2];h:{if(d){d=e&4;f=d?f:0-f|0;d=d?5:6;break h}d=5;i:{if(e&131072){break i}d=8;if(v[a+480180>>2]==1024){break i}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break i}d=6}e=g+8|0;Db(e,i,80);if(!Cb(e)){break h}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}e=B(b,872)+a|0;d=(0-B(w[e+1075816|0],f)|0)/(1<<d)|0;qk(a,h,c,d,0);c=nu(a,b);if(!c){break g}f=c;e=v[e+1075648>>2];if(e){e=w[e+33|0]}else{e=2}kb[v[v[c>>2]+88>>2]](f,d,e<<24>>24,b)}if(!k){break a}c=g+8|0;Db(c,a+1074312|0,21);if(Cb(c)){break a}t[j|0]=w[j|0]+w[(B(b,872)+a|0)+1075815|0]}gb=g+16|0}function O2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2509;b=ge(a+152|0,a+160|0,a+16|0);v[22708]=0;Fc(a+144|0,e);h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22708]=0;h=T(21,a+144|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}t[a+143|0]=0;e=v[e+4>>2];v[22708]=0;c=ra(2510,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(!c){break e}c=w[11855]|w[11856]<<8|(w[11857]<<16|w[11858]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[11852]|w[11853]<<8|(w[11854]<<16|w[11855]<<24);v[a+128>>2]=w[11848]|w[11849]<<8|(w[11850]<<16|w[11851]<<24);v[a+132>>2]=c;v[22708]=0;Y(2474,h|0,a+128|0,a+138|0,a+118|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[a+4>>2]=2458;d=ge(a+8|0,0,a+4|0);h=v[a+148>>2];e=a+16|0;if((h-v[b>>2]|0)<99){break h}Ee(d,Cd((h-v[b>>2]|0)+2|0));if(v[d>>2]){break i}v[22708]=0;X(2459);c=v[22708];v[22708]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+128|0;while(1){j=e,k=w[((Xm(a+118|0,h,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;if(c>>>0<y[a+148>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((sH(a+16|0,a)|0)==1){break f}v[22708]=0;_(2511,5133);c=v[22708];v[22708]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[22708]=0;c=Q(2461,a+280|0,a+272|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Wb(a+144|0);Hc(b);gb=a+288|0;return c|0}e=P()|0;O()|0}Wb(a+144|0)}Hc(b);S(e|0);L()}L()}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;q=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;n=v[a+56>>2];v[f+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;if(d){while(1){n=1;i=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];t=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];k=0;e=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[i+(h|8)>>1],o)+B(u[i+(h|4)>>1],l)|0)+B(u[i+(h|12)>>1],m)|0)+B(j,u[i+(h|16)>>1])|0)/2|0)+((((B(u[i+(h|-8)>>1],w)+B(u[i+(h|-12)>>1],x)|0)+B(u[i+(h|-4)>>1],t)|0)+B(u[i+h>>1],p)|0)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];m=v[a+60>>2];o=m;h=(f+32|0)+(k<<3)|0;k=v[h>>2];e=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(v[h+4>>2],-16777216,16776704);p=m>>31;m=g<<8;g=m;g=nqa(o,p,g,g>>31);o=jb;l=nqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+o|0;e=g>>>0<l>>>0?e+1|0:e;p=g;g=v[a+68>>2];g=nqa(g,g>>31,i,i>>31);i=p+g|0;e=jb+e|0;e=i>>>0<g>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[h+4>>2]=k;i=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(i&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];n=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function s2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;u=gb-16|0;gb=u;v[c>>2]=a;A=d&512;B=h<<2;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=Vs(g,32);h=v[c>>2];v[c>>2]=h+4;v[h>>2]=p;break a;case 3:if(gd(n)){break a}p=v[xk(n,0)>>2];h=v[c>>2];v[c>>2]=h+4;v[h>>2]=p;break a;case 2:if(gd(m)|!A){break a}D=c,E=Xi(zd(m),vi(m),v[c>>2]),v[D>>2]=E;break a;case 4:break b;default:break a}}C=v[c>>2];e=e+B|0;h=e;c:{if(h>>>0>=f>>>0){break c}while(1){if(!jl(g,2048,v[h>>2])){break c}h=h+4|0;if(h>>>0<f>>>0){continue}break}}if((o|0)>=1){d:{e:{if(e>>>0>=h>>>0){q=o;break e}r=v[c>>2];q=o;while(1){f:{h=h-4|0;v[r>>2]=v[h>>2];p=q;q=p-1|0;r=r+4|0;if(e>>>0>=h>>>0){break f}if((p|0)>1){continue}}break}v[c>>2]=r;if((p|0)>1){break e}p=v[c>>2];r=p+4|0;break d}z=Vs(g,48);s=v[c>>2];r=s+4|0;while(1){v[s>>2]=z;p=r;r=p+4|0;x=(q|0)>1;q=q-1|0;s=p;if(x){continue}break}}v[c>>2]=r;v[p>>2]=j}g:{if((e|0)==(h|0)){p=Vs(g,48);h=v[c>>2];r=h+4|0;v[c>>2]=r;v[h>>2]=p;break g}if(gd(l)){p=-1}else{p=t[pc(l,0)|0]}s=0;q=0;while(1){h:{if((p|0)!=(q|0)){break h}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;q=0;s=s+1|0;if(Ab(l)>>>0<=s>>>0){break h}if(w[pc(l,s)|0]==127){p=-1;break h}p=t[pc(l,s)|0]}h=h-4|0;z=v[h>>2];x=v[c>>2];r=x+4|0;v[c>>2]=r;v[x>>2]=z;q=q+1|0;if((e|0)!=(h|0)){continue}break}}rx(C,r)}y=y+1|0;if((y|0)!=4){continue}break}if(Ab(n)>>>0>1){D=u,E=zd(n),v[D+8>>2]=E;e=gb-16|0;gb=e;v[e+8>>2]=v[u+8>>2];Qe(e+8|0);gb=e+16|0;D=c,E=Xi(v[e+8>>2],vi(n),v[c>>2]),v[D>>2]=E}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=u+16|0}function cN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){if(!ng(d)){while(1){d=v[d+8>>2];if(!ng(d)){continue}break}}d=v[d+8>>2];break c}d=TV(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(ng(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){v[d+8>>2]=v[b+8>>2];f:{if(ng(b)){f=v[d+8>>2];break f}f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;fp(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){fp(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=ng(c);d=w[c+12|0];g:{h:{if(!b){if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;tr(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];i:{if(!(w[b+12|0]?0:b)){b=v[c+4>>2];if(w[b+12|0]?0:b){break i}t[c+12|0]=0;j:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break j}a=b}t[a+12|0]=1;return}if(!ng(b)){break h}b=v[b+8>>2]+4|0;break g}a=v[c+4>>2];if(w[a+12|0]?0:a){break i}t[b+12|0]=1;t[c+12|0]=0;sr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;tr(v[c+8>>2]);return}if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;sr(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];k:{if(w[d+12|0]?0:d){break k}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(ng(b)){b=v[b+8>>2]+4|0;break g}b=v[b+8>>2];break g}if(w[d+12|0]?0:d){break k}t[b+12|0]=1;t[c+12|0]=0;tr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;sr(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function c8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;g=mc(a);a=b+24|0;f=Sb(v[a>>2]+484360|0);v[22708]=0;h=Ti(f);f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)==1){break c}v[22708]=0;R(1422,g|0,h|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}d:{e:{if(h){f=0;while(1){c=x[sc(Sb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[22708]=0;d=cm(d+484344|0,c);i=v[22708];v[22708]=0;if((i|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[sc(Sb(v[a>>2]+484360|0),f)>>1]);v[22708]=0;R(2100,e|0,c|0);c=v[22708];v[22708]=0;g:{h:{i:{if((c|0)!=1){v[22708]=0;U(2094,e+16|0,b|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;R(1424,g|0,e+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}vb(e+16|0);vb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e+16|0)}vb(e);break a}v[22708]=0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if((c|0)==65534){v[22708]=0;c=Q(70,e+16|0,6397)|0;d=v[22708];v[22708]=0;j:{if((d|0)!=1){v[22708]=0;R(1424,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22708]=0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if((c|0)==65535){v[22708]=0;c=Q(70,e+16|0,6359)|0;d=v[22708];v[22708]=0;k:{if((d|0)!=1){v[22708]=0;R(1424,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break k}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22708]=0;c=Q(70,e+16|0,11817)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;R(1424,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}vb(c)}f=f+1|0;if((h|0)!=(f|0)){continue}break}}gb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function Ao(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){d=f+8|0;Db(d,a+1074312|0,15);if(Cb(d)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}c:{if(Kj(b)){d=x[b+768>>1];if(!d){break c}e=v[b+856>>2];c=b;g=v[a+1074392>>2];i=0-d|0;j=d;d=v[b+708>>2];h=(+(g>>>0)+1)*+(((d|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[c+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?e:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+852>>2]=d+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}v[b+708>>2]=d-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}c=1;e:{if(!(t[b+851|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){d=f+8|0;Db(d,a+1074312|0,6);if(Cb(d)){break e}}c=0;if(v[a+480180>>2]!=8){break e}c=(w[a+480208|0]&2)>>>1|0}d=x[b+768>>1];e=v[a+480180>>2];f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}e=(e|0)==268435456&d>>>0>239;if(!(e?t[b+851|0]&1:c)){break f}c=b+700|0;d=B(v[a+480180>>2]==64?2:4,e?d-240|0:d);d=rk(a)?d:0-d|0;e=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&8?0:(e|0)>=(g|0))){qk(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((e|0)<=(g|0)){break f}qk(a,b,c,0-d|0,1);e=v[b+700>>2];d=v[b+708>>2];g:{if((e|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(e|0)){break f}}c=f+8|0;Db(c,a+1074312|0,112);if(!Cb(c)){break f}t[b+851|0]=w[b+851|0]|8}if(v[b+700>>2]!=v[b+708>>2]){break c}c=f+8|0;Db(c,a+1074312|0,25);if(!Cb(c)&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}gb=f+16|0}function A_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-80|0;gb=e;vc(b);rs(a);a:{if(!Ih(b,e+72|0)){break a}if(!vF(e+72|0)){break a}if(!c){j=1;break a}if(!Pb(b,4)){break a}Xw(a);p=e,q=Ww(),v[p+48>>2]=q;c=e+48|0;Vw(mj(a)+32|0,c);ps(c);k=v[mj(a)+32>>2];c=lm(b);if(c&1){break a}d=c-4|0;Wc(b,d);g=gb-16|0;gb=g;c=g+8|0;Fw(c,b);f=w[ic(c,0)|0];i=w[ic(c,1)|0];c=w[ic(c,2)|0];gb=g+16|0;g=c|(i<<8|f<<16);if(!g){break a}v[22708]=0;R(271,k|0,g|0);c=v[22708];v[22708]=0;j=1;if((c|0)==1){a=V(89104)|0;if((O()|0)==(ea(89104)|0)){Z(a|0)|0;$();j=0;break a}S(a|0);L()}Wc(b,4);l=e+48|0;uF(l,b);i=v[k>>2];f=gb-32|0;gb=f;b=v[l>>2];t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=tF(f+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;dk(c,w[d-1|0]);b=g;while(1){b:{if(!dk(c,1)){v[f+4>>2]=1;while(1){d=dk(c,2);v[f+4>>2]=d+v[f+4>>2];if((d|0)==3){continue}break}qc(f+4|0,b);d=0;if(v[f+4>>2]){while(1){b=b-1|0;p=i+b|0,q=dk(c,8),t[p|0]=q;d=d+1|0;if(d>>>0<y[f+4>>2]){continue}break}}if(!b){break b}}d=dk(c,2);v[f+4>>2]=d+2;c:{if((d|0)==3){d=c;if(dk(c,1)){h=w[ic(f+24|0,3)|0]}else{h=7}m=dk(d,h);while(1){d=dk(c,3);v[f+4>>2]=d+v[f+4>>2];if((d|0)==7){continue}break}break c}m=dk(c,w[ic(f+24|0,d)|0])}qc(f+4|0,b);h=0;n=v[f+4>>2];if(n){while(1){d=0;o=b+m|0;if(g>>>0>o>>>0){d=w[i+o|0]}b=b-1|0;t[i+b|0]=d;h=h+1|0;if((n|0)!=(h|0)){continue}break}}if(b){continue}}break}gb=f+32|0;Ud(e+32|0,k);b=v[e+36>>2];v[e+16>>2]=v[e+32>>2];v[e+20>>2]=b;rh(e+40|0,e+16|0);b=Td(e+24|0);c=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;b=os(l,e+8|0,e);Vc(mj(a)+12|0,b);xb(b)}gb=e+80|0;return j|0}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;q=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;e=v[a+48>>2];v[g+36>>2]=e;k=v[a+52>>2];v[g+40>>2]=k;n=v[a+56>>2];v[g+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];i=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=i;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;if(d){while(1){f=(((i&2147483647)<<1|j>>>31)&-2)+q|0;n=1;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];w=u[e+28>>1];x=u[e+26>>1];y=u[e+24>>1];k=0;e=1;h=0;while(1){v[(g+8|0)+(h<<2)>>2]=(((((B(t[f+(h|4)|0],o)+B(t[f+(h|2)|0],l)|0)+B(t[f+(h|6)|0],m)|0)+B(j,t[f+(h|8)|0])<<8)/2|0)+((((B(t[f+(h|-4)|0],x)+B(t[f+(h|-6)|0],y)|0)+B(t[f+(h|-2)|0],w)|0)+B(t[h+f|0],p)<<8)/2|0)|0)/16384;i=e;e=0;h=1;if(i){continue}break}while(1){j=(g+8|0)+(k<<2)|0;f=v[j>>2];m=v[a+60>>2];o=m;i=(g+32|0)+(k<<3)|0;k=v[i>>2];e=Lb(k,-16777216,16776704);l=v[a+64>>2];h=Lb(v[i+4>>2],-16777216,16776704);p=m>>31;m=f<<8;f=m;f=nqa(o,p,f,f>>31);o=jb;l=nqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+o|0;e=f>>>0<l>>>0?e+1|0:e;l=f;f=v[a+68>>2];f=nqa(f,f>>31,h,h>>31);h=l+f|0;e=jb+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Jc(h,e,24);v[i+4>>2]=k;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[i>>2]=e-(h&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],r);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];i=v[g+28>>2];continue}break}j=v[g+24>>2];i=v[g+28>>2];n=v[g+44>>2];k=v[g+40>>2];h=v[g+32>>2];e=v[g+36>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=h;v[a>>2]=j;v[a+4>>2]=i;gb=g+48|0}function w2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=gb-16|0;gb=x;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=qn(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(gd(n)){break a}q=w[pc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(gd(m)|!A){break a}C=c,D=Xi(zd(m),ff(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!nh(g,2048,t[r|0])){break c}r=r+1|0;if(r>>>0<f>>>0){continue}break}}if((o|0)>=1){q=o;d:{if(e>>>0<r>>>0){while(1){e:{r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;s=q;q=q-1|0;if(e>>>0>=r>>>0){break e}if((s|0)>1){continue}}break}u=0;p=0;if((s|0)<2){break d}}u=qn(g,48);p=q}q=v[c>>2];v[c>>2]=q+1;if((p|0)>=1){while(1){t[q|0]=u;q=v[c>>2];v[c>>2]=q+1;s=(p|0)>1;p=p-1|0;if(s){continue}break}}t[q|0]=j}f:{if((e|0)==(r|0)){q=qn(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break f}if(gd(l)){q=-1}else{q=t[pc(l,0)|0]}u=0;p=0;while(1){g:{if((p|0)!=(q|0)){break g}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;p=0;u=u+1|0;if(Ab(l)>>>0<=u>>>0){break g}if(w[pc(l,u)|0]==127){q=-1;break g}q=t[pc(l,u)|0]}r=r-1|0;s=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=s;p=p+1|0;if((e|0)!=(r|0)){continue}break}}pm(B,v[c>>2])}y=y+1|0;if((y|0)!=4){continue}break}if(Ab(n)>>>0>1){C=x,D=zd(n),v[C+8>>2]=D;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];v[e+8>>2]=v[e+8>>2]+1;gb=e+16|0;C=c,D=Xi(v[e+8>>2],ff(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<1){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if(i>>>0>2147483647&(f|0)>=-2|(f|0)>-2){break d}break b}if(i>>>0>2147483648&(f|0)>=1|(f|0)>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;j=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];r=v[a+60>>2];b=Lb(m,-16777216,16776704);o=v[a+64>>2];g=Lb(g,-16777216,16776704);b=nqa(o,o>>31,b,b>>31);o=jb;q=b;j=(((((((B(i,n)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=nqa(r,r>>31,b,b>>31);e=q+f|0;b=jb+o|0;b=e>>>0<f>>>0?b+1|0:b;q=e;e=v[a+68>>2];e=nqa(e,e>>31,g,g>>31);g=q+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];e=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;n=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,n);k=e+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,i);b=b-(g&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function Os(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Op(c,d);v[i+4>>2]=2458;n=jH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!gd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22708]=0;h=Q(2460,a|0,i+120|0)|0;b=v[22708];v[22708]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22708]=0;b=Q(2461,a|0,i+120|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[22708]=0;p=T(2462,a|0)|0;b=v[22708];v[22708]=0;f:{if((b|0)!=1){if(g){break f}v[22708]=0;p=Q(2463,e|0,p|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=t[pc(h,r)|0];h:{if(g){break h}v[22708]=0;q=Q(2463,e|0,q<<24>>24)|0;u=v[22708];v[22708]=0;if((u|0)!=1){break h}break b}i:{if((p&255)==(q&255)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22708]=0;T(2464,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);S(a|0)}L()}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;h=j>>>21&2040;j=u[h+46166>>1];i=u[h+46164>>1];k=u[h+46162>>1];p=u[h+46160>>1];h=0;g=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],p)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;l=g&1;g=0;f=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;g=v[j>>2];i=v[a+60>>2];k=i;h=(b+32|0)+(h<<3)|0;p=v[h>>2];e=Lb(p,-16777216,16776704);l=v[a+64>>2];f=Lb(v[h+4>>2],-16777216,16776704);q=i>>31;i=g<<8;g=i;g=nqa(k,q,g,g>>31);k=jb;l=nqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+k|0;e=g>>>0<l>>>0?e+1|0:e;k=g;g=v[a+68>>2];g=nqa(g,g>>31,f,f>>31);f=k+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[h+4>>2]=p;f=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(f&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);n=e+n|0;k=n>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}k=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<1){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if(i>>>0>2147483647&(f|0)>=-2|(f|0)>-2){break d}break b}if(i>>>0>2147483648&(f|0)>=1|(f|0)>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(j>>>16&65520)+p|0;j=u[e+14>>1];i=t[b+3|0];o=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Lb(m,-16777216,16776704);n=v[a+64>>2];g=Lb(g,-16777216,16776704);b=nqa(n,n>>31,b,b>>31);n=jb;J=b;b=v[a+68>>2];q=nqa(b,b>>31,g,g>>31);g=J+q|0;b=jb+n|0;b=g>>>0<q>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,o)|0)+B(f,j)<<8)/32768<<8;f=nqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];j=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;o=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,o);k=j+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,i);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function tfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=gb-48|0;gb=g;h=Mi(b)^-1;a:{if(Nb(d)>>>0<=h>>>0){$t(a);break a}Mi(b);c=c+4|0;if((w[c|0]|w[c+1|0]<<8)>>>0>=60){Rb(b,4)}k=g,l=Mi(b),v[k+44>>2]=l;Rb(b,4);i=Mi(b);j=Mi(b);if(!((i|0)>=1&(j|0)>36)){$t(a);break a}b:{if(!f){break b}if(!wr(Ad(e,v[Mb(d,h)>>2]),f)){break b}$t(a);break a}Tw(g,b,j,i);b=kc(g+24|0,g);xb(g);v[22708]=0;d=T(275,b|0)|0;e=v[22708];v[22708]=0;c:{if((e|0)==1){break c}d:{e:{if(!d){v[22708]=0;T(1428,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break e}break c}if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[22708]=0;Q(318,b|0,8)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[22708]=0;Q(318,b|0,16)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}}v[22708]=0;T(1420,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}f:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[22708]=0;T(1420,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;Q(318,b|0,8)|0;break f}if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[22708]=0;Q(318,b|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;T(1420,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;Q(318,b|0,4)|0;break f}if((w[c|0]|w[c+1|0]<<8)>>>0>=62){v[22708]=0;T(1420,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;Q(318,b|0,4)|0;break f}v[22708]=0;T(1420,b|0)|0}c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=T(1420,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;U(288,g|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break d}kc(a,g);v[a+20>>2]=v[g+44>>2];xb(g)}xb(b);break a}}a=P()|0;O()|0;xb(b);S(a|0);L()}gb=g+48|0}function HS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-32|0;gb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;d=!(b&2);b=w[a+14|0];if(d|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}while(1){d=Cc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Nb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}d=x[Cc(a,w[a+14|0])>>1];e=Cc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Cc(a,b)>>1]-1&65535;d=Uq(a,b,64,64);q=f,r=Vb(a),v[q+8>>2]=r;q=f,r=_o(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Gd(f+24|0,f+16|0);h=pr(f,b,d&255);g=gb-32|0;gb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=Vb(a),v[q>>2]=r;d=d+(ov(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[wb(a)>>2]){i=v[b+4>>2];if((i|0)!=(d|0)){break d}rW(b,h);break c}e=wb(b);e=zp(g,fh(b,Nb(b)+1|0),d-v[b>>2]>>2,e);v[22708]=0;R(1080,e|0,h|0);l=v[22708];v[22708]=0;e:{if((l|0)==1){break e}v[22708]=0;d=W(1081,b|0,e|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}hj(e);break c}a=P()|0;O()|0;hj(e);S(a|0);L()}m=gb-16|0;gb=m;l=d;o=b;p=v[b+4>>2];b=(p-(d+4|0)|0)+d|0;j=Eg(m,o,i-b>>2);f:{g:{if(b>>>0<i>>>0){k=v[j+4>>2];e=b;while(1){n=wb(o);v[22708]=0;hn(n,k,e);n=v[22708];v[22708]=0;if((n|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}$b(j);yr(l,b,p);gb=m+16|0;break f}a=P()|0;O()|0;$b(j);S(a|0);L()}u[d>>1]=x[h>>1];t[d+2|0]=w[h+2|0]}Gg(d);gb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}gb=f+32|0}function Ms(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Op(c,d);v[i+4>>2]=2458;n=jH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!gd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22708]=0;h=Q(2487,a|0,i+120|0)|0;b=v[22708];v[22708]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22708]=0;b=Q(2488,a|0,i+120|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[22708]=0;p=T(2489,a|0)|0;b=v[22708];v[22708]=0;f:{if((b|0)!=1){if(g){break f}v[22708]=0;p=Q(2490,e|0,p|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=v[xk(h,r)>>2];h:{if(g){break h}v[22708]=0;q=Q(2490,e|0,q|0)|0;u=v[22708];v[22708]=0;if((u|0)!=1){break h}break b}i:{if((p|0)==(q|0)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22708]=0;T(2491,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);S(a|0)}L()}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(Bj(b)){zh(c+56|0);break n}v[22708]=0;R(2098,c+40|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;a=T(2086,c+40|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break l}v[c+56>>2]=a;Yf(c+40|0)}if(Bj(b)){a=b+36|0}else{a=v[c+56>>2]}e=jo(a);v[22708]=0;R(1422,f|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}h=c,i=Vb(a),v[h+32>>2]=i;h=c,i=Zb(a),v[h+24>>2]=i;if(Gb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Rj(v[a>>2]+484360|0,w[e+16|0]);v[22708]=0;R(2099,c+8|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}v[22708]=0;R(2041,c+40|0,c+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}v[22708]=0;R(1424,f|0,c+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}vb(c+40|0);vb(c+8|0);o:{if(!gd(GK(f))){break o}d=w[e+12|0];v[22708]=0;d=Q(472,b|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[22708]=0;d=Jk(d);g=v[22708];v[22708]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[sc(b,v[e+12>>2])>>1]);v[22708]=0;R(2100,c+8|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Y(360,c+40|0,0,d|0,c+8|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=c+40|0;Eb(GK(f),b);vb(b);vb(c+8|0)}b=c+32|0;$K(b);if(Gb(b,c+24|0)){continue}break}}wl(c+56|0);gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Yf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(c+40|0)}vb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(c+8|0);break b}b=P()|0;O()|0}wl(c+56|0)}yd(f);S(b|0);L()}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=gb-32|0;gb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;d=0;l=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(l>>>0<=b>>>0){break a}if(!c|Ti(a)>>>0>=l>>>0){break a}yg(e+28|0,l-b&65535);s=e,t=$l(a),u[s+8>>1]=t;b=Ke(e+30|0,e+8|0);eW(a,x[e+28>>1]+x[b>>1]|0);b=x[e+30>>1];if(tc(a)>>>0<b>>>0){Bf(a,x[e+30>>1])}s=e,t=Vb(a),v[s>>2]=t;c=x[e+30>>1];b=gb-16|0;gb=b;v[b+8>>2]=v[e>>2];v[b+8>>2]=v[b+8>>2]+(c<<1);gb=b+16|0;v[e+8>>2]=v[b+8>>2];b=v[Gd(e+16|0,e+8|0)>>2];f=x[e+28>>1];i=e+26|0;j=gb-32|0;gb=j;v[j+24>>2]=b;c=a;b=v[c>>2];s=j,t=Vb(c),v[s>>2]=t;d=b+(rp(j+24|0,j)<<1)|0;b:{c:{d:{if(!f){break d}b=v[wb(c)>>2];g=v[c+4>>2];if(f>>>0<=b-g>>1>>>0){b=f;k=g-d|0;h=k>>1;if(b>>>0>h>>>0){tp(c,f-h|0,i);b=h;if(!k){break d}}p=gb-16|0;gb=p;k=c;m=g;n=d;r=v[c+4>>2];h=(r-((f<<1)+d|0)|0)+d|0;q=mi(p,c,g-h>>1);if(g>>>0>h>>>0){o=v[q+4>>2];g=h;while(1){wb(k);So(o,g);o=o+2|0;v[q+4>>2]=o;g=g+2|0;if(m>>>0>g>>>0){continue}break}}$b(q);yr(n,h,r);gb=p+16|0;mv(d,b,i+((d>>>0<=i>>>0?i>>>0<y[c+4>>2]?f:0:0)<<1)|0);break d}b=wb(c);g=Fn(j,Uk(c,tc(c)+f|0),d-v[c>>2]>>1,b);v[22708]=0;U(312,g|0,f|0,i|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=c;Ep(c);f=g;k=v[f+4>>2];h=d;n=f+4|0;Ck(wb(c),v[c>>2],d,n);wb(c);i=f+8|0;m=i;d=v[c+4>>2];if((h|0)!=(d|0)){c=v[m>>2];while(1){So(c,h);c=v[m>>2]+2|0;v[m>>2]=c;h=h+2|0;if((d|0)!=(h|0)){continue}break}}xc(b,n);xc(b+4|0,i);xc(wb(b),dc(f));v[f>>2]=v[f+4>>2];_r(b,tc(b));d=k;Hh(g)}Gg(d);gb=j+32|0;break b}a=P()|0;O()|0;Hh(g);S(a|0);L()}if(tc(a)>>>0>l>>>0){Bf(a,l)}d=x[e+28>>1]}gb=e+32|0;return d&65535}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;f=v[a+52>>2];v[b+40>>2]=f;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;g=j>>>21&2040;j=u[g+46166>>1];i=u[g+46164>>1];k=u[g+46162>>1];p=u[g+46160>>1];h=0;m=1;f=1;g=0;while(1){v[(b+8|0)+(g<<2)>>2]=(((B(t[e+g|0],k)+B(t[e+(g|-2)|0],p)|0)+B(i,t[e+(g|2)|0])|0)+B(j,t[e+(g|4)|0])<<8)/16384;l=f&1;f=0;g=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;f=v[j>>2];i=v[a+60>>2];k=i;g=(b+32|0)+(h<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);l=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=nqa(k,r,f,f>>31);k=jb;l=nqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=v[a+68>>2];f=nqa(f,f>>31,h,h>>31);h=k+f|0;e=jb+e|0;e=f>>>0>h>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Jc(h,e,24);v[g+4>>2]=p;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[g>>2]=e-(h&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;g=n>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];f=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}g=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=f;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=g;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function Xt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}t[a|0]=0;break b}f=1;t[a|0]=1;t[e+15|0]=64;h=b,i=w[ac(b,e+15|0)|0],t[h|0]=i;break a}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=12;break b}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=13;break b}g=w[b|0];if(g>>>0<240){d=0;while(1){f=w[d+39104|0];m:{n:{if(c){if(f>>>0>=g>>>0){break n}break m}if((f|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=d;break b}f=0;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break b}o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;break b}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;break b}c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;break b}g=c&240;if(!g){t[a|0]=4;break b}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;break b}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;break b}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){t[b|0]=0;break r}if(w[b|0]){break a}}t[a|0]=8;break b}s:{if(c){t[e+14|0]=w[b|0]&15;t[e+13|0]=9;d=w[ac(e+14|0,e+13|0)|0];break s}d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8}f=1}gb=e+16|0;return f}function A3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);v[22708]=0;Fc(a+16|0,d);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[22708]=0;b=T(2482,a+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[22708]=0;Y(2494,b|0,83408,83434,a+224|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22708]=0;d=Q(2487,a+344|0,a+336|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22708]=0;R(76,c|0,b<<1);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[22708]=0;d=T(2489,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(qm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22708]=0;T(2491,a+344|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22708]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22708]=0;d=ga(2478)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[a>>2]=f;v[22708]=0;b=da(2479,b|0,d|0,a|0,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(c);vb(h);gb=a+352|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function N3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);v[22708]=0;Fc(a+16|0,d);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[22708]=0;b=T(21,a+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[22708]=0;Y(2474,b|0,83408,83434,a+224|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22708]=0;d=Q(2460,a+264|0,a+256|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22708]=0;R(76,c|0,b<<1);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[22708]=0;d=T(2462,a+264|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(rm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22708]=0;T(2464,a+264|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22708]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22708]=0;d=ga(2478)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[a>>2]=f;v[22708]=0;b=da(2479,b|0,d|0,a|0,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22708]=0;b=Q(2461,a+264|0,a+256|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(c);vb(h);gb=a+272|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;ud(b,2);d=e+16|0;Lk(d,2,a+1|0);f=e+32|0;Bc(f,d);v[22708]=0;Q(303,b+43|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;f=e+32|0;h=b,i=v[Fb(f,e+16|0)>>2],v[h+4>>2]=i;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=b,i=v[Fb(f,b)>>2],v[h+8>>2]=i;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>=2&d>>>0>y[b+4>>2]){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}f=e+16|0;Ai(f,a+16|0);d=e+32|0;g=v[f>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;Ai(f,a+20|0);g=v[e+16>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d+4|0]=g;t[d+5|0]=g>>>8;t[d+6|0]=g>>>16;t[d+7|0]=g>>>24;Ai(f,a+24|0);f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Ro(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;h=b,i=w[ac(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;d=a+32|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(w[a|0]==2){d=x[b>>1];v[b>>2]=d;break b}a=b;if(y[b>>2]>=65536){v[a>>2]=65535}d=v[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}v[b>>2]=a}gb=e+48|0;return}a=P()|0;O()|0;vb(e+32|0);S(a|0);L()}function eha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0;f=gb+-64|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}x=l-4|0;n=B(b,e);o=n-8|0;while(1){v[22708]=0;b=Q(191,c|0,l|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22708]=0;U(288,f+16|0,c|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}g=f+40|0;b=f+16|0;p=kc(g,b);xb(b);v[22708]=0;R(757,b|0,g|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;y=Rd(f+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}q=v[f+16>>2];if(e){r=q-4|0;g=0;while(1){v[22708]=0;b=T(746,p|0)|0;i=v[22708];v[22708]=0;h:{if((i|0)!=1){v[f+12>>2]=b;v[22708]=0;b=T(374,p|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}v[f+8>>2]=b;Yd(f+8|0,0,89);v[22708]=0;Q(318,f+40|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}i=g+m|0;if(o>>>0<i>>>0){break h}k=0;b=e+g<<2;if(r>>>0<b>>>0){break h}while(1){j=zb(w[b+y|0]);s=k&1;j=s?j>>>4|0:j&15;h=v[f+8>>2];v[f+8>>2]=t[(j&7)+36568|0]+h;h=u[(h<<1)+36576>>1];h=(((0-(j&1)&h>>2)+(h>>3)|0)+(j<<30>>31&h>>1)|0)+(h&j<<29>>31)|0;v[f+12>>2]=v[f+12>>2]+(j&8?0-h|0:h);Yd(f+8|0,0,88);Yd(f+12|0,-32768,32767);u[(i<<1)+a>>1]=v[f+12>>2];i=e+i|0;b=b+s|0;k=k+1|0;if((k|0)!=8){continue}if(i>>>0>o>>>0){break h}k=0;b=b+x|0;if(r>>>0>=b>>>0){continue}break}break h}break f}g=g+1|0;if((g|0)!=(e|0)){continue}break}}m=(q-l<<1)+m|0;zc(f+16|0);xb(f+40|0);continue}}xb(c);gb=f- -64|0;return}b=P()|0;O()|0;zc(f+16|0);break d}b=P()|0;O()|0}xb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}xb(c);S(b|0);L()}
function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Td(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=lg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=(h<<1)+p|0;b:{if((b|0)<=0){break b}while(1){Jd(v[i+8>>2],u[(e<<1)+h>>1]/4<<16>>16);Id(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Jd(b,u[h+(v[f+44>>2]<<1)>>1]/4<<16>>16);Id(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=ig(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Lb(o,-16777216,16776704);k=v[a+64>>2];g=Lb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=nqa(j,l,e,e>>31);j=jb;k=nqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=nqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb+-64|0;gb=d;c=x[a+480190>>1];t[d+48|0]=0;vR(b,c+1|0,d+48|0);if(x[a+480192>>1]){i=mc(d+48|0);c=a+484344|0;l=d,m=Vb(c),v[l+40>>2]=m;l=d,m=Zb(c),v[l+32>>2]=m;if(Gb(d+40|0,d+32|0)){while(1){a:{h=v[d+40>>2];if(!ii(h)){break a}c=x[a+480188>>1];v[22708]=0;t[d+8|0]=0;U(1130,i|0,c|0,d+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){b:{l=d,m=Vb(h),v[l+24>>2]=m;j=0;if(!v[h+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{c=v[d+24>>2];v[22708]=0;c=ce(c);e=v[22708];v[22708]=0;if((e|0)==1){break d}e:{if(!c){break e}c=w[v[d+24>>2]+1|0];t[d+23|0]=c;if(!w[v[d+24>>2]+1|0]){c=w[lc(i,f)|0];t[d+23|0]=c}if(c&255){u[d+8>>1]=0;f:{if(x[d+8>>1]>w[d+23|0]){break f}e=v[((w[v[d+24>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[vd(e+236|0,w[v[d+24>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}g=d+8|0;Ce(g,b,e);Uf(g,1)}l=lc(i,f),m=c,t[l|0]=m;break e}c=x[a+480192>>1];if(!c){break e}e=c;while(1){g=v[((c<<2)+a|0)+900380>>2];g:{if(!g){break g}g=x[vd(g+236|0,w[v[d+24>>2]]-1|0)>>1];if(g>>>0>x[a+480190>>1]){break g}k=d+8|0;Ce(k,b,g);Uf(k,1)}c=c-1|0;e=e-1|0;if(e&65535){continue}break}}$j(d+24|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[h+12>>2]){continue}break}break a}}a=P()|0;O()|0;gc(i);S(a|0);L()}c=d+40|0;VO(c);if(Gb(c,d+32|0)){continue}break}}c=x[a+480190>>1];h:{if(!c){f=0;break h}f=0;e=c;while(1){h=d+8|0;Ce(h,b,c);if(!Cb(h)){f=Md((B(c,104)+a|0)+484380|0)+f|0}c=c-1|0;e=e-1|0;if(e&65535){continue}break}}gc(i)}gb=d- -64|0;return f&65535}function h3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-384|0;gb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Ks(f+376|1,18726,v[c+4>>2]);v[f+332>>2]=f+336;a=xe();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Gf(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=Gf(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2458;i=ge(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22708]=0;a=ga(2478)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22708]=0;A[f+8>>3]=e;a=da(2497,f+332|0,a|0,f+376|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break e}break c}v[22708]=0;a=ga(2478)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22708]=0;a=da(2497,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Ee(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=Tg(g,h,c);v[f+68>>2]=2458;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=Cd(a<<3);if(!a){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+332>>2]}v[22708]=0;Fc(f+56|0,c);l=v[22708];v[22708]=0;h:{i:{if((l|0)!=1){v[22708]=0;ja(2506,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break i}Wb(f+56|0);v[22708]=0;a=la(2507,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(g);Hc(i);gb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function t3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-208|0;gb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Ks(f+200|1,18726,v[c+4>>2]);v[f+156>>2]=f+160;a=xe();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Gf(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=Gf(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2458;i=ge(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22708]=0;a=ga(2478)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22708]=0;A[f+8>>3]=e;a=da(2497,f+156|0,a|0,f+200|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break e}break c}v[22708]=0;a=ga(2478)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22708]=0;a=da(2497,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Ee(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=Tg(g,h,c);v[f+68>>2]=2458;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=Cd(a<<1);if(!a){v[22708]=0;X(2459);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+156>>2]}v[22708]=0;Fc(f+56|0,c);l=v[22708];v[22708]=0;h:{i:{if((l|0)!=1){v[22708]=0;ja(2498,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break i}Wb(f+56|0);v[22708]=0;a=la(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(g);Hc(i);gb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function wL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=gb-48|0;gb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;hc(c,v[a>>2]+24604|0,40);v[d+8>>2]=b;Xz(v[a>>2],c);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=gb-16|0;gb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}b=ba(8)|0;v[22708]=0;c=Q(70,g|0,8063)|0;a=v[22708];v[22708]=0;i:{if((a|0)!=1){rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break g}a=P()|0;O()|0;vb(c);break i}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}gb=g+16|0;break f}L()}t[e+8|0]=b;if(!Ny(d+8|0,v[f>>2]+24648|0)){break d}Wz(v[f>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;hc(b,v[a>>2]+24604|0,40);e=gb-48|0;gb=e;j:{if((c|0)==-1){It(b,v[Vq(e+8|0)+32>>2]);Lo(b,v[Vq(e+8|0)+36>>2]);break j}if((c|0)<=0){It(b,0);Lo(b,0);break j}c=B(c,1e3);It(b,c);Lo(b,c)}gb=e+48|0;if(v[v[a>>2]+24636>>2]==v[d+40>>2]&v[v[a>>2]+24640>>2]==v[d+44>>2]){break d}Xz(v[a>>2],d+8|0);break d;default:a=ba(8)|0;v[22708]=0;b=Q(70,d+8|0,7655)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b;case 0:break e}}h=a,i=oe(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[h+48>>2]=i}gb=d+48|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function jM(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=gb-16|0;gb=d;k=d,l=C(Wy(z[a+4216>>2])/C(xf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=Pp(C(z[Gm(d+12|0,d+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=oe(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))/C(20)));k=d,l=C(Wy(z[a+4220>>2])/C(xf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[Gm(d+12|0,d+8|0)>>2];k=d,l=C(Wy(z[a+4224>>2])/C(xf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(C(z[Gm(d+12|0,d+8|0)>>2]*C(6.2831854820251465))*C(.5));e=gb-16|0;gb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=$n(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=$n(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=$n(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=$n(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=$n(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=ay(b,e+8|0);b=$n(A[e+8>>3],c&1)}gb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Pp(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+51648>>2];gb=d+16|0}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Td(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=lg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=h+p|0;b:{if((b|0)<=0){break b}while(1){Jd(v[i+8>>2],t[e+h|0]<<6);Id(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Jd(b,t[h+v[f+44>>2]|0]<<6);Id(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=ig(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Lb(o,-16777216,16776704);k=v[a+64>>2];g=Lb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=nqa(j,l,e,e>>31);j=jb;k=nqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=nqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function cqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22708]=0;R(456,f|0,j|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[pc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22708]=0;W(457,f|0,1,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22708]=0;W(457,f|0,1,123)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(vs(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22708]=0;Q(458,f|0,g|0)|0;h=v[22708];v[22708]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(vs(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22708]=0;Q(458,f|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22708]=0;W(457,f|0,1,125)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if(k&l|a){break c}}return}a=ba(8)|0;v[22708]=0;T(185,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(186,a|0,27304,24);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;ca(a|0)}vb(f);S(e|0)}L()}function pH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-272|0;gb=g;i=v[b>>2];v[g+12>>2]=i;m=a?a:g+16|0;e=0;a:{b:{c:{d=a?d:256;if(!i|!d){break c}f=c>>>0>=d>>>0;j=f;if(!(f|c>>>0>32)){break b}while(1){j=j?d:c;c=c-j|0;i=0;n=gb-16|0;gb=n;d:{e:{f:{g:{f=m;if(f){if(j>>>0>=4){break g}h=j;break f}j=0;f=v[g+12>>2];h=v[f>>2];if(!h){break d}while(1){l=1;if(h>>>0>=128){i=-1;l=pl(n+12|0,h,0);if((l|0)==-1){break d}}h=v[f+4>>2];f=f+4|0;j=j+l|0;i=j;if(h){continue}break}break d}l=v[g+12>>2];h=j;while(1){k=v[l>>2];h:{if(k-1>>>0>=127){if(!k){t[f|0]=0;v[g+12>>2]=0;break e}i=-1;k=pl(f,k,0);if((k|0)==-1){break d}h=h-k|0;f=f+k|0;break h}t[f|0]=k;h=h-1|0;l=v[g+12>>2];f=f+1|0}l=l+4|0;v[g+12>>2]=l;if(h>>>0>3){continue}break}}if(h){l=v[g+12>>2];while(1){k=v[l>>2];i:{if(k-1>>>0>=127){if(!k){t[f|0]=0;v[g+12>>2]=0;break e}i=-1;k=pl(n+12|0,k,0);if((k|0)==-1){break d}if(h>>>0<k>>>0){break e}pl(f,v[l>>2],0);h=h-k|0;f=f+k|0;break i}t[f|0]=k;h=h-1|0;l=v[g+12>>2];f=f+1|0}l=l+4|0;v[g+12>>2]=l;if(h){continue}break}}i=j;break d}i=j-h|0}gb=n+16|0;if((i|0)==-1){d=0;i=v[g+12>>2];e=-1;break c}f=(g+16|0)==(m|0)?0:i;m=f+m|0;e=e+i|0;i=v[g+12>>2];d=d-f|0;if(!i|!d){break c}f=c>>>0>=d>>>0;j=f;if(f|c>>>0>32){continue}break}break b}if(!i){break a}}if(!d|!c){break a}j=e;while(1){j:{f=pl(m,v[i>>2],0);k:{if(f+1>>>0<=1){e=-1;if(f){break a}v[g+12>>2]=0;break k}i=v[g+12>>2]+4|0;v[g+12>>2]=i;j=f+j|0;d=d-f|0;if(d){break j}}e=j;break a}m=f+m|0;e=j;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[g+12>>2]}gb=g+272|0;return e|0}function n$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22708]=0;R(182,f|0,j|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[pc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22708]=0;W(183,f|0,1,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22708]=0;W(183,f|0,1,123)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(vs(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22708]=0;Q(184,f|0,g|0)|0;h=v[22708];v[22708]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(vs(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22708]=0;Q(184,f|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22708]=0;W(183,f|0,1,125)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if(k&l|a){break c}}return}a=ba(8)|0;v[22708]=0;T(185,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(186,a|0,27304,24);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;ca(a|0)}vb(f);S(e|0)}L()}function lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;j=v[a+48>>2];v[b+36>>2]=j;k=v[a+52>>2];v[b+40>>2]=k;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;g=0;k=1;f=0;while(1){i=f<<1;h=u[i+e>>1];v[(b+8|0)+(f<<2)>>2]=h+((B(j,u[e+(i|4)>>1]-h|0)|0)/16384|0);h=k&1;k=0;f=1;if(h){continue}break}while(1){k=(b+8|0)+(g<<2)|0;f=v[k>>2];j=v[a+60>>2];i=j;h=(b+32|0)+(g<<3)|0;p=v[h>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=nqa(i,r,f,f>>31);i=jb;o=nqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+i|0;e=f>>>0<o>>>0?e+1|0:e;i=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=i+f|0;e=jb+e|0;e=f>>>0>g>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=Jc(g,e,24);v[h+4>>2]=p;g=v[a+72>>2];v[k>>2]=(e|0)/256;v[h>>2]=e-(g&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];k=v[b+40>>2];j=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;gb=b+48|0}function iA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=oA(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Ob(c,0,1);Ob(c,7,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,11,1);Ob(c,12,1);Ob(c,13,1);Ob(c,14,1);Ob(c,15,1);Ob(c,16,1);Ob(c,17,1);Ob(c,18,1);Ob(c,19,1);Ob(c,20,1);Ob(c,21,1);Ob(c,22,1);Ob(c,23,1);Ob(c,24,1);Ob(c,25,1);Ob(c,26,1);Ob(c,27,1);Ob(c,28,1);Ob(c,29,1);Ob(c,30,1);Ob(c,31,1);Ob(c,32,1);Ob(c,33,1);Ob(c,34,1);Ob(c,35,1);Ob(c,36,1);Ob(c,37,1);Ob(c,38,1);Ob(c,39,1);Ob(c,40,1);Ob(c,41,1);Ob(c,42,1);Ob(c,43,1);Ob(c,44,1);Ob(c,45,1);Ob(c,46,1);Ob(c,47,1);Ob(c,48,1);Ob(c,103,1);Ob(c,50,1);Ob(c,87,1);Ob(c,88,1);Ob(c,100,1);Ob(c,102,1);Ob(c,104,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Ob(c,0,1);Ob(c,4,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,17,1);Ob(c,40,1);Ob(c,51,1);Ob(c,52,1);Ob(c,53,1);Ob(c,54,1);Ob(c,55,1);Ob(c,56,1);Ob(c,57,1);Ob(c,58,1);Ob(c,59,1);Ob(c,60,1);Ob(c,61,1);Ob(c,62,1);Ob(c,63,1);Ob(c,64,1);Ob(c,65,1);Ob(c,66,1);Ob(c,67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Ob(c,g,1);Ob(c,e,1);Ob(c,d,1);Ob(c,A,1);Ob(c,z,1);Ob(c,y,1);Ob(c,x,1);Ob(c,w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Ob(c,o,1);Ob(c,n,1);Ob(c,m,1);Ob(c,l,1);g=k;f=j;e=i;d=h}Ob(c,g,1)}Ob(c,f,1);Ob(c,e,1);Ob(c,d,1)}}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];j=v[a+8>>2];d:{if((f|0)<=1&j>>>0<=805306368|(f|0)<1){if((f|0)>=-2&j>>>0>=3489660928|(f|0)>-2){break c}if(j>>>0>2147483647&(f|0)>=-2|(f|0)>-2){break d}break b}if(j>>>0>2147483648&(f|0)>=1|(f|0)>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];g=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=(i>>>16&65520)+m|0;f=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(g,-16777216,16776704);b=nqa(l,l>>31,b,b>>31);l=jb;n=b;i=(((((((B(j,s)+B(f,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;f=nqa(o,o>>31,b,b>>31);e=n+f|0;b=jb+l|0;b=e>>>0<f>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=nqa(e,e>>31,g,g>>31);g=n+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,r);v[c+4>>2]=v[c+4>>2]+B(e,q);b=b-(g&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;k=v[a+52>>2];v[b+40>>2]=k;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){j=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+r|0;g=0;l=1;k=1;f=0;while(1){i=t[e+f|0];v[(b+8|0)+(f<<2)>>2]=((B(j,t[e+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;f=1;if(i){continue}break}while(1){k=(b+8|0)+(g<<2)|0;j=v[k>>2];h=v[a+60>>2];o=h;i=(b+32|0)+(g<<3)|0;q=v[i>>2];e=Lb(q,-16777216,16776704);g=v[a+64>>2];f=Lb(v[i+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=nqa(o,p,h,h>>31);o=jb;p=h;h=nqa(g,g>>31,e,e>>31);g=p+h|0;e=jb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;g=v[a+68>>2];g=nqa(g,g>>31,f,f>>31);f=h+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[i+4>>2]=q;f=v[a+72>>2];v[k>>2]=(e|0)/256;v[i>>2]=e-(f&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];k=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=k;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=i;v[a+4>>2]=e;gb=b+48|0}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<1){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if(i>>>0>2147483647&(f|0)>=-2|(f|0)>-2){break d}break b}if(i>>>0>2147483648&(f|0)>=1|(f|0)>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=e+o|0;f=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(g,-16777216,16776704);b=nqa(l,l>>31,b,b>>31);l=jb;J=b;b=v[a+68>>2];n=nqa(b,b>>31,g,g>>31);g=J+n|0;b=jb+l|0;b=g>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(f,j)<<8)/32768<<8;f=nqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];f=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-112|0;gb=c;d=c+88|0;Tm(d,b,1413829443);v[22708]=0;b=T(275,d|0)|0;d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22708]=0;U(1431,c- -64|0,a+140|0,1413894985);a=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22708]=0;a=Q(1436,c- -64|0,10951)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[22708]=0;a=T(467,c- -64|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;W(413,c- -64|0,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;d=Q(69,c+16|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;_(1437,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}v[22708]=0;U(1438,c+32|0,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break j}a=c+32|0;Eb(b,a);vb(a);vb(c);vb(d);v[22708]=0;U(13,a|0,2,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}v[22708]=0;a=T(972,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}vb(c+32|0);vb(b);b=a-1>>>0<19398657?1252:28591}xb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(c)}vb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}vb(b);break d}a=P()|0;O()|0}xb(c- -64|0);break b}v[22708]=0;a=Q(191,c+88|0,2)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22708]=0;b=T(287,c+88|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}xb(c+88|0);S(a|0);L()}xb(c+88|0);gb=c+112|0;return b|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=h;i=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=i;if(d){while(1){l=1;i=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=k>>>21&2040;k=u[b+46166>>1];j=u[b+46164>>1];m=u[b+46162>>1];n=u[b+46160>>1];f=0;b=1;g=0;while(1){h=g<<1;v[(e+8|0)+(g<<2)>>2]=(((B(u[h+i>>1],m)+B(u[i+(h|-4)>>1],n)|0)+B(u[i+(h|4)>>1],j)|0)+B(k,u[i+(h|8)>>1])|0)/16384;h=b;b=0;g=1;if(h){continue}break}while(1){k=(e+8|0)+(f<<2)|0;i=v[k>>2];j=v[a+60>>2];m=j;h=(e+32|0)+(f<<3)|0;n=v[h>>2];b=Lb(n,-16777216,16776704);f=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);j=j>>31;i=i<<8;j=nqa(m,j,i,i>>31);m=jb;r=j;j=nqa(f,f>>31,b,b>>31);f=r+j|0;b=jb+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=j+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[h+4>>2]=n;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&i);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];h=v[e+28>>2];continue}break}k=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=k;v[a+4>>2]=h;gb=e+48|0}function B3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-384|0;gb=a;v[a+368>>2]=c;v[a+376>>2]=b;ux(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=v[a+232>>2];h=v[a+236>>2];while(1){d:{v[22708]=0;g=Q(2487,a+376|0,a+368|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+196>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+196>>2]=g+c}v[22708]=0;g=T(2489,a+376|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(tx(g,a+23|0,a+22|0,c,a+196|0,h,b,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22708]=0;T(2491,a+376|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22708]=0;Y(2477,a|0,c|0,v[a+196>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;hf(a+216|0,a+32|0,v[a+28>>2],e);v[22708]=0;b=Q(2488,a+376|0,a+368|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];vb(d);vb(a+216|0);gb=a+384|0;break a}}b=P()|0;O()|0;vb(d);vb(a+216|0);S(b|0);L()}return b|0}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;xx(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=t[a+238|0];h=t[a+239|0];while(1){d:{v[22708]=0;g=Q(2460,a+280|0,a+272|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+204>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+204>>2]=g+c}v[22708]=0;g=T(2462,a+280|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(wx(g,a+23|0,a+22|0,c,a+204|0,h,b,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22708]=0;T(2464,a+280|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22708]=0;Y(2477,a|0,c|0,v[a+204>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;hf(a+224|0,a+32|0,v[a+28>>2],e);v[22708]=0;b=Q(2461,a+280|0,a+272|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];vb(d);vb(a+224|0);gb=a+288|0;break a}}b=P()|0;O()|0;vb(d);vb(a+224|0);S(b|0);L()}return b|0}function TU(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-16|0;gb=f;a:{if((b|0)==(c|0)){break a}v[f+12>>2]=-1953789045;UB(b,c,f+12|0);c=c-b>>2;v[f+8>>2]=c;e=1;j=Nb(a);h=j+1|0;v[f+4>>2]=h;k=v[Mc(f+4|0,f+8|0)>>2];g=v[((v[f+8>>2]<<2)+b|0)-4>>2];i=c;d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}l=i-d>>>1|0;c=(l<<2)+b|0;i=B(av(g^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=i+v[c>>2];m=d+l|0;c=(m<<2)+b|0;d=c;g=v[c>>2];c=j+i|0;v[d>>2]=g+c;v[b>>2]=c;c=v[f+8>>2];if(j){while(1){g=e-1|0;d=((e+l>>>0)%(c>>>0)<<2)+b|0;n=(e>>>0)%(c>>>0)|0;o=(n<<2)+b|0;i=B(av(v[((g>>>0)%(c>>>0)<<2)+b>>2]^(v[d>>2]^v[o>>2])),1664525);v[d>>2]=i+v[d>>2];d=Mb(a,g);c=v[f+8>>2];g=((e+m>>>0)%(c>>>0)<<2)+b|0;d=v[d>>2]+(i+n|0)|0;v[g>>2]=d+v[g>>2];v[o>>2]=d;e=e+1|0;if(j>>>0>=e>>>0){continue}break}}if(h>>>0<k>>>0){while(1){a=((h+l>>>0)%(c>>>0)<<2)+b|0;d=(h>>>0)%(c>>>0)|0;j=(d<<2)+b|0;e=B(av(v[((h-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[j>>2])),1664525);v[a>>2]=e+v[a>>2];c=v[f+8>>2];a=((h+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=e+d|0;v[i>>2]=g+a;v[j>>2]=a;h=h+1|0;if((k|0)!=(h|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}e=k;while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;j=(d<<2)+b|0;h=B(av(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[j>>2]|0)|0),1566083941);v[a>>2]=h^v[a>>2];c=v[f+8>>2];a=((e+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=h-d|0;v[i>>2]=g^a;v[j>>2]=a;e=e+1|0;if(e>>>0<c+k>>>0){continue}break}}gb=f+16|0}function aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;b=v[a+48>>2];v[e+36>>2]=b;g=v[a+52>>2];v[e+40>>2]=g;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];j=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=j;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;if(d){while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+o|0;b=k>>>21&2040;k=u[b+46166>>1];i=u[b+46164>>1];m=u[b+46162>>1];n=u[b+46160>>1];g=0;l=1;b=1;f=0;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+h|0],m)+B(t[h+(f|-2)|0],n)|0)+B(t[h+(f|2)|0],i)|0)+B(k,t[h+(f|4)|0])<<8)/16384;j=b;b=0;f=1;if(j){continue}break}while(1){k=(e+8|0)+(g<<2)|0;h=v[k>>2];i=v[a+60>>2];m=i;j=(e+32|0)+(g<<3)|0;n=v[j>>2];b=Lb(n,-16777216,16776704);g=v[a+64>>2];f=Lb(v[j+4>>2],-16777216,16776704);i=i>>31;h=h<<8;i=nqa(m,i,h,h>>31);m=jb;r=i;i=nqa(g,g>>31,b,b>>31);g=r+i|0;b=jb+m|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=v[a+68>>2];g=nqa(g,g>>31,f,f>>31);f=i+g|0;b=jb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Jc(f,b,24);v[j+4>>2]=n;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[j>>2]=b-(f&h);g=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];j=v[e+28>>2];continue}break}k=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];g=v[e+40>>2];f=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=g;v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=k;v[a+4>>2]=j;gb=e+48|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Td(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=lg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[h+8>>2],u[(e<<1)+g>>1]/4<<16>>16);Id(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Jd(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Id(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=ig(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=nqa(j,p,e,e>>31);j=jb;l=nqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=nqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function Moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-32|0;gb=f;t[f+24|0]=44;v[f+16>>2]=-1;v[f+20>>2]=0;v[f+8>>2]=1042;v[f+12>>2]=2;n=a;o=b;c=gb+-64|0;gb=c;p=c;j=f+8|0;b=v[j>>2]&2?16:10;g=gb-32|0;gb=g;d=Ge(g+16|0,1,0);a:{b:{c:{while(1){i=g+8|0;k=Jb(d);l=Jb(d)+Ab(d)|0;h=x[o>>1];e=b;d:{if((e|0)!=10){a=l;while(1){e:{if((a|0)==(k|0)){a=k;break e}m=h&65535;h=(m|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(m-B(e,h)|0)+1991|0];if(h&65535){continue}}break}f:{if(!(h&65535)){e=l-a|0;if(e){break f}}v[i+4>>2]=61;v[i>>2]=l;break d}a=yh(k,a,e);v[i+4>>2]=0;v[i>>2]=a+e;break d}wA(i,k,l,h)}if(!v[g+12>>2]){break c}a=Ab(d);v[22708]=0;v[g+4>>2]=a;e=yf(g+4|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;U(75,d|0,e|0,0);a=v[22708];v[22708]=0;if((a|0)!=1){continue}}break}break b}b=v[g+8>>2];a=Jb(d);v[22708]=0;R(76,d|0,b-a|0);a=v[22708];v[22708]=0;g:{if((a|0)!=1){v[22708]=0;R(86,p|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}break b}break b}vb(d);gb=g+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}a=c+16|0;Ll(a,c,j);v[22708]=0;U(93,c+32|0,a|0,j|0);a=v[22708];v[22708]=0;h:{i:{j:{k:{l:{if((a|0)!=1){v[22708]=0;U(94,c+48|0,c+32|0,j|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;R(85,n|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function Tz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=gb-16|0;gb=j;k=j;a:{if(!Kj(c)){h=b;i=v[c+704>>2];g=gb-16|0;gb=g;v[g+12>>2]=d;f=0;b:{if(!d){break b}if(v[h+480180>>2]&20){e=h+1074312|0;Db(g,e,73);d=Cb(g)?d&65535:d;if(w[h+480208|0]&16){Db(g,e,73);e=Cb(g)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;f=v[((d>>>0)%768<<2)+40384>>2]<<6>>>e|0;break b}if(!d){v[g+12>>2]=1;d=1}f=229079296/(d>>>0)|0;break b}f=227001280/(d>>>0)|0;if(Zl(h)){break b}f=(d+i<<4)-133808|0;if(v[h+480180>>2]==64){break b}d=v[h+480180>>2];qc(g+12|0,16777215);if(d&17408){f=Qc(qqa(nqa(i?i:8363,0,3506176,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}if(rk(h)){f=e>>31;d=v[g+12>>2];h=d>>>24|0;i=d<<8;e=i+e|0;d=h+f|0;d=e>>>0<i>>>0?d+1|0:d;f=(d&15)<<28|e>>>4;break b}if(w[h+480208|0]&16){f=Qc(qqa(nqa(i?i:8363,0,7012352,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}f=Qc(qqa(-1485242368,13,(v[g+12>>2]<<8)+e|0,0),jb)}gb=g+16|0;e=f;break a}e=v[c+700>>2]}v[k+12>>2]=e;d=v[c+656>>2];c=u[c+774>>1];c:{if(!c){break c}c=d?B(t[d+33|0],c):c;if(!c){break c}e=Ah(Dk(+(c|0)/393216)*+(e>>>0));v[j+12>>2]=e}d:{if(!d){break d}c=v[d+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];f=nqa(f,f>>31,e,e>>31);e=d+f|0;d=jb+(d>>31)|0;l=j,m=Ac(oqa(e,e>>>0<f>>>0?d+1|0:d,c,c>>31),jb),v[l+12>>2]=m}qc(j+12|0,2147483647);c=j;l=c,m=oqa(0,v[c+12>>2],v[b+24620>>2]<<4,0),v[l>>2]=m;v[c+4>>2]=jb;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;v[a+8>>2]=v[c+12>>2];gb=c+16|0}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=c;d=v[a+4>>2];v[22708]=0;R(866,d|0,b|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+56;$b(a);gb=c+16|0;break a}b=P()|0;O()|0;$b(a);S(b|0);L()}return}l=gb-32|0;gb=l;j=a;e=wb(a);f=l+8|0;g=a;d=cr(a)+1|0;h=gb-16|0;gb=h;v[h+12>>2]=d;i=gb-16|0;gb=i;v[i+12>>2]=76695844;v[22708]=0;v[i+8>>2]=2147483647;k=Fb(i+12|0,i+8|0);c=v[22708];v[22708]=0;b:{if((c|0)!=1){gb=i+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=IU(g);if(d>>>0<c>>>1>>>0){v[h+8>>2]=d<<1;c=v[Mc(h+8|0,h+12|0)>>2]}gb=h+16|0;break c}Sc();L()}d=cr(a);a=0;g=gb-16|0;gb=g;v[g+12>>2]=0;jf(f+12|0,e);if(c){a=c;if(a>>>0>=76695845){rd(8445);L()}a=Nc(B(a,56),4)}v[f>>2]=a;d=B(d,56)+a|0;v[f+8>>2]=d;v[f+4>>2]=d;m=dc(f),n=B(c,56)+a|0,v[m>>2]=n;gb=g+16|0;a=f;c=v[a+8>>2];v[22708]=0;R(866,c|0,b|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){v[a+8>>2]=v[a+8>>2]+56;b=a;f=a+4|0;k=f;c=v[j+4>>2];g=v[j>>2];if((c|0)!=(g|0)){d=v[k>>2];while(1){e=d-56|0;c=c-56|0;Yu(e,c);Yu(e+12|0,c+12|0);TB(e+24|0,c+24|0);u[e+52>>1]=x[c+52>>1];d=v[c+48>>2];v[e+44>>2]=v[c+44>>2];v[e+48>>2]=d;d=v[c+40>>2];v[e+36>>2]=v[c+36>>2];v[e+40>>2]=d;d=v[k>>2]-56|0;v[k>>2]=d;if((c|0)!=(g|0)){continue}break}}wc(j,f);wc(j+4|0,b+8|0);wc(wb(j),dc(b));v[b>>2]=v[b+4>>2];HU(a);gb=l+32|0;break d}b=P()|0;O()|0;HU(a);S(b|0);L()}}function NZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;vc(c);a:{if(!Pb(c,3)){break a}while(1){e=g+24|0;Ur(e,c);f=qd(e);i=Ve(e);if(y[a+12>>2]<=w[e|0]){break a}h=Yc(a,w[e|0],b);e=w[f|0];b:{if(e>>>0<=126){if(!(e|w[i|0])){t[h|0]=254;break b}t[h|0]=e+1;if(w[i|0]==255){break b}t[h+2|0]=1;t[h+4|0]=w[i|0];break b}c:{switch(e-127|0){case 1:t[h+1|0]=w[i|0]+1;break b;case 0:break b;default:break c}}d=t[i|0];t[g+23|0]=d;i=0;e=e&127;if(e>>>0<=23){i=w[e+28432|0]}e=g;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=w[f|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((d|0)>-1){break g}f=0-d&15;break f}t[g+16|0]=64;d=w[ac(g+23|0,g+16|0)|0];if(w[h+2|0]>1){break e}t[h+4|0]=d;t[h+2|0]=1;break b}f=3;if((d|0)>-1){break d}f=0-d&127;break f}if(!d){break b}f=0-d|-16;if((d|0)<=-1){break f}f=d<<4|15;break f}if(!d){break b}e=(d|0)>-1;if(!e){d=0-d&15;t[g+23|0]=d;j=w[f|0]}f=e?3:2;d=((j|0)==22?-32:-16)|d;t[g+23|0]=d;break d}f=d&15|-48;break f}f=d&15|-64;break f}f=164;if((d|0)==100){break f}v[g+16>>2]=d- -64;v[g+12>>2]=0;v[g+8>>2]=128;d=v[ej(g+16|0,g+12|0,g+8|0)>>2];if(!w[h+3|0]){break e}p:{switch(w[h+2|0]){case 0:case 2:break p;default:break b}}t[h+2|0]=2;t[h+4|0]=(d&254)>>>1;break b}f=d<<4}d=f;t[e+23|0]=d}f=i;if(!i){break b}}t[h+5|0]=d;t[h+3|0]=f}if(Pb(c,3)){continue}break}}gb=g+32|0}function Tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=ic(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=vd(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=vd(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}iC(a+484|0,b+48|0,0);iC(a+590|0,b+68|0,0);iC(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[ac(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Pc(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Pc(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;hm(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;gm(b,w[a|0]&127,w[a|0]>>>7|0);gb=e+16|0}function kO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=gb-16|0;gb=c;d=B(b,872)+a|0;a:{if(v[d+1075080>>2]&134218752){break a}if(!sk(d+1074992|0)){break a}h=v[(B(b,872)+a|0)+1075648>>2];if(w[h+15|0]&2){break a}d=Lm(a,b,2,1);if((d-1&255)>>>0>249){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,872)+a|0;d=w[e+1075780|0];b:{if(w[e+1075782|0]==1){t[c+8|0]=64;f=w[ac(e+1075784|0,c+8|0)|0];break b}f=255;if(w[e+1075783|0]!=13){break b}t[c+8|0]=64;f=w[ac((B(b,872)+a|0)+1075785|0,c+8|0)|0]}e=c+8|0;j=a+1074312|0;Db(e,j,2);if(Cb(e)){if(d){e=a;f=b;if(ve(d)){d=w[ic(h+108|0,d-1|0)|0]}Mm(e,f,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((f|0)==255){break a}kb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=w[h+35|0]?k<<2:v[(B(b,872)+a|0)+1075680>>2];i=u[(B(b,872)+a|0)+1075768>>1];l=c+8|0;Db(l,j,28);m=c,n=e+(Cb(l)?i<<2:i)|0,v[m+4>>2]=n;Yd(c+4|0,0,256);e=d;i=b;if(ve(d)){e=w[ic(h+108|0,d-1|0)|0]}Mm(a,i,e&255,x[c+4>>1])}e=w[h+35|0];a=c+8|0;Db(a,j,101);i=(f|0)!=255;if(Cb(a)){a=(d|0)!=0}else{a=ve(d)}if(!(a?0:i)&(!a|(e|0)!=1)){break a}c:{switch(w[h+36|0]){case 1:if((f|0)!=255){FM(g,f<<1);break a}FM(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;n=g,o=7,p=w[ac(c+8|0,c+4|0)|0],q=b,m=v[v[g>>2]+76>>2],kb[m](n|0,o|0,p|0,q|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;q=g,p=7,o=w[Fb(c+8|0,c+4|0)|0],n=b,m=v[v[g>>2]+76>>2],kb[m](q|0,p|0,o|0,n|0)}gb=c+16|0}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Td(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=lg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[h+8>>2],t[e+g|0]<<6);Id(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Jd(b,t[g+v[f+44>>2]|0]<<6);Id(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=ig(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=nqa(j,p,e,e>>31);j=jb;l=nqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=nqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function uJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{b:{c:{g=a+8|0;d:{if(vl(g)){f=vl(g);break d}f=gq(g)}if(!((f|0)>(b|0)&(b|0)>=0)){c=ba(8)|0;v[22708]=0;b=Q(70,i|0,3092)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(c,b);v[22708]=0;U(186,c|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}if(c>>>0>=120){c=ba(8)|0;v[22708]=0;b=Q(70,i|0,8608)|0;a=v[22708];v[22708]=0;if((a|0)!=1){rc(c,b);v[22708]=0;U(186,c|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}a=P()|0;O()|0;ca(c|0);break b}h=a+32|0;a=sA(v[h>>2],65535);j=(a|0)==65535?255:a;u[i>>1]=j;f=v[h>>2]+B(j,872)|0;g=f+1074992|0;$m(g,7,v[h>>2],65535,1024);a=c+1|0;t[f+1075794|0]=a;t[f+1075791|0]=a;u[f+1075778>>1]=0;Nm(g);Eo(v[h>>2],g,b+1|0,0,1,1);v[f+1075688>>2]=65536;ru(v[h>>2],g,a,0,1,1,65535);m=f+1075684|0,n=Qo(CA(e*128,-128,128)+128),v[m>>2]=n;m=f+1075680|0,n=Qo(CA(d*256,0,256)),v[m>>2]=n;a=v[h>>2]+1074478|0;k=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;l=f;g=i;c=g;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((l|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[g>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=_q(k,b);u[v[h>>2]+480212>>1]=a;gb=i+16|0;return j|0}a=P()|0;O()|0;ca(c|0)}S(a|0)}L()}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;n=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=u[e-4>>1];p=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Lb(m,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];q=nqa(e,e>>31,f,f>>31);e=I+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=nqa(G,H,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function iJ(a){var b=0,c=0,d=0,e=0;he(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){he(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}he(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){he(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){he(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}he(d,b)}he(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;he(a,v[b+8>>2]);he(a,v[b+28>>2]);he(a,v[b+32>>2]);he(a,v[b+2084>>2]);b=v[b+2088>>2];he(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}he(d,b)}he(a,v[a+260>>2]);he(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){he(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){he(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}he(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;he(a,v[d+800>>2]);he(a,v[d+928>>2]);he(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;he(a,v[b+1068>>2]);he(a,v[b+1076>>2]);he(a,v[b+1084>>2]);he(a,v[b+1092>>2]);he(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function pM(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=gb-16|0;gb=e;c=xf(v[a+16>>2]);o=a,r=oe(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))/C(20))),z[o+4232>>2]=r;f=C(C(c>>>0)/C(1e3));o=a,r=oe(C(10),C(C(-1)/C(f*C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))))),z[o+4236>>2]=r;o=a,r=oe(C(10),C(C(-1)/C(f*C(C(z[a+4216>>2]*C(2950))+C(50))))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(oe(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))/C(20)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!(c>>>0>=8388608&(c|0)>-1)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(C(d*C(67108864))/C(.6931471824645996))+C(67108864);o=a,r=C(z[Gm(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(f*C(z[a+4228>>2]*C(4)))+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;gb=e+16|0}function cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;d=b+1298264|0;if(!Dd(d)){e=i;f=gb-16|0;gb=f;c=tf(12);v[22708]=0;h=T(1646,c|0)|0;g=v[22708];v[22708]=0;a:{if((g|0)!=1){c=gb-16|0;gb=c;v[c+12>>2]=h;wq(f+8|0,c+12|0);gb=c+16|0;gb=f+16|0;c=v[f+8>>2];break a}a=P()|0;O()|0;Yb(c);S(a|0);L()}v[e+8>>2]=c;e=i+8|0;YO(d,be(e));ju(e)}e=v[d>>2];f=0;c=gb-48|0;gb=c;d=c+16|0;TO(d,a);v[22708]=0;U(9,c+32|0,0,d|0);d=v[22708];v[22708]=0;b:{c:{d:{e:{f:{if((d|0)!=1){vb(c+16|0);k=c,l=Vb(e),v[k+8>>2]=l;k=c,l=Zb(e),v[k>>2]=l;g:{if(Gb(c+8|0,c)){e=0;while(1){h=0;d=v[c+8>>2];if(v[v[d>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){h=v[v[d>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}g=v[d>>2];v[22708]=0;R(1647,c+16|0,g+8|0);g=v[22708];v[22708]=0;if((g|0)==1){break g}v[22708]=0;g=OS(c+16|0,c+32|0);j=v[22708];v[22708]=0;h:{i:{if((j|0)!=1){vb(c+16|0);g=!g;if(!(g&h)){break i}f=v[d>>2];e=3;break h}e=P()|0;O()|0;vb(c+16|0);break d}if((e|0)<2&h){f=v[d>>2];e=2;break h}h=v[d>>2];d=g&(e|0)<1;f=d?h:f;e=d?1:e}d=c+8|0;Qe(d);if(Gb(d,c)){continue}break}break f}e=0;break e}e=P()|0;O()|0;break d}e=P()|0;O()|0;vb(c+16|0);break c}e=0;if(!f){break e}d=v[f+4>>2];if(!d){break e}v[22708]=0;a=W(d|0,f|0,b|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){e=(a|0)!=0;break e}e=P()|0;O()|0;break d}vb(c+32|0);gb=c+48|0;break b}vb(c+32|0)}S(e|0);L()}gb=i+16|0;return e|0}function e1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!v[i>>2]){break a}i=i+4|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}m=1;while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];n=wi(l+8|0,l+12|0);v[22708]=0;j=pH(f,e,i-c>>2,g-f|0,b);o=v[22708];v[22708]=0;d:{if((o|0)!=1){gf(n);gb=l+16|0;break d}a=P()|0;O()|0;gf(n);S(a|0);L()}e:{f:{g:{h:{i:{j:{switch(j+1|0){case 0:v[h>>2]=f;k:{if(v[e>>2]==(c|0)){break k}while(1){b=mx(f,v[c>>2],k+8|0,v[a+8>>2]);if((b|0)==-1){break k}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break i;case 1:break b;default:break j}}f=j+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break g}if((d|0)==(i|0)){c=v[e>>2];i=d;break e}j=mx(k+4|0,0,b,v[a+8>>2]);if((j|0)!=-1){break h}}m=2;break b}f=v[h>>2];if(j>>>0>g-f>>>0){break b}if(!j){break f}c=w[k+4|0];v[h>>2]=f+1;t[f|0]=c;i=k+4|0;c=j-1|0;if(!c){break f}while(1){j=w[i+1|0];f=v[h>>2];v[h>>2]=f+1;t[f|0]=j;i=i+1|0;c=c-1|0;if(c){continue}break}break f}c=v[e>>2];break c}c=v[e>>2]+4|0;v[e>>2]=c;f=c;i=d;l:{if((d|0)==(f|0)){break l}while(1){i=f;if(!v[f>>2]){break l}f=f+4|0;if((f|0)!=(d|0)){continue}break}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}m=(c|0)!=(d|0)}gb=k+16|0;return m|0}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;n=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=t[e-2|0];p=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Lb(m,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];q=nqa(e,e>>31,f,f>>31);e=J+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=nqa(H,I,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=nqa(k,r,f,f>>31);k=jb;o=nqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=nqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;ux(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22708]=0;g=Q(2487,a+360|0,a+352|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[22708]=0;g=T(2489,a+360|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(tx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2491,a+360|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=C(ya(2473,c|0,v[a+180>>2],e|0));b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}z[f>>2]=j;hf(a+200|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+360|0,a+352|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;j=fg(a,c);se(g+8|0,v[a+28>>2]);d=v[g+20>>2];v[g+24>>2]=v[g+16>>2];v[g+28>>2]=d;a:{if(!j){if(nd(a,5)){break a}}d=gb-144|0;gb=d;h=Hm(d+40|0,v[a+28>>2]);v[22708]=0;f=Q(620,d+24|0,49650)|0;e=v[22708];v[22708]=0;b:{c:{d:{e:{if((e|0)!=1){v[22708]=0;v[d+16>>2]=19923026;v[d+20>>2]=0;U(621,h|0,f|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}Hb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f);break c}k=d,l=Te(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[22708]=0;f=Q(620,d+24|0,7375)|0;e=v[22708];v[22708]=0;f:{if((e|0)!=1){v[22708]=0;e=W(1094,h|0,d+14|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}Hb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}yg(d+16|0,4e3);g:{if(x[d+16>>1]<=Te(b)>>>0){break g}v[22708]=0;R(330,b|0,x[d+16>>1]);e=v[22708];v[22708]=0;if((e|0)!=1){break g}e=P()|0;O()|0;break c}e=0;u[d+12>>1]=0;if(!x[d+16>>1]){break b}h:{while(1){i:{f=_b(b,e&65535);v[22708]=0;R(1495,d+24|0,d+12|0);i=v[22708];v[22708]=0;if((i|0)==1){break i}v[22708]=0;da(1479,h|0,f|0,d+24|0,1496)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}Hb(d+24|0);e=e+1|0;u[d+12>>1]=e;if(x[d+16>>1]>(e&65535)>>>0){continue}break b}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(d+24|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f)}gh(h);S(e|0);L()}gh(h);gb=d+144|0}Zf(a,j,c,g+24|0);gb=g+32|0}function T3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;xx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2460,a+264|0,a+256|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2462,a+264|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(wx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2464,a+264|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=C(ya(2473,c|0,v[a+188>>2],e|0));b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}z[f>>2]=j;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+264|0,a+256|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+q|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=nqa(k,r,f,f>>31);k=jb;o=nqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=nqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function QH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-96|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=v[b>>2];j:{if(!b){Tb(a,6892);break j}if(!(b&65535)){d=gb-16|0;gb=d;e=Tb(d,1508);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22708]=0;v[c+24>>2]=b>>>24;R(134,c- -64|0,c+24|0);d=v[22708];v[22708]=0;k:{l:{m:{n:{if((d|0)!=1){v[22708]=0;v[c+8>>2]=b>>>16&255;R(135,c+48|0,c+8|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}v[22708]=0;Y(136,a|0,c+80|0,c- -64|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);Hb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=gb-16|0;gb=d;e=Tb(d,1232);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22708]=0;v[c+44>>2]=b>>>24;R(134,c- -64|0,c+44|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}v[22708]=0;v[c+40>>2]=b>>>16&255;R(135,c+48|0,c+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}v[22708]=0;v[c+20>>2]=b>>>8&255;R(135,c+24|0,c+20|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;v[c+4>>2]=b&255;R(135,c+8|0,c+4|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;ka(137,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);Hb(c+80|0)}gb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}Hb(c+80|0);S(b|0);L()}function C3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;ux(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22708]=0;g=Q(2487,a+360|0,a+352|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[22708]=0;g=T(2489,a+360|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(tx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2491,a+360|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=+oa(2476,c|0,v[a+180>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}A[f>>3]=j;hf(a+200|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+360|0,a+352|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function R3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;xx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2460,a+264|0,a+256|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2462,a+264|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(wx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2464,a+264|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=+oa(2476,c|0,v[a+188>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}A[f>>3]=j;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+264|0,a+256|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;p=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;j=v[a+48>>2];v[e+36>>2]=j;k=v[a+52>>2];v[e+40>>2]=k;g=v[a+56>>2];v[e+44>>2]=g;q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=b;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;s=a;if(d){while(1){l=i>>>18|0;k=1;g=((((b&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;f=0;b=1;j=0;while(1){h=j<<1;i=u[h+g>>1];v[(e+8|0)+(j<<2)>>2]=i+((B(l,u[g+(h|4)>>1]-i|0)|0)/16384|0);i=b;b=0;j=1;if(i){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=v[j>>2];h=v[a+60>>2];m=h;i=(e+32|0)+(f<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);f=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);n=h>>31;l=l<<8;h=l;h=nqa(m,n,h,h>>31);m=jb;n=h;h=nqa(f,f>>31,b,b>>31);f=n+h|0;b=jb+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=h+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&l);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];b=v[e+28>>2];continue}break}i=v[e+24>>2];b=v[e+28>>2];k=v[e+40>>2];j=v[e+36>>2];f=v[e+32>>2];g=v[e+44>>2]}v[s+56>>2]=g;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=b;gb=e+48|0}function X4(){var a=0,b=0,c=0;a=gb-16|0;gb=a;ct(463600);v[115910]=463656;v[115908]=90520;v[115900]=78556;v[115912]=-1;t[463652]=0;b=a+8|0;Ys(b,463600);c=v[v[115900]+8>>2];v[22708]=0;R(c|0,463600,b|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break a}b=P()|0;O()|0;Wb(a+8|0);ym(463600);S(b|0);L()}hu(462928);v[115732]=77164;v[115730]=77144;v[115731]=0;v[22708]=0;R(2405,462928,463600);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;oh(462928);S(a|0);L()}a=gb-16|0;gb=a;gI(463664);v[115926]=463720;v[115924]=90520;v[115916]=78656;v[115928]=-1;t[463716]=0;b=a+8|0;Ys(b,463664);c=v[v[115916]+8>>2];v[22708]=0;R(c|0,463664,b|0);b=v[22708];v[22708]=0;b:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break b}b=P()|0;O()|0;Wb(a+8|0);$p(463664);S(b|0);L()}EH(463016);v[115754]=77212;v[115752]=77192;v[115753]=0;v[22708]=0;R(2406,463016,463664);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;oh(463016);S(a|0);L()}IH(463728,90664,463776);Kx(463096,463728);HH(463784,90664,463832);Jx(463180,463784);IH(463840,90144,463888);Kx(463264,463840);Kx(463432,v[(v[v[115816]-12>>2]+463264|0)+24>>2]);HH(463896,90144,463944);Jx(463348,463896);Jx(463516,v[(v[v[115837]-12>>2]+463348|0)+24>>2]);GH(v[v[115730]-12>>2]+462920|0);FH(v[v[115752]-12>>2]+463008|0);_N(v[v[115816]-12>>2]+463264|0);_N(v[v[115837]-12>>2]+463348|0);GH(v[v[115816]-12>>2]+463264|0);FH(v[v[115837]-12>>2]+463348|0)}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-176|0;gb=b;d=Tb(b+8|0,8890);v[22708]=0;Q(70,b+20|0,8238)|0;e=v[22708];v[22708]=0;c=1;a:{b:{if((e|0)==1){break b}v[22708]=0;Q(70,b+32|0,8720)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=2;break b}v[22708]=0;Q(70,b+44|0,8230)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=3;break b}v[22708]=0;Q(70,b+56|0,5376)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=4;break b}v[22708]=0;Q(70,b+68|0,8215)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=5;break b}v[22708]=0;Q(70,b+80|0,5442)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=6;break b}v[22708]=0;Q(70,b+92|0,2712)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=7;break b}v[22708]=0;Q(70,b+104|0,9258)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=8;break b}v[22708]=0;Q(70,b+116|0,8663)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=9;break b}v[22708]=0;Q(70,b+128|0,9459)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=10;break b}v[22708]=0;Q(70,b+140|0,2564)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=11;break b}v[22708]=0;Q(70,b+152|0,4379)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=12;break b}v[b+172>>2]=13;v[b+168>>2]=d;v[22708]=0;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2088,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){a=b+164|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}gb=b+176|0;return}a=b+164|0;break a}a=(b+8|0)+B(c,12)|0}b=P()|0;O()|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}S(b|0);L()}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=gb-16|0;gb=g;m=a+44|0;if(ni(m)){j=Nd(m,0);k=Nd(m,1);h=od(m,0);i=od(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Fb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){e=0;if(!f){break b}while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}n=C(C(1)/C(y[a+4220>>2]));while(1){o=C(e>>>0);z[h>>2]=n*C(z[j>>2]*o);z[i>>2]=n*C(z[k>>2]*o);i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Fb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(r<C(1))){e=0;if(f){break e}break d}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}n=C(C(1)/C(y[a+4220>>2]));while(1){o=C(e>>>0);z[h>>2]=n*C(z[j>>2]*o);z[i>>2]=n*C(z[k>>2]*o);i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}Gi(a,b,c,od(m,0),od(m,1),d)}gb=g+16|0}function rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;j=v[a+56>>2];v[e+44>>2]=j;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;j=1;b=1;f=0;while(1){h=t[f+g|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){k=(e+8|0)+(i<<2)|0;f=v[k>>2];l=v[a+60>>2];m=l;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Lb(i,-16777216,16776704);n=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);r=l>>31;l=f<<8;f=l;f=nqa(m,r,f,f>>31);m=jb;n=nqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=nqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[h+4>>2]=i;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&l);i=1;b=j&1;j=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];j=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=j;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Yh(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;return}d=b&224;a:{if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;g=c&d;b:{if(g){Lo(e,f);break b}Lo(e,0)}t[f+40|0]=!g;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){aB((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(B(b&256?d+9|0:d,44)+a|0)+16|0;d=v[a+36>>2];c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}b=c&32;ZR(a,b>>>5|0);f=c>>>2&7;YR(a,f);e=a;a=c&3;XR(e,a);if(!d){break a}ZR(d,(b|0)!=0);YR(d,f);XR(d,a);return}WR(a,c);if(!d){break a}WR(d,c);return}t[a+42|0]=(c&32)>>>5;t[a+41|0]=(c&16)>>>4;b=c>>>1&7;u[a+30>>1]=b?9-b|0:0;u[a+32>>1]=c&1;return}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=t[(b&31)+35296|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;Mo(a);u[a+14>>1]=x[((c&15)<<1)+35328>>1];return;case 1:u[a+68>>1]=w[(c>>>6|0)+18711|0];VR(a);u[a+22>>1]=(c&63)<<2;return;case 2:u[a+24>>1]=c>>>4;Mo(a);u[a+26>>1]=c&15;Mo(a);return;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;Mo(a);return;case 6:break d;default:break a}}u[a+12>>1]=c&7}}function TR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(vk(a)){h=gb-16|0;gb=h;j=h+8|0;f=tf(3848);k=v[e+12>>2];c=f+808|0;b=f+16|0;while(1){v[b+16>>2]=0;v[b+20>>2]=0;v[b+36>>2]=0;t[b+42|0]=1;u[b+40>>1]=257;v[b+24>>2]=0;v[b+28>>2]=0;u[b+32>>1]=0;b=b+44|0;if((c|0)!=(b|0)){continue}break}c=f+3832|0;b=f+808|0;while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+68>>2]=0;v[b+72>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;u[b+20>>1]=511;v[b+16>>2]=-1;u[b+14>>1]=1;u[b+6>>1]=0;u[b+8>>1]=0;u[b+10>>1]=0;u[b+12>>1]=0;t[b+73|0]=0;t[b+74|0]=0;t[b+75|0]=0;t[b+76|0]=0;t[b+77|0]=0;t[b+78|0]=0;t[b+79|0]=0;t[b+80|0]=0;b=b+84|0;if((c|0)!=(b|0)){continue}break}b=f;v[b+3832>>2]=0;v[b+3836>>2]=0;c=b+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){df((b+B(g,84)|0)+808|0,b);g=g+1|0;if((g|0)!=36){continue}break}while(1){v[(b+B(d,44)|0)+32>>2]=b;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=(b+B(d,44)|0)+16|0;g=v[(d<<2)+35216>>2];b:{if(!(!(1<<d&3591)|d>>>0>11)){i=c;c=b+B(g,84)|0;$R(i,c+808|0,c+1060|0,c+1312|0,c+1564|0);break b}i=c;c=b+B(g,84)|0;$R(i,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Mo((b+B(d,84)|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}_R(b,k);b=v[Yi(j,f)>>2];gb=h+16|0;v[e+8>>2]=b;b=e+8|0;VC(a,b);ln(b);break a}_R(v[a>>2],b)}_A(a);gb=e+16|0}function Ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=gb-16|0;gb=e;f=Tb(e,1547);Dc(d- -64|0,f);vb(f);gb=e+16|0;v[22708]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=nqa(e,e>>31,1e4,0)+14780|0;b=jb;b=oqa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(112,d+48|0,d+44|0);g=v[22708];v[22708]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22708]=0;v[d+28>>2]=(e-B(f,12)|0)+1;R(114,d+32|0,d+28|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}v[22708]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(114,d+16|0,d+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}v[22708]=0;ha(556,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}Ef(d- -64|0,1527);v[22708]=0;R(557,d+48|0,d+78|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;U(167,a|0,d- -64|0,d+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}}vb(d+48|0);Hb(d- -64|0);gb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}Hb(d- -64|0);S(b|0);L()}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=Un(d,a+224|0);Tn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;h=Q(2487,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2489,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(qm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22708]=0;T(2491,a+344|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2468,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function E3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=Un(d,a+224|0);Tn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;h=Q(2487,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2489,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(qm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22708]=0;T(2491,a+344|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2472,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Oz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;i=nO(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}e=v[i>>2];f=g+8|0;j=a+1074312|0;Db(f,j,31);f=Cb(f);d=mw(v[b+656>>2],c);if(cd(d)){break a}f=e+(f^1)|0;e=g+8|0;Db(e,j,31);h=Cb(e);e=w[d+12|0];b:{c:{if(!h){d:{if(!(e&2)){break d}e=x[Mb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){h=g+8|0;Db(h,j,70);k=Cb(h)}if((e|0)!=(f|0)|k){break d}f=x[Mb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Mb(d,w[d+16|0])>>1]+1|0)!=(f|0)){break b}f=x[Mb(d,w[d+15|0])>>1];a=g+8|0;Db(a,j,93);if(!Cb(a)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;e=x[vo(d)>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}e=g+8|0;Db(e,j,97);if(Cb(e)){break f}e=w[d+12|0]}if(e&2){e=x[Mb(d,w[d+13|0])>>1];h=x[Mb(d,w[d+14|0])>>1]+1|0;break e}e=x[vo(d)>>1];k=f>>>0>e>>>0;h=e;break e}e=x[Mb(d,w[d+15|0])>>1];h=x[Mb(d,w[d+16|0])>>1]+1|0}e=f>>>0<h>>>0?f:e}g:{if(!k|c){break g}if(!(!(v[a+480180>>2]&16777248)&(!(w[b+89|0]&8)|v[a+480180>>2]==16384))){v[b+88>>2]=v[b+88>>2]|4096}if(w[vo(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}f=e}a=g+8|0;Db(a,j,31);l=i,m=Cb(a)+f|0,v[l>>2]=m}gb=g+16|0}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Un(d,a+224|0);Tn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2487,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2489,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(qm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2491,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2465,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Un(d,a+224|0);Tn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2487,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2489,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(qm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2491,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2469,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}u[f>>1]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function G3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Un(d,a+224|0);Tn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2487,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2489,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(qm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2491,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2470,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Un(d,a+224|0);Tn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2487,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2489,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(qm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2491,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2471,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2488,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function V3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Vn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22708]=0;h=Q(2460,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2462,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(rm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2464,a+232|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2472,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function $3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Vn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22708]=0;h=Q(2460,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2462,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(rm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2464,a+232|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2468,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function l3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;m=Px(g);g=vx(g);Ug(k,g);a:{b:{c:{d:{if(gd(k)){v[22708]=0;Y(2494,m|0,a|0,c|0,d|0);g=v[22708];v[22708]=0;if((g|0)==1){break d}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;e:{f:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break f;default:break e}}v[22708]=0;j=Q(2504,m|0,h<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22708]=0;h=Q(2504,m|0,48)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22708]=0;h=Q(2504,m|0,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}pm(j,c);v[22708]=0;n=T(2492,g|0)|0;g=v[22708];v[22708]=0;g:{if((g|0)!=1){if(c>>>0>j>>>0){break g}g=v[f>>2];break b}break d}o=(c-j|0)+j|0;g=j;h=0;i=0;while(1){h:{if(!w[pc(k,h)|0]){break h}if(t[pc(k,h)|0]!=(i|0)){break h}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=n;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}l=t[g|0];v[22708]=0;p=Q(2504,m|0,l|0)|0;l=v[22708];v[22708]=0;if((l|0)!=1){l=v[f>>2];v[f>>2]=l+4;v[l>>2]=p;i=i+1|0;g=g+1|0;if((o|0)==(g|0)){break c}continue}break}}a=P()|0;O()|0;vb(k);S(a|0);L()}g=l+4|0}rx((j-a<<2)+d|0,g);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;vb(k);gb=k+16|0}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function X0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{if(d>>>0<=b>>>0){break a}b:{while(1){if(f>>>0>=g>>>0){break b}j=t[b|0];c=j&255;l=a;c:{if((j|0)>=0){u[f>>1]=c;b=b+1|0;break c}j=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-b|0)<2){break b}i=w[b+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|c<<6&1984;b=b+2|0;break c}if(c>>>0<=239){if((d-b|0)<3){break b}k=w[b+2|0];i=w[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|c<<12);b=b+3|0;break c}if(c>>>0>244){break a}if((d-b|0)<4){break b}k=w[b+3|0];i=w[b+2|0];b=w[b+1|0];f:{g:{switch(c-240|0){case 0:if((b+112&255)>>>0<48){break f}break a;case 4:if((b&240)==128){break f}break a;default:break g}}if((b&192)!=128){break a}}if((i&192)!=128|(k&192)!=128){break a}if((g-f|0)<4){break b}c=c&7;if((b<<12&196608|c<<18)>>>0>1114111){break a}b=b<<2;u[f>>1]=(i>>>4&3|(b&192|c<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[l+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;b=v[a+12>>2];if(d>>>0>b>>>0){continue}break}j=0;break a}j=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return j|0}function c4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Vn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2460,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2462,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2464,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2465,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Vn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2460,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2462,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2464,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2469,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}u[f>>1]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function X3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Vn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2460,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2462,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2464,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2470,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function W3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Vn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2460,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2462,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2464,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=da(2471,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;hf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2461,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function k_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){ud(b,32);li(d,1,a+4|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}vb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;yg(b+30|0,256);u[b+32>>1]=w[a+17|0];yg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;yg(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);wk(b);t[b+38|0]=w[(w[a+79|0]&7)+46144|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=d+32|0;return c|0}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=gb-144|0;gb=k;SB(a);a:{b:{if(!Wf(a,64)){break b}c:{d:{if(!Vl(a,60)){break d}if(!qU(a,11407)){break d}h=15;e=450;break c}SB(a);if(!Wf(a,128)){break b}b=0;if(!Vl(a,124)){break a}if(!qU(a,12499)){break a}h=31;e=930}SB(a);b=0;while(1){j=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;Ai(d,f+8|0);g=yb(d);d=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=d;v[c>>2]=i;v[c+4>>2]=d;d=a;i=c+16|0;hd(i,a,c);i=yb(i);if((i|0)==(g|0)){bd(d,yb(c+24|0))}gb=c+32|0;if((g|0)==(i|0)){d=f+8|0;j=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))}gb=f+16|0;if(j>>>0>131072){break a}l=l+1|0;if((l&65535)>>>0<h>>>0){continue}break}bd(a,4);if(!Wf(a,2)){break b}h=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;Bn(d,f+8|0);j=yb(d);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;g=c+16|0;hd(g,a,c);g=yb(g);if((g|0)==(j|0)){bd(d,yb(c+24|0))}gb=c+32|0;if((g|0)==(j|0)){d=f+8|0;h=Ib(w[d|0]|w[d+1|0]<<8)}gb=f+16|0;if(h>>>0<178){break a}b=-1;if(!Wf(a,e)){break a}bd(a,e);e=gb-32|0;gb=e;d=e+24|0;h=k+8|0;nV(d,h);d=yb(d);c=v[e+28>>2];f=v[e+24>>2];v[e+8>>2]=f;v[e+12>>2]=c;v[e>>2]=f;v[e+4>>2]=c;c=e+16|0;hd(c,a,e);c=yb(c);if((c|0)==(d|0)){bd(a,yb(e+24|0))}gb=e+32|0;a=(c|0)==(d|0);if(!a){ZB(h)}if(!a){break a}b=pU(k+8|0);break a}b=-1}gb=k+144|0;return b|0}function s_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-1088|0;gb=e;Jh(a);Qb(a+20|0,0,1040);i=a;v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;g=a+1072|0;v[g>>2]=0;v[g+4>>2]=0;v[a+1080>>2]=0;t[a+1084|0]=d;a:{if(fd(c)){g=a+1064|0;while(1){v[a+1064>>2]=0;v[a+1068>>2]=0;b:{if(!v[c>>2]){break b}while(1){v[22708]=0;d=Q(191,b|0,2)|0;f=v[22708];v[22708]=0;c:{d:{e:{if((f|0)!=1){if(!d){break b}v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}if(!d){break c}v[22708]=0;U(288,e|0,b|0,d|0);d=v[22708];v[22708]=0;f:{g:{if((d|0)!=1){v[22708]=0;d=Kp(e+24|0,e);f=v[22708];v[22708]=0;if((f|0)==1){break g}Vc(i,d);hc(i+20|0,d+20|0,1040);xb(e+24|0);xb(e);v[a+1076>>2]=0;v[a+1080>>2]=0;f=jj(v[a+1060>>2]);d=v[a+1060>>2];if(f>>>0<2){break f}d=v[d+20>>2];v[22708]=0;R(289,a|0,d+(h<<1)|0);d=v[22708];v[22708]=0;if((d|0)!=1){break c}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;xb(e);break a}d=v[d+20>>2];v[22708]=0;R(290,a|0,d+h|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}break c}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break a}Z(d|0)|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){break c}d=P()|0;O()|0;break a}if(y[g>>2]<y[c>>2]){continue}break}}h=h+1|0;if(fd(v[a+1060>>2])>>>0>h>>>0){continue}break}}gb=e+1088|0;return a|0}xb(a);S(d|0);L()}function dJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0);d=(b<<2)+a|0;g=d+1068|0;l=c<<1&-4;q=g,r=_d(a,l),v[q>>2]=r;i=d+1076|0;q=i,r=_d(a,l),v[q>>2]=r;k=_d(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}i=v[i>>2];if(!i|!k){break a}d=c;b:{if((d|0)<4){break b}j=C(d|0);p=d>>>2|0;while(1){m=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))/j);q=m+g|0,s=C(Le(f)),z[q>>2]=s;n=e|1;o=n<<2;q=o+g|0,s=C(-C(si(f))),z[q>>2]=s;f=+C(C(C(C(n|0)*C(3.1415927410125732))/j)*C(.5));q=i+m|0,s=C(C(Le(f))*C(.5)),z[q>>2]=s;q=i+o|0,s=C(C(si(f))*C(.5)),z[q>>2]=s;e=e+2|0;h=h+1|0;if((p|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;e=0;h=0;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);q=k+(e<<2)|0,s=C(Le(f)),z[q>>2]=s;q=k+(g<<2)|0,s=C(-C(si(f))),z[q>>2]=s;e=e+2|0;h=h+1|0;if((d|0)!=(h|0)){continue}break}}e=(b<<2)+a|0;d=_d(a,l);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;f=+(b|0);h=(b|0)>1?b:1;b=0;while(1){j=C(si((+(b|0)+.5)/f*.5*3.1415927410125732));q=d+(b<<2)|0,s=C(si(+C(j*j)*1.5707963705062866)),z[q>>2]=s;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=_d(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=Dm(a);if((a|0)>=8){c=36-d|0;d=a>>>3|0;a=0;while(1){q=b+(a<<1)|0,r=Bm(a)>>>c<<2,u[q>>1]=r;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}ec(a,3);return 0}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<1){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if(h>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(h>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;gb=g+32|0}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=gb-32|0;gb=i;v[i+24>>2]=b;b=v[a>>2];p=i,q=Vb(a),v[p>>2]=q;b=b+B(Wt(i+24|0,i),6)|0;a:{b:{if(!c){break b}e=v[wb(a)>>2];f=v[a+4>>2];if((e-f|0)/6>>>0>=c>>>0){g=c;h=f-b|0;e=(h|0)/6|0;if(e>>>0<c>>>0){SC(a,c-e|0,d);g=e;if(!h){break b}}l=gb-16|0;gb=l;j=a;e=b;o=f;n=v[a+4>>2];h=B((n-(B(c,6)+e|0)|0)/6|0,6)+e|0;m=Ar(l,a,(f-h|0)/6|0);if(f>>>0>h>>>0){k=v[m+4>>2];f=h;while(1){wb(j);DN(k,f);k=k+6|0;v[m+4>>2]=k;f=f+6|0;if(o>>>0>f>>>0){continue}break}}$b(m);f=h-e|0;if(f){yh(n+B((f|0)/-6|0,6)|0,e,f)}gb=l+16|0;a=B(b>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;if(g){while(1){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;e=e+6|0;g=g-1|0;if(g){continue}break}}break b}g=wb(a);g=LW(i,DC(a,Jg(a)+c|0),(b-v[a>>2]|0)/6|0,g);v[22708]=0;U(643,g|0,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}QC(a);c=v[g+4>>2];f=g+4|0;JW(wb(a),v[a>>2],b,f);wb(a);h=g+8|0;d=h;j=v[a+4>>2];if((j|0)!=(b|0)){e=v[d>>2];while(1){DN(e,b);e=v[d>>2]+6|0;v[d>>2]=e;b=b+6|0;if((j|0)!=(b|0)){continue}break}}xc(a,f);xc(a+4|0,h);xc(wb(a),dc(g));v[g>>2]=v[g+4>>2];FC(a,Jg(a));b=c;rv(g)}Gg(b);gb=i+32|0;return}a=P()|0;O()|0;rv(g);S(a|0);L()}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Lb(k,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];l=nqa(e,e>>31,f,f>>31);e=I+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;h=nqa(G,H,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function A2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-448|0;gb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2509;h=ge(a+24|0,a+32|0,a+20|0);v[22708]=0;Fc(a+16|0,e);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[22708]=0;i=T(2482,a+16|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[22708]=0;b=ra(2517,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break c}c=gb-16|0;gb=c;b=g;e:{if(De(b)){d=v[b>>2];v[c+12>>2]=0;Fe(d,c+12|0);de(b,0);break e}v[c+8>>2]=0;Fe(b,c+8|0);_e(b,0)}gb=c+16|0;if(!w[a+15|0]){break d}v[22708]=0;b=Q(2504,i|0,45)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(63,g|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22708]=0;b=Q(2504,i|0,48)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;f:{if(e>>>0>=d>>>0){break f}while(1){if((b|0)!=v[e>>2]){break f}e=e+4|0;if(d>>>0>e>>>0){continue}break}}v[22708]=0;U(2522,g|0,e|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break b}v[22708]=0;b=Q(2488,a+440|0,a+432|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Wb(a+16|0);Hc(h);gb=a+448|0;return b|0}e=P()|0;O()|0;Wb(a+16|0)}Hc(h);S(e|0);L()}function spa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-1072|0;gb=e;v[e+1068>>2]=c;l=Ae(b);g=nD(e+8|0,b);v[22708]=0;m=nn(g);c=v[22708];v[22708]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22708]=0;c=T(467,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}v[e+4>>2]=c;v[22708]=0;v[e>>2]=536870911;c=Fb(e+4|0,e);d=v[22708];v[22708]=0;if((d|0)==1){break c}qc(e+1068|0,v[c>>2]<<3);v[22708]=0;k=Q(513,a|0,v[e+1068>>2])|0;a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;c=8;f=Q(200,g|0,8)|0;d=v[22708];v[22708]=0;a=1;e:{f:{if((d|0)==1){break f}d=zb(f&255);n=lc(k,0),o=d,t[n|0]=o;g:{if(y[e+1068>>2]<2){break g}while(1){v[22708]=0;j=c&255;d=Q(200,g|0,j|0)|0;h=v[22708];v[22708]=0;h:{i:{j:{k:{if((h|0)!=1){if(d){break k}if(j>>>0>8){break g}c=c+1|0;break j}break f}h=f;f=d>>>1|0;f=h+(d&1?0-f|0:f)|0;h=zb(f&255);n=lc(k,a),o=h,t[n|0]=o;a=a+1|0;if(!(d<<1>>>j|0)){break i}}i=0;break h}i=i+1|0;d=i&255;c=c-(j>>>0>1&d>>>0>=l>>>0)|0;i=d>>>0<l>>>0?i:0}if(y[e+1068>>2]>a>>>0){continue}break}}v[22708]=0;a=nn(g);c=v[22708];v[22708]=0;if((c|0)==1){break f}v[22708]=0;Q(190,b|0,((a-m|0)+3&-4)+m|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break e}}c=P()|0;O()|0;gc(k);break a}xb(g);gb=e+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}xb(g);S(c|0);L()}function Y0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;if(c>>>0<d>>>0){continue}break}}f=0;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return f|0}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<1){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if(g>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(g>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;gb=f+32|0}function x3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;l=zD(g);g=zx(g);Ug(k,g);a:{b:{if(gd(k)){v[22708]=0;Y(2474,l|0,a|0,c|0,d|0);g=v[22708];v[22708]=0;if((g|0)==1){break a}g=(c-a|0)+d|0;v[f>>2]=g;break b}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22708]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22708]=0;h=Q(22,l|0,48)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22708]=0;h=Q(22,l|0,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}pm(j,c);v[22708]=0;o=T(2466,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}if(c>>>0>j>>>0){p=(c-j|0)+j|0;g=j;h=0;i=0;while(1){e:{if(!w[pc(k,h)|0]){break e}if(t[pc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22708]=0;n=Q(22,l|0,n|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break a}m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;i=i+1|0;g=g+1|0;if((p|0)!=(g|0)){continue}break}}pm((j-a|0)+d|0,v[f>>2]);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);S(a|0);L()}function Eu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{f=a;d=b;b:{c:{i=a+58|0;h=ic(i,b);b=t[h|0];if((b|0)==-1){break c}if((b|0)>-1){break b}b=b&127;e=vd(f+22|0,b);g=x[e>>1];if((g|0)!=65535&(d|0)!=(g|0)){break c}u[e>>1]=d;t[h|0]=b;break b}m=f+4|0;j=f+22|0;g=255;b=0;e=255;while(1){k=vd(j,b);l=x[k>>1];if((l|0)==65535){u[k>>1]=d;t[h|0]=b;break b}if(!(w[ic(m,b)|0]&32)){g=t[ic(i,l)|0]>-1?g:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(g&255)==255?e:g;e=vd(j,b&255);n=ic(i,x[e>>1]),o=255,t[n|0]=o;u[e>>1]=d;t[h|0]=b}b=Nl(f,d)}e=b&255;if((e|0)==255){break a}if(vk(a)){break a}d=YA(a+314|0,e);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=b;t[d+9|0]=b>>>8;t[d+10|0]=b>>>16;t[d+11|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=b;t[d+5|0]=b>>>8;t[d+6|0]=b>>>16;t[d+7|0]=b>>>24;g=SR(e);h=g+3|0;b=0;d=1;while(1){f=d;d=d?g:h;Yh(v[a>>2],(d|32)&65535,w[ic(c,b)|0]);Yh(v[a>>2],(d|64)&65535,w[ic(c,b|2)|0]);Yh(v[a>>2],(d|96)&65535,w[ic(c,b|4)|0]);Yh(v[a>>2],(d|128)&65535,w[ic(c,b|6)|0]);Yh(v[a>>2],(d|224)&65535,w[ic(c,b|8)|0]);d=0;b=1;if(f){continue}break}Yh(v[a>>2],Fu(e)|192,w[ic(c,10)|0])}}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Lb(k,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];l=nqa(e,e>>31,f,f>>31);e=J+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;h=nqa(H,I,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function Gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;e=u[f>>1];v[b+8>>2]=e;v[b+12>>2]=u[f+2>>1];i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Lb(n,-16777216,16776704);m=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=nqa(l,r,e,e>>31);l=jb;m=nqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=nqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=c>>>4;v[e+16>>2]=v[a>>2];j=v[Fb(e+24|0,e+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){d=b;f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[bh(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=ee(h);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=d,n=Uc(f),u[m>>1]=n;d=b;f=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24);g=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[bh(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=ee(h);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=d,n=Uc(f),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=e+32|0;return j<<4}function r2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-496|0;gb=a;g=a+488|0;Fc(g,d);v[22708]=0;m=T(2482,g|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=v[xk(f,0)>>2];v[22708]=0;h=Q(2504,m|0,45)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[22708]=0;na(2526,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}v[a+4>>2]=2458;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+420>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Cd(j<<2));i=v[c>>2];if(i){break e}v[22708]=0;X(2459);b=v[22708];v[22708]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22708]=0;qa(2527,i|0,a+4|0,a|0,j|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;b=la(2507,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}Ic(h);Ic(g);vb(k)}Wb(a+488|0);S(f|0);L()}Hc(c);Ic(h);Ic(g);vb(k);Wb(a+488|0);gb=a+496|0;return b|0}function zna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=qv(a);if(b>>>0<=63){k=gb-32|0;gb=k;a:{b:{j=64-b|0;c:{if(j>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/33>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(j,33);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){CC(a);a=a+33|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}i=wb(a);f=k+8|0;d=a;c=qv(a)+j|0;h=gb-16|0;gb=h;v[h+12>>2]=c;e=gb-16|0;gb=e;v[e+12>>2]=130150524;v[22708]=0;v[e+8>>2]=2147483647;g=Fb(e+12|0,e+8|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){gb=e+16|0;b=v[g>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0>=c>>>0){c=sW(d);if(c>>>0<b>>>1>>>0){v[h+8>>2]=c<<1;b=v[Mc(h+8|0,h+12|0)>>2]}gb=h+16|0;break e}Sc();L()}d=qv(a);e=0;g=gb-16|0;gb=g;v[g+12>>2]=0;jf(f+12|0,i);if(b){c=b;if(b>>>0>=130150525){rd(8445);L()}e=Nc(B(c,33),1)}v[f>>2]=e;c=B(d,33)+e|0;v[f+8>>2]=c;v[f+4>>2]=c;l=dc(f),m=B(b,33)+e|0,v[l>>2]=m;gb=g+16|0;v[22708]=0;wW(f,j);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=a;c=f;i=c+4|0;d=v[a+4>>2];a=v[a>>2];g=d-a|0;d=v[i>>2]+B((g|0)/-33|0,33)|0;v[i>>2]=d;if((g|0)>=1){hc(d,a,g)}wc(b,i);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];vW(f)}gb=k+32|0;break a}a=P()|0;O()|0;vW(f);S(a|0);L()}return}if((b|0)!=64){Zk(a,v[a>>2]+2112|0)}}function d1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;i=d;j=(c|0)==(d|0);a:{if(j){break a}i=c;while(1){if(!w[i|0]){break a}i=i+1|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];m=wi(l+8|0,l+12|0);v[22708]=0;j=oH(f,e,i-c|0,g-f>>2,b);n=v[22708];v[22708]=0;d:{if((n|0)!=1){gf(m);gb=l+16|0;break d}a=P()|0;O()|0;gf(m);S(a|0);L()}e:{f:{g:{h:{i:{j:{k:{if((j|0)==-1){v[h>>2]=f;if(v[e>>2]!=(c|0)){while(1){g=1;l:{m:{n:{b=FG(f,c,i-c|0,k+8|0,v[a+8>>2]);switch(b+2|0){case 0:break i;case 2:break l;case 1:break n;default:break m}}v[e>>2]=c;break k}g=b}f=v[h>>2]+4|0;v[h>>2]=f;c=c+g|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break c}f=v[h>>2]+(j<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break h}c=v[e>>2];if((d|0)==(i|0)){i=d;break e}if(!FG(f,c,1,b,v[a+8>>2])){break j}}a=2;break b}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;if((c|0)==(d|0)){break g}while(1){if(!w[i|0]){break f}i=i+1|0;if((i|0)!=(d|0)){continue}break}break g}v[e>>2]=c;a=1;break b}c=v[e>>2];break c}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}a=(c|0)!=(d|0)}gb=k+16|0;return a|0}function Hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+o|0;e=t[f|0]<<8;v[b+8>>2]=e;v[b+12>>2]=t[f+1|0]<<8;i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Lb(n,-16777216,16776704);m=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=nqa(l,r,e,e>>31);l=jb;m=nqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=nqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function sea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);i=gb-16|0;gb=i;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Nb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}h=u[d+2>>1];if((h|0)<(g|0)){break a}if((Nb(b)-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Nb(b)){break b}while(1){if(!(z[Mb(b,f)>>2]<C(0))){f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=qN(Nb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;Dl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=Vb(b);f=Zb(b);l=i,m=Vb(g),v[l+8>>2]=m;h=_o(i+8|0,u[e>>1]-u[d>>1]|0);b=gb-16|0;gb=b;yc(b+8|0,Ln(_l(c),_l(f),_l(h)));gb=b+16|0;c=u[a+28>>1];f=u[e>>1];c:{if((c|0)>=(f|0)){break c}b=f;while(1){b=b-1|0;j=z[Mb(g,u[a+30>>1]+(b-c|0)|0)>>2];k=z[a+32>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;f=u[e>>1];c=u[a+28>>1];if((c|0)>=(b|0)){break c}if((f|0)!=-32768){continue}break}}d:{h=u[a+30>>1];b=h+f|0;if((b|0)>u[d+2>>1]|(32767-h|0)<(f|0)){break d}while(1){j=z[a+32>>2];k=z[Mb(g,b-((c<<16>>16)+h|0)|0)>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(j*k),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}h=u[a+30>>1];if(u[e>>1]>(32767-h|0)){break d}b=b+1|0;c=x[a+28>>1];continue}}mq(a);f=1}gb=i+16|0;return f|0}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function pga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;b=a+8|0;lu(b,Xd(b));l=wb(b),m=0,v[l>>2]=m;l=b,m=fc(b),v[l>>2]=m;l=fc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;d=a+4|0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];j=x[b+480188>>1];v[h+8>>2]=0;v[h+12>>2]=0;i=h+8|0;u[i+4>>1]=65280;v[i>>2]=0;g=gb-16|0;gb=g;v[g+12>>2]=j;f=a+20|0;a:{if(tg(f)>>>0>=j>>>0){l=g,m=sf(f),v[l+8>>2]=m;c=v[f>>2];b=i;e=v[Fb(g+12|0,g+8|0)>>2];if(e){while(1){v[c>>2]=v[b>>2];u[c+4>>1]=x[b+4>>1];c=c+8|0;e=e-1|0;if(e){continue}break}}b=v[g+12>>2];c=v[g+8>>2];if(b>>>0>c>>>0){fP(f,b-c|0,i);break a}Zk(f,v[f>>2]+(b<<3)|0);break a}b=f;if(v[b>>2]){Od(b);gP(v[b>>2],tg(b));l=wb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}c=gs(f,j);if(Iw()>>>0<c>>>0){Sc();L()}e=c;if(c>>>0>=536870912){rd(8445);L()}e=Nc(e<<3,4);v[b>>2]=e;v[b+4>>2]=e;l=wb(b),m=e+(c<<3)|0,v[l>>2]=m;fP(f,j,i)}gb=g+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(k,872);$m((b+v[d>>2]|0)+616|0,7,v[a>>2],k&65535,134217728);t[(b+v[d>>2]|0)+1433|0]=0;t[(b+v[d>>2]|0)+1432|0]=0;t[(b+v[d>>2]|0)+1415|0]=0;t[(b+v[d>>2]|0)+1418|0]=0;t[(b+v[d>>2]|0)+1413|0]=0;k=k+1|0;if(k>>>0<x[v[a>>2]+480188>>1]){continue}break}}gb=h+16|0}function lqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;hb=a-B(b,c)|0;ib=0;jb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}hb=a;ib=f&g;a=g>>>mqa(e)|0;jb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}hb=0;a=(g>>>0)/(e>>>0)|0;ib=g-B(a,e)|0;jb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}hb=a&f;ib=0;if((e|0)==1){break a}c=a;a=mqa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}jb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;f=i>>31;e=f;i=e;f=c&e;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}hb=l;ib=f;e=b<<1|a>>>31;a=k|a<<1;jb=e|m;return a}hb=a;ib=b;a=0;b=0}jb=b;return a}function wga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;g=gb-32|0;gb=g;s=g,t=B(v[a>>2],fd(a)),v[s+4>>2]=t;qc(g+4|0,c>>>3|0);c=zb(b);j=A[e+8>>3];k=v[g+4>>2];a:{if(!k){break a}e=k;while(1){m=0;f=c;o=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=h<<24|h<<8&16711680;p=m;m=o<<24|h>>>8;f=o<<8|h>>>24;p=p|0;m=m&65280|f&255|q;f=o;l(0,((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24)|p);l(1,m&2147483647);i=+n();j=j<i?i:j;c=c+8|0;e=e-1|0;if(e){continue}break}if(j==0){break a}r=1/j;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24;q=0;o=h<<8&16711680|f;p=a<<24|h>>>8;f=a<<8|h>>>24;e=a;l(0,((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,o|(p&65280|f&255));s=g,x=r*+n(),A[s+24>>3]=x;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;i=A[bh(g+24|0,g+16|0,g+8|0)>>3]*32768;A[g+24>>3]=i;a=c;i=ee(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}s=a,t=Uc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;k=k-1|0;if(k){continue}break}}if(d){A[d>>3]=j}gb=g+32|0;return v[g+4>>2]<<3}function v2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-192|0;gb=a;g=a+184|0;Fc(g,d);v[22708]=0;m=T(21,g|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=w[pc(f,0)|0];v[22708]=0;h=Q(22,m|0,45)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[22708]=0;na(2524,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}v[a+4>>2]=2458;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+124>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Cd(j));i=v[c>>2];if(i){break e}v[22708]=0;X(2459);b=v[22708];v[22708]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22708]=0;qa(2525,i|0,a+4|0,a|0,j|0,o|0,f+p|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;b=la(17,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}vb(h);vb(g);vb(k)}Wb(a+184|0);S(f|0);L()}Hc(c);vb(h);vb(g);vb(k);Wb(a+184|0);gb=a+192|0;return b|0}function xW(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+28896|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[ac(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[ac(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}gb=c+16|0}function VY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-144|0;gb=g;v[22708]=0;l=T(416,a|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){a:{if(l){e=g+8|0;o=e|4;p=e|6;q=e|5;k=e|2;m=e|3;while(1){v[22708]=0;R(445,a|0,g+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}e=g+8|0;e=Ib(w[e|0]|w[e+1|0]<<8);b:{if(!e|e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[22708]=0;e=ki(e,b);f=v[22708];v[22708]=0;if((f|0)==1){break a}c:{if(!w[m|0]){break c}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}t[g+4|0]=w[m|0];v[22708]=0;t[g+7|0]=31;f=ac(g+4|0,g+7|0);i=v[22708];v[22708]=0;if((i|0)==1){break a}f=w[f|0];v[22708]=0;i=f+1&255;R(446,e|0,i|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e+13|0]=w[q|0];t[e+14|0]=w[p|0];f=w[o|0];t[e+15|0]=f;t[e+16|0]=f;f=0;if(!i){break b}while(1){h=(g+8|0)+(f<<2)|0;j=h+8|0;j=Ib(w[j|0]|w[j+1|0]<<8);r=Mb(e,f),s=j,u[r>>1]=s;h=h+10|0;h=Ib(w[h|0]|w[h+1|0]<<8);u[g+4>>1]=d?h+128>>>2|0:h;yg(g+4|0,64);h=w[g+4|0];r=Mb(e,f),s=h,t[r+2|0]=s;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<l>>>0){continue}break}}xb(a);gb=g+144|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function Hx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;r=a;j=gb-1040|0;gb=j;s=v[115189];a:{b:{c:{a=j+16|0;m=a;e=b;g=v[22614];d:{e:{while(1){if((e|0)!=w[d+74896|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=74992;break d}d=74992;while(1){h=w[d|0];e=d+1|0;d=e;if(h){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[g+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];i=v[f>>2]+1794895138|0;l=tm(v[f+8>>2],i);g=tm(v[f+12>>2],i);h=tm(v[f+16>>2],i);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((g|h)&3|(c>>>0<=g>>>0|c>>>0<=h>>>0)){break f}u=h>>>2|0;x=g>>>2|0;while(1){n=l>>>1|0;g=n+o|0;h=g<<1;c=(h+x<<2)+f|0;p=tm(v[c>>2],i);c=tm(v[c+4>>2],i);if(c>>>0>=k>>>0|k-c>>>0<=p>>>0|w[(c+p|0)+f|0]){break f}c=xj(d,c+f|0);if(!c){d=(h+u<<2)+f|0;c=tm(v[d>>2],i);d=tm(v[d+4>>2],i);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}q=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?n:l-n|0;o=c?o:g;continue}}}d=q?q:e;e=Nf(d);g:{if(e>>>0>=1024){hc(m,d,1023);t[m+1023|0]=0;e=68;break g}hc(m,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[115189]}a=18726;if((e|0)==28){break a}Da();L()}if(!w[a|0]){v[j>>2]=b;a=j+16|0;Xx(a,1024,10351,j)}v[115189]=s;Tb(r,a);gb=j+1040|0}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;a:{if(!Pb(b,9)){break a}i=a+484344|0;j=a+480280|0;while(1){hp(b,c+44|0);d=sg(b);b:{e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}if(Pb(b,d)){break b}}pg(b,8);break a}Sd(c,b,d);g=kc(c+24|0,c);xb(c);d=j;d:{e:{f:{if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1481001027){while(1){v[22708]=0;e=T(192,g|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}t[d+8|0]=e;d=d+32|0;if((i|0)!=(d|0)){continue}break d}}if(w[c+44|0]!=70){break e}e=w[c+45|0];h=(e|0)==88;g:{if(!h){if((e-48&255)>>>0>9){break e}d=t[c+46|0];if((d|0)>47){break g}break e}d=t[c+46|0];if((d|0)<48){break e}}if((d|0)>57){break e}f=t[c+47|0];if((f|0)<48|(f|0)>57){break e}d=(f+(h?-16:B(e,100)+48|0)|0)+B(d,10)&255;if(d>>>0>249){break d}v[22708]=0;R(605,g|0,(B(d,160)+a|0)+906300|0);d=v[22708];v[22708]=0;if((d|0)!=1){break d}}a=P()|0;O()|0;xb(c+24|0);S(a|0);L()}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;k=1}xb(c+24|0);if(Pb(b,9)){continue}break}}gb=c+48|0;return k|0}function CI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=gb-16|0;gb=k;a:{b:{c:{if((c|0)<=36){g=w[a|0];if(g){break c}f=a;break b}v[115189]=28;d=0;e=0;break a}f=a;d:{while(1){if(!Am(g<<24>>24)){break d}g=w[f+1|0];h=f+1|0;f=h;if(g){continue}break}f=h;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=-48;h=t[f|0];h:{if((h-48&255)>>>0<10){break h}g=-87;if((h-97&255)>>>0<26){break h}g=-55;if((h-65&255)>>>0>25){break g}}h=g+h|0;if((h|0)>=(l|0)){break g}rf(k,p,q,0,0,j,i,0,0);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=nqa(j,i,p,q);n=jb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[115189]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[115189]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[115189]=68;break a}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^i)-((a>>>0>b>>>0)+c|0)|0}gb=k+16|0;jb=e;return d}function CV(a,b){var c=0,d=0;a:{b:{c:{d:{if(je(a,13819)){break d}if(je(a,14601)){break d}if(je(a,10889)){break d}if(je(a,11026)){break d}if(!je(a,11476)){break c}}u[b+10>>1]=4;v[b>>2]=9290;break b}e:{f:{if(je(a,14596)){break f}if(je(a,10894)){break f}if(!je(a,13809)){break e}}t[b+12|0]=1;v[b>>2]=5538;u[b+10>>1]=4;return 1}g:{if(!je(a,11511)){if(!je(a,11516)){break g}}u[b+10>>1]=8;v[b>>2]=5302;break b}h:{if(!je(a,12489)){if(!je(a,12494)){break h}}v[b>>2]=14173;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!je(a,33192)){if(!je(a,33197)){break i}}v[b+4>>2]=1;v[b>>2]=13979;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(sd(a,12596,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=5656;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(sd(a,10959,3)){if(sd(a,11083,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=5401;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!sd(a+1|0,11104,3)){t[b+14|0]=1;v[b>>2]=5704;u[b+10>>1]=t[a|0]-48;return 1}c=w[a+2|0]|w[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(w[a+1|0]-48&255)>>>0>9){break k}t[b+14|0]=1;v[b>>2]=5704;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}if(sd(a,10780,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=5565;u[b+10>>1]=t[a+3|0]-48}d=1}return d}function IP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;d=v[b+64>>2];a:{b:{h=v[b+60>>2];e=x[b+68>>1];if(!((h|0)==-1&(e|0)==65535)){c:{if((d|0)==-1){break c}g=f+24|0;d=a+1074312|0;Db(g,d,68);if(Cb(g)){break c}g=f+16|0;Db(g,d,103);if(i=Cb(g),j=0,k=(e|0)!=65535,k?i:j){break c}g=f+8|0;Db(g,d,49);if(i=Cb(g),j=0,k=(e|0)!=65535,k?i:j){break c}d=v[b+64>>2];break b}if((e|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}d=x[b+68>>1];e=a+484360|0;d:{if(tc(Sb(e))>>>0>d>>>0){d=x[b+68>>1];break d}d=x[Sb(e)+28>>1];u[b+68>>1]=d}e:{if(x[b+72>>1]==(d&65535)){break e}d=f+24|0;e=a+1074312|0;Db(d,e,26);if(Cb(d)){break e}d=f+16|0;Db(d,e,68);if(Cb(d)|v[a+480180>>2]==1|!x[a+480188>>1]){break e}d=0;while(1){t[(B(d,872)+b|0)+1457|0]=0;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[b+52>>2]=v[b+60>>2];if(c){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((d|0)!=-1){break b}c=0;break a}v[b+52>>2]=d;u[b+74>>1]=x[b+72>>1];f:{if(!v[b+20>>2]){break f}if(v[a+480180>>2]==32){c=f+24|0;Db(c,a+1074312|0,103);if(Cb(c)){break f}}if(v[a+480180>>2]==2){break f}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[_b(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}gb=f+32|0;return c}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb-2160|0;gb=b;Qb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[22708]=0;b=Q(70,b+96|0,7723)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}g=v[c>>2];d=v[c+12>>2];h=v[c+8>>2];v[b+88>>2]=h;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;c=b;j=b;i=bL(b+32|0);if(i){e=b- -64|0;v[e>>2]=h;v[b+68>>2]=d;d=v[e+4>>2];v[b+24>>2]=v[e>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;d=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=d;d=aL(b+16|0)}else{d=0}v[j+72>>2]=d;v[c+76>>2]=0;c=0;d=2048;while(1){d:{e=kb[f|0](g,(b+112|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}c=wd(b+48|0,zb(b+112|0),c);f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;a=hA(a,b+8|0,i?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[22708]=0;b=Q(70,b+96|0,5190)|0;c=v[22708];v[22708]=0;if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;ca(a|0);break b}gb=b+2160|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Roa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;e=a;g=a+3|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=w[a+3|0];switch(b-14|0){case 0:break j;case 2:case 3:case 4:case 5:break b;case 8:break g;case 6:case 7:break h;case 1:break i;default:break k}}switch(b-31|0){case 2:break e;case 0:break f;default:break b}}c=w[a+5|0];if(!c){c=14;break d}l:{if((c|0)!=15){if((c|0)!=240){break l}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(c>>>0>=16){t[a+5|0]=c|15;break c}t[a+5|0]=c|240;break c}t[a+5|0]=w[a+5|0]^128;break c}c=w[a+5|0];if(c>>>0>=16){t[d+15|0]=c>>>4;t[d+14|0]=15;h=a,i=w[ac(d+15|0,d+14|0)|0]|240,t[h+5|0]=i;break c}t[a+5|0]=c|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}h=a,i=ei(w[a+5|0]<<1),t[h+5|0]=i;break c}b=32;m:{n:{o:{p:{q:{r:{s:{f=w[a+5|0];switch(f>>>4|0){case 12:case 13:break m;case 3:break n;case 5:break o;case 14:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break d}}b=64;break n}b=176;break n}b=224;break n}t[a+5|0]=119;break c}b=48}t[a+5|0]=f&15|b;break c}if(f){break c}}t[e+3|0]=w[c+28832|0];break a}b=w[e+3|0]}if(b>>>0<36){t[e+3|0]=w[b+28832|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;t[a+4|0]=w[a+5|0];g=a+5|0}t[g|0]=0}gb=d+16|0}function NO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{d=a+484360|0;if(tc(Sb(d))>>>0<=b>>>0){break b}if(Oo(Sb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(tc(Sb(d))>>>0<=c>>>0){break a}if(!Oo(Sb(d),b&65535)){continue}break}break a}c=b}if(tc(Sb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1298224|0;c=a+1074992|0;while(1){t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;f=e+8|0;Db(f,d,23);if(Cb(f)){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;if((g|0)!=(c|0)){continue}break}MO(a);c:{if(!(b&65535)){b=a;c=0;while(1){$m((b+B(c,872)|0)+1074992|0,7,b,c&65535,134217728);c=c+1|0;if((c|0)!=256){continue}break}Jo(b+1298224|0,1);v[b+1074456>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;uA(b+1074376|0);u[b+1074450>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}gb=e+16|0}function upa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-32|0;gb=h;v[h+24>>2]=b;b=v[a>>2];m=h,n=Vb(a),v[m>>2]=n;b=ak(h+24|0,h)+b|0;a:{g=UX(c,d);b:{if((g|0)<1){break b}i=v[wb(a)>>2];e=v[a+4>>2];if((g|0)<=(i-e|0)){v[h>>2]=d;i=e-b|0;if((i|0)<(g|0)){v[h>>2]=c;lw(h,i);l=v[h>>2];k=gb-16|0;gb=k;j=Bi(k,a,g-i|0);wb(a);f=gb-16|0;gb=f;v[f>>2]=d;v[f+8>>2]=l;if(Gb(f+8|0,f)){while(1){d=f+8|0;lp(v[j+4>>2],v[d>>2]);Oe(d);v[j+4>>2]=v[j+4>>2]+1;if(Gb(d,f)){continue}break}}gb=f+16|0;$b(j);gb=k+16|0;if((i|0)<1){break b}}k=gb-16|0;gb=k;f=e;j=b;i=a;l=v[a+4>>2];a=(l-(b+g|0)|0)+b|0;g=Bi(k,i,e-a|0);if(a>>>0<e>>>0){e=v[g+4>>2];d=a;while(1){wb(i);lp(e,d);e=e+1|0;v[g+4>>2]=e;d=d+1|0;if(f>>>0>d>>>0){continue}break}}$b(g);yr(j,a,l);gb=k+16|0;Xi(c,v[h>>2],b);break b}e=wb(a);e=Zg(h,qh(a,oc(a)+g|0),b-v[a>>2]|0,e);v[22708]=0;TX(e,c,d);c=v[22708];v[22708]=0;if((c|0)==1){break a}ut(a);c=v[e+4>>2];j=e+4|0;Ck(wb(a),v[a>>2],b,j);wb(a);i=e+8|0;d=i;g=v[a+4>>2];if((g|0)!=(b|0)){f=v[d>>2];while(1){lp(f,b);f=v[d>>2]+1|0;v[d>>2]=f;b=b+1|0;if((g|0)!=(b|0)){continue}break}}xc(a,j);xc(a+4|0,i);xc(wb(a),dc(e));v[e>>2]=v[e+4>>2];tt(a,oc(a));b=c;ae(e)}Gg(b);gb=h+32|0;return}a=P()|0;O()|0;ae(e);S(a|0);L()}function yq(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=Vb(a),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;d=1;if(!Gb(c+8|0,c)){break a}while(1){a=v[c+8>>2];if(!(!ii(a)|v[a+12>>2]==64)){d=4;break a}a=c+8|0;VO(a);if(Gb(a,c)){continue}break}break a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}gb=c+16|0;return d}function p8(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-80|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(Bj(a)){zh(d+72|0);break g}c=d+32|0;oo(c,a);v[22708]=0;c=T(2086,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+72>>2]=c;Yf(d+32|0)}if(Bj(a)){e=a+36|0}else{e=v[d+72>>2]}c=v[a+8>>2];if((c|0)!=-1){break c}c=v[e+4>>2]-24|0;h=jo(e);if(h){break e}break d}g=P()|0;O()|0;Yf(d+32|0);break a}j=A[c>>3];while(1){f=Wl(e,g);if(i+A[f>>3]>b){c=f;break d}i=i+j;g=g+1|0;if((h|0)!=(g|0)){continue}break}}b=b-i;break b}c=Wl(e,c)}e=a+24|0;f=v[e>>2];g=x[c+12>>1];v[22708]=0;R(2087,f|0,g|0);f=v[22708];v[22708]=0;if((f|0)!=1){h:{f=v[e>>2];g=w[a+64|0];c=vL(wV(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22708]=0;h=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=h;h=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=h;h=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=h;Y(2051,d+56|0,f|0,(g?7:1)|0,d+8|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}g=d+56|0;c=IO(g);f=t[c+26|0]&1;h=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];en(g);u[v[e>>2]+1074448>>1]=f;u[v[e>>2]+1074450>>1]=f;v[v[e>>2]+1074428>>2]=h;v[v[e>>2]+1074392>>2]=-2;b=i+b;A[a+16>>3]=b;wl(d+72|0);gb=d+80|0;return+b}}g=P()|0;O()|0;wl(d+72|0)}S(g|0);L()}function jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;t[f+16|0]=44;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=1058;v[f+4>>2]=2;j=a;c=gb+-64|0;gb=c;k=c;a=f;h=v[a>>2]&2?16:10;g=gb-32|0;gb=g;d=Ge(g+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);i=Jb(d);l=Ab(d);m=v[b>>2];v[22708]=0;ha(92,g+8|0,e|0,i+l|0,m|0,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!v[g+12>>2]){break c}e=Ab(d);v[22708]=0;v[g+4>>2]=e;e=yf(g+4|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break b}b=v[g+8>>2];h=Jb(d);v[22708]=0;R(76,d|0,b-h|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,k|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=g+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=c+16|0;Ll(b,c,a);v[22708]=0;U(89,c+32|0,b|0,a|0);b=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(90,c+48|0,c+32|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}v[22708]=0;R(72,j|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;a:{b:{if(!Md(a)){break b}if((b|0)==(c|0)|(fd(a)|0)!=2){break b}if(l=Md(b),m=0,n=(a|0)!=(b|0),n?l:m){break b}if(l=Md(c),m=0,n=(a|0)!=(c|0),n?l:m){break b}if((a|0)==(b|0)){j=v[b+20>>2]}else{j=Rq(v[a>>2],jj(a))}e=j;if((a|0)==(c|0)){f=v[c+20>>2]}else{f=Rq(v[a>>2],jj(a))}if(!(f?e:0)){if((a|0)!=(b|0)){Sq(j)}if((a|0)==(c|0)){break b}Sq(f);break b}c:{if((jj(a)|0)==2){g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){u[g>>1]=x[h>>1];u[e>>1]=x[h+2>>1];h=h+4|0;e=e+2|0;g=g+2|0;i=i-1|0;if(i){continue}break}}break c}if((jj(a)|0)!=1){break c}g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){t[g|0]=w[h|0];t[e|0]=w[h+1|0];h=h+2|0;e=e+1|0;g=g+1|0;i=i-1|0;if(i){continue}break}}}ap(b,a);v[b+20>>2]=j;u[b+34>>1]=x[b+34>>1]&65471;ap(c,a);v[c+20>>2]=f;u[c+34>>1]=x[c+34>>1]&65471;j=d+1298224|0;a=d+1074992|0;while(1){f=v[a+104>>2];if(!((f|0)!=(b|0)&(c|0)!=(f|0))){v[a+88>>2]=v[a+88>>2]&-65}a=a+872|0;if((j|0)!=(a|0)){continue}break}v[22708]=0;_h(b,d,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[22708]=0;_h(c,d,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}g=1}gb=k+16|0;return g|0}a=P()|0;O()|0;S(a|0);L()}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function kZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;t[g+12|0]=0;l=TD(g+16|0,d,g+12|0);h=v[l>>2];v[g+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=g;i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[22708]=0;v[g+8>>2]=f;f=Fb(g+8|0,g+12|0);i=v[22708];v[22708]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[h|0]=i;f=v[g+12>>2]-1|0;v[g+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;gc(l);S(a|0);L()}t[h|0]=e;f=v[g+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[g+12>>2]-1|0}v[m+12>>2]=f;h=h+1|0}if(!i){break a}a=k;b=i;if(f){continue}break}}k=v[l>>2];e=d-f|0;if(e){h=128;i=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+i|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=i+1|0;i=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(B(h,257)&65535)>>>f&255;k=k+1|0;n=n+1|0;if((n|0)!=(e|0)){continue}break}j=0;while(1){d=c;f=d;m=j<<24>>24;b=t[d|0];d=128;e:{if((b|0)==-128){break e}a=b;d=a;if((a|0)>-1){break e}d=0-(b&127)|0}j=m-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}gc(l);gb=g+32|0}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=gb-48|0;gb=j;l=-1;e=gb-32|0;gb=e;f=e+24|0;i=j+8|0;pF(f,i);g=yb(f);f=v[e+28>>2];d=v[e+24>>2];v[e+8>>2]=d;v[e+12>>2]=f;v[e>>2]=d;v[e+4>>2]=f;d=e+16|0;f=a;hd(d,f,e);d=yb(d);if((d|0)==(g|0)){bd(f,yb(e+24|0))}gb=e+32|0;f=(d|0)==(g|0);if(!f){qF(i)}a:{if(!f){break a}l=0;if(!YN(j+8|0)){break a}if(c){e=a;d=j+8|0;b:{if(!c){break b}m=Nf(c);if(!m){break b}q=v[e+12>>2];if(Vl(e,w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24))){c:{if(!(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))){break c}while(1){if(!Wf(e,5)){break c}d:{if((w[d+4|0]|w[d+5|0]<<8)>>>0>=64){f=e;i=bw(e);h=i&63;e:{if(!(i&64)){break e}g=6;while(1){k=bw(f);h=(k&127)<<g|h;if(!(k&128)){break e}k=g>>>0<25;g=g+7|0;if(k){continue}break}}if(((i&128?0-h|0:h)|0)<1){break d}}h=0;g=1;while(1){f=bw(e);if(f){k=Yq(f<<24>>24);o=h>>>0>=m>>>0;i=o&g;f=i;f:{if(o){break f}f=i;if(!(g&1)){break f}f=w[c+h|0]==(k&255)}g=f;h=h+1|0;continue}break}bd(e,4);n=(h|0)==(m|0)?g?1:n:n}p=p+1|0;if(p>>>0<(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))>>>0){continue}break}}h=n&1}Vl(e,q)}if(!h){break a}}l=Ne(a,b,XN(j+8|0),0)}gb=j+48|0;return l|0}function JM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=gb-96|0;gb=c;d=v[b+4>>2];v[c+64>>2]=v[b>>2];v[c+68>>2]=d;b=Td(c+56|0);d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=os(c+72|0,c+8|0,c);v[22708]=0;b=T(467,d|0)|0;e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}v[22708]=0;b=W(1597,d|0,c+16|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}b:{if(!b|v[c+16>>2]!=542066252){break b}b=c+16|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+24|0;f=a,g=Go((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+28|0;f=a,g=Go((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+32|0;f=a,g=Go((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+36|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+40|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+44|0]!=0;t[a+4241|0]=w[c+45|0]!=0;t[a+4242|0]=w[c+46|0]!=0;t[a+4243|0]=w[c+47|0]!=0;t[a+4244|0]=w[c+48|0]!=0;Qt(a)}xb(d);gb=c+96|0;return}a=P()|0;O()|0;xb(d);S(a|0);L()}function M$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Sg(a,v[b+8>>2],e)){cx(b,c,d);return}a:{if(Sg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}d=v[a+12>>2];if((d|0)<=0){v[b+44>>2]=4;break b}i=((d<<3)+a|0)+16|0;f=a+16|0;j=b;c:{d:{while(1){e:{u[b+52>>1]=0;bx(f,b,c,c,1,e);if(w[b+54|0]){break e}f:{if(!w[b+53|0]){break f}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break d}h=1;g=1;if(w[a+8|0]&2){break f}break d}h=1;d=g;if(!(t[a+8|0]&1)){break d}}f=f+8|0;if(i>>>0>f>>>0){continue}}break}d=g;a=4;if(!h){break c}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;Bs(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}Bs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Bs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}Bs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function I2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-160|0;gb=h;v[h+144>>2]=c;v[h+152>>2]=b;v[h+20>>2]=2509;b=ge(h+24|0,h+32|0,h+20|0);v[22708]=0;Fc(h+16|0,e);a=v[22708];v[22708]=0;a:{b:{c:{d:{if((a|0)!=1){v[22708]=0;a=T(21,h+16|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break b}t[h+15|0]=0;e=v[e+4>>2];v[22708]=0;c=ra(2510,h+152|0,c|0,d|0,h+16|0,e|0,f|0,h+15|0,a|0,b|0,h+20|0,h+132|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!c){break c}Se(g);if(!w[h+15|0]){break d}v[22708]=0;c=Q(22,a|0,45)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;R(61,g|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22708]=0;d=Q(22,a|0,48)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}e=v[b>>2];c=v[h+20>>2];e:{if(e>>>0>=c-1>>>0){break e}a=(c+(e^-1)|0)+e|0;d=d&255;while(1){if((d|0)!=w[e|0]){break e}e=e+1|0;if((a|0)!=(e|0)){continue}break}e=a}v[22708]=0;U(2516,g|0,e|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}v[22708]=0;a=Q(2461,h+152|0,h+144|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(a){v[f>>2]=v[f>>2]|2}a=v[h+152>>2];Wb(h+16|0);Hc(b);gb=h+160|0;return a|0}e=P()|0;O()|0;Wb(h+16|0)}Hc(b);S(e|0);L()}function U0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){if(f>>>0>=g>>>0){break b}k=t[c|0];b=k&255;c:{if((k|0)>-1){i=1;break c}k=2;if(b>>>0<194){break a}if(b>>>0<=223){if((d-c|0)<2){break b}i=w[c+1|0];if((i&192)!=128){break a}b=i&63|b<<6&1984;i=2;break c}if(b>>>0<=239){if((d-c|0)<3){break b}j=w[c+2|0];i=w[c+1|0];d:{e:{if((b|0)!=237){if((b|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}b=j&63|(b<<12&61440|(i&63)<<6);i=3;break c}if(b>>>0>244){break a}if((d-c|0)<4){break b}l=w[c+3|0];m=w[c+2|0];j=w[c+1|0];f:{g:{switch(b-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;b=l&63|(m<<6&4032|(b<<18&1835008|(j&63)<<12));if(b>>>0>1114111){break a}}v[f>>2]=b;v[a+12>>2]=c+i;f=v[a+8>>2]+4|0;v[a+8>>2]=f;c=v[a+12>>2];if(d>>>0>c>>>0){continue}break}}k=0;break a}k=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return k|0}function bT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(w[d|0]){e=ne(g+8|0,b);b=Pj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Fb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){td(a,c,mqa(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){sB(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){td(a,c,mqa(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}td(a,c,mqa(e));break b}td(a,c,b)}break a}e=ne(g,b);b=Pj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Fb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){td(a,c,mqa(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){sB(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){td(a,c,mqa(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}td(a,c,mqa(e));break d}td(a,c,b)}}gb=d+16|0;gb=g+16|0}function _g(a,b,c,d){var e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+12>>2]=d;e=b-1|0;f=0;a:{if(e>>>0>249){break a}h=Zl(a);f=v[a+480180>>2];if(!h){if(f&17408){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+39696>>1]<<4>>>a|0;break a}if(!d){v[g+12>>2]=8363;d=8363}if(rk(a)){a=((e&255)>>>0)/12|0;b=nqa(v[(e-B(a,12)<<6&960)+43584>>2]<<a,0,d,0);a=jb;c=a>>>21|0;f=Qc((a&2097151)<<11|b>>>21,c);break a}if(w[a+480208|0]&16){a=e&255;f=x[((a>>>0)%12<<1)+39696>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;qc(g+12|0,-1>>>a|0);f=Qc(qqa(nqa(x[((e-B(a,12)&255)<<1)+39696>>1],0,267616,0),jb,v[g+12>>2]<<a,0),jb);break a}if(f&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Db(g,a+1074312|0,76);b=Cb(g)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;f=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[g>>2]=d+8;Yd(g,0,103);c=b;b=b>>31;c=(c+b^b)&15;b=d+(b|1)|0;b=(b|0)>-8?b:-8;f=B(c,x[(((b|0)<95?b:95)<<1)+40192>>1])+B(x[(v[g>>2]<<1)+40176>>1],16-c|0)<<1>>>a|0;break a}a=c>>>4&15;if(!(!(a|e>>>0<24)&e>>>0<108)){b=B(a,12);a=((e&255)>>>0)/12|0;f=x[(b+(e-B(a,12)&255)<<1)+39296>>1]<<5>>>a|0;break a}f=x[(b<<1)+39070>>1]<<2}gb=g+16|0;return f}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=e;h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=e;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=i+q|0;i=t[e+2|0];m=t[e+1|0];n=t[e|0];o=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];p=nqa(e,e>>31,f,f>>31);e=w+p|0;f=jb+j|0;f=e>>>0<p>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(n,u[e+46162>>1])+B(o,u[e+46160>>1])|0)+B(m,u[e+46164>>1])|0)+B(i,u[e+46166>>1])<<8)/16384<<8;e=i;h=nqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=h+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<1){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if(h>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(h>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=g+32|0}function fda(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-32|0;gb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=kb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[pd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[22708]=0;R(440,d+4|0,b+4|0);b=v[22708];v[22708]=0;c:{if((b|0)!=1){b=v[a+20>>2];v[22708]=0;Ud(c+8|0,b+4|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[c>>2]=0;v[c+4>>2]=0;d=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;v[22708]=0;_(1635,b|0);b=v[22708];v[22708]=0;d:{e:{if((b|0)==1){break e}b=v[v[a>>2]+180>>2];v[22708]=0;R(b|0,a|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=0;if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[22708]=0;f=C(Za(d|0,a|0,b|0));d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;z[c+8>>2]=f;R(1636,c+16|0,c+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+184>>2];v[22708]=0;_(b|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(89104)|0;break c}b=V(89104)|0;break c}b=V(89104)|0;break c}b=V(89104)|0}if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;xr(v[a+20>>2]+4|0);$()}gb=c+32|0;return}S(b|0);L()}function Hd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;v[a+480180>>2]=b;b=yq(a);kA(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;fu(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Yb(pv(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;jA(a,4);e=gb+-64|0;gb=e;b=a+484344|0;CN(b);f=Sf(b);c=mz(e+8|0,b);v[22708]=0;U(1489,b|0,f|0,c|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){Km(c);gb=e- -64|0;break a}a=P()|0;O()|0;Km(c);S(a|0);L()}mS(a+484360|0);Se(a+1298268|0);Se(a+1298280|0);Se(a+1298292|0);c=a+1298304|0;d=Qb(d,0,64);b=$O(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];ku(b);sD(a+1298368|0);Fg(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}gb=d- -64|0}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;i=g;c=gb-160|0;gb=c;e=c+24|0;h=hu(e+56|0);v[e>>2]=78016;v[h>>2]=78036;v[22708]=0;f=e+4|0;W(95,e|0,78048,f|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)!=1){b:{v[e>>2]=78016;v[h>>2]=78036;v[22708]=0;Q(96,f|0,16)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}break a}}a=P()|0;O()|0;oh(h);S(a|0);L()}h=v[v[e>>2]-12>>2];v[22708]=0;f=ga(79)|0;d=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{if((d|0)==1){break h}v[22708]=0;U(80,c+16|0,h+(c+24|0)|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}Wb(c+16|0);v[22708]=0;f=Gg(17);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;v[c>>2]=f;f=mP(e,c);d=v[22708];v[22708]=0;if((d|0)==1){break g}j=A[b>>3];v[22708]=0;_a(83,f|0,+j)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;R(84,c|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;R(77,i|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c);Bq(e);gb=c+160|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(c)}Bq(e);S(a|0);L()}v[22708]=0;R(72,a|0,g|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(g);gb=g+16|0;return}a=P()|0;O()|0;vb(g);S(a|0);L()}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;i=u[f>>1];m=u[f-2>>1];n=u[f+2>>1];r=u[f+4>>1];p=v[a+60>>2];f=Lb(b,-16777216,16776704);o=v[a+64>>2];g=Lb(e,-16777216,16776704);e=nqa(o,o>>31,f,f>>31);o=jb;f=e;e=j>>>21&2040;j=(((B(i,u[e+46162>>1])+B(m,u[e+46160>>1])|0)+B(n,u[e+46164>>1])|0)+B(r,u[e+46166>>1])|0)/16384<<8;e=j;i=nqa(p,p>>31,e,e>>31);f=f+i|0;e=jb+o|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=nqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);k=g+k|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,m);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=gb-32|0;gb=e;a:{b:{c:{g=v[a+12>>2];f=v[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<1){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if(f>>>0>2147483647&(g|0)>=-2|(g|0)>-2){break d}break b}if(f>>>0>2147483648&(g|0)>=1|(g|0)>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;gb=e+32|0}function Ena(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(qv(c)>>>0>d>>>0){g=yW(c,d);h=gb-16|0;gb=h;c=a;t[c+12|0]=0;Fg(c);f=gb-32|0;gb=f;a:{b:{d=c;if(pe(d)>>>0<=14){e=wb(d);e=zp(f+8|0,15,Nb(d),e);v[22708]=0;R(300,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}hj(e)}gb=f+32|0;break a}a=P()|0;O()|0;hj(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=pr(h+8|0,f&65535,w[ac(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[wb(d)>>2]){rW(d,j);break d}k=gb-32|0;gb=k;e=d;l=wb(d);d=zp(k+8|0,fh(d,Nb(d)+1|0),Nb(d),l);m=v[d+8>>2];v[22708]=0;hn(l,m,j);j=v[22708];v[22708]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[22708]=0;R(300,e|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break f}hj(d);gb=k+32|0;break e}a=P()|0;O()|0;hj(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}gb=h+16|0}g:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break g}b=cd(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c}function eK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Kf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(Jf(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=ee(A[Wg(a,h,k)>>3]*134217728);c=Mb(b,h);m=c;c=_m(f)+(v[c>>2]>>1)|0;n=c;c=yt(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=fo(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=d- -64|0}function ZJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Kf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(Jf(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=ee(A[Wg(a,h,k)>>3]*134217728);c=Mb(b,h);m=c;c=_m(f)+(v[c>>2]>>1)|0;n=c;c=yt(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=eo(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=d- -64|0}function Om(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;d=e+8|0;f=a+1074312|0;Db(d,f,96);d=Cb(d);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&v[a+480180>>2]==16384)|0;b:{if(ce(b+788|0)){d=v[b+656>>2];if(d){d=x[vd(d+236|0,w[b+788|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if((!(w[b+88|0]&2)|y[b+84>>2]>c>>>0)&y[b+76>>2]>c>>>0){break b}c=e+8|0;Db(c,f,57);if(!(!Cb(c)&v[a+480180>>2]!=16)){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){c=e+8|0;Db(c,f,27);if(Cb(c)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}gb=e+16|0}function Ou(a,b){var c=0,d=0,e=0,f=0;f=gb-48|0;gb=f;e=f+24|0;sT(e,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);sT(f,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=1;a=v[e>>2];d=Ib(w[a|0]|w[a+1|0]<<8);a=f;c=v[a>>2];a:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=0;c=v[a>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=1;c=v[e+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+4>>2];b:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=0;c=v[a+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+4>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=1;c=v[e+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+8>>2];c:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=0;c=v[a+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+8>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=1;c=v[e+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[a+12>>2];d:{if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=0;c=v[a+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[e+12>>2];if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=v[e+16>>2];c=Ib(w[b|0]|w[b+1|0]<<8);b=v[a+16>>2];b=c>>>0<Ib(w[b|0]|w[b+1|0]<<8)>>>0;if(!b){a=v[a+16>>2];Ib(w[a|0]|w[a+1|0]<<8);a=v[e+16>>2];Ib(w[a|0]|w[a+1|0]<<8)}}}}}gb=f+48|0;return b}function oo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;g=dd(a);e=b+24|0;a:{b:{if(Ri(v[e>>2]+484360|0)){if(Ri(v[e>>2]+484360|0)){b=0;while(1){f=v[e>>2];a=vL(xV(c+40|0,1),b&255,0,0);v[22708]=0;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;Y(2051,c- -64|0,f|0,0,c|0);a=v[22708];v[22708]=0;c:{d:{if((a|0)!=1){a=c- -64|0;i=c,j=Vb(a),v[i+32>>2]=j;i=c,j=Zb(a),v[i+24>>2]=j;if(Gb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{a=v[c+32>>2];h=A[a>>3];f=v[a+16>>2];d=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=d;v[a+8>>2]=f;A[a>>3]=h;v[22708]=0;R(2052,g|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}a=c+32|0;v[a>>2]=v[a>>2]+32;if(Gb(a,c+24|0)){continue}break c}break}a=P()|0;O()|0;en(c- -64|0);break b}en(c- -64|0);b=b+1|0;if(Ri(v[e>>2]+484360|0)>>>0>b>>>0){continue}break}}gb=c+80|0;return}b=ba(8)|0;v[22708]=0;c=Q(70,c+40|0,4354)|0;a=v[22708];v[22708]=0;if((a|0)!=1){rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;ca(b|0)}Yf(g);S(a|0)}L()}function wI(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=md(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;g=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=md(a)}b=c-48|0;if(!(g|b>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(b>>>0<10){while(1){d=(B(d,10)+c|0)-48|0;e=(d|0)<214748364;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=md(a)}b=c-48|0;if(e&b>>>0<=9){continue}break}e=d;d=d>>31;h:{if(b>>>0>=10){break h}while(1){e=nqa(e,d,10,0);c=e+c|0;b=jb;b=c>>>0<e>>>0?b+1|0:b;e=c-48|0;d=b-(c>>>0<48)|0;b=v[a+4>>2];i:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break i}c=md(a)}b=c-48|0;if(b>>>0>9){break h}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];j:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break j}b=md(a)}if(b-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;jb=-2147483648;return 0}jb=d;return e}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(y[a+4>>2]<y[wb(a)>>2]){h=gb-16|0;gb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+28;a=wb(a);d=v[c+4>>2];v[22708]=0;yu(a,d,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+28;$b(c);gb=h+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}return}i=gb-32|0;gb=i;h=a;j=wb(a);e=i+8|0;c=$i(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=c;d=c;c=gb-16|0;gb=c;g=a;wb(a);v[c+12>>2]=153391689;v[22708]=0;v[c+8>>2]=2147483647;k=Fb(c+12|0,c+8|0);l=v[22708];v[22708]=0;b:{if((l|0)!=1){gb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=aj(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break c}Sc();L()}g=$i(a);a=0;d=gb-16|0;gb=d;v[d+12>>2]=0;Bh(e+12|0,j);if(c){a=c;if(a>>>0>153391689){rd(8445);L()}a=Nc(B(a,28),4)}v[e>>2]=a;g=B(g,28)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=dc(e),n=B(c,28)+a|0,v[m>>2]=n;gb=d+16|0;a=v[e+8>>2];v[22708]=0;yu(j,a,b);a=v[22708];v[22708]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+28;v[22708]=0;RQ(h,e);a=v[22708];v[22708]=0;if((a|0)==1){break e}QQ(e);gb=i+32|0;break d}a=P()|0;O()|0;QQ(e);S(a|0);L()}}function Rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;ud(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Ah(Dk(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[ac(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+46144|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[ac(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=e+16|0}function Jpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-2608|0;gb=f;d=f;nD(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22708]=0;_(490,d|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((a|0)!=1){if(!(u[d+1068>>1]<0|u[d+1070>>1]<0)){if(!c){break d}while(1){v[22708]=0;j=Q(200,d|0,1)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}a=0;while(1){v[22708]=0;k=Q(200,d|0,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}a=u[(B(a,6)+d|0)+(k?1070:1068)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break h}if(u[e+1070>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}v[22708]=0;a=nn(d);b=v[22708];v[22708]=0;if((b|0)!=1){break c}}a=V(27364)|0;break e}a=V(27364)|0;break e}a=V(27364)|0}if((O()|0)!=(ea(27364)|0)){break a}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}v[22708]=0;a=nn(d);b=v[22708];v[22708]=0;if((b|0)!=1){break c}a=P()|0;O()|0;break a}xb(d);gb=f+2608|0;return a|0}a=P()|0;O()|0}xb(d);S(a|0);L()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[f+8>>2],u[(i<<1)+g>>1]/4<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Jd(b,u[g+(v[e+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function nka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=gb-48|0;gb=k;if(Te(b)>>>0>c>>>0){while(1){f=l&65535;if(ii(bf(b,f))){n=k+24|0;r=n;e=Vb(bf(b,f));f=Zb(bf(b,f));o=lT(k,d);p=o;h=gb-16|0;gb=h;v[h>>2]=f;v[h+8>>2]=e;if(Gb(h+8|0,h)){while(1){f=p;j=gb-16|0;gb=j;m=h+8|0;e=v[m>>2];if(!(w[e+3|0]!=4|w[e+5|0])){g=j+8|0;Ce(g,f,x[f+14>>1]);Uf(g,0);t[e+3|0]=0}g=w[e+2|0];if(!(w[e+4|0]|(g|0)!=11)){i=j+8|0;Ce(i,f,x[f+14>>1]);Uf(i,0);t[e+2|0]=0;g=0}a:{b:{c:{if(!w[e|0]){g=j+8|0;Ce(g,f,x[f+14>>1]);if(Cb(g)){break c}g=w[e+2|0]}i=w[e+3|0];q=j+8|0;Ce(q,f,x[f+14>>1]);Uf(q,(i|0)==4|(g|0)==11);g=w[e+3|0];break b}g=w[e+3|0];i=w[e+2|0];if(!(g|(i|0)==11)){t[e+5|0]=0;t[e+3|0]=4;break a}if(i|(g|0)==4){break b}t[e+4|0]=0;t[e+2|0]=11}d:{if(!(!w[f+16|0]|g)){t[e+5|0]=125;t[e+3|0]=17;break d}e:{switch(g-16|0){case 1:break d;case 0:break e;default:break a}}if(w[e+5|0]){break a}t[e+5|0]=6;t[f+16|0]=1;break a}t[f+16|0]=0}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];gb=j+16|0;$j(m);if(Gb(m,h)){continue}break}}jT(r,p);gb=h+16|0;Ye(n);Ye(o)}l=l+1|0;if((l&65535)>>>0<=c>>>0){continue}break}}jT(a,d);gb=k+48|0}function YN(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}d=a+16|0;b=d;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}e=a+24|0;b=e;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}f=a+32|0;b=f;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}c=a+12|0;b=c;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=c;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>858993459){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>536870911){break a}a=a+28|0;g=w[a+1|0]<<8;h=w[a+2|0]<<16|w[a+3|0]<<24;if(!(w[a|0]|g|h)|(h|(g|w[a|0]))>>>0>1073741823|B(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24),-5)-1>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<<3^-1)>>>0){break a}i=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))<<2^-1)>>>0}return i}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;if(!w[a+4242|0]){dz(a);a:{if(!w[a+4240|0]){break a}e=OO(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Pt(a)}f=a+4256|0;b:{if(w[a+4244|0]){g=f;if(A[f>>3]>1){v[g>>2]=0;v[g+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<1)){bz(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=si(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];WP(h+8|0,1);f=nk(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){k=f,l=g>>>8&15|176|(g&127)<<8|gn(A[h+8>>3]*127)<<16,j=v[v[f>>2]+68>>2],kb[j](k|0,l|0)|0;break f}kb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}g=a;a=a+44|0;Gi(g,b,c,Nd(a,0),Nd(a,1),d);gb=h+16|0}function iv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;t[e+16|0]=44;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=1058;v[e+4>>2]=2;i=a;c=gb+-64|0;gb=c;j=c;a=e;h=v[a>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){eO(f+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Ab(d);v[22708]=0;v[f+4>>2]=g;g=yf(f+4|0);k=v[22708];v[22708]=0;if((k|0)!=1){v[22708]=0;U(75,d|0,g|0,0);g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}b=v[f+8>>2];h=Jb(d);v[22708]=0;R(76,d|0,b-h|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){v[22708]=0;R(77,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=f+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}b=c+16|0;Ll(b,c,a);v[22708]=0;U(89,c+32|0,b|0,a|0);b=v[22708];v[22708]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22708]=0;U(90,c+48|0,c+32|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;R(72,i|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=e+32|0}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;o=k,p=Zb(a),v[o>>2]=p;d=v[Gd(k+8|0,k)>>2];h=gb-32|0;gb=h;v[h+24>>2]=d;d=v[a>>2];o=h,p=Vb(a),v[o>>2]=p;d=d+(rp(h+24|0,h)<<1)|0;a:{b:{f=_q(b,c);c:{if((f|0)<1){break c}i=v[wb(a)>>2];e=v[a+4>>2];if((f|0)<=i-e>>1){j=e-d|0;i=j>>1;d:{if((i|0)>=(f|0)){g=c;break d}v[h>>2]=b;jS(h,i);g=v[h>>2];cS(a,g,c,f-i|0);if((j|0)<1){break c}}m=gb-16|0;gb=m;i=e;j=d;l=a;n=v[a+4>>2];a=(n-((f<<1)+d|0)|0)+d|0;f=mi(m,l,e-a>>1);if(a>>>0<e>>>0){e=v[f+4>>2];c=a;while(1){wb(l);So(e,c);e=e+2|0;v[f+4>>2]=e;c=c+2|0;if(i>>>0>c>>>0){continue}break}}$b(f);yr(j,a,n);gb=m+16|0;Ln(b,g,d);break c}g=wb(a);e=Fn(h,Uk(a,tc(a)+f|0),d-v[a>>2]>>1,g);v[22708]=0;YQ(e,b,c);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=a;Ep(a);c=e;i=v[c+4>>2];g=d;l=c+4|0;Ck(wb(a),v[a>>2],d,l);wb(a);f=c+8|0;j=f;d=v[a+4>>2];if((g|0)!=(d|0)){a=v[j>>2];while(1){So(a,g);a=v[j>>2]+2|0;v[j>>2]=a;g=g+2|0;if((d|0)!=(g|0)){continue}break}}xc(b,l);xc(b+4|0,f);xc(wb(b),dc(c));v[c>>2]=v[c+4>>2];_r(b,tc(b));d=i;Hh(e)}Gg(d);gb=h+32|0;break a}a=P()|0;O()|0;Hh(e);S(a|0);L()}gb=k+16|0}function bda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;g=dd(a);v[22708]=0;_(1649,g|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=50400;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=wg(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22708]=0;f=Q(70,c+32|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break k}v[22708]=0;R(1650,c+48|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22708]=0;e=Q(70,c|0,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break i}v[22708]=0;R(1650,c+16|0,e|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}v[22708]=0;da(1651,d|0,h|0,c+48|0,c+16|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break g}Hb(c+16|0);vb(e);Hb(c+48|0);vb(f);v[c+60>>2]=d;v[22708]=0;R(1652,g|0,c+60|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=50712){continue}break}gb=c- -64|0;return a|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Hb(c+16|0)}vb(e)}Hb(c+48|0)}vb(f)}Yb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Gl(g);S(b|0);L()}
function hc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){$a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Vf(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>11>>>0){c=gb-16|0;gb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){wb(g);v[22708]=0;cz(a);e=v[22708];v[22708]=0;if((e|0)==1){break d}a=a+2048|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}h=wb(a);i=f+8|0;b=Vf(a)+e|0;d=gb-16|0;gb=d;v[d+12>>2]=b;c=b;b=gb-16|0;gb=b;g=a;wb(a);v[b+12>>2]=2097151;v[22708]=0;v[b+8>>2]=2147483647;j=Fb(b+12|0,b+8|0);k=v[22708];v[22708]=0;e:{if((k|0)!=1){gb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=Cl(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Mc(d+8|0,d+12|0)>>2]}gb=d+16|0;break f}Sc();L()}b=QM(i,b,Vf(a),h);v[22708]=0;R(1543,b|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(1539,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Rt(b)}gb=f+32|0;break a}a=P()|0;O()|0;Rt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;Vf(a);PM(a,b);RM(a)}}function Jka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-16|0;gb=i;ud(d,32);g=i+8|0;LT(g,a+20|0,b);p=g;g=fc(g);LT(i,a+36|0,c);q=i;a=0;g=v[g>>2];if(g-1>>>0<=838859){a=v[fc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;l=Pl(d);if(l){k=g<<2;e=+(k>>>0);r=+(a>>>0)/e;s=+(g>>>0)/e;z=1/+y[d>>2];g=0;while(1){m=+(g>>>0);a=v[p>>2];n=0;o=0;if(Md(b)){e=s*m+ +(a>>>0);a:{if(e<4294967296&e>=0){a=~~e>>>0;break a}a=0}f=fd(b);h=B(a,f);e=e-+(a>>>0);b:{if(t[b+34|0]&1){j=v[b+20>>2];a=x[j+(h<<1)>>1];f=u[j+(f+h<<1)>>1];break b}a=v[b+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}o=(1-e)*+(a<<16>>16)+e*+(f<<16>>16)}a=v[q>>2];if(Md(c)){e=r*m+ +(a>>>0);c:{if(e<4294967296&e>=0){a=~~e>>>0;break c}a=0}f=fd(c);h=B(a,f);e=e-+(a>>>0);d:{if(t[c+34|0]&1){j=v[c+20>>2];a=x[j+(h<<1)>>1];f=u[j+(f+h<<1)>>1];break d}a=v[c+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}n=(1-e)*+(a<<16>>16)+e*+(f<<16>>16)}f=0;a=g;while(1){e=z*+(a>>>0);h=KT(n*e+o*(1-e));u[v[d+20>>2]+(a<<1)>>1]=h;a=a+k|0;f=f+1|0;if((f|0)!=80){continue}break}g=g+1|0;if((k|0)!=(g|0)){continue}break}}a=(l|0)!=0}gb=i+16|0;return a|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!ni(i)){break a}k=Nd(i,0);l=Nd(i,1);m=od(i,0);n=od(i,1);if(d){j=a+4256|0;e=v[a+4268>>2];o=d;while(1){f=z[l>>2];g=z[k>>2];s=Mb(j,e<<1),t=g,z[s>>2]=t;s=Mb(j,v[a+4268>>2]<<1|1),t=f,z[s>>2]=t;f=C(C(D(kM(C(C(C(D(g))+C(D(f)))*C(536870912)),31,5)))*C(4.656612873077393e-10));g=z[a+4276>>2];f=C(f+C(C(g-f)*z[(f>=g?4236:4240)+a>>2]));z[a+4276>>2]=f;p=z[a+4232>>2];g=z[a+4244>>2];f=C(C(C(z[a+4248>>2]*C(g-(f<g?g:f)))+C(.9999998807907104))*C(2147483648));b:{if(f<C(4294967296)&f>=C(0)){e=~~f>>>0;break b}e=0}h=e<<5;q=h;r=h|-2147483648;h=e>>>0<67108864;f=C(p*C(C((h?q:r)>>>(h?31:32-(e>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));e=v[a+4272>>2];e=(((e+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;s=m,t=C(z[Mb(j,e)>>2]*f),z[s>>2]=t;s=n,t=C(z[Mb(j,e|1)>>2]*f),z[s>>2]=t;h=v[a+4268>>2];e=h-1|0;v[a+4268>>2]=e;if(!h){e=v[a+4272>>2]+e|0;v[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}Gi(a,b,c,od(i,0),od(i,1),d)}}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[f+8>>2],t[g+i|0]<<6);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Jd(b,t[g+v[e+44>>2]|0]<<6);Id(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function TT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=dh(a);if(c>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=v[wb(a)>>2]-v[a+4>>2]>>8>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(i<<8);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){BB(a);a=a+256|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}k=wb(a);e=j+8|0;d=a;b=dh(a)+i|0;f=gb-16|0;gb=f;v[f+12>>2]=b;g=gb-16|0;gb=g;v[g+12>>2]=16777215;v[22708]=0;v[g+8>>2]=2147483647;h=Fb(g+12|0,g+8|0);c=v[22708];v[22708]=0;d:{if((c|0)!=1){gb=g+16|0;c=v[h>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0<=c>>>0){b=FB(d);if(b>>>0<c>>>1>>>0){v[f+8>>2]=b<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break e}Sc();L()}d=dh(a);b=0;h=gb-16|0;gb=h;v[h+12>>2]=0;jf(e+12|0,k);if(c){b=c;if(b>>>0>=16777216){rd(8445);L()}b=Nc(b<<8,1)}v[e>>2]=b;d=(d<<8)+b|0;v[e+8>>2]=d;v[e+4>>2]=d;l=dc(e),m=(c<<8)+b|0,v[l>>2]=m;gb=h+16|0;v[22708]=0;wT(e,i);b=v[22708];v[22708]=0;if((b|0)==1){break b}Yk(a,e);vT(e)}gb=j+32|0;break a}a=P()|0;O()|0;vT(e);S(a|0);L()}return}if(b>>>0<c>>>0){Zk(a,v[a>>2]+(b<<8)|0)}}function r7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Kf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(Jf(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(_m(ee(A[Wg(g,b,i)>>3]*134217728))+id(xt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[bh(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=eo(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=c- -64|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Kf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(Jf(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(_m(ee(A[Wg(g,b,i)>>3]*134217728))+id(xt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[bh(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=fo(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=c- -64|0}function PZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-32|0;gb=h;d=b;e=tc(d);f=c;a:{if(e>>>0<f>>>0){l=gb-32|0;gb=l;b:{c:{i=f-e|0;d:{if(i>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){e=gb-16|0;gb=e;e:{f=mi(e,d,i);g=v[f+4>>2];i=v[f+8>>2];if((g|0)!=(i|0)){while(1){wb(d);v[22708]=0;Ok(g);j=v[22708];v[22708]=0;if((j|0)==1){break e}g=g+2|0;v[f+4>>2]=g;if((g|0)!=(i|0)){continue}break}}$b(f);gb=e+16|0;break d}a=P()|0;O()|0;$b(f);S(a|0);L()}k=wb(d);f=Uk(d,tc(d)+i|0);m=tc(d);j=gb-16|0;gb=j;v[j+12>>2]=0;e=l+8|0;Bh(e+12|0,k);if(f){g=f;if(f>>>0>2147483647){rd(8445);L()}g=Nc(g<<1,1)}v[e>>2]=g;k=(m<<1)+g|0;v[e+8>>2]=k;v[e+4>>2]=k;n=dc(e),o=(f<<1)+g|0,v[n>>2]=o;gb=j+16|0;v[22708]=0;R(345,e|0,i|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}v[22708]=0;R(346,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}hE(e)}gb=l+32|0;break b}a=P()|0;O()|0;hE(e);S(a|0);L()}break a}if(e>>>0>f>>>0){yn(d,v[d>>2]+(f<<1)|0)}}c=Pb(a,c<<1);if(c){d=gb-16|0;gb=d;bc(h+24|0,v[b>>2],tc(b)<<1);gb=d+16|0;b=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=b;kd(h+16|0,a,h+8|0)}gb=h+32|0;return c|0}function vK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;v[a+4>>2]=c;v[a>>2]=b;b=(c>>>0)/48|0;g=((B(b,48)|0)!=(c|0))+b|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;j=b>>>0<64;e=a;h=a;d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}f=j?0:0;v[h+24>>2]=f;h=e;e=j?d&65536:0;v[h+28>>2]=e;a:{b:{d=f;j=0-d|0;f=qqa(d,e,g,0);e=65536-(e+((d|0)!=0)|0)|0;d=jb;if((e|0)==(d|0)&f>>>0<j>>>0|d>>>0<e>>>0){g=g+1|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;if(b>>>0>63){break b}d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}v[a+24>>2]=0;v[a+28>>2]=d&65536}v[a+16>>2]=g-((c>>>0)%(g>>>0)|0);if(b>>>0>62){break a}i=1;c=b+1|0;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}k=d&65536;break a}v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=(B(b,g)-c|0)+g}v[a+32>>2]=l;v[a+36>>2]=k;c=a;h=a;d=63-b|0;e=d&31;if((d&63)>>>0>=32){d=0;e=-1>>>e|0}else{f=-1>>>e|0;d=f;e=d|(1<<e)-1<<32-e}v[h+48>>2]=i?e:-1;v[c+52>>2]=i?d:-1;i=b;f=a;b=64-b|0;d=b&31;if((b&63)>>>0>=32){b=0;d=-1>>>d|0}else{e=-1>>>d|0;b=e;d=b|(1<<d)-1<<32-d}v[f+40>>2]=i?d:0;v[c+44>>2]=i?b:0;return a}function $m(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;if(b&2){t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;g=f+8|0;Db(g,c+1074312|0,23);if(Cb(g)){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&240;$o(a+788|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&207}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0}gb=f+16|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=f+32|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+q|0;m=t[e+1|0];e=t[e|0];g=v[a+60>>2];n=g;o=g>>31;g=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);g=nqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=nqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=((B(m-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=nqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function bJ(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){rl(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=Cm(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}ec(a,21);return 0}k=B(d,l);m=(k+(j+m|0)|0)>(p|0)?(j+p|0)-k|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(n+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=n+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}ec(a,21);return 0}aa(4596,10534,1887,3608);L()}function nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+q|0;m=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];n=g;o=g>>31;g=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);g=nqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=nqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=e+((B(m-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=nqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Tt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22708]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22708]=0;v[f+4>>2]=e;e=yf(f+4|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(93,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(94,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(85,i|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Nw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);b:{c:{d:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22708]=0;ha(92,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!v[f+12>>2]){break d}e=Ab(d);v[22708]=0;v[f+4>>2]=e;e=yf(f+4|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break c}b=v[f+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d);gb=f+32|0;break b}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(93,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(94,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(85,i|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break a}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function LV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22708]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22708]=0;v[f+4>>2]=e;e=yf(f+4|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(89,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(90,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(72,i|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(aF(b)){j=b>>>0>4?b:4;b=a?a:1;a:{b:{while(1){h=gb-16|0;gb=h;v[h+12>>2]=0;e=b;c:{d:{a=j;if((a|0)!=8){if(a&3|a>>>0<4){break c}c=a>>>2|0;if(c-1&c|e>>>0>-64-a>>>0){break c}c=16;d=a>>>0>16?a:16;e:{if(!(d-1&d)){a=d;break e}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}if(e>>>0>=-64-a>>>0){v[115189]=48;break c}i=e>>>0<11?16:e+11&-8;f=Cd((i+a|0)+12|0);if(!f){break c}c=f-8|0;f:{if(!(f&a-1)){a=c;break f}e=f-4|0;d=v[e>>2];g=a;a=((a+f|0)-1&0-a)-8|0;a=(a-c>>>0>15?0:g)+a|0;g=a-c|0;f=(d&-8)-g|0;if(!(d&3)){c=v[c>>2];v[a+4>>2]=f;v[a>>2]=c+g;break f}v[a+4>>2]=f|v[a+4>>2]&1|2;d=a+f|0;v[d+4>>2]=v[d+4>>2]|1;v[e>>2]=g|v[e>>2]&1|2;d=c+g|0;v[d+4>>2]=v[d+4>>2]|1;As(c,g)}d=v[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=i+16>>>0){break g}v[a+4>>2]=i|d&1|2;e=a+i|0;d=c-i|0;v[e+4>>2]=d|3;c=a+c|0;v[c+4>>2]=v[c+4>>2]|1;As(e,d)}a=a+8|0;break d}a=Cd(e);if(a){break d}break c}v[h+12>>2]=a}gb=h+16|0;a=v[h+12>>2];if(!a){a=v[116502];if(!a){break b}kb[a|0]();continue}break}break a}a=ba(4)|0;nm(a);ia(a|0,89104,1930);L()}return a}return tf(a)}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<1){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if(h>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(h>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;gb=g+16|0}function kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=Vb(a),v[m>>2]=n;b=b+(rp(f+24|0,f)<<1)|0;d=v[a+4>>2];a:{b:{if(d>>>0<y[wb(a)>>2]){if((b|0)!=(d|0)){break b}d=gb-16|0;gb=d;a=mi(d,a,1);Er(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;$b(a);gb=d+16|0;break a}d=wb(a);e=AD(f,NY(a,tc(a)+1|0),b-v[a>>2]>>1,d);v[22708]=0;R(447,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=v[e+4>>2];j=e+4|0;ol(v[a>>2],b,j);h=e+8|0;i=h;g=v[a+4>>2];if((g|0)!=(b|0)){d=v[i>>2];while(1){Er(d,b);d=v[i>>2]+2|0;v[i>>2]=d;b=b+2|0;if((g|0)!=(b|0)){continue}break}}wc(a,j);wc(a+4|0,h);wc(wb(a),dc(e));v[e>>2]=v[e+4>>2];b=c;qp(e);break a}a=P()|0;O()|0;qp(e);S(a|0);L()}l=gb-16|0;gb=l;j=d;k=v[a+4>>2];i=b;e=b+(k-(b+2|0)|0)|0;h=mi(l,a,d-e>>1);if(d>>>0>e>>>0){g=v[h+4>>2];d=e;while(1){Er(g,d);g=g+2|0;v[h+4>>2]=g;d=d+2|0;if(j>>>0>d>>>0){continue}break}}$b(h);if((e|0)!=(i|0)){while(1){k=k-2|0;e=e-2|0;DY(k,e);if((e|0)!=(i|0)){continue}break}}gb=l+16|0;a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}Gg(b);gb=f+32|0}function JV(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!lf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!lf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!lf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!lf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!lf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}gb=f+16|0}function rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-432|0;gb=e;vc(b);xC(b,e+376|0,e+296|0,e+8|0);d=e;f=e+408|0;if(Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){f=w[e+427|0]+1|0}else{f=1}n=d,o=ei(f),t[n+4|0]=o;h=w[ac(29024,e+4|0)|0];t[e+7|0]=h;u[e+4>>1]=4;a:{b:{if(!h){break b}f=e+392|0;k=e+291|0;while(1){d=e+8|0;d=Ib(w[d|0]|w[d+1|0]<<8);c:{d:{if(w[k|0]>63){break d}d=d<<16>>16;if((d|0)<0){break d}if(d){l=d&65535;g=0;while(1){d=f;e:{if(!Wc(b,Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(g<<2)|0)){break e}if(!Wc(b,Jr(b))){break e}d=e;f:{if(!c){j=Ae(b);break f}j=Lr(b)}u[d+2>>1]=j;n=e,o=x[Ke(e+4|0,e+2|0)>>1],u[n+4>>1]=o}g=g+1|0;if((l|0)!=(g|0)){continue}break}}d=e+296|0;if(Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>m>>>0){d=e+296|0;if(Wc(b,Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break c}}t[e+7|0]=i+1;break b}Wr(a);break a}d=e+296|0;m=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));xC(b,e+376|0,d,e+8|0);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}vC(a,e+4|0,e+7|0)}gb=e+432|0}function ID(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((w[a|0]-1&255)>>>0>14){break a}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<-1){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){b:{h=0;f=B(d,13)+a|0;if(w[f+14|0]){break b}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}c=e+422|0;if(w[f+942|0]|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048575){break b}b=B(d,11)+a|0;f=b+1346|0;if(w[f|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break b}c:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break c}b=e+430|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>1048574){break c}if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break b}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break b}}h=1;b=1;d:{if(g){break d}e:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break e}if(sd(f,28493,11)){break e}b=0;break d}b=1}g=b;d=d+1|0;if((d|0)!=32){continue}}break}g=g&h}return g}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=C(0);h=a+44|0;g=Nd(h,0);k=Nd(h,1);m=od(h,0);n=od(h,1);p=B(w[a+4233|0],v[v[a+16>>2]+1074404>>2]);e=p<<1;i=a+4208|0;if(Nb(i)>>>0<e>>>0){Dl(i,e)}j=BM(a);a:{if(j){if(!d){break a}e=v[a+4220>>2];x=j-1|0;j=0;while(1){if(e>>>0>=p>>>0){v[a+4220>>2]=0;e=0}s=z[k>>2];t=z[g>>2];o=e;e=e-p|0;e=((e|0)<0?o:e)<<1;u=z[Mb(i,e)>>2];f=z[Mb(i,e|1)>>2];q=C(t+u);z[m>>2]=q;r=C(s+f);z[n>>2]=r;f=C(0);l=C(0);b:{c:{switch(x|0){case 0:f=z[a+4224>>2];l=C(r*f);f=C(q*f);break b;case 1:case 2:f=z[a+4224>>2];l=C(q*f);f=C(r*f);break b;case 3:break c;default:break b}}f=C(C(u+C(C(t+s)*C(.5)))*z[a+4224>>2]);l=f}n=n+4|0;m=m+4|0;k=k+4|0;g=g+4|0;y=Mb(i,v[a+4220>>2]<<1),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Mb(i,v[a+4220>>2]<<1|1),A=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[y>>2]=A;e=v[a+4220>>2]+1|0;v[a+4220>>2]=e;j=j+1|0;if((j|0)!=(d|0)){continue}break}break a}o=g;g=d<<2;AM(o,o+g|0,m);AM(k,g+k|0,n)}Gi(a,b,c,od(h,0),od(h,1),d)}function hpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;ud(b,32);e=a+4|0;h=b,i=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;e=b;if(c?d:1){c=a+46|0;c=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!Ib(w[d|0]|w[d+1|0]<<8)){break a}if((Ib(w[d|0]|w[d+1|0]<<8)|0)==48){break a}c=(c-(Ib(w[d|0]|w[d+1|0]<<8)<<7)|0)+6144|0}Po(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[ac(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}gb=f+16|0}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<1){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if(g>>>0>2147483647&(e|0)>=-2|(e|0)>-2){break d}break b}if(g>>>0>2147483648&(e|0)>=1|(e|0)>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;gb=f+16|0}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=Sf(a);if(e>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{d=b-e|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/52>>>0){lz(a,d,c);break c}f=wb(a);g=zN(a,Sf(a)+d|0);i=Sf(a);e=0;h=gb-16|0;gb=h;v[h+12>>2]=0;b=j+8|0;jf(b+12|0,f);if(g){e=vN(g)}v[b>>2]=e;f=B(i,52)+e|0;v[b+8>>2]=f;v[b+4>>2]=f;l=dc(b),m=B(g,52)+e|0,v[l>>2]=m;gb=h+16|0;v[22708]=0;U(1494,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=a;DO(a);wb(a);e=b;f=b+4|0;g=f;h=v[a>>2];a=v[a+4>>2];if((h|0)!=(a|0)){d=v[g>>2];while(1){d=d-52|0;a=a-52|0;i=tN(d,wb(a));v[d>>2]=v[a>>2];v[d+4>>2]=v[a+4>>2];k=v[wb(a)>>2];l=wb(i),m=k,v[l>>2]=m;l=wb(a),m=0,v[l>>2]=m;v[a>>2]=0;v[a+4>>2]=0;v[d+20>>2]=v[a+20>>2];i=v[a+16>>2];v[d+12>>2]=v[a+12>>2];v[d+16>>2]=i;Yu(d+24|0,a+24|0);Dc(d+36|0,a+36|0);v[d+48>>2]=v[a+48>>2];d=v[g>>2]-52|0;v[g>>2]=d;if((a|0)!=(h|0)){continue}break}}wc(c,f);wc(c+4|0,e+8|0);wc(wb(c),dc(e));v[e>>2]=v[e+4>>2];uN(c,Sf(c));sN(b)}gb=j+32|0;break a}a=P()|0;O()|0;sN(b);S(a|0);L()}return}if(b>>>0<e>>>0){AN(a,v[a>>2]+B(b,52)|0)}}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;gb=f+32|0}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;d=gb-16|0;gb=d;ZW(d+8|0,b);gb=d+16|0;v[i+16>>2]=v[d+8>>2];j=i+24|0;k=j;f=gb-32|0;gb=f;c=b;e=a;b=Xd(e);d=fc(e);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(zu(wb(e),c,h)){if(!v[b>>2]){break b}d=b;break e}if(!zu(wb(e),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[f+28>>2]=b;b=d;break a}v[f+28>>2]=b;b=d;break a}b=fc(e)}v[f+28>>2]=b}d=b;b=v[b>>2];t[f+27|0]=0;if(!b){h=gb-16|0;gb=h;b=fc(a);e=Nc(40,4);g=h+8|0;t[g+4|0]=0;v[g>>2]=b;c=gb-16|0;gb=c;v[c+12>>2]=e;v[22708]=0;e=f+8|0;b=e;NQ(b,c+12|0,g);g=v[22708];v[22708]=0;f:{if((g|0)!=1){gb=c+16|0;break f}V(0)|0;O()|0;Bb();L()}c=v[b>>2];v[22708]=0;g=c+16|0;c=v[22708];v[22708]=0;g:{if((c|0)!=1){c=gb-16|0;gb=c;v[c+8>>2]=v[i+16>>2];Dc(g,v[c+8>>2]);Kb(g+12|0);gb=c+16|0;l=fc(b),m=1,t[l+4|0]=m;gb=h+16|0;break g}a=P()|0;O()|0;OQ(b);S(a|0);L()}AS(a,v[f+28>>2],d,v[e>>2]);b=be(e);t[f+27|0]=1;OQ(e)}l=k,m=v[yc(f+8|0,b)>>2],v[l>>2]=m;t[k+4|0]=w[f+27|0];gb=f+32|0;a=ue(j);gb=i+32|0;return a+12|0}function cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];i=v[a+4>>2];h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=i;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=i+n|0;i=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];k=nqa(e,e>>31,f,f>>31);e=w+k|0;f=jb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(u[e+46162>>1],p)+B(q,u[e+46160>>1])|0)+B(o,u[e+46164>>1])|0)+B(i,u[e+46166>>1])<<8)/16384<<8;e=i;h=nqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,m);v[c+4>>2]=v[c+4>>2]+B(h,l);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=Nb(f);e=c;a:{if(d>>>0<e>>>0){l=gb-32|0;gb=l;b:{c:{h=e-d|0;d:{if(h>>>0<=v[wb(f)>>2]-v[f+4>>2]>>2>>>0){i=gb-16|0;gb=i;e:{d=Eg(i,f,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){wb(f);v[22708]=0;_j(e);j=v[22708];v[22708]=0;if((j|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=i+16|0;break d}a=P()|0;O()|0;$b(d);S(a|0);L()}k=wb(f);i=fh(f,Nb(f)+h|0);m=Nb(f);e=0;j=gb-16|0;gb=j;v[j+12>>2]=0;d=l+8|0;Bh(d+12|0,k);if(i){e=SW(i)}v[d>>2]=e;k=(m<<2)+e|0;v[d+8>>2]=k;v[d+4>>2]=k;n=dc(d),o=(i<<2)+e|0,v[n>>2]=o;gb=j+16|0;v[22708]=0;R(662,d|0,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;R(663,f|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}TW(d)}gb=l+32|0;break b}a=P()|0;O()|0;TW(d);S(a|0);L()}break a}if(d>>>0>e>>>0){ij(f,v[f>>2]+(e<<2)|0)}}c=Pb(a,c<<2);if(c){f=gb-16|0;gb=f;bc(g+24|0,v[b>>2],Nb(b)<<2);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(f,-16777216,16776704);f=nqa(k,k>>31,e,e>>31);k=jb;e=f;f=i>>>21&2040;i=(((B(j,u[f+46162>>1])+B(p,u[f+46160>>1])|0)+B(u[f+46164>>1],q)|0)+B(r,u[f+46166>>1])|0)/16384<<8;f=i;j=nqa(l,l>>31,f,f>>31);e=e+j|0;f=jb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];g=nqa(e,e>>31,g,g>>31);e=j+g|0;f=jb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];g=(f|0)/256|0;v[c>>2]=v[c>>2]+B(g,n);v[c+4>>2]=v[c+4>>2]+B(g,m);e=f-(e&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-48|0;gb=g;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;d=g+44|0;hp(b,d);a:{if(!SS(d)){break a}c=w[g+46|0];f=w[g+47|0];e=w[g+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;f=f>>>0<192;u[a+2>>1]=x[(B(d,6)+(e<<1)|0)+33672>>1]<<f;e=B(B(w[(e+B(d,3)|0)+33449|0],x[((B(d,90)+B(e,30)|0)+(c>>>3&30)|0)+33456>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+(c&6)|0)+33648>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[(f|d<<1)+33684|0];if(e+8>>>0>(c&65535)>>>0){break a}d=g;c=gb-48|0;gb=c;v[c+44>>2]=e+4;v[c+24>>2]=36;f=v[Fb(c+44|0,c+24|0)>>2];if(!Pb(b,f)){f=nf(b)}h=c+24|0;cs(h,d);i=wd(c+32|0,v[h>>2],f);j=v[i+4>>2];v[c+8>>2]=v[i>>2];v[c+12>>2]=j;cc(c+16|0,b,c+8|0);cs(h,d);Qb(v[c+24>>2]+f|0,0,36-f|0);Rb(b,v[c+44>>2]);gb=c+48|0;b=2;if(e>>>0>2){while(1){if(w[b+g|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+g|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){d=1}else{d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=d}gb=g+48|0;return a|0}function hk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Fc(b,d);v[22708]=0;j=T(2482,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(il(i+24|0,i+16|0)){break b}c:{if((Qn(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Qn(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Qn(j,v[g+8>>2])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(jl(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(jl(j,8192,v[g>>2])){continue}}break}if(!wm(i+24|0,i+16|0)){break c}while(1){if(!jl(j,8192,vm(i+24|0))){break c}b=i+24|0;um(b);if(wm(b,i+16|0)){continue}break}break c}if((qn(j,vm(i+24|0))|0)==(qn(j,v[g>>2])|0)){g=g+4|0;um(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(il(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function ik(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Fc(b,d);v[22708]=0;j=T(21,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(kk(i+24|0,i+16|0)){break b}c:{if((Rn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Rn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Rn(j,t[g+2|0])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(nh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(nh(j,8192,t[g|0])){continue}}break}if(!lk(i+24|0,i+16|0)){break c}while(1){if(!nh(j,8192,nl(i+24|0))){break c}b=i+24|0;ml(b);if(lk(b,i+16|0)){continue}break}break c}if((yx(j,nl(i+24|0))|0)==(yx(j,t[g|0])|0)){g=g+1|0;ml(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(kk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function aJ(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[a>>2];j=z[d>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=f+z[b>>2];i=C(i-j);f=C(f-g);z[d>>2]=C(i*z[e>>2])-C(f*z[e+4>>2]);z[b>>2]=C(f*z[e>>2])+C(i*z[e+4>>2]);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=f+j;h=a-12|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+32>>2])-C(g*z[e+36>>2]);z[b>>2]=C(g*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=f+j;h=a-20|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+64>>2])-C(g*z[e+68>>2]);z[b>>2]=C(g*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=f+j;h=a-28|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+96>>2])-C(g*z[e+100>>2]);z[b>>2]=C(g*z[e+96>>2])+C(f*z[e+100>>2]);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}aa(12897,10534,2423,6368);L()}function xm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;v[a+4>>2]=0;if(w[uj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[22708]=0;b=v[(a+b|0)+24>>2];d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;b=T(2311,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}if(He(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!He(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[22708]=0;d=v[(a+d|0)+24>>2];e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;e=T(2311,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(He(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(He(e,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;Z(b|0)|0;d=1;tj(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Bb()}L()}d=2}ih(v[v[a>>2]-12>>2]+a|0,d)}gb=f+16|0;return a|0}function u5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;v[22708]=0;g=Q(15,d+24|0,a|0)|0;c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=v[v[a>>2]-12>>2];v[22708]=0;Fc(d+16|0,a+c|0);c=v[22708];v[22708]=0;e:{f:{g:{if((c|0)!=1){v[22708]=0;c=T(2319,d+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}Wb(d+16|0);e=dj(d+8|0,a);f=v[v[a>>2]-12>>2];v[22708]=0;f=a+f|0;h=T(16,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}e=v[e>>2];v[22708]=0;c=Ra(2320,c|0,e|0,f|0,h|0,+b)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!_v(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+c|0,5);c=v[22708];v[22708]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Wb(d+16|0);break e}c=V(0)|0;O()|0}ll(g);break c}ll(g);break b}c=V(0)|0;O()|0}Z(c|0)|0;c=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=d+32|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function F4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Ps(b,c,0)|0)!=-1){while(1){f=Ps(b,c,e);v[22708]=0;Y(140,d|0,b|0,e|0,f-e|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;R(141,d+16|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}v[22708]=0;R(142,a|0,d+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break h}vb(d+16|0);vb(d);e=Ps(b,c,e)+Ab(c)|0;if((Ps(b,c,e)|0)!=-1){continue}break}}k:{if(cd(a)){v[22708]=0;Y(140,d+16|0,b|0,e|0,-1);c=v[22708];v[22708]=0;if((c|0)==1){break f}c=d+16|0;f=Ab(c);vb(c);if(!f){break k}}v[22708]=0;Y(140,d|0,b|0,e|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;R(141,d+16|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;R(142,a|0,d+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+16|0);vb(d)}gb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;vb(d+16|0)}vb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0)}vb(d)}sm(a);S(e|0);L()}function Xu(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;default:break b}}t[a+3|0]=0}}function dy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Lf(g+16|0,a,b,c,e,h-15233|0);om(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}gb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function vz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;d=a+2|0;if(!(w[d|0]==255|!w[d|0])){v[f+12>>2]=w[d|0]+1;v[f+8>>2]=10;kh(b,v[pd(f+12|0,f+8|0)>>2]);d=w[a+3|0];t[b+15|0]=d;t[b+16|0]=d;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];d=0;g=511;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Nb(b)){c=g>>>1|e;while(1){h=(d<<2)+a|0;e=h+6|0;e=w[e|0]|w[e+1|0]<<8;i=Mb(b,d),j=e>>>4|0,u[i>>1]=j;e=0;c:{if(d){e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break c}e=x[Mb(b,e)>>1]+1|0}i=Mb(b,d),j=e,u[i>>1]=j}e=h+8|0;v[f+12>>2]=(c+((w[e|0]|w[e+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;e=v[ej(f+12|0,f+8|0,f+4|0)>>2];i=Mb(b,d),j=e,t[i+2|0]=j;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;if(w[a|0]&2){d=w[b+15|0];e=Nb(b);d=w[b+12|0]&-5|(d>>>0<=e>>>0)<<2}else{d=w[b+12|0]&-5}t[c+12|0]=d;c=b;d:{e:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break e}}a=w[b+12|0]&-3;break d}d=Nb(b);a=w[b+12|0]&-3|(a>>>0<=d>>>0)<<1}t[c+12|0]=a}gb=f+16|0}function s7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Kf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(Jf(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Wg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=ee(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=eo(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function HO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=nqa(c,c>>31,5e4,0);f=jb;b=v[Mc(d+12|0,d+8|0)>>2];c=Ac(oqa(c,f,b,b>>31),jb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=nqa(c,c>>31,1e4,0);f=jb;b=v[Mc(d+12|0,d+8|0)>>2];c=Ac(oqa(c,f,b,b>>31),jb);break a;case 1:break b}}e=60/(+y[b+44>>2]/1e4*(+(nqa(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(jb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=a+484344|0;if(!me(c,x[b+70>>1])){break d}if(!(cd(_b(c,x[b+70>>1])+24|0)^1)){break d}c=_b(c,x[b+70>>1])+24|0;break c}c=a+480248|0}if(!cd(c)){e=e*+y[Mb(c,y[b+48>>2]%(Nb(c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=A[b+8>>3]+(e-+(c>>>0));A[b+8>>3]=e;if(e>=1){A[b+8>>3]=e+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=e+1;c=c-1|0}b=nqa(v[a+480244>>2],0,c,0)+32768|0;a=jb;a=b>>>0<32768?a+1|0:a;a=Qc((a&65535)<<16|b>>>16,a>>>16|0);gb=d+16|0;return(a?a:1)|0}function B7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Kf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(Jf(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Wg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=ee(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=fo(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function xP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=B(b,872)+a|0;a:{if(c){e=h+8|0;Db(e,a+1074312|0,90);if(!Cb(e)){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[f+1075804|0]}e=f+1074992|0;g=c&255;j=0-g|0;i=d?i:!(v[a+480180>>2]&204473357);sP(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}f=v[(B(b,872)+a|0)+1075648>>2];if(!f|!v[f+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){rP(a,e,240-g|0);break b}if(!(b>>>0<224|d)){qP(e,224-g|0);break b}pP(e,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=65535}if((c&255)>>>0>223&i){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}nP(a,e,d);break b}if(v[a+480180>>2]==524288){break d}uP(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){c=h+8|0;Db(c,a+1074312|0,6);if(Cb(c)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}qk(a,e,(B(b,872)+a|0)+1075692|0,0-(g<<2)|0,0)}gb=h+16|0}function Bc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=v[b>>2];f=gb-48|0;gb=f;e=v[b+4>>2];d=w[b+8|0];e=e-(((d|0)==1|(d|0)==4)&(e|0)!=0)|0;b=Kb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){t[f+32|0]=0;a=Xm(c,c+e|0,f+32|0);v[22708]=0;U(68,b|0,c|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((d-3&255)>>>0>1){break h}v[22708]=0;U(68,b|0,c|0,c+e|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}c=zd(b);d=ff(b);e=zd(b);a=gb-32|0;gb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=e;if(Gb(a+24|0,a+16|0)){while(1){d=a+8|0;c=a+24|0;e=t[v[c>>2]];t[v[d>>2]]=e?e:32;Oe(c);Oe(d);if(Gb(c,a+16|0)){continue}break}}gb=a+32|0;v[22708]=0;c=Q(69,f+16|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;d=Q(70,f|0,14911)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}v[22708]=0;U(71,f+32|0,c|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}a=f+32|0;Eb(b,a);vb(a);vb(d);vb(c)}gb=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d)}vb(c)}vb(b);S(a|0);L()}}function Zv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=a;a=gb+-64|0;gb=a;i=a;g=v[c>>2]&2?16:10;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){eO(e+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],g);if(!v[e+12>>2]){break c}f=Ab(d);v[22708]=0;v[e+4>>2]=f;f=yf(e+4|0);j=v[22708];v[22708]=0;if((j|0)!=1){v[22708]=0;U(75,d|0,f|0,0);f=v[22708];v[22708]=0;if((f|0)!=1){continue}}break}break b}b=v[e+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){v[22708]=0;R(86,i|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=e+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(93,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22708]=0;U(94,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}v[22708]=0;R(85,h|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function v_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-112|0;gb=d;vc(b);rs(a);a:{if(!nF(b,d+72|0)){break a}if(!oF(d+72|0)){break a}b:{if(!c){break b}c=d+72|4;if(!Pb(b,Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}Xw(a);g=d,h=Ww(),v[g+48>>2]=h;e=d+48|0;Vw(mj(a)+32|0,e);ps(e);f=v[mj(a)+32>>2];v[22708]=0;R(281,e|0,b|0);b=v[22708];v[22708]=0;c:{if((b|0)==1){break c}b=v[d+48>>2];c=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));e=Xb(w[d+84|0]|w[d+85|0]<<8|(w[d+86|0]<<16|w[d+87|0]<<24));v[22708]=0;b=da(282,b|0,c-28|0,f|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}e=0;if(!b){break a}Ud(d+32|0,f);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;rh(d+40|0,d+16|0);b=Td(d+24|0);c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=os(d+48|0,d+8|0,d);Vc(mj(a)+12|0,b);xb(b);break b}a=Ca(89104,28304)|0;b=O()|0;d:{if((ea(89104)|0)!=(b|0)){if((ea(28304)|0)!=(b|0)){break d}}Z(a|0)|0;$();e=0;break a}S(a|0);L()}e=1}gb=d+112|0;return e|0}function fC(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;vV(a,b);i=gb-16|0;gb=i;ud(c,1);a=b+22|0;k=c,l=Ib(w[a|0]|w[a+1|0]<<8)<<1,v[k>>2]=l;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[ac(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;j=Ib(w[a|0]|w[a+1|0]<<8);a=j<<1;f=b+28|0;g=Ib(w[f|0]|w[f+1|0]<<8);f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}gb=i+16|0;Qk(h,3,b);a=h+16|0;Bc(a,h);v[22708]=0;Q(301,d|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){a=d+32|0;vb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=gC(b);gb=h+32|0;return a}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}function mq(a){a=a|0;var b=0,c=0,d=0,e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0);b=v[a+36>>2];if(!b){Fg(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Fg(c);return}Dl(c,b);b=x[a+28>>1];d=a+4|0;Nb(d);e=Im(a,(b<<16)+65536>>16);f=u[a+28>>1];Nb(d);b=1;e=oe(C(e/Im(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){g=oe(e,C(b>>>0));k=Mb(c,b-1|0),l=g,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:c=a+16|0;d=x[a+30>>1];if(d>>>0>1e3/(b>>>0)>>>0){Fg(c);return}Dl(c,B(b,d));b=u[a+28>>1];Nb(a+4|0);h=b;b=x[a+30>>1];h=ro(h,b);if(!d){break b}while(1){b=ro(f+h<<16>>16,b&65535)<<16;j=b>>16;e=oe(C(Im(a,b+65536>>16)/Im(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));i=1;b=1;if(v[a+36>>2]){while(1){g=oe(e,C((b&65535)>>>0));k=Mb(c,(B(v[a+36>>2],j)+i|0)-1|0),l=g,z[k>>2]=l;b=b+1|0;i=b&65535;if(i>>>0<=y[a+36>>2]){continue}break}}f=f+1|0;if(d>>>0<=(f&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}Fg(a+16|0);v[a+36>>2]=0}return}Fg(a+16|0)}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22708]=0;b=T(2482,g|0)|0;a=v[22708];v[22708]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22708]=0;a=T(2483,g|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}Wb(g);v[22708]=0;R(2484,g|0,a|0);d=v[22708];v[22708]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22708]=0;R(2485,g|12,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;d=g+24|0;a=sa(2486,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Ic(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Ic(g);break d}b=P()|0;O()|0;while(1){d=Ic(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function d4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22708]=0;b=T(21,g|0)|0;a=v[22708];v[22708]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22708]=0;a=T(2454,g|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}Wb(g);v[22708]=0;R(2455,g|0,a|0);d=v[22708];v[22708]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22708]=0;R(2456,g|12,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;d=g+24|0;a=sa(2457,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;vb(g);break d}b=P()|0;O()|0;while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function cq(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[a>>2];k=z[d>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=g+z[c>>2];j=C(j-k);g=C(g-h);z[d>>2]=C(j*z[e>>2])-C(g*z[e+4>>2]);z[c>>2]=C(g*z[e>>2])+C(j*z[e+4>>2]);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=g+k;i=a-12|0;h=z[i>>2];z[i>>2]=h+z[f>>2];i=c;g=C(g-k);c=b+e|0;h=C(h-j);z[i>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[f>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=g+k;i=a-20|0;h=z[i>>2];z[i>>2]=h+z[e>>2];g=C(g-k);c=b+c|0;h=C(h-j);z[f>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[e>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=g+k;i=a-28|0;h=z[i>>2];z[i>>2]=h+z[e>>2];g=C(g-k);c=b+c|0;h=C(h-j);z[f>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[e>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=(h<<1)+j|0;a:{if((b|0)<=0){break a}while(1){Jd(v[f+8>>2],u[(i<<1)+h>>1]/4<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Jd(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function yP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;h=gb-16|0;gb=h;g=B(b,872)+a|0;a:{if(c){e=h+8|0;Db(e,a+1074312|0,90);if(!Cb(e)){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[g+1075803|0]}e=g+1074992|0;f=c&255;i=d?i:!(v[a+480180>>2]&204473357);sP(a,b,f,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,872)+a|0)+1075648>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){rP(a,e,f-240|0);break b}if(!(b>>>0<224|d)){qP(e,f-224|0);break b}pP(e,f);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=1}if((c&255)>>>0>223&i){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}oP(a,e,d);break b}if(v[a+480180>>2]==524288){break d}tP(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){c=h+8|0;Db(c,a+1074312|0,6);if(Cb(c)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}qk(a,e,(B(b,872)+a|0)+1075692|0,f<<2,0)}gb=h+16|0}function Eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=u[(g<<1)+o>>1];i=v[a+60>>2];f=Lb(b,-16777216,16776704);n=v[a+64>>2];g=Lb(e,-16777216,16776704);j=j<<8;e=j;e=nqa(i,i>>31,e,e>>31);i=jb;k=nqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=nqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Vd(a){var b=0,c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;v[c+12>>2]=0;v[c+8>>2]=2561;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;d=gb-16|0;gb=d;e=a;if(v[a>>2]!=-1){yc(d,rT(d+8|0,b));b=d;a:{b:{c:{if(!v[e>>2]){d:{df(e,1);v[22708]=0;f=v[22708];v[22708]=0;e:{if((f|0)==1){break e}v[22708]=0;_(2567,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[e>>2]=-1;v[22708]=0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;a=v[22708];v[22708]=0;f:{if((a|0)==1){break f}df(e,0);v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)==1){break c}S(a|0);L()}}break a}V(0)|0;O()|0;Bb()}L()}}gb=d+16|0;gb=c+32|0;return v[a+4>>2]-1|0}function FO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-560|0;gb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=GS(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;aA(b+48|0,c+48|0);aA(b+68|0,c+68|0);aA(b+88|0,c+88|0);hc(b+108|0,c+108|0,448);pv(c);break c}b=wg(556);if(!b){f=0;v[d>>2]=0;break b}v[22708]=0;f=Q(1325,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}v[d>>2]=b}h=a,i=x[Ke(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}gb=e+560|0;return f|0}a=P()|0;O()|0;Yb(b);S(a|0);L()}function Fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=t[g+o|0];i=v[a+60>>2];f=Lb(b,-16777216,16776704);n=v[a+64>>2];g=Lb(e,-16777216,16776704);j=j<<16;e=j;e=nqa(i,i>>31,e,e>>31);i=jb;k=nqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=nqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function V0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{b=v[a+12>>2];d:{if(d>>>0>b>>>0){while(1){c=v[b>>2];if(c>>>0>1114111|(c&-2048)==55296){break b}e:{if(c>>>0<=127){f=v[a+8>>2];b=1;if((g-f|0)<1){break d}v[a+8>>2]=f+1;t[f|0]=c;break e}if(c>>>0<=2047){b=v[a+8>>2];if((g-b|0)<2){break c}v[a+8>>2]=b+1;t[b|0]=c>>>6|192;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}b=v[a+8>>2];f=g-b|0;if(c>>>0<=65535){if((f|0)<3){break c}v[a+8>>2]=b+1;t[b|0]=c>>>12|224;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}if((f|0)<4){break c}v[a+8>>2]=b+1;t[b|0]=c>>>18|240;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>12&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;if(b>>>0<d>>>0){continue}break}}b=0}break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return b|0}function MI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-208|0;gb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;e=4;g=2;while(1){f=e;e=b;b=(b+4|0)+f|0;v[(d+16|0)+(g<<2)>>2]=b;g=g+1|0;if(b>>>0<h>>>0){continue}break}e=(a+h|0)-4|0;b:{if(e>>>0<=a>>>0){g=0;b=1;e=0;break b}g=1;b=1;while(1){c:{if((g&3)==3){$x(a,c,b,d+16|0);jt(d+8|0,2);b=b+2|0;break c}f=b-1|0;d:{if(y[(d+16|0)+(f<<2)>>2]>=e-a>>>0){it(a,c,d+8|0,b,0,d+16|0);break d}$x(a,c,b,d+16|0)}if((b|0)==1){ht(d+8|0,1);b=0;break c}ht(d+8|0,f);b=1}f=v[d+8>>2];g=f|1;v[d+8>>2]=g;a=a+4|0;if(e>>>0>a>>>0){continue}break}g=f>>>0>1;e=v[d+12>>2]!=0}it(a,c,d+8|0,b,0,d+16|0);if(!(e?1:(b|0)!=1|g)){break a}while(1){e:{if((b|0)<=1){f=d+8|0;e=KI(f);jt(f,e);g=v[d+8>>2];b=b+e|0;break e}f=d+8|0;ht(f,2);v[d+8>>2]=v[d+8>>2]^7;jt(f,1);i=a-4|0;h=d+16|0;e=b-2|0;it(i-v[h+(e<<2)>>2]|0,c,f,b-1|0,1,h);ht(f,1);g=v[d+8>>2]|1;v[d+8>>2]=g;it(i,c,f,e,1,h);b=e}a=a-4|0;if(v[d+12>>2]|(g|0)!=1|(b|0)!=1){continue}break}}gb=d+208|0}function mT(a,b,c){var d=0,e=0;d=w[a|0]&15;t[a|0]=w[d+33392|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d:{d=w[b|0];e=d&15;if((e|0)!=2){d=d&240;if((d|0)!=32){break d}}t[a|0]=20;t[b|0]=159;return}e:{if((e|0)!=12){if((d|0)!=192){break b}if(c>>>0>50){break e}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:f:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break f;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function _K(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(Bj(a)){zh(d+24|0);break g}c=d+8|0;oo(c,a);v[22708]=0;c=T(2086,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+24>>2]=c;Yf(d+8|0)}if(Bj(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((jo(c)|0)>(b|0)){break d}}b=ba(8)|0;v[22708]=0;c=Q(70,d+8|0,8199)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break c}a=P()|0;O()|0;Yf(d+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Wl(c,e)+16|0];v[22708]=0;Si(b+484360|0,f);b=v[22708];v[22708]=0;h:{if((b|0)==1){break h}b=Wl(c,e);c=v[b+8>>2];b=v[b+12>>2];v[22708]=0;+oa(1946,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;wl(d+24|0);gb=d+32|0;return}a=P()|0;O()|0}wl(d+24|0)}S(a|0)}L()}function Rfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=d;b=gb-32|0;gb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;v[b+12>>2]=15;c=tf(64);v[22708]=0;f=T(1317,c|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{if((g|0)!=1){c=ns(b+8|0,f);f=v[c>>2];v[22708]=0;R(1318,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=v[c>>2];v[22708]=0;a=W(1319,a|0,b+22|0,b+16|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}d:{if(!a){cA(b+24|0);break d}a=v[c>>2];v[22708]=0;R(1320,a|0,b+12|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}qi(b+24|0,c)}Ig(c);gb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Yb(c);break b}a=P()|0;O()|0;Ig(c)}S(a|0);L()}v[e+24>>2]=a;a=0;e:{f:{g:{while(1){b=v[d+24>>2];v[22708]=0;u[d+22>>1]=a;e=Q(2,d+8|0,(a<<2)+38432|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;U(1316,b|0,d+22|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}vb(e);a=a+1|0;if((a|0)!=12){continue}break}gb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e)}Ig(d+24|0);S(a|0);L()}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;g=gb-16|0;gb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;TN(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);TN(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=vd(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;h=w[d+31|0];a:{b:{if(!h){e=1;break b}e=16;if(h>>>0<17){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[Pc(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];gb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=vd(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Qk(f,3,a+4|0);d=f+16|0;Bc(d,f);v[22708]=0;Q(301,b+492|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}gb=f+32|0;return}a=P()|0;O()|0;vb(f+16|0);S(a|0);L()}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;wK(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;$b(c);gb=c+16|0;return}i=gb-32|0;gb=i;j=wb(a);d=i+8|0;e=a;h=jo(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=h;a:{c=FV();if(h>>>0<=c>>>0){e=hv(e);if(e>>>0<c>>>1>>>0){v[f+8>>2]=e<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break a}Sc();L()}h=jo(a);f=gb-16|0;gb=f;v[f+12>>2]=0;jf(d+12|0,j);if(c){e=c;if(c>>>0>=178956971){rd(8445);L()}g=Nc(B(e,24),8)}v[d>>2]=g;e=B(h,24)+g|0;v[d+8>>2]=e;v[d+4>>2]=e;k=dc(d),l=B(c,24)+g|0,v[k>>2]=l;gb=f+16|0;c=d;wK(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=a;e=c+4|0;g=v[a>>2];a=v[a+4>>2]-g|0;f=v[e>>2]+B((a|0)/-24|0,24)|0;v[e>>2]=f;if((a|0)>=1){hc(f,g,a)}wc(b,e);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];a=c;b=v[c+8>>2];d=v[c+4>>2];if((b|0)!=(d|0)){v[a+8>>2]=b+B(((b-d|0)-24>>>0)/24^-1,24)}a=v[c>>2];if(a){Ey(a,(v[dc(c)>>2]-v[c>>2]|0)/24|0)}gb=i+32|0}function Uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;ud(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Pc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Pc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49050|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}gb=e+16|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Td(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=h+j|0;a:{if((b|0)<=0){break a}while(1){Jd(v[f+8>>2],t[h+i|0]<<6);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Jd(b,t[h+v[e+44>>2]|0]<<6);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function j0(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb+-64|0;gb=c;a=Kb(a);v[22708]=0;b=ga(147)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[22708]=0;d=Q(2,c+32|0,6094)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=ga(147)|0;e=v[22708];v[22708]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[22708]=0;v[c+12>>2]=b;R(153,c+16|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;U(3,c+48|0,d|0,c+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}b=c+48|0;Eb(a,b);vb(b);vb(c+16|0);vb(d);v[22708]=0;b=ga(149)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!b){break e}v[22708]=0;Q(154,a|0,14604)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(c+16|0)}vb(d);break a}v[22708]=0;b=ga(148)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!b){break d}v[22708]=0;Q(154,a|0,13875)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}}gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(a);S(b|0);L()}function Sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=zb(b);a:{b:{c:{d:{e:{f:{g:{while(1){b=c;if(!c){break g}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break e}c=0;break f}if((d|0)==4){break d}f=(d|0)==2;break c}while(1){h:{i:{j:{d=c+h|0;i=w[d|0];switch(i-10|0){case 0:break i;case 3:break j;default:break h}}e=e+1|0;break h}f=f+1|0}g=c?(w[d-1|0]==13&(i|0)==10)+g|0:g;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}f=(d|0)==2;break b}k:{if((e|0)==(f|0)){d=2;if((e|0)==(g|0)){break k}}if(e){d=0;if(!f){break k}}d=e?3:f?1:3}f=(d|0)==2;if(b){break b}}b=0;g=1;e=0;break a}g=0;c=0;e=0;while(1){e=e+1|0;c=((w[c+h|0]==13&f)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}Se(a);Qq(a,e);if(!g){g=(d|0)==1?32:13;d=d&-3?13:32;c=0;while(1){l:{m:{n:{o:{e=t[c+h|0];switch(e-10|0){case 1:case 2:break l;case 0:break m;case 3:break n;default:break o}}if(e){break l}e=32;break l}c=c+f|0;e=g;break l}e=d}No(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;gb=f+32|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=e+o|0;p=t[g+1|0];g=t[g|0];e=v[a+60>>2];q=e;r=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=nqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=((B(p-g|0,i>>>10&4194048)|0)/16384|0)+(g<<8)<<8;i=nqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function sL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){v[22708]=0;b=c;T(1292,b|0)|0;a=v[22708];v[22708]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;Ek(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=wb(f);v[22708]=0;d=d-4|0;R(1327,e|0,d|0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[f+4>>2]=g;ai(wb(a),v[a>>2],pe(a))}Yb(c)}v[b+4>>2]=0;nA(b+1298368|0);ku(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);ju(b+1298264|0);iu(b+1298260|0);Dq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Aq(a-160|0);if((c|0)!=(a|0)){continue}break}Hu(b+484360|0);lA(b+484344|0);Lc(b+480248|0);break a}V(0)|0;O()|0;nA(b+1298368|0);ku(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);ju(b+1298264|0);iu(b+1298260|0);Dq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Aq(a-160|0);if((c|0)!=(a|0)){continue}break}Hu(b+484360|0);lA(b+484344|0);Lc(b+480248|0);Bb();L()}Yb(b)}}function Rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;m=c,n=nf(a)>>>5|0,u[m+32>>1]=n;u[c+16>>1]=3999;m=b,n=x[Pc(c+32|0,c+16|0)>>1],u[m+480190>>1]=n;a:{if(x[b+480190>>1]){h=c+58|0;i=c+56|0;j=c+62|0;l=c+52|0;k=c+60|0;g=1;while(1){d=g&65535;f=Ak(b,d);e=c+32|0;dv(a,e);ud(f,0);Yj(c,2,e);e=c+16|0;Bc(e,c);v[22708]=0;Q(301,((d<<5)+b|0)+946304|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}d=c+16|0;vb(d);v[f+24>>2]=8287;m=c,n=Ib(w[k|0]|w[k+1|0]<<8),u[m+16>>1]=n;u[c>>1]=64;m=f,n=x[Pc(d,c)>>1]<<2,u[m+30>>1]=n;d=l;m=f,n=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))&-2,v[m>>2]=n;d=Ib(w[j|0]|w[j+1|0]<<8);m=Pe(f+68|0,0),n=d,v[m>>2]=n;d=Ib(w[i|0]|w[i+1|0]<<8);e=Ib(w[h|0]|w[h+1|0]<<8);b:{if(e>>>0<2){break b}e=d+e<<1;if(e>>>0>y[f>>2]){break b}v[f+16>>2]=e;v[f+12>>2]=d<<1;u[f+34>>1]=x[f+34>>1]|8}g=g+1|0;if(x[b+480190>>1]>=(g&65535)>>>0){continue}break}}gb=c- -64|0;return}a=P()|0;O()|0;vb(c+16|0);S(a|0);L()}function sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=(e<<1)+o|0;p=u[g+2>>1];g=u[g>>1];e=v[a+60>>2];q=e;r=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=nqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=nqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=g+((B(p-g|0,i>>>18|0)|0)/16384|0)<<8;i=nqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function $y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=gb+-64|0;gb=b;d=v[a+20>>2];a:{if(!d){break a}if(oc(d+4|0)>>>0<4){break a}Ud(b+32|0,v[a+20>>2]+4|0);d=Td(b+24|0);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[d+4>>2];v[b+8>>2]=v[d>>2];v[b+12>>2]=c;d=WX(b+40|0,b+16|0,b+8|0);v[22708]=0;c=T(192,d|0)|0;f=v[22708];v[22708]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[22708]=0;c=T(c|0,a|0)|0;f=v[22708];v[22708]=0;c:{if((f|0)==1){break c}if(oc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+172>>2];f=0;v[22708]=0;R(e|0,a|0,-1);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(c){while(1){v[22708]=0;g=C(Ba(635,d|0));e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[22708]=0;Aa(e|0,a|0,f|0,C(g));e=v[22708];v[22708]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+176>>2];v[22708]=0;_(c|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;xb(d);S(a|0);L()}xb(d)}gb=b- -64|0}function Of(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function fg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;d=v[a+28>>2];no(v[v[d>>2]-12>>2]+d|0,0);if(!nd(a,4)){Ry(a)}a:{if(!v[a+4>>2]){break a}if(nd(a,6)){break a}if(nd(a,7)){break a}g=v[a+28>>2];e=v[a+84>>2];h=B(v[a+20>>2],v[a+4>>2]);f=h+v[a+80>>2]|0;e=sh(c- -64|0,f,f>>>0<h>>>0?e+1|0:e);f=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=f;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;jk(g,c+16|0)}d=0;b:{if(!nd(a,5)){break b}g=0;e=a+44|0;h=vf(e);d=0;if(!h){break b}d=a+32|0;while(1){c:{f=(v[a+96>>2]+g>>>0)%(h>>>0)|0;if(y[Tc(e,f)>>2]>=oc(d)>>>0){break c}i=po(c+48|0,lc(d,v[Tc(e,f)>>2]),x[Tc(e,f)+12>>1]);j=Uy(b,i);Hb(i);if(!j){break c}v[a+96>>2]=(f+1>>>0)%(h>>>0);b=v[Tc(e,f)+4>>2];if(b){h=v[a+28>>2];g=b+v[a+8>>2]|0;a=v[a+12>>2];a=sh(c+32|0,g,b>>>0>g>>>0?a+1|0:a);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;jk(h,c)}d=Tc(e,f);break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}d=0}gb=c+80|0;return d}function su(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;e=f+8|0;g=a+1074312|0;Db(e,g,77);a:{if(j=Cb(e),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{i=c;if(d){e=w[c+841|0];if(!e){break c}d=e-1|0;t[c+841|0]=d;if(d&255){break b}c=f+8|0;Db(c,g,16);if(!Cb(c)&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[i+764>>2]=a;break a}e=f+8|0;Db(e,g,17);if(!(Cb(e)|v[a+480180>>2]&3|!x[a+480188>>1])){e=b+616|0;while(1){if(w[e+841|0]?(c|0)!=(e|0):0){break a}e=e+872|0;h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;d:{if((d|0)==-1){break d}e:{if(v[b+60>>2]==-1){break e}e=f+8|0;Db(e,g,68);if(!Cb(e)){break e}v[b+60>>2]=d}v[b+64>>2]=d;d=f+8|0;Db(d,g,103);if(!Cb(d)){break d}u[b+68>>1]=65535}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break a}d=0;while(1){e=B(d,872)+b|0;v[e+1380>>2]=v[c+764>>2];t[e+1457|0]=w[c+841|0];d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}gb=f+16|0}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<1){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if(h>>>0>2147483647&(g|0)>=-2|(g|0)>-2){break d}break b}if(h>>>0>2147483648&(g|0)>=1|(g|0)>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function H8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;v[e+72>>2]=c;c=qi(a,e+72|0);g=zh(a+4|0);h=zh(a+24|0);i=zh(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22708]=0;R(2081,a|0,d|0);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];l=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=l;b=Td(e+24|0);f=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=f;v[22708]=0;f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;U(2075,e+48|0,e+8|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;U(2082,a|0,e+48|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}xb(e+48|0);v[22708]=0;_(2083,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}eg(e+72|0);gb=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+48|0);break a}a=P()|0;O()|0}yd(k);Yf(j);hq(i);Fi(h);Ei(g);eg(c);eg(e+72|0);S(a|0);L()}function fK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Kf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(Jf(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Xg(a,g,j);c=Mb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=yt(f)+c&-4096;v[l>>2]=e-c;c=id(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=fo(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=d- -64|0}function _J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Kf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(Jf(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Xg(a,g,j);c=Mb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=yt(f)+c&-4096;v[l>>2]=e-c;c=id(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=eo(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=d- -64|0}function DM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;Ai(f+8|0,b);b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;h=gb-32|0;gb=h;c=v[f+4>>2];b=h;d=v[f>>2];v[b+8>>2]=d;v[b+12>>2]=c;v[b+16>>2]=d;v[b+20>>2]=c;rh(b+24|0,b+8|0);c=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=c;c=gb-32|0;gb=c;i=c,j=Gg(a),v[i+24>>2]=j;a=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=a;v[c+16>>2]=b;v[c+20>>2]=a;d=c+8|0;b=gb-16|0;gb=b;g=v[c+24>>2];e=g;a=v[e+12>>2];e=v[e+8>>2];a:{if((a|0)<0){break a}if(yb(g)>>>0<e>>>0&(a|0)>=0|(a|0)>0){break a}g=yb(v[c+24>>2]);e=v[c+24>>2];a=v[e+8>>2];e=0-((g>>>0<a>>>0)+v[e+12>>2]|0)|0;v[b+8>>2]=g-a;v[b+12>>2]=e;i=b,j=yb(d),v[i>>2]=j;v[b+4>>2]=0;a=Or(b+8|0,b);a=KA(v[a>>2],v[a+4>>2]);if((yb(d)|0)!=(a|0)){break a}Rg(v[d>>2],a+v[d>>2]|0,zb(v[v[c+24>>2]>>2]+v[v[c+24>>2]+8>>2]|0));d=v[c+24>>2];e=d;g=a+v[d+8>>2]|0;d=v[d+12>>2];v[e+8>>2]=g;v[e+12>>2]=a>>>0>g>>>0?d+1|0:d}gb=b+16|0;gb=c+32|0;gb=h+32|0;gb=f+16|0}function nT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=gb-16|0;gb=d;e=Kb(a);i=b;b:{if(Ab(b)){while(1){a=v[xk(i,g)>>2];c:{if(a>>>0>=2097152){v[22708]=0;R(66,e|0,63);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}c=0;d:{e:{while(1){f=a&63;t[(d+10|0)+c|0]=f;if(a>>>0<64){break e}a=a>>>6|0;c=c+1|0;if((c|0)!=6){continue}break}b=7;c=6;break d}f:{if(!c){v[22708]=0;R(66,e|0,t[d+10|0]);break f}b=c+1|0;if((b|0)!=2){break d}c=1;b=2;if((f|0)!=1){break d}v[22708]=0;R(66,e|0,t[d+10|0]|64)}a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}f=(-1<<b^-1)<<7-c;c=b-1|0;j=c+(d+10|0)|0;a=b;while(1){g:{if((a|0)==(b|0)){a=w[j|0];v[22708]=0;R(66,e|0,(a|f)<<24>>24);h=v[22708];v[22708]=0;a=c;if((h|0)!=1){break g}break b}v[22708]=0;a=a-1|0;R(66,e|0,t[a+(d+10|0)|0]|-128);h=v[22708];v[22708]=0;if((h|0)==1){break b}}if(a){continue}break}}g=g+1|0;if(Ab(i)>>>0>g>>>0){continue}break}}gb=d+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function hJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];b=v[a+1380>>2];a:{b:{if((b|0)==-1){h=1;b=-1;break b}d=v[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){ec(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){ec(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[90128]|w[90129]<<8|(w[90130]<<16|w[90131]<<24))){ec(a,21);break a}if(w[c+4|0]){ec(a,21);break a}e:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break e}ec(a,21);break a}if(t[c+5|0]&1){break e}ec(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break d}h=0;b=0;f=0;f:{if(!e){break f}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break f}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}ec(a,1);break a}ec(a,1)}return 0}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;gb=f+32|0}function tx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=sx(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+83408|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=v[e>>2];if((b|0)!=(d|0)){a=-1;if((w[b-1|0]&95)!=(w[c|0]&127)){break a}}v[e>>2]=b+1;t[b|0]=g;a=0;break a}t[c|0]=80;break d}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=0,B=0,E=C(0);f=gb-16|0;gb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!ni(g)){break a}l=z[a+4220>>2];A=f,B=Nd(g,0),v[A+8>>2]=B;A=f,B=Nd(g,1),v[A+12>>2]=B;A=f,B=od(g,0),v[A>>2]=B;A=f,B=od(g,1),v[A+4>>2]=B;if(d){m=a+4208|0;t=C(C(1)-l);j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;u=v[((n<<2)+a|0)+4248>>2];x=v[a+4240>>2];y=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;q=z[e>>2];e=y-u|0;r=z[Mb(m,n+((e>>31&x)+e<<1)|0)>>2];s=C(C(q*z[a+4260>>2])+C(r*z[a+4224>>2]));A=Mb(m,v[a+4244>>2]<<1|h),E=C(D(s))<C(1.0000000195414814e-24)?C(0):s,z[A>>2]=E;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=C(t*q)+C(l*r);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}Gi(a,b,c,od(g,0),od(g,1),d)}gb=f+16|0}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<1){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if(h>>>0>2147483647&(g|0)>=-2|(g|0)>-2){break d}break b}if(h>>>0>2147483648&(g|0)>=1|(g|0)>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>4;v[d+16>>2]=v[a>>2];h=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=ee(e);a:{if(D(e)<2147483648){g=~~e;break a}g=-2147483648}i=f,j=Uc(g),u[i>>1]=j;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[d+24>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=ee(e);b:{if(D(e)<2147483648){g=~~e;break b}g=-2147483648}i=f,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return h<<4}function wx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Xm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+83408|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function IS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;h=gb-16|0;gb=h;if(Kj(a)){e=w[(ve(w[a+797|0])?a+797|0:a+799|0)|0];f=h+8|0;Db(f,d+1074312|0,34);if(!(!Cb(f)|!e|e>>>0>120)){e=w[ic(v[a+656>>2]+108|0,e-1|0)|0]}d=a;k=C(C(v[a+704>>2]<<4)*b);e=(c+e<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];i=v[c+36>>2];a=v[a+852>>2]+u[a+772>>1]|0;a:{if(!(a?i:0)){b=Im(c,a+e<<16>>16);break a}j=i+1|0;l=hz(a,j);f=ro(a,j);a=u[c+28>>1];g=c+4|0;Nb(g);b=C(1);e=e+l<<16>>16;b:{if((e|0)<(a|0)){break b}if((e|0)>(x[c+28>>1]+Nb(g)<<16)-65536>>16){break b}if(!f){b=z[Mb(g,e-u[c+28>>1]|0)>>2];break a}a=x[c>>1];c:{if((a|0)==3){a=c+16|0;if(Nb(a)){b=z[Mb(a,f-1|0)>>2];break c}a=x[c>>1]}d:{if((a&65535)!=1){break d}a=c+16|0;if(!Nb(a)){break d}b=z[Mb(a,(B(i,ro(e,x[c+30>>1])<<16>>16)+f|0)-1|0)>>2];break c}b=oe(C(Im(c,(e<<16)+65536>>16)/Im(c,e)),C(C(f|0)/C(j|0)))}b=C(b*z[Mb(g,e-u[c+28>>1]|0)>>2])}}m=d,n=Jj(C(k*b)),v[m+700>>2]=n}gb=h+16|0}function vI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;Lf(h+16|0,a,b,g,e,f-16129|0);om(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}gb=h+32|0;return l(2,d&-2147483648|e),q()}function CH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Hf(c+24|0,a+44|0)>>2];if((e|0)>=1){f=(e|0)>0?e:0;while(1){g=Us(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(PH(v[a+36>>2],d,h,f,c+16|0,c+23|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=Us(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Ts(Lg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Lg(t[c+23|0]),v[k+48>>2]=l}d=Lg(t[c+23|0]);break a}d=-1}gb=c+32|0;return d}function QT(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;b=v[a>>2];yc(g+8|0,b);a:{b:{c:{d:{e=b+16|0;e:{if(Dd(e)){while(1){f:{d=v[e>>2];v[22708]=0;d=T(56,d|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break f}f=d|f;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(89080)|0;if((O()|0)!=(ea(89080)|0)){break c}Z(c|0)|0;t[b+20|0]=0;v[22708]=0;_(38,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break d}v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break c}t[b+20|0]=0}if(!w[b+20|0]){b=v[b+24>>2];c=v[b+2496>>2];e=(c<<2)+b|0;h=v[b+((c+397>>>0)%624<<2)>>2];d=(c+1>>>0)%624|0;c=v[b+(d<<2)>>2];c=h^(c&2147483647|v[e>>2]&-2147483648)>>>1^B(c&1,-1727483681);v[e>>2]=c;v[b+2496>>2]=d;b=c^c>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;f=f^(b>>>18^b)}gb=g+16|0;break a}c=P()|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Bb();L()}return v[a+28>>2]&f}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);c=0;while(1){if((l|0)>=1){j=(k<<1)+b|0;n=j+(l<<1)|0;while(1){o=c;u[e+6>>1]=0;JV(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{if(!i){h=x[e+6>>1];break a}h=x[e+6>>1];c=x[e+12>>1];g=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!lf(a,e+5|0)){break a}f=w[e+5|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}h=f|h<<1;g=g-1|0;if(g&255){continue}break}}c=1;m=h&65535;b:{if(m>>>0<4){break b}g=15;while(1){c=g;f=c&255;if(m>>>f&1){break b}g=c-1|0;if(f>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=h&1;t[e+14|0]=c;g=c-1^(h&65534)>>>1;c=g+x[e+8>>1]|0;u[e+6>>1]=c;u[j>>1]=c;v[e+8>>2]=((g>>1)-(o<<16>>16)|0)+(c<<16>>16<<1);Yd(e+8|0,-32768,32767);j=(d<<1)+j|0;if(n>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function W0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){i=d;f=t[a|0];b=1;b:{if((f|0)>-1){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}b=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}b=3;if((h&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(h&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}g=g+1|0;b=4}a=b+a|0;if(i>>>0<=a>>>0){break a}g=g+1|0;if(g>>>0<e>>>0){continue}break}}return a-c|0}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Nd(f,0);j=Nd(f,1);k=od(f,0);l=od(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[i>>2];o=z[j>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Mb(h,e)>>2];e=Mb(h,e|1);r=z[a+4256>>2];s=z[a+4248>>2];t=z[a+4252>>2];q=z[e>>2];u=z[a+4244>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(q*u));w=Mb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(o*r)+C(n*s))+C(q*t))+C(p*u));w=Mb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(n*z[a+4240>>2])+C(p*z[a+4236>>2]);z[l>>2]=C(o*z[a+4240>>2])+C(q*z[a+4236>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}Gi(a,b,c,od(f,0),od(f,1),d)}}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=g>>>21&2040;g=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;gb=e+32|0}function TN(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;t[k+15|0]=c;t[k+14|0]=12;kh(b,w[ac(k+15|0,k+14|0)|0]);if(Nb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=w[j|0]|w[j+1|0]<<8;m=Mb(b,c),n=j,u[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=w[j|0]|w[j+1|0]<<8;m=Mb(b,c),n=j,u[m>>1]=n;i=i+146|0}i=w[i|0];m=Mb(b,c),n=i,t[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}if(x[Mb(b,c)>>1]>255){break d}j=w[Mb(b,i)+1|0];l=Mb(b,c);u[l>>1]=x[l>>1]|j<<8;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}i=Mb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(cd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}gb=k+16|0}function H1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=Nb(465840);if(b>>>0<a>>>0){g=gb-32|0;gb=g;e=a-b|0;a:{if(e>>>0<=v[116462]-v[116461]>>2>>>0){NG(e);break a}f=jx(465840);b=g+8|0;d=Nb(465840)+e|0;c=gb-16|0;gb=c;v[c+12>>2]=d;b:{a=mp();if(d>>>0<=a>>>0){d=pe(465840);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;break b}Sc();L()}h=Nb(465840);c=0;d=gb-16|0;gb=d;v[d+12>>2]=0;jf(b+12|0,f);if(a){c=AG(v[b+16>>2],a)}v[b>>2]=c;f=(h<<2)+c|0;v[b+8>>2]=f;v[b+4>>2]=f;i=dc(b),j=(a<<2)+c|0,v[i>>2]=j;gb=d+16|0;d=gb-16|0;gb=d;a=Sk(d,b+8|0,e);c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Yo(c);c=v[a>>2]+4|0;v[a>>2]=c;if(v[a+4>>2]!=(c|0)){continue}break}}_c(a);gb=d+16|0;a=b+4|0;ol(v[116460],v[116461],a);wc(465840,a);wc(465844,b+8|0);wc(465848,dc(b));v[b>>2]=v[b+4>>2];a=b;rC(a);b=v[a>>2];if(b){zG(v[a+16>>2],b,Bk(a))}}gb=g+32|0;return}if(a>>>0<b>>>0){de(465840,v[116460]+(a<<2)|0)}}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Kb(d+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[22708]=0;c=T(1420,b|0)|0;e=v[22708];v[22708]=0;d:{if((e|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22708]=0;Q(70,a|0,18726)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}v[22708]=0;c=T(467,b|0)|0;e=v[22708];v[22708]=0;e:{if((e|0)==1){break e}c=Vi(c);v[22708]=0;v[d+8>>2]=c;c=pd(d+12|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}c=v[c>>2];v[22708]=0;R(60,f|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[22708]=0;c=T(374,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}if(!c){break f}v[22708]=0;W(1421,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break a}v[22708]=0;Q(318,b|0,4)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}Dc(a,f)}vb(f);gb=d+32|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function GS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=iB(a+48|0);e=iB(a+68|0);f=iB(a+88|0);v[22708]=0;Tq(a+492|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Tq(a+524|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;hm(a,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;gm(a,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[22708]=0;or(a,b);b=v[22708];v[22708]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=ic(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;cp(f);cp(e);cp(d);S(a|0);L()}function T0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){f=1;b=t[a|0];b:{if((b|0)>-1){break b}b=b&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}f=3;if((g&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244){break a}f=w[a+3|0];i=w[a+2|0];g=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((g+112&255)>>>0<48){break e}break a;case 4:if((g&240)==128){break e}break a;default:break f}}if((g&192)!=128){break a}}if((i&192)!=128|(f&192)!=128){break a}f=4;if((b<<18&1835008|(g&48)<<12)>>>0>1114111){break a}}a=a+f|0;if(d>>>0<=a>>>0){break a}h=h+1|0;if(h>>>0<e>>>0){continue}break}}return a-c|0}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=ze(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>5>>>0){f=gb-16|0;gb=f;d=DB(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){WB(e);e=e+32|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=Zq(e,ze(e)+i|0);m=ze(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;jf(d+12|0,j);if(f){h=f;if(f>>>0>=134217728){rd(8445);L()}h=Nc(h<<5,1)}v[d>>2]=h;j=(m<<5)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<5)+h|0,v[n>>2]=o;gb=l+16|0;v[22708]=0;CT(d,i);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(e,d);BT(d)}gb=k+32|0;break b}a=P()|0;O()|0;BT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Zk(e,v[e>>2]+(d<<5)|0)}}if(Pb(a,c<<5)){bc(g+24|0,v[b>>2],ze(b)<<5);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=vf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){f=gb-16|0;gb=f;d=bq(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){Gv(e);e=e+16|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=ey(e,vf(e)+i|0);m=vf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;jf(d+12|0,j);if(f){h=f;if(f>>>0>=268435456){rd(8445);L()}h=Nc(h<<4,1)}v[d>>2]=h;j=(m<<4)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<4)+h|0,v[n>>2]=o;gb=l+16|0;v[22708]=0;yT(d,i);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(e,d);xT(d)}gb=k+32|0;break b}a=P()|0;O()|0;xT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Zk(e,v[e>>2]+(d<<4)|0)}}if(Pb(a,c<<4)){bc(g+24|0,v[b>>2],vf(b)<<4);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb+-64|0;gb=e;g=so(a);a:{b:{if(b-1>>>0>1023){break b}f=v[a+12>>2];if((f|0)==(b|0)){break b}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break b}f=v[a+12>>2]}f=B(Li(a),b>>>0>f>>>0?b-f|0:f-b|0);c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=Zb(a);break d}d=Vb(a)}v[c+48>>2]=d;c=Gd(e+56|0,e+48|0);d=e+40|0;hi(d);c=v[c>>2];v[22708]=0;Y(1477,a|0,c|0,f|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(a|0)|0;$();break b}if(d){i=e,j=Zb(a),v[i+48>>2]=j;i=e,j=YC(e+48|0,f),v[i+40>>2]=j;c=Gd(e+32|0,e+40|0);i=e,j=Zb(a),v[i+16>>2]=j;d=Gd(e+24|0,e+16|0);LN(a,v[c>>2],v[d>>2]);break c}i=e,j=Vb(a),v[i+40>>2]=j;c=Gd(e+8|0,e+40|0);i=e,j=Vb(a),v[i+16>>2]=j;i=e,j=DX(e+16|0,f),v[i+48>>2]=j;d=Gd(e,e+48|0);LN(a,v[c>>2],v[d>>2])}v[a+12>>2]=b;h=1}gb=e- -64|0;return h|0}S(a|0);L()}function H5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[22708]=0;d=T(2304,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}e=dj(c+8|0,a);f=Wi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2307,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}Wb(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(!(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1)){break e}v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function xga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=gb-32|0;gb=f;m=f,o=B(v[a>>2],fd(a)),v[m+4>>2]=o;qc(f+4|0,c>>>3|0);c=zb(b);g=A[e+8>>3];h=v[f+4>>2];a:{if(!h){break a}e=h;while(1){k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,k|0);j=+n();g=g<j?j:g;c=c+8|0;e=e-1|0;if(e){continue}break}if(g==0){break a}j=1/g;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=j*+n(),A[m+24>>3]=p;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;i=A[bh(f+24|0,f+16|0,f+8|0)>>3]*32768;A[f+24>>3]=i;a=c;i=ee(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Uc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;h=h-1|0;if(h){continue}break}}if(d){A[d>>3]=g}gb=f+32|0;return v[f+4>>2]<<3}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Uc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function AH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Hf(c+24|0,a+44|0)>>2];if((e|0)>=1){f=(e|0)>0?e:0;while(1){g=Us(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(PH(v[a+36>>2],d,h,f,c+16|0,c+20|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=Us(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Ts(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}gb=c+32|0;return d}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22708]=0;_(2009,a|0);e=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22708]=0;_(1962,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}e=0;v[22708]=0;_(2010,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}a=Qb(c,0,d);if(!w[b|0]){break b}if(xj(b,4310)|(d|0)!=8){break d}v[a+4>>2]=2011;v[a>>2]=2012;break c}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,9520,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();return 0}if(xj(b,8531)|(d|0)!=64){break b}v[a+60>>2]=2013;v[a+56>>2]=2014;v[a+52>>2]=2015;v[a+48>>2]=2016;v[a+44>>2]=2017;v[a+40>>2]=2018;v[a+36>>2]=2019;v[a+32>>2]=2020;v[a+28>>2]=2021;v[a+24>>2]=2022;v[a+20>>2]=2023;v[a+16>>2]=2024;v[a+12>>2]=2025;v[a+8>>2]=2026;v[a+4>>2]=2027;v[a>>2]=2028}e=1}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;v[g+12>>2]=1;a:{if(bi(a)){n=g,o=ze(a),v[n+8>>2]=o;f=v[a>>2];c=b;k=v[Fb(g+12|0,g+8|0)>>2];if(k){while(1){d=c;if((c|0)!=(f|0)){h=Vb(d);l=Zb(d);i=gb-16|0;gb=i;j=vD(h,l);e=f;b:{if(j>>>0<=Og(e)>>>0){if(tc(e)>>>0<j>>>0){v[i+8>>2]=h;jS(i+8|0,tc(e));m=h;h=v[i+8>>2];Xi(m,h,v[e>>2]);sS(e,h,l,j-tc(e)|0);break b}yn(e,Xi(h,l,v[e>>2]));break b}rS(e);XB(e,Uk(e,j));sS(e,h,l,j)}gb=i+16|0;gk(f+12|0,d+12|0);u[f+28>>1]=x[d+28>>1]}f=f+32|0;k=k-1|0;if(k){continue}break}}d=v[g+12>>2];c=v[g+8>>2];if(d>>>0>c>>>0){fB(a,d-c|0,b);break a}lS(a,v[a>>2]+(d<<5)|0);break a}c=a;if(v[c>>2]){ze(c);gS(c);eS(c);Xk(wb(c),v[c>>2],bi(c));n=wb(c),o=0,v[n>>2]=o;v[c>>2]=0;v[c+4>>2]=0}f=Zq(a,1);if(AT()>>>0<f>>>0){Sc();L()}wb(c);d=dS(f);v[c>>2]=d;v[c+4>>2]=d;n=wb(c),o=d+(f<<5)|0,v[n>>2]=o;eB(c,0);fB(a,1,b)}gb=g+16|0}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=h>>>21&2040;h=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;gb=e+32|0}function doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;g=fg(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!g){if(nd(a,5)){break a}}d=gb-48|0;gb=d;h=v[a+28>>2];ag(h,d+46|0);b:{c:{d:{e:{f:{if(x[d+46>>1]>=4001){k=v[b+12>>2];e=gb-16|0;gb=e;i=d+16|0;j=Tb(e,13033);Dc(i,j);vb(j);gb=e+16|0;v[22708]=0;U(1092,d+32|0,i|0,d+46|0);e=v[22708];v[22708]=0;if((e|0)==1){break f}v[22708]=0;U(560,k|0,2,d+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}vb(d+32|0);Hb(d+16|0);u[d+46>>1]=4e3}Bf(Rj(b,0),x[d+46>>1]);b=Rj(b,0);l=d,m=Vb(b),v[l+32>>2]=m;l=d,m=Zb(b),v[l+16>>2]=m;if(Gb(d+32|0,d+16|0)){break c}break b}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d+32|0)}Hb(d+16|0);S(a|0);L()}while(1){b=d+32|0;e=v[b>>2];ag(h,d+14|0);u[e>>1]=x[d+14>>1];of(b);if(Gb(b,d+16|0)){continue}break}}gb=d+48|0}Zf(a,g,c,f+24|0);gb=f+32|0}function Cm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;rl(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=Bm(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}ec(a,21);v[a+1396>>2]=0}return-1}aa(8668,10534,1705,2537);L()}function t7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Kf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(Jf(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=id((v[Xg(a,b,g)>>2]+id(xt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=eo(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=c- -64|0}function C7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Kf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(Jf(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=id((v[Xg(a,b,g)>>2]+id(xt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=fo(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=c- -64|0}function Ex(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=Nf(a);a:{if(!v[115992]|!w[a|0]){break a}c=a;b:{if(c&3){while(1){b=w[c|0];if(!b|(b|0)==61){break b}c=c+1|0;if(c&3){continue}break}}b=v[c>>2];c:{if((b^-1)&b-16843009&-2139062144){break c}while(1){b=b^1027423549;if((b^-1)&b-16843009&-2139062144){break c}b=v[c+4>>2];c=c+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}while(1){b=c;e=w[c|0];if(e){c=b+1|0;if((e|0)!=61){continue}}break}c=b}if(w[c|0]==61?c:0){break a}d=v[v[115992]>>2];if(!d){break a}d:{while(1){i=v[115992];c=a;e=0;g=h;b=0;e:{if(!g){break e}b=w[c|0];f:{if(!b){break f}while(1){g:{j=w[d|0];if(!j){break g}g=g-1|0;if(!g|(b|0)!=(j|0)){break g}d=d+1|0;b=w[c+1|0];c=c+1|0;if(b){continue}break f}break}e=b}b=(e&255)-w[d|0]|0}if(!b){c=v[(f<<2)+i>>2]+h|0;if(w[c|0]==61){break d}}f=f+1|0;d=v[(f<<2)+i>>2];if(d){continue}break}return 0}f=c+1|0}return f}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);n=(l|0)<1;j=4;while(1){if(!n){i=b+k|0;o=l+i|0;while(1){p=g;t[e+7|0]=0;IV(a,e+15|0,e+12|0,e+7|0);a:{if(!j){g=w[e+7|0];break a}g=w[e+7|0];c=x[e+12>>1];f=j;b:{while(1){h=c<<1;c=h&254;c:{if(c){h=(h&65534)>>>0>255;break c}if(!lf(a,e+6|0)){break b}c=w[e+6|0];h=c>>>7|0;c=c<<1&254|1}g=g<<1|h;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;m=g&255;d:{if(m>>>0<4){break d}f=7;while(1){c=f;h=c&255;if(m>>>h&1){break d}f=c-1|0;if(h>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;f=f-1^(g&254)>>>1;g=f+w[e+8|0]|0;t[e+7|0]=g;t[i|0]=g;v[e+8>>2]=((f>>1)-(p<<24>>24)|0)+(g<<24>>24<<1);Yd(e+8|0,-128,127);j=(c+j&254)>>>1|0;i=d+i|0;if(o>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function Ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(g<<1)+n>>1];j=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);i=i<<8;e=i;e=nqa(j,j>>31,e,e>>31);j=jb;k=nqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=nqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function sA(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1298260|0;while(1){e=B(d,872)+a|0;c=e+1075068|0;b:{if(v[c>>2]){break b}if(!sk(e+1074992|0)){break a}if(v[c>>2]){break b}if(w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Dd(f)){break a}if(!DP(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){d=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,872)+a|0;if(!(v[c+1075688>>2]?0:v[c+1075068>>2])){f=(v[c+1075680>>2]|v[c+1075672>>2]<<9)>>>(v[c+1075080>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075716>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075716>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=d;j=fg(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!j){if(nd(a,5)){break a}}l=v[e+24>>2];d=gb-48|0;gb=d;h=v[a+28>>2];yl(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>=257|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){ag(h,d+38|0);f=Kb(d+24|0);v[22708]=0;W(655,h|0,f|0,255)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[22708]=0;U(13,d+8|0,l|0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break e}v[22708]=0;g=Q(1517,b|0,d+38|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}i=g;g=d+8|0;Eb(i,g);vb(g);vb(f);f=v[d+44>>2];k=k+1|0;if(!f&k>>>0<y[d+40>>2]|f){continue}break}}gb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+8|0)}vb(f);S(a|0);L()}}Zf(a,j,c,e+16|0);gb=e+32|0}function s3(){var a=0,b=0,c=0,d=0;c=gb-32|0;gb=c;a:{a=Tb(c+16|0,12535);if(!Ab(a)){break a}b:{if((vg(a,11846)|0)!=-1){b=vg(a,11846);v[22708]=0;Y(151,c|0,a|0,b+1|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,13873)|0)!=-1){b=vg(a,13873);v[22708]=0;Y(151,c|0,a|0,b+1|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,11163)|0)!=-1){b=vg(a,11163);v[22708]=0;Y(151,c|0,a|0,0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,11038)|0)!=-1){b=vg(a,11038);v[22708]=0;Y(151,c|0,a|0,0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,11081)|0)!=-1){b=vg(a,11081);v[22708]=0;Y(151,c|0,a|0,0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}v[22708]=0;b=T(152,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;vb(a);S(c|0);L()}vb(a);gb=c+32|0;return b|0}function Jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[g+n|0];j=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);i=i<<16;e=i;e=nqa(j,j>>31,e,e>>31);j=jb;k=nqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=nqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Baa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){d=Kb(c+32|0);b=v[a+24>>2];v[22708]=0;R(1961,c+16|0,b|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=Vb(b),v[e+8>>2]=f;e=c,f=Zb(b),v[e>>2]=f;if(!Gb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[22708]=0;Q(1168,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=c+8|0;rr(b);e=c,f=Zb(c+16|0),v[e>>2]=f;if(!Gb(b,c)){break b}v[22708]=0;Q(1919,d|0,11821)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(c+16|0);break d}b=V(0)|0;O()|0}vb(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=0;v[22708]=0;Y(1913,3648,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=ie(Jb(d));yd(c+16|0);vb(d)}gb=c+48|0;return b|0}function W9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){d=Kb(c+32|0);b=v[a+24>>2];v[22708]=0;R(1996,c+16|0,b|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=Vb(b),v[e+8>>2]=f;e=c,f=Zb(b),v[e>>2]=f;if(!Gb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[22708]=0;Q(1168,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=c+8|0;rr(b);e=c,f=Zb(c+16|0),v[e>>2]=f;if(!Gb(b,c)){break b}v[22708]=0;Q(1919,d|0,11821)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(c+16|0);break d}b=V(0)|0;O()|0}vb(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=0;v[22708]=0;Y(1913,4111,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=ie(Jb(d));yd(c+16|0);vb(d)}gb=c+48|0;return b|0}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-32|0;gb=c;k=c,l=uL(),v[k+24>>2]=l;d=c+24|0;sL(a+24|0,be(d));Fi(d);u[a+28>>1]=0;g=dY();v[c+16>>2]=4;e=c;h=gb-16|0;gb=h;f=tf(144);j=c+16|0;i=v[j>>2];v[22708]=0;g=W(2054,f|0,g|0,i|0)|0;i=v[22708];v[22708]=0;a:{if((i|0)!=1){f=v[Yi(h+8|0,g)>>2];gb=h+16|0;break a}a=P()|0;O()|0;Yb(f);S(a|0);L()}v[e+24>>2]=f;rL(a+32|0,be(d));hq(d);k=c,l=tL(v[a>>2]),v[k+24>>2]=l;qL(a+4|0,be(d));Ei(d);mo(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;k=c,l=nr(b),v[k+24>>2]=l;k=c,l=Dh(b),v[k+16>>2]=l;b:{if(og(d,j)){while(1){e=ue(c+24|0);b=gg(c,e);v[22708]=0;Y(2002,a|0,b|0,e+12|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(b);b=c+24|0;Sj(b);if(og(b,c+16|0)){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function EU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;wb(b);ef(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){Xr(a,v[b+4>>2]);zk(c+32|0,b);Ul(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=gb-80|0;gb=b;f=a;g=v[a+4>>2];d=v[c+20>>2];j=d;h=v[c+16>>2];v[b+72>>2]=h;v[b+76>>2]=d;e=v[c+12>>2];k=e;i=v[c+8>>2];v[b+64>>2]=i;v[b+68>>2]=e;v[b+24>>2]=h;v[b+28>>2]=d;v[b+16>>2]=i;v[b+20>>2]=e;d=DU(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!g){e=d-1|0;break b}e=d-1|0;if((e^g-1)>>>0<32){break a}}v[v[f>>2]+((d>>>0<33?0:e>>>5|0)<<2)>>2]=0}v[b+48>>2]=i;v[b+52>>2]=k;v[b+56>>2]=h;v[b+60>>2]=j;d=b+40|0;yp(d,f,g);f=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=f;f=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=f;CU(b+32|0,b+8|0,b,d);gb=b+80|0}gb=c+48|0;return a|0}function oN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-32|0;gb=h;l=h,m=$q(b),v[l+16>>2]=m;i=h+24|0;k=i;c=gb-32|0;gb=c;f=b;d=a;b=Xd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{g=b+16|0;e:{if(fN(d,f,g)){if(!v[b>>2]){break b}e=b;break e}if(!eN(g,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);f=c+8|0;g=Tj(f,$W(),Uj(d+8|0,b));b=v[g>>2];v[22708]=0;j=b+16|0;b=v[22708];v[22708]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[h+16>>2];u[j>>1]=x[v[b+8>>2]>>1];Kb(j+4|0);gb=b+16|0;l=fc(g),m=1,t[l+4|0]=m;gb=d+16|0;break f}a=P()|0;O()|0;dN(g);S(a|0);L()}Gk(a,v[c+28>>2],e,v[f>>2]);b=be(f);t[c+27|0]=1;dN(f)}Vj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(i);gb=h+32|0;return a+4|0}function yga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],fd(a)),v[k>>2]=m;qc(f,c>>>2|0);c=zb(b);h=z[e+4>>2];e=v[f>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);j=C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q())));h=h<j?j:h;c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;i=C(z[Af(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=i;a=c;i=fe(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Uc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}gb=f+16|0;return v[f>>2]<<2}function Ypa(){var a=0,b=0,c=0;b=gb-16|0;gb=b;Kb(90844);a=gb-16|0;gb=a;v[a+12>>2]=0;v[22714]=v[a+12>>2];gb=a+16|0;t[90860]=0;a=gb-16|0;gb=a;v[a+12>>2]=0;v[22716]=v[a+12>>2];gb=a+16|0;v[22708]=0;a=ga(36)|0;c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;a=b+8|0;RX(90856,be(a));qD(a);t[90860]=0;a=0;break e}a=Ca(89104,89080)|0;c=O()|0;if((ea(89104)|0)==(c|0)){Z(a|0)|0;v[22708]=0;X(37);a=v[22708];v[22708]=0;if((a|0)==1){break c}L()}if((ea(89080)|0)!=(c|0)){break b}Z(a|0)|0;v[22708]=0;t[90860]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;break b}a=w[90860]}if(a&255){break d}v[22708]=0;_(38,90840);a=v[22708];v[22708]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}gb=b+16|0;return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break a}}ln(90864);qD(90856);vb(90844);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function F8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb+-64|0;gb=f;v[f+56>>2]=d;d=qi(a,f+56|0);g=zh(a+4|0);h=zh(a+24|0);i=zh(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22708]=0;R(2081,a|0,e|0);l=v[22708];v[22708]=0;a:{b:{c:{d:{if((l|0)!=1){v[22708]=0;bc(f+24|0,b,c);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=Td(f+16|0);v[22708]=0;c=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=c;c=v[b+4>>2];v[f>>2]=v[b>>2];v[f+4>>2]=c;U(2085,f+32|0,f+8|0,f|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;U(2082,a|0,f+32|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}xb(f+32|0);v[22708]=0;_(2083,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(f+32|0)}yd(k);Yf(j);hq(i);Fi(h);Ei(g);eg(d);eg(f+56|0);S(a|0);L()}eg(f+56|0);gb=f- -64|0;return a|0}function u7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=id(v[Xg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=eo(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=id(v[Xg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=fo(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function xp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{if(!b){break a}if(c){c=ne(f+8|0,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}gb=a+16|0;break a}c=ne(f,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}gb=a+16|0}gb=f+16|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];c=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(c){a=v[a+20>>2];h=c;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=e,j=Uc(g),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=e,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;h=h-1|0;if(h){continue}break}}gb=d+16|0;return c<<3}function qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+32;wb(a);eP(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=Zq(a,ze(a)+1|0);i=ze(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;jf(c+12|0,f);if(d){e=d;if(d>>>0>=134217728){rd(8445);L()}e=Nc(e<<5,8)}v[c>>2]=e;f=(i<<5)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=dc(c),k=(d<<5)+e|0,v[j>>2]=k;gb=h+16|0;eP(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;ev(a);wb(a);b=c+4|0;ol(v[a>>2],v[a+4>>2],b);wc(a,b);wc(a+4|0,c+8|0);wc(wb(a),dc(c));v[c>>2]=v[c+4>>2];eB(a,ze(a));a=c;b=c;c=v[c+4>>2];a:{while(1){d=v[b+8>>2];if((d|0)==(c|0)){break a}v[b+8>>2]=d-32;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){mV(v[a+16>>2],b,CB(a))}gb=g+32|0}function $w(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+90032>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=ji(c,b)}return c}return a+1}function lga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;i=a;a:{b:{if(!((b|0)==(c|0)|(e|0)>-1)){t[b|0]=45;f=d;d=0-d|0;e=0-(((f|0)!=0)+e|0)|0;b=b+1|0}f=c-b|0;if((f|0)<=19){g=E(e);g=B(64-((g|0)==32?E(d|1)+32|0:g)|0,1233)>>>12|0;h=(g<<3)+27088|0;j=f;f=v[h+4>>2];if((j|0)<((g-((e|0)==(f|0)&d>>>0<y[h>>2]|e>>>0<f>>>0)|0)+1|0)){break b}}c=a;c:{if(!e&d>>>0<=99999999){a=Zx(b,d);break c}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){a=qqa(d,e,1e8,0);e=jb;f=Zx(b,a);a=d-nqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=wj(wj(f,b),a-B(b,1e4)|0);break c}a=qqa(d,e,1874919424,2328306);f=jb;g=Yx(b,a);a=nqa(a,f,1874919424,2328306);b=d-a|0;a=qqa(b,e-(jb+(a>>>0>d>>>0)|0)|0,1e8,0);e=jb;f=(a>>>0)/1e4|0;d=wj(wj(g,f),a-B(f,1e4)|0);a=b-nqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=wj(wj(d,b),a-B(b,1e4)|0)}v[c>>2]=a;a=0;break a}v[a>>2]=c;a=61}v[i+4>>2]=a}function gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=gb-4112|0;gb=c;i=kb[v[v[a>>2]+116>>2]](a)|0;if(!i){kb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=gb-16|0;gb=f;h=a+44|0;if(Vf(h)){while(1){e=Hn(h,d);g=Hn(h,d);v[f+12>>2]=0;g=(g+2048|0)-e>>2;if((g|0)>=1){while(1){z[e>>2]=z[f+12>>2];e=e+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}d=d+1|0;if(Vf(h)>>>0>d>>>0){continue}break}}gb=f+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;qc(c+8|0,512);d=c+16|0;Xo(d);kb[v[v[a>>2]+60>>2]](a,d,f,v[c+8>>2]);e=0;d=0;if(v[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;z[c+4>>2]=D(z[e>>2]);k=c,l=z[az(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[e+2048>>2]);k=c,l=z[az(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=v[c+8>>2];d=d+1|0;if(e>>>0>d>>>0){continue}break}}b=b-e|0;if(b){continue}break}}if(!i){kb[v[v[a>>2]+124>>2]](a)}gb=c+4112|0;return C(z[c+12>>2])}function M5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2304,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=dj(c+8|0,a);f=Wi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2305,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function J5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2304,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=dj(c+8|0,a);f=Wi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2306,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2304,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=dj(c+8|0,a);f=Wi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2308,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function D5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2304,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=dj(c+8|0,a);f=Wi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2309,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function B5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2304,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=dj(c+8|0,a);f=Wi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2310,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;k=f,l=$q(b),v[k+16>>2]=l;e=gb-32|0;gb=e;g=b;d=a;b=Xd(d);c=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+13|0;e:{if(Nu(g,d)){if(!v[b>>2]){break b}c=b;break e}if(!Nu(d,g)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c;c=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=c;break a}v[e+28>>2]=b;b=c;break a}b=fc(d)}v[e+28>>2]=b}g=b;b=v[b>>2];t[e+27|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);d=e+8|0;j=Tj(d,lC(),Uj(i+8|0,b));b=v[j>>2];h=gb-16|0;gb=h;v[h+8>>2]=v[f+16>>2];c=v[h+8>>2];c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+17|0]=0;t[b+13|0]=c;t[b+14|0]=c>>>8;t[b+15|0]=c>>>16;t[b+16|0]=c>>>24;gb=h+16|0;k=fc(j),l=1,t[k+4|0]=l;gb=i+16|0;Gk(a,v[e+28>>2],g,v[d>>2]);b=be(d);t[e+27|0]=1;mC(d)}Vj(f+24|0,yc(e+8|0,b),e+27|0);gb=e+32|0;gb=f+32|0;return v[f+24>>2]+17|0}function $s(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;c=v[v[a>>2]-12>>2];v[22708]=0;c=v[(a+c|0)+24>>2];b=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[22708]=0;c=Q(15,d+8|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[22708]=0;b=v[(a+b|0)+24>>2];e=v[22708];v[22708]=0;f:{if((e|0)==1){break f}v[22708]=0;b=T(2302,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+b|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;ll(c);break c}b=V(0)|0;O()|0;break c}ll(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kA(a,b){var c=0;c=gb-16|0;gb=c;a=oA(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(a,7,1);Ob(a,9,1);Ob(a,10,1);Ob(a,13,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,20,1);Ob(a,21,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,28,1);Ob(a,30,1);Ob(a,31,1);Ob(a,33,1);Ob(a,34,1);Ob(a,39,1);Ob(a,41,1);Ob(a,44,1);Ob(a,46,1);Ob(a,45,1);Ob(a,47,1);Ob(a,48,1);Ob(a,50,1);Ob(a,99,1);Ob(a,102,1);Ob(a,104,1);Ob(a,105,1);break a;case 1:iA(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Rf(a,107);break a;case 3:iA(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Rf(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}iA(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}gb=c+16|0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=gb-16|0;gb=i;j=a+44|0;if(ni(j)){h=Nd(j,0);v[i+8>>2]=h;k=Nd(j,1);v[i+12>>2]=k;e=od(j,0);v[i>>2]=e;f=od(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4236>>2];r=z[a+4232>>2];s=z[a+4228>>2];t=z[a+4220>>2];u=z[a+4224>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(C(l*t)+C(u*n))+C(s*p))-C(r*o))-C(q*w));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;hc(e,g,h);hc(f,k,h)}Gi(a,b,c,od(j,0),od(j,1),d)}gb=i+16|0}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-80|0;gb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){h=Td(d+72|0);f=b-e|0;b=Mu(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Ul(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}wb(a);b=xB(d+56|0);e=v[a+4>>2];v[22708]=0;e=Q(951,a|0,e+f|0)|0;g=v[22708];v[22708]=0;c:{if((g|0)==1){break c}v[22708]=0;R(952,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;zk(d+40|0,a);Ul(d+32|0,a);e=d+24|0;zk(e,b);v[22708]=0;g=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=g;g=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=g;Y(953,d+48|0,d+8|0,d|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;wB(a,b);Ye(b);break b}a=P()|0;O()|0;Ye(b);S(a|0);L()}v[a+4>>2]=b;break a}xp(ne(d+16|0,h),f,c)}gb=d+80|0}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22708]=0;_(1962,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;_(1962,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22708]=0;d=Q(70,e+16|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;c=Q(70,e|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;Y(2002,f|0,d|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c);vb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;vb(c)}vb(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,3466,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=e+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function RY(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+28528|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=gb-32|0;gb=i;a:{b:{c:{if((b|0)!=(c|0)){j=v[115189];v[115189]=0;g=gb-16|0;gb=g;xe();e=gb-16|0;gb=e;f=gb-16|0;gb=f;Ux(f,b,i+28|0,2);k=v[f>>2];h=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=h;gb=f+16|0;h=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=h;v[g+4>>2]=f;gb=e+16|0;h=v[g>>2];f=v[g+4>>2];e=v[g+12>>2];b=i;v[b+16>>2]=v[g+8>>2];v[b+20>>2]=e;v[b+8>>2]=h;v[b+12>>2]=f;gb=g+16|0;h=v[b+16>>2];f=v[b+20>>2];g=v[b+8>>2];e=v[b+12>>2];b=v[115189];if(!b){break c}if(v[i+28>>2]!=(c|0)){break b}l=g;m=e;n=h;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115189]=j;if(v[i+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;h=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=h;v[a+12>>2]=f;gb=i+32|0}function xq(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=nqa(b,d,5e4,0);e=jb;b=v[Mc(c+8|0,c)>>2];b=Ac(oqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=nqa(v[a+1074420>>2],0,nqa(v[a+1074408>>2],0,v[a+1074416>>2],0),jb),v[g>>2]=h;v[c+4>>2]=jb;d=gb-16|0;gb=d;e=c+8|0;f=sw(e,c);gb=d+16|0;d=nqa(b,0,6e5,0);b=f?c:e;b=qqa(d,jb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=nqa(b,d,1e4,0);e=jb;b=v[Mc(c+8|0,c)>>2];b=Ac(oqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=nqa(a,a>>31,b,b>>31)+32768|0;a=jb;a=Ac(oqa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[d>>2]=a?a:1;gb=c+16|0}function haa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1982,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1983,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,9165,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1984,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1983,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,9133,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function faa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1985,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1983,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,9071,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1986,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1983,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,9101,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function daa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1987,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1983,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,9036,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1988,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1983,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,9197,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function xy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=_m(ee(A[Wg(a,c,f)>>3]*134217728));i=yy(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function Ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=_m(ee(A[Wg(a,c,f)>>3]*134217728));i=By(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function lJ(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=gb-96|0;gb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){j=(e+48|0)+(f<<3)|0;h=(f<<4)+a|0;i=z[h+4>>2];g=z[h+8>>2];z[j+4>>2]=i+g;k=f<<1;z[(8-k<<2)+e>>2]=i-g;i=z[h+16>>2];g=z[h+12>>2];z[(7-k<<2)+e>>2]=i-g;z[j+8>>2]=-C(i+g);f=f+1|0;if((f|0)!=4){continue}break}kJ(e+48|0);kJ(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];h=0;while(1){f=h<<2;j=f+b|0;i=z[j>>2];g=z[f+(e+48|0)>>2];l=z[f+68176>>2];m=z[f+68212>>2];n=z[e+f>>2];z[j>>2]=C(g*l)-C(m*n);j=a+f|0;f=c+f|0;g=C(C(g*m)+C(n*l));z[j>>2]=C(i*z[f>>2])-C(g*z[f+36>>2]);z[(17-h<<2)+a>>2]=C(i*z[f+36>>2])+C(g*z[f>>2]);h=h+1|0;if((h|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}gb=e+96|0}function HL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=gb+-64|0;gb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[22708]=0;v[j+20>>2]=d?d:1921;a=Q(1922,j+20|0,j+60|0)|0;b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[iq(j+32|0,j+24|0)>>2];b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;v[22708]=0;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+za(1923,j|0,+c,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}Dj(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Dj(j+24|0)}Z(a|0)|0;v[22708]=0;ja(1924,12246,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}gb=j- -64|0;return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Tw(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+60>>2]=d;a:{f=v[b>>2];b:{if(!(kb[v[v[f>>2]+36>>2]](f,c,d)|0)){NF(a);break b}im(e+40|0,b);v[22708]=0;b=v[b>>2];d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[22708]=0;b=T(d|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;v[e+36>>2]=b-c;b=Fb(e+60|0,e+36|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;b=gb-16|0;gb=b;d=e+16|0;f=im(b+8|0,d);v[22708]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;Y(221,e+48|0,b|0,c|0,g|0);c=v[22708];v[22708]=0;c:{if((c|0)!=1){Kd(d);gb=b+16|0;break c}a=P()|0;O()|0;Kd(d);S(a|0);L()}b=Td(e+24|0);c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;Hw(a,e+8|0,e)}gb=e- -64|0;return}a=P()|0;O()|0;Kd(e+40|0);S(a|0);L()}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);while(1){if((m|0)>=1){j=(k<<1)+b|0;o=j+(m<<1)|0;while(1){u[e+10>>1]=0;JV(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{if(!i){g=x[e+10>>1];break a}g=x[e+10>>1];c=x[e+12>>1];h=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!lf(a,e+9|0)){break a}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}g=f|g<<1;h=h-1|0;if(h&255){continue}break}}c=1;f=g&65535;b:{if(f>>>0<4){break b}h=15;while(1){c=h;n=c&255;if(f>>>n&1){break b}h=c-1|0;if(n>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=g&1;t[e+14|0]=c;l=(c-1^(g&65534)>>>1)+l|0;u[e+10>>1]=l;u[j>>1]=l;j=(d<<1)+j|0;if(o>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function UF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[22708]=0;g=Q(15,d+24|0,a|0)|0;e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=dj(d+8|0,a);f=v[v[a>>2]-12>>2];h=v[(f+a|0)+4>>2];v[22708]=0;f=a+f|0;i=T(16,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break d}e=v[e>>2];v[22708]=0;c=b+c|0;b=la(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!_v(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+b|0,5);b=v[22708];v[22708]=0;if((b|0)!=1){break e}break d}ll(g);break b}b=V(0)|0;O()|0;ll(g);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}$()}gb=d+32|0;return a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){V(0)|0;O()|0;Bb();L()}S(a|0);L()}function yK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;v[f+12>>2]=c;a:{if(!b){a=a+120|0;go(a);c=v[f+12>>2];b=a;d=vh(b);b:{if(!c){break b}v[22708]=0;R(2114,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;At(b,c);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Dy(d);S(a|0);L()}t[a+20|0]=0;break a}d=gb-16|0;gb=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;go(b);iK(b,a,d+12|0);t[b+20|0]=1;break c}e=gb-16|0;gb=e;v[e+12>>2]=c;d:{if((b|0)==2){a=a+120|0;go(a);c=v[e+12>>2];b=a;g=b;h=vh(b);e:{if(!c){break e}v[22708]=0;R(2116,g|0,c|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;At(g,c);c=v[22708];v[22708]=0;if((c|0)!=1){break e}}a=P()|0;O()|0;Dy(h);S(a|0);L()}Td(b+12|0);t[a+20|0]=2;break d}b=gb-16|0;gb=b;v[b+12>>2]=c;c=a+120|0;go(c);iK(c,a,b+12|0);t[c+20|0]=3;gb=b+16|0}gb=e+16|0}gb=d+16|0}gb=f+16|0}function oH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;h=gb-1040|0;gb=h;i=v[b>>2];v[h+12>>2]=i;g=a?d:256;j=a?a:h+16|0;d=0;a:{b:{c:{if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(f>>>0<g>>>0&c>>>0<=131){break b}while(1){f=k?g:f;c=c-f|0;f=Bx(j,h+12|0,f,e);if((f|0)==-1){g=0;i=v[h+12>>2];d=-1;break c}i=(h+16|0)==(j|0)?0:f;g=g-i|0;j=(i<<2)+j|0;d=d+f|0;i=v[h+12>>2];if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(c>>>0>131|f>>>0>=g>>>0){continue}break}break b}if(!i){break a}}if(!g|!c){break a}f=d;while(1){d:{d=_p(j,i,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[h+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}i=v[h+12>>2]+d|0;v[h+12>>2]=i;f=f+1|0;g=g-1|0;if(g){break d}}d=f;break a}j=j+4|0;c=c-d|0;d=f;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+1040|0;return d|0}function jk(a,b){var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;d=v[v[a>>2]-12>>2]+a|0;f=v[d+16>>2]&-3;no(d,f);a:{b:{if(w[uj(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;d=v[(a+d|0)+24>>2];e=v[22708];v[22708]=0;c:{d:{if((e|0)==1){break d}v[22708]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;Y(2314,c+40|0,d|0,c+8|0,8);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=sh(c+24|0,-1,-1);v[22708]=0;b=HJ(c+40|0,b);d=v[22708];v[22708]=0;if((d|0)==1){break d}b=b?f|4:f;break c}b=V(0)|0;O()|0;Z(b|0)|0;b=f|1;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,b)}gb=c- -64|0;return}V(0)|0;O()|0;Bb()}L()}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;ud(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;g=c,h=w[ac(e,d)|0]<<2,u[g+30>>1]=h;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;Lk(d,2,b+1|0);Bc(e,d);v[22708]=0;Q(303,c+43|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){vb(d+16|0);e=Rc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}Zi(e,16);Cf(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;l=g,m=bX(b),v[l+16>>2]=m;i=g+24|0;k=i;c=gb-32|0;gb=c;d=b;e=a;b=Xd(a);f=fc(a);a:{b:{if(b){e=wb(e);c:{while(1){d:{h=b+16|0;e:{if(NC(e,d,h)){if(!v[b>>2]){break b}f=b;break e}if(!MC(h,d)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=f;break a}v[c+28>>2]=b;b=f;break a}b=fc(e)}v[c+28>>2]=b}f=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;b=fc(a);d=c+8|0;j=Tj(d,$W(),Uj(e+8|0,b));h=v[j>>2]+16|0;b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];u[h>>1]=x[v[b+8>>2]>>1];Kb(h+4|0);gb=b+16|0;l=fc(j),m=1,t[l+4|0]=m;gb=e+16|0;Gk(a,v[c+28>>2],f,v[d>>2]);b=be(d);t[c+27|0]=1;a=v[d>>2];v[d>>2]=0;if(a){if(w[fc(d)+4|0]){Fk(a+16|0)}if(a){_W(a)}}}Vj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(i);gb=g+32|0;return a+4|0}function lZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Rr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Rr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Ju(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}gb=d+16|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((Vf(a)|0)==(b|0)){if((Vf(a+12|0)|0)==(c|0)){break b}}v[22708]=0;R(1536,a|0,b|0);d=v[22708];v[22708]=0;c:{d:{if((d|0)==1){break d}v[22708]=0;e=a+12|0;R(1536,e|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;f=a+24|0;R(1537,f|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;g=a+36|0;R(1537,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Hn(a,d);i=Mb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;_M(a);ZM(a);b=a+12|0;_M(b);ZM(b);b=a+24|0;Fg(b);YM(b);a=a+36|0;Fg(a);YM(a);$();return 0}a=0;while(1){b=Hn(e,a);i=Mb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=v[Xg(a,c,f)>>2];i=By(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function jW(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-48|0;gb=b;f=b,g=Xb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[f+8>>2]=g;v[b+12>>2]=0;f=b,g=Xb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[f+16>>2]=g;v[b+20>>2]=0;d=b;c=b;if(Xb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))){e=Xb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))}else{e=52}v[c+24>>2]=e;v[d+28>>2]=0;a=Xb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24));v[b+44>>2]=4;v[b+32>>2]=a+80;v[b+36>>2]=0;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;d=gb-16|0;gb=d;a=v[b>>2];e=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}c=a+8|0;if((e|0)==(c|0)){break a}while(1){a=sw(a,c)?c:a;c=c+8|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0;gb=b+48|0;b=v[a>>2];d=b-52|0;jb=v[a+4>>2]-(b>>>0<52)|0;return d}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;f=c+32|0;Wc(b,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));h=dd(a);f=c+28|0;a=f;e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=0;v[22708]=0;R(1425,h|0,e|0);e=v[22708];v[22708]=0;if((e|0)!=1){a:{e=f;b:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break b}e=c+4|0;while(1){v[22708]=0;c=Q(191,b|0,4)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}if(!c){break b}c=w[e|0]|w[e+1|0]<<8;v[22708]=0;c=Q(1426,b|0,c|0)|0;i=v[22708];v[22708]=0;c:{if((i|0)!=1){v[g+12>>2]=c;if(Ec(d)>>>0<=c>>>0){break c}v[22708]=0;R(1427,h|0,g+12|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}}break a}a=a+1|0;c=f;if(a>>>0<(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){continue}break}}gb=g+16|0;return}}a=P()|0;O()|0;Lc(h);S(a|0);L()}function vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Xg(a,c,f);i=yy(g,c,f),j=C(C(v[h>>2])*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function r8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Ti(Sb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[sc(Sb(v[e>>2]+484360|0),b)>>1];c:{if(!cm(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;c=b&65535;NO(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=d+48|0;tu(b,e,f?7:1,d);h=a,i=A[IO(b)>>3],A[h+16>>3]=i;en(b);a=a+16|0}gb=d- -64|0;return+A[a>>3]}function M3(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22708]=0;R(99,c+32|0,b|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22708]=0;d=ga(79)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Wb(c+8|0);v[22708]=0;b=HN(a);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;b=Q(105,b|0,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22708]=0;b=El(b+d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[c+32>>2];wf(a);gb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;wf(a)}S(b|0);L()}return a|0}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;ud(b,4);u[b+30>>1]=w[a+12|0]<<2;yg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Tb(d,18726);v[22708]=0;Q(303,b+43|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){vb(a);gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function b8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=mc(a);f=b+24|0;a=v[f>>2];v[22708]=0;a=nq(a+484344|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)==1){break c}v[22708]=0;R(1422,e|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[22708]=0;c=nq(c+484344|0);g=v[22708];v[22708]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[22708]=0;R(2100,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;U(2094,d+16|0,b|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;R(1424,e|0,d+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}a=a+1|0;vb(d+16|0);vb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Uc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<3}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=gb-16|0;gb=g;v[g+12>>2]=c;c=gb+-64|0;gb=c;m=c;j=c+16|0;k=gb-16|0;gb=k;n=dU(k+8|0);while(1){e=b;h=gb+-64|0;gb=h;d=n;f=v[d+4>>2]-v[d>>2]|0;a:{if(!f){d=v[d>>2];break a}f=f+1|0;if(!f){d=uK(vK(h+8|0,e,32));break a}i=e;e=E(f);e=vK(h+8|0,i,(f&-1>>>e+1?32:31)-e|0);while(1){i=uK(e);if(f>>>0<=i>>>0){continue}break}d=v[d>>2]+i|0}gb=h- -64|0;o=Pe(j,l),p=d,v[o>>2]=p;l=l+1|0;if((l|0)!=12){continue}break}gb=k+16|0;d=kU(m,j,rU(j));v[22708]=0;b=a;RB(b,d,0);e=v[22708];v[22708]=0;b:{if((e|0)!=1){Lc(d);gb=c- -64|0;break b}a=P()|0;O()|0;Lc(d);S(a|0);L()}c=b+120|0;tK(c,b,g+12|0);t[c+20|0]=1;v[22708]=0;R(2109,b|0,v[g+12>>2]);b=v[22708];v[22708]=0;c:{if((b|0)!=1){gb=g+16|0;break c}a=P()|0;O()|0;go(c);S(a|0);L()}return a|0}function aN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-16|0;gb=d;a:{if(Nb(a)>>>0>511){break a}if(!_f(v[v[b>>2]-12>>2]+b|0)){break a}j=d;g=b;h=c;f=gb-16|0;gb=f;e=tf(64);v[22708]=0;i=T(1317,e|0)|0;k=v[22708];v[22708]=0;b:{c:{if((k|0)!=1){e=ns(f,i);i=v[e>>2];v[22708]=0;g=W(1531,i|0,g|0,h|0)|0;h=v[22708];v[22708]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}cA(f+8|0);break d}a=P()|0;O()|0;Ig(e);break c}qi(f+8|0,e)}Ig(e);gb=f+16|0;g=v[f+8>>2];break b}a=P()|0;O()|0;Yb(e)}S(a|0);L()}v[j+8>>2]=g;f:{g:{if(!Dd(d+8|0)){v[22708]=0;b=Q(1529,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}v[d>>2]=b;eX(d+8|0,be(d));Ig(d)}if(!Dd(d+8|0)){break f}b=d+8|0;l=v[b>>2];v[22708]=0;R(1530,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;Ig(d+8|0);S(a|0);L()}Ig(d+8|0)}gb=d+16|0;return l}function rH(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Ex(11165);if(w[b|0]?b:0){break a}b=Ex(B(a,12)+79456|0);if(w[b|0]?b:0){break a}b=Ex(11412);if(w[b|0]?b:0){break a}b=11954}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=11954;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!xj(d,11954)){break e}if(xj(d,10846)){break d}}if(!a){c=74820;if(w[d+1|0]==46){break c}}return 0}c=v[115995];if(c){while(1){if(!xj(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115995];if(c){while(1){if(!xj(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=Cd(28);g:{if(!c){c=0;break g}v[c+4>>2]=20;v[c>>2]=74800;b=c+8|0;hc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115995];v[115995]=c}c=a|c?c:74820}return c}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;m=g,n=$q(b),v[m+16>>2]=n;j=g+24|0;l=j;d=gb-32|0;gb=d;f=b;c=a;b=Xd(c);e=fc(c);a:{b:{if(b){wb(c);c:{while(1){d:{c=b+14|0;e:{if(dP(f,c)){if(!v[b>>2]){break b}e=b;break e}if(!dP(c,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=fc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);f=d+8|0;k=Tj(f,lC(),Uj(i+8|0,b));b=v[k>>2];c=gb-16|0;gb=c;v[c+8>>2]=v[g+16>>2];h=v[c+8>>2];h=x[h>>1]|x[h+2>>1]<<16;u[b+18>>1]=0;u[b+14>>1]=h;u[b+16>>1]=h>>>16;gb=c+16|0;m=fc(k),n=1,t[m+4|0]=n;gb=i+16|0;Gk(a,v[d+28>>2],e,v[f>>2]);b=be(f);t[d+27|0]=1;mC(f)}Vj(l,yc(d+8|0,b),d+27|0);gb=d+32|0;a=Xl(j);gb=g+32|0;return a+4|0}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;t[e+15|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);o=(m|0)<1;j=4;while(1){if(!o){i=b+k|0;p=m+i|0;while(1){t[e+11|0]=0;IV(a,e+15|0,e+12|0,e+11|0);a:{if(!j){h=w[e+11|0];break a}h=w[e+11|0];c=x[e+12>>1];f=j;b:{while(1){g=c<<1;c=g&254;c:{if(c){g=(g&65534)>>>0>255;break c}if(!lf(a,e+10|0)){break b}c=w[e+10|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;g=h&255;d:{if(g>>>0<4){break d}f=7;while(1){c=f;n=c&255;if(g>>>n&1){break d}f=c-1|0;if(n>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&254)>>>1)+l|0;t[e+11|0]=l;t[i|0]=l;j=(c+j&254)>>>1|0;i=d+i|0;if(p>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function zW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}xW(g+15|0,g+13|0);xW(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}qz(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){to(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(uo(c)>>>0<=uo(w[g+14|0])>>>0){break b}gi(g+15|0,g+14|0);gi(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];gb=g+16|0}function Ly(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;vq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=mg(g+32|0,c,hL(c),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;zt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=56252;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=55456;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Gt(c,v[Tk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function Ky(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;vq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=mg(g+32|0,c,hL(c),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;zt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=57096;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=56332;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Gt(c,v[Tk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function yma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-528|0;gb=d;c=-1;a:{if(!Wf(a,1468)){break a}Vl(a,1464);b=d+524|0;EV(a,b);if(!je(b,33202)){c=0;if(!je(d+524|0,12635)){break a}}Vl(a,20);b=1;while(1){c=-1;if(!BV(a,d)){break a}e=gC(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;f=e;c=gb-32|0;gb=c;b=a;b:{if(!Wf(b,2)){t[c+16|0]=0;kE(f,c+16|0);break b}Bn(c+24|0,f);f=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=f;_B(c+16|0,b,c+8|0)}gb=c+32|0;f=qd(e);c=0;if(w[e|0]>128){break a}b=d;c=gb-32|0;gb=c;c:{if(!Wf(a,512)){jV(b);break c}Sv(c+24|0,b);e=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=e;_B(c+16|0,a,c+8|0)}gb=c+32|0;a=d+512|0;c=w[f|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}gb=d+528|0;return c|0}function cpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-304|0;gb=e;Se(b);if(Pb(a,1)){a:{while(1){d=e+48|0;td(e+24|0,d,d+256|0);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;d=gb-48|0;gb=d;f=v[a>>2];i=v[a+8>>2];g=v[e+12>>2];h=v[e+8>>2];v[d+16>>2]=h;v[d+20>>2]=g;v[d+24>>2]=h;v[d+28>>2]=g;rh(d+32|0,d+16|0);g=v[v[f>>2]+28>>2];h=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=h;kb[g|0](d+40|0,f,i,d+8|0);f=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=f;f=e+32|0;rh(f,d);gb=d+48|0;j=e,k=yb(f),v[j+44>>2]=k;j=e,k=c-Ab(b)|0,v[j+20>>2]=k;d=v[Fb(e+44|0,e+20|0)>>2];if(!d){break a}t[e+32|0]=0;h=d;d=e+48|0;g=h+d|0;i=e+32|0;f=Xm(d,g,i);j=e,k=ff(b),v[j+32>>2]=k;Gd(e+16|0,i);NX(b,v[e+16>>2],d,f);Rb(a,f-d|0);if(f>>>0>=g>>>0){continue}break}Rb(a,1)}d=(Ab(b)|0)!=0}gb=e+304|0;return d|0}function Cj(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-48|0;gb=f;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}tO(v[d>>2],1);break a}e=f+8|0;hc(e,v[d>>2]+24604|0,40);h=v[e+32>>2];i=v[e+36>>2];v[f+28>>2]=c;v[f+24>>2]=b;It(e,h);Lo(e,i);Xz(v[d>>2],e);if((b|0)==(g|0)){break a}b=v[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break b}kb[v[v[b>>2]+108>>2]](b,0);kb[v[v[b>>2]+96>>2]](b);kb[v[v[b>>2]+124>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(kb[v[v[b>>2]+116>>2]](b)|0){break c}kb[v[v[b>>2]+108>>2]](b,1);kb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}t[a+29|0]=1;gb=f+48|0}function Pn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;h=a;a=gb-16|0;gb=a;i=a;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);j=Ab(d);k=v[b>>2];v[22708]=0;xu(e+8|0,c,f+j|0,k);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=yf(e+4|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,i|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(85,h|0,a|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=g+16|0}function Lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;c=Li(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((Jg(a)|0)!=(c|0)){break b}b=gb-16|0;gb=b;c=Vb(a);d=Zb(a);hi(b+8|0);a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=c;d=Wt(a,a+8|0);g=gb-16|0;gb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){h=g+8|0;c=v[h>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;$j(h);d=d-1|0;if(c){continue}break}}gb=g+16|0;gb=a+16|0;gb=b+16|0;break a}d=f+8|0;hi(d);c=nX(f+16|0,c,d);EN(a);kp(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[wb(c)>>2];i=wb(a),j=d,v[i>>2]=j;i=wb(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;jn(c);v[a+12>>2]=b}a=1}else{a=0}gb=f+32|0;return a|0}function x7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=A[Wg(a,c,f)>>3];i=By(g,c,f),j=C(h),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function o7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Kf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Jf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Wg(a,c,f);i=yy(g,c,f),j=C(A[h>>3]),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;gb=e+32|0}function uV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0>32768){break a}h=Ib(w[d+42|0]|w[d+43|0]<<8)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function M8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-96|0;gb=d;v[22708]=0;f=v[b+12>>2];v[d+40>>2]=v[b+8>>2];v[d+44>>2]=f;f=v[b+4>>2];v[d+32>>2]=v[b>>2];v[d+36>>2]=f;f=T(2077,d+32|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){a:{b:{if(f){v[22708]=0;R(2078,d+72|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=d+80|0;f=d+72|0;Gw(b,f);e=Xf(d+88|0,b);g=Xf(d- -64|0,c);h=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=h;e=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=e;Hw(a,d+8|0,d);break b}break a}v[22708]=0;R(2079,d+72|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=d+80|0;f=d+72|0;Gw(b,f);e=Xf(d+56|0,b);g=Xf(d+48|0,c);h=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=h;e=v[g+4>>2];v[d+16>>2]=v[g>>2];v[d+20>>2]=e;Hw(a,d+24|0,d+16|0)}Kd(b);Kd(f);Kd(c);gb=d+96|0;return}}a=P()|0;O()|0;Kd(c);S(a|0);L()}function pO(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-1;a:{if(!Pz(a,b,2)){break a}i=v[b+656>>2];d=e+8|0;f=a+1074312|0;Db(d,f,31);b:{if(Cb(d)){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}h=e+8|0;Db(h,f,31);f=d-Cb(h)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Uq(i+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+746|0]&16){g=Iq(a,b,!(v[b+88>>2]&32768),d);break a}if(Kj(b)){if((d|0)==u[b+772>>1]){break a}j=b,k=Uc(d),u[j+772>>1]=k;t[b+851|0]=w[b+851|0]|32;break a}b=rk(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;bk(e+8|0,255);a=(v[e+8>>2]<<2)+(b?44608:43584)|0;break c}bk(e+8|0,255);a=(v[e+8>>2]<<2)+(b?43584:44608)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];j=f,k=Ac(oqa(nqa(b,d,a,a>>31),jb,65536,0),jb),v[j>>2]=k}gb=e+16|0;return g}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];j=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){k=0;e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24|h>>>8;e=0;l=f&65280;f=e;e=g<<8|h>>>24;f=f|k;k=e&255|l|(h<<24|h<<8&16711680);v[d+24>>2]=((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24)|f;v[d+28>>2]=k;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;i=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=i;e=a;i=ee(i);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}m=e,n=Uc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return j<<3}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){g=Jb(d);i=Jb(d);j=Ab(d);k=v[b+4>>2];c=v[b>>2];v[22708]=0;Pa(78,e+8|0,g|0,i+j|0,c|0,k|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=yf(e+4|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(72,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Pp(a){var b=C(0),c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=ti(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-ti(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=ui(f+1.5707963267948966);break a}b=ui(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ti(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=ui(-4.71238898038469-+a);break a}b=ui(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(ay(a,c+8|0)&3){case 0:b=ti(A[c+8>>3]);break a;case 1:b=ui(-A[c+8>>3]);break a;case 2:b=C(-ti(A[c+8>>3]));break a;default:break b}}b=ui(A[c+8>>3])}a=b;gb=c+16|0;return a}function pN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=C(0);f=gb-16|0;gb=f;g=u[d>>1];e=u[d+2>>1];if(!(!x[b>>1]|(g|0)>(e|0)|(!(z[c>>2]>C(0))|(e-g|0)>32766))){u[a>>1]=3;h=a+4|0;Fg(h);u[a+28>>1]=65472;v[f+12>>2]=1065353216;rN(h,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Fg(a+16|0);u[a+28>>1]=x[d>>1];g=a;e=gb-16|0;gb=e;u[e+14>>1]=x[b>>1];v[22708]=0;u[e+12>>1]=32767;b=Pc(e+14|0,e+12|0);j=v[22708];v[22708]=0;a:{if((j|0)!=1){gb=e+16|0;b=u[b>>1];break a}V(0)|0;O()|0;Bb();L()}u[g+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=oe(i,C(C(1)/C(u[a+30>>1])));j=1;Dl(h,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){k=oe(i,C(b|0));l=Mb(h,b-u[a+28>>1]|0),m=k,z[l>>2]=m;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}mq(a)}gb=f+16|0;return j|0}function Hi(a,b,c,d){var e=0,f=0,g=0,h=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=50140;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;h=dd(b);f=dd(b+12|0);g=dd(b+24|0);e=dd(b+36|0);v[22708]=0;W(1534,b|0,2,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){a=P()|0;O()|0;Lc(e);Lc(g);Nt(f);Nt(h);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[22708]=0;e=T(1634,a+92|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){v[c>>2]=e;g=v[a+20>>2];f=v[a+16>>2];b=w[a+4200|0];if(!((g|0)==((f+B(b,160)|0)+906300|0)|b>>>0>248)){e=a+4200|0;while(1){c=b+1|0;if((g|0)!=((f+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[e|0]=c}return a}a=P()|0;O()|0;GM(b);S(a|0);L()}function EL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);d=Ab(b);h=Jb(c);i=Ab(c);g=d+f|0;d=-1;a:{while(1){if((f|0)==(g|0)){break a}g=g-1|0;if(sp(h,i,g)){continue}break}d=g-f|0}b:{c:{if((d|0)!=-1){k=e,l=zd(b),v[k+16>>2]=l;k=e,l=we(e+16|0,d),v[k+24>>2]=l;k=e,l=we(e+24|0,1),v[k+32>>2]=l;c=Gd(e+40|0,e+32|0);k=e,l=ff(b),v[k>>2]=l;d=Gd(e+8|0,e);eG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}i=Jb(b);f=Ab(b);d=Jb(c);c=Ab(c);if(!c|!f){c=-1}else{g=d;j=c+d|0;d=i;f=f+d|0;d:{if((d|0)==(f|0)){break d}c=f;while(1){h=g;if((j|0)!=(g|0)){while(1){if(kb[26](t[d|0],t[h|0])|0){break d}h=h+1|0;if((j|0)!=(h|0)){continue}break}}d=d+1|0;if((c|0)!=(d|0)){continue}break}d=c}c=(d|0)==(f|0)?-1:d-i|0}if(c){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;gb=e+32|0}function nZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-208|0;gb=e;d=a;if(!Yv(c,a)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0}UD(c,e+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=e;d=gb-16|0;gb=d;v[d+12>>2]=64;v[22708]=0;v[d+8>>2]=255;f=Fb(d+12|0,d+8|0);g=v[22708];v[22708]=0;b:{if((g|0)!=1){gb=d+16|0;d=w[f|0];break b}V(0)|0;O()|0;Bb();L()}t[c+12|0]=d;kh(b,w[ac(a+4|0,e+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Nb(b)){break a}a=0;while(1){if(a){c=x[Mb(b,a-1|0)>>1];v[e+12>>2]=1;d=(e+16|0)+B(a,3)|0;v[e+8>>2]=(t[d+1|0]&1)<<8|w[d|0];d=x[Hf(e+12|0,e+8|0)>>1];h=Mb(b,a),i=c+d|0,u[h>>1]=i}c=w[((e+16|0)+B(a,3)|0)+2|0];h=Mb(b,a),i=c,t[h+2|0]=i;a=a+1|0;if(Nb(b)>>>0>a>>>0){continue}break}}gb=e+208|0}function Co(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}a=f+48|0;h=b,i=Uc(Uq(a,v[b+724>>2],256,64)),u[h+728>>1]=i;h=b,i=x[Mb(a,w[f+65|0])>>1],v[h+724>>2]=i}}function vG(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=ui(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-ti(d+1.5707963267948966));break a}a=ti(d+-1.5707963267948966);break a}a=ui(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=ti(d+4.71238898038469);break a}a=C(-ti(d+-4.71238898038469));break a}a=ui(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(ay(a,b+8|0)&3){case 0:a=ui(A[b+8>>3]);break a;case 1:a=ti(A[b+8>>3]);break a;case 2:a=ui(-A[b+8>>3]);break a;default:break b}}a=C(-ti(A[b+8>>3]))}gb=b+16|0;return a}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=f>>>21&2040;l=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function ina(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;m=g,n=bX(b),v[m+16>>2]=n;i=g+24|0;k=i;c=gb-32|0;gb=c;f=b;d=a;b=Xd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+14|0;e:{if(NC(d,f,h)){if(!v[b>>2]){break b}e=b;break e}if(!MC(h,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);f=c+8|0;j=Tj(f,lC(),Uj(d+8|0,b));h=v[j>>2];b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];l=x[v[b+8>>2]>>1];u[h+16>>1]=0;u[h+14>>1]=l;gb=b+16|0;m=fc(j),n=1,t[m+4|0]=n;gb=d+16|0;Gk(a,v[c+28>>2],e,v[f>>2]);b=be(f);t[c+27|0]=1;mC(f)}Vj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Xl(i);gb=g+32|0;return a+2|0}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Zz(c,a);wb(a);fz(v[d+4>>2],b);v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;return}f=gb-32|0;gb=f;d=wb(a);d=wo(f+8|0,kr(a,Nb(a)+1|0),Nb(a),d);fz(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;b=a;Ek(a);wb(a);c=d;h=c+4|0;e=h;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[e>>2];while(1){a=a-4|0;fz(g-4|0,a);g=v[e>>2]-4|0;v[e>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];dn(b,Nb(b));a=d;b=a;d=v[a+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-4|0;v[b+8>>2]=c;v[22708]=0;R(1327,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){ai(v[a+16>>2],b,Bk(a))}gb=f+32|0}function qba(){var a=0,b=0,c=0,d=0,e=0;b=gb-48|0;gb=b;c=Kb(b+32|0);v[22708]=0;_(1918,b+16|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+16|0;d=b,e=Vb(a),v[d+8>>2]=e;d=b,e=Zb(a),v[d>>2]=e;if(!Gb(b+8|0,b)){break c}while(1){e:{a=v[b+8>>2];v[22708]=0;Q(1168,c|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}a=b+8|0;rr(a);d=b,e=Zb(b+16|0),v[d>>2]=e;if(!Gb(a,b)){break c}v[22708]=0;Q(1919,c|0,11821)|0;a=v[22708];v[22708]=0;if((a|0)!=1){continue}}break}a=V(0)|0;O()|0;yd(b+16|0);break d}a=V(0)|0;O()|0}vb(c);Z(a|0)|0;a=0;v[22708]=0;Y(1913,4042,0,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$();break b}a=ie(Jb(c));yd(b+16|0);vb(c)}gb=b+48|0;return a|0}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function kJ(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(d+f)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function xs(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[22708]=0;b=Q(2,d|0,12963)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Eb(a,b);vb(b);break b;case 1:v[22708]=0;b=Q(2,d|0,12988)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 2:v[22708]=0;b=Q(2,d|0,12936)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 3:v[22708]=0;b=Q(2,d|0,12910)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 4:v[22708]=0;b=Q(2,d|0,10317)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 5:break c;default:break b}}v[22708]=0;b=Q(2,d|0,4280)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Eb(a,b);vb(b)}gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function zga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=C(0),j=0,k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],fd(a)),v[k>>2]=m;qc(f,c>>>2|0);c=zb(b);g=z[e+4>>2];e=v[f>>2];if(e){while(1){i=C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q())));g=g<i?i:g;c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}i=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;h=C(z[Af(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=h;a=c;h=fe(h);b:{if(C(D(h))<C(2147483648)){j=~~h;break b}j=-2147483648}k=a,m=Uc(j),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}gb=f+16|0;return v[f>>2]<<2}function t2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=RG(c);b:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break b}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}oj(i,k);Ic(k);l=e,m=sj(a),v[l>>2]=m;l=f,m=rj(a),v[l>>2]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);oj(h,k);Ic(k);a=dl(a);break a}a=QG(c);c:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break c}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}oj(i,k);Ic(k);l=e,m=sj(a),v[l>>2]=m;l=f,m=rj(a),v[l>>2]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);oj(h,k);Ic(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}function bD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=a;a=gb-16|0;gb=a;h=a;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);i=Ab(d);j=v[b>>2];v[22708]=0;tA(e+8|0,c,f+i|0,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=yf(e+4|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(85,g|0,a|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}}function xw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;g=a+1|0;d=f+15|0;kh(b,w[ac(g,d)|0]);e=w[ac(a+2|0,d)|0];t[b+13|0]=e;j=b,k=Fd(w[a+3|0],e,w[f+15|0]),t[j+14|0]=k;d=w[ac(a+4|0,d)|0];t[b+15|0]=d;j=b,k=Fd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[ac(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Lb(w[e+6|0]+c<<24>>24,0,64);j=Mb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Mb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}if(x[Mb(b,d)>>1]>255){break a}h=w[Mb(b,e)+1|0];i=Mb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=Mb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[ac(f+14|0,g)|0]){continue}break}}gb=f+16|0}function ll(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22708]=0;b=v[(b+c|0)+24>>2];c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22708]=0;b=_f(b+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(yH()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22708]=0;b=v[(b+c|0)+24>>2];c=v[22708];v[22708]=0;c:{if((c|0)==1){break c}v[22708]=0;b=T(2302,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+b|0,1);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function vla(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22708]=0;R(99,c+32|0,b|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22708]=0;d=ga(79)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Wb(c+8|0);v[22708]=0;b=Q(101,a|0,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22708]=0;b=El(b+d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=x[c+32>>1];wf(a);gb=c+192|0;a=(b?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;wf(a)}S(b|0);L()}return a|0}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ud(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49050|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){a=v[a+20>>2];c=g;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);a:{if(C(D(e))<C(2147483648)){f=~~e;break a}f=-2147483648}i=h,j=Uc(f),u[i>>1]=j;v[d+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);b:{if(C(D(e))<C(2147483648)){f=~~e;break b}f=-2147483648}i=h,j=Uc(f),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return g<<3}function x2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=UG(c);b:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break b}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=sj(a),t[l|0]=m;l=f,m=rj(a),t[l|0]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=dl(a);break a}a=TG(c);c:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break c}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=sj(a),t[l|0]=m;l=f,m=rj(a),t[l|0]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0;g=gb-16|0;gb=g;j=a+44|0;if(ni(j)){o=g,p=Nd(j,0),v[o+8>>2]=p;o=g,p=Nd(j,1),v[o+12>>2]=p;o=g,p=od(j,0),v[o>>2]=p;o=g,p=od(j,1),v[o+4>>2]=p;if(d){k=d;while(1){e=0;l=1;while(1){h=e<<2;i=h+(g+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+h|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=kM(C(f*C(1073741824)),w[a+4272|0],w[a+4273|0]);i=e+4244|0;e=e+4252|0;m=z[e>>2];n=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[i>>2]*z[a+4268>>2]))-C(m*n));z[e>>2]=f;z[i>>2]=m+C(n*f);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=f*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}Gi(a,b,c,od(j,0),od(j,1),d)}gb=g+16|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Hi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=52544;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Ho(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22708]=0;W(1534,a+44|0,2,2)|0;b=v[22708];v[22708]=0;a:{if((b|0)!=1){v[22708]=0;Th(d);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Lc(c);if((c|0)!=(e|0)){continue}break}kf(d);S(a|0);L()}return a|0}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=w[b|0];v[22708]=0;xu(e+8|0,c,g+i|0,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=yf(e+4|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(72,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Zt(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function Lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=v[b>>2];v[22708]=0;xu(e+8|0,c,g+i|0,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=yf(e+4|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(72,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Qm(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-16|0;gb=g;if(e){v[e>>2]=0}h=a+484344|0;a:{if(!me(h,b)){break a}d=Yc(_b(h,b),c,d);f=w[d+5|0];b:{c:{d:{e:{i=w[d+3|0];switch(i-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(i-35>>>0>=2){break a}}v[g+12>>2]=1;j=0;if((i|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[g+12>>2]=2;j=0}m=g,n=v[_b(h,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;c=0;a=v[Fb(g+8|0,g+12|0)>>2];f:{if(!a){break f}k=a;while(1){d=B(Li(_b(h,b)),6)+d|0;if(w[d+3|0]!=34){break f}l=f<<8;f=w[d+5|0]|(j?f>>>0<256?l+-8192|0:l:l);c=c+1|0;k=k-1|0;if(k){continue}break}c=a}f=(i-35&255)>>>0>1?f:c?f:f<<8;if(!e){break a}v[e>>2]=c}gb=g+16|0;return f|0}function k8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[22708]=0;c=dA(c,b&65535);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;c=Q(70,e|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=gd(c);v[22708]=0;Q(1168,a|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(1919,a|0,18696)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22708]=0;Q(368,h|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function j8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[22708]=0;c=eA(c,b&65535);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;c=Q(70,e|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=gd(c);v[22708]=0;Q(1168,a|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(1919,a|0,18696)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22708]=0;Q(368,h|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Ec(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/12>>>0){c=gb-16|0;gb=c;d=Mp(c,a,e);a=v[d+4>>2];b=v[d+8>>2];if((a|0)!=(b|0)){while(1){WT(a);a=a+12|0;v[d+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(d);gb=c+16|0;break c}b=wb(a);d=Wu(f+8|0,PB(a,Ec(a)+e|0),Ec(a),b);v[22708]=0;ZT(d,e);b=v[22708];v[22708]=0;if((b|0)==1){break b}c=d;e=c+4|0;g=e;b=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){h=v[g>>2];while(1){a=a-12|0;OB(h-12|0,a);h=v[g>>2]-12|0;v[g>>2]=h;if((a|0)!=(i|0)){continue}break}}wc(b,e);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];YT(d)}gb=f+32|0;break a}a=P()|0;O()|0;YT(d);S(a|0);L()}return}if(b>>>0<c>>>0){$T(a,v[a>>2]+B(b,12)|0)}}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;h=fg(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!h){if(nd(a,5)){break a}}g=v[a+28>>2];d=gb-16|0;gb=d;v[d+12>>2]=0;$M(g,d+12|0,1);e=v[d+12>>2];i=e>>>2&3;t[d+11|0]=i;if(i){t[d+4|0]=3;e=w[ac(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!e){break b}Vh(g,d+4|0);if((e|0)==1){break b}Vh(g,d);if(e>>>0<3){break b}Vh(g,d+10|0);j=w[d+10|0]<<24}e=w[d+12|0]|w[d+4|0]<<8|w[d|0]<<16|j;v[d+12>>2]=e}v[d+4>>2]=e>>>4;v[d>>2]=1e6;vu(b,v[Fb(d+4|0,d)>>2]);if(Ab(b)){e=0;while(1){kl(g,pc(b,e),1);e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}b=(v[d+12>>2]>>>4|0)-Ab(b)|0;v[d+12>>2]=b;if(b){xm(g,b,-1)}gb=d+16|0}Zf(a,h,c,f+24|0);gb=f+32|0}function P2(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22708]=0;R(99,c+32|0,b|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22708]=0;d=ga(79)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Wb(c+8|0);v[22708]=0;b=Q(103,a|0,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22708]=0;b=El(b+d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[c+32>>2];wf(a);gb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;wf(a)}S(b|0);L()}return a|0}function yh(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return hc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}t[d|0]=w[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[d>>2]=v[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-16|0;gb=g;i=g+8|0;k=i;h=c;e=gb-32|0;gb=e;j=b;d=Xd(b);f=fc(b);a:{b:{if(d){c:{while(1){d:{b=d+16|0;e:{if(LA(c,b)){if(!v[d>>2]){break b}b=d;break e}if(!LA(b,c)){break c}b=d+4|0;if(!v[d+4>>2]){break d}d=b;b=d}f=b;d=v[d>>2];continue}break}v[e+28>>2]=d;break a}v[e+28>>2]=d;b=f;break a}d=fc(b)}v[e+28>>2]=d;b=d}d=v[b>>2];t[e+27|0]=0;if(!d){d=gb-16|0;gb=d;f=fc(j);c=e+8|0;f=Tj(c,Nc(28,4),Uj(d+8|0,f));l=v[f>>2];v[22708]=0;R(1418,l+16|0,h|0);h=v[22708];v[22708]=0;f:{if((h|0)!=1){m=fc(f),n=1,t[m+4|0]=n;gb=d+16|0;break f}a=P()|0;O()|0;$N(f);S(a|0);L()}Gk(j,v[e+28>>2],b,v[c>>2]);d=be(c);t[e+27|0]=1;$N(c)}Vj(k,yc(e+8|0,d),e+27|0);gb=e+32|0;DS(a,i);gb=g+16|0}function ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=f>>>21&2040;l=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function G7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-80|0;gb=d;a=v[a+4>>2];xz(d+16|0,b);v[22708]=0;b=Q(2,d|0,14864)|0;e=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22708]=0;U(3,d+32|0,d+16|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break h}v[22708]=0;U(652,d+48|0,d+32|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;R(2041,d- -64|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22708]=0;R(c|0,a|0,d- -64|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}vb(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);gb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);S(a|0);L()}function a8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[22708]=0;R(1422,g|0,a|0);c=v[22708];v[22708]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[22708]=0;c=dA(c,a&65535);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;c=Q(70,d|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;U(2094,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(1424,g|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function $7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[22708]=0;R(1422,g|0,a|0);c=v[22708];v[22708]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[22708]=0;c=eA(c,a&65535);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;c=Q(70,d|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;U(2094,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(1424,g|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function hO(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:tq(a,C(1));sq(a,C(3.725290298461914e-9));rq(a,C(268435456));qq(a,0);break b;case 1:tq(a,C(32));sq(a,C(4.656612873077393e-10));rq(a,C(2147483648));qq(a,0);break b;case 2:tq(a,C(2));sq(a,C(7.450580596923828e-9));rq(a,C(134217728));qq(a,1);break b;default:tq(a,C(1));sq(a,C(7.450580596923828e-9));rq(a,C(134217728));qq(a,1);Lz(a,0);Kz(a,1);Jz(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}tq(a,C(.75));sq(a,C(7.450580596923828e-9));rq(a,C(134217728));qq(a,1);Lz(a,0);b=(b|0)==4;Kz(a,b?2:3);Jz(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Lz(a,1);Kz(a,0);Jz(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function p5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=v[b+44>>2];g=v[b+24>>2];if(i>>>0<g>>>0){v[b+44>>2]=g;i=g}l=-1;g=-1;m=f&24;a:{if(!m|(m|0)==24&(e|0)==1){break a}if(i){h=i-Jb(b+32|0)|0;n=h;h=h>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=n;k=h}e=d+k|0;c=c+j|0;e=j>>>0>c>>>0?e+1|0:e;d=c;c=e;if((h|0)<=(e|0)&d>>>0>n>>>0|(e|0)>(h|0)|(e|0)<0){break a}e=f&8;d:{if(!(c|d)){break d}if(v[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(e){e=v[b+8>>2];Xn(b,e,d+e|0,v[b+44>>2])}if(f&16){Nx(b,v[b+20>>2],v[b+28>>2]);Zs(b,d)}l=d;g=c}sh(a,l,g)}function fL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;vq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=mg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;zt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=57924;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57152;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Gt(c,v[Tk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function eL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;vq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=mg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;zt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=58752;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57980;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Gt(c,v[Tk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-80|0;gb=e;c=Qf(e+48|0);v[22708]=0;d=Q(1182,b|0,c|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(d){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1183,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}if(Xb(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){d=Xb(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))}else{d=-1}v[22708]=0;U(288,e|0,b|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}f=kc(e+24|0,e);Vc(c+8|0,f);xb(f);xb(e);d:{d=d&1;if(!d){break d}v[22708]=0;Q(318,b|0,2-d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}Zj(a,c)}ed(c);gb=e+80|0;return}a=P()|0;O()|0;ed(c);S(a|0);L()}function wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);li(d,1,a);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){e=d+16|0;vb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Po(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[ac(e,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-112|0;gb=i;a:{if(!Md(a)){break a}if(Ec(b)>>>0<2){break a}e=ap(i+8|0,a);v[e+20>>2]=0;v[e>>2]=0;c=Ec(b);b:{if(c){g=v[a>>2];c:{while(1){f=Ad(b,h);j=v[f>>2];if(g>>>0<=j>>>0){break c}f=v[f+4>>2];if(f>>>0>g-j>>>0|268435456-f>>>0<d>>>0){break c}d=d+f|0;v[e>>2]=d;h=h+1|0;if((c|0)!=(h|0)){continue}break}h=c}if(!Pl(e)){break a}if(!h){break b}f=e+68|0;c=0;d=0;while(1){g=Ad(b,c);hc(zb(v[e+20>>2])+d|0,zb(v[a+20>>2])+v[g>>2]|0,v[g+4>>2]);v[g>>2]=d;if(!(!c|c>>>0>9)){k=Pe(f,c-1|0),l=d,v[k>>2]=l}d=v[g+4>>2]+d|0;c=c+1|0;if((h|0)!=(c|0)){continue}break}break b}if(!Pl(e)){break a}}Ol(a);ap(a,e);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}gb=i+112|0}function TL(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=xf(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-3e3/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(fk(10,d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(fk(10,d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=fk(10,l*+(j+v[(e+h|0)+16>>2]>>>0));b=fk(10,d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=(1-f)*.5;z[e+12>>2]=b*f;z[e+8>>2]=b*(1-f);b=b*+g;b=b*(b*(b*(b+1)+1)+1)+1;k=k+b*b;c=c+1|0;if((c|0)!=4){continue}break}d=fk(10,+SL(z[a+4208>>2])*.05);b=fk(10,+SL(z[a+4212>>2])*.1);z[a+4228>>2]=4/K(k)*d*K(b);z[a+4224>>2]=d*K(1-b)}function NX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=b;k=e,l=zd(a),v[k+8>>2]=l;g=ak(e+24|0,e+8|0);b=Zh(c,d);a:{b:{if(!b){break b}if(cD(c,Jb(a),Jb(a)+Ab(a)|0)){b=Nj(e+8|0,c,d);c=v[e+24>>2];d=Jb(b);g=Jb(b);h=Ab(b);v[22708]=0;c=da(543,a|0,c|0,d|0,g+h|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}h=Ab(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Jb(a);i=h-g|0;if(!i){break c}j=g+f|0;em(b+j|0,j,i);break c}Ym(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;jh(a,b);t[e+8|0]=0;Bd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Bd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=zd(a),v[k+8>>2]=l;c=we(e+8|0,g)}gb=e+32|0;return c|0}function ZP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b|0]);d=zb(w[b+1|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+2|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+3|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+4|0])|(f|g);k=a,l=Jc(d|0,zb(w[b+5|0])<<8|f|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[k>>1]=l;e=zb(w[b+8|0]);d=zb(w[b+9|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+10|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+11|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+12|0])|(f|g);k=a,l=Jc(d|j,zb(w[b+13|0])<<8|f|zb(w[b+14|0])<<16|zb(w[b+15|0])<<24,48),u[k+2>>1]=l;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function YP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b+7|0]);d=zb(w[b+6|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+5|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+4|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+3|0])|(f|g);k=a,l=Jc(d|0,zb(w[b+2|0])<<8|f|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[k>>1]=l;e=zb(w[b+15|0]);d=zb(w[b+14|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+13|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+12|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+11|0])|(f|g);k=a,l=Jc(d|j,zb(w[b+10|0])<<8|f|zb(w[b+9|0])<<16|zb(w[b+8|0])<<24,48),u[k+2>>1]=l;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function Boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;a:{if(tv(a)){v[b>>2]=0;a=0;break a}OW(c+32|0,c+48|0);e=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=e;e=c+40|0;cc(e,a,c+16|0);g=yb(e);d=zb(w[c+48|0]);e=d&127;v[b>>2]=e;h=d<<24>>24;i=(h|0)<0;d=1;if(e){while(1){f=f+1|0;j=e>>>0>1;e=e>>>1|0;if(j){continue}break}}e=f;b:{if(g>>>0<2|(h|0)>-1){break b}while(1){f=zb(w[(c+48|0)+d|0]);v[b>>2]=f&127|v[b>>2]<<7;e=e+7|0;f=f<<24>>24;i=(f|0)<0;d=d+1|0;if((g|0)==(d|0)){Rb(a,g);OW(c+24|0,c+48|0);d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;d=c+40|0;cc(d,a,c+8|0);g=yb(d);d=0}if(d>>>0>=g>>>0){break b}if((f|0)<0){continue}break}}Rb(a,d);if(e>>>0>=33){v[b>>2]=-1;a=0;break a}a=!i}gb=c- -64|0;return a|0}function yJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{b:{c:{d:{if((b|0)>=0){if((ho(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;c=Q(70,f|0,7993)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}gb=f+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function qA(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}d=v[a+480180>>2]&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){e=v[a+480208>>2]&4096;if(!d){break h}if(!e){break b}c=0-(d>>>2|0)|0;break d}e=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!e){break b}c=c<<2;break c}d=0;if(!e){break f}break b}if(e){break b}if(!c){break e}}c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}d=f+8|0;Db(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(d)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Lb(v[b+692>>2]+c|0,0,256);u[b+784>>1]=0;v[b+692>>2]=a}gb=f+16|0}function Sp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);e=j(1)|0;g=j(0)|0;a:{b:{c:{b=e;e=b;if(!(b>>>0>=1048576&(b|0)>-1)){if(!(b&2147483647|g)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;h=-1023;if((e|0)!=1072693248){b=e;break b}if(g){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;g=j(0)|0;h=-1077}b=b+614242|0;d=+((b>>>20|0)+h|0);a=d*.6931471803691238;l(0,g|0);l(1,(b&1048575)+1072079006|0);f=+n()+-1;c=f/(f+2);i=a;k=d*1.9082149292705877e-10;m=c;a=f*(f*.5);d=c*c;c=d*d;a=i+(f+(k+m*(a+(c*(c*(c*.15313837699209373+.22222198432149784)+.3999999999940942)+d*(c*(c*(c*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-a))}return a}function CF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=sf(a);if(c>>>0<b>>>0){g=gb-32|0;gb=g;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>3>>>0){c=gb-16|0;gb=c;b=fs(c,a,e);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){jm(a);a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}f=wb(a);b=gs(a,sf(a)+e|0);i=sf(a);c=0;h=gb-16|0;gb=h;v[h+12>>2]=0;d=g+8|0;jf(d+12|0,f);if(b){c=b;if(b>>>0>=536870912){rd(8445);L()}c=Nc(c<<3,1)}v[d>>2]=c;f=(i<<3)+c|0;v[d+8>>2]=f;v[d+4>>2]=f;j=dc(d),k=(b<<3)+c|0,v[j>>2]=k;gb=h+16|0;v[22708]=0;Jw(d,e);b=v[22708];v[22708]=0;if((b|0)==1){break b}Yk(a,d);AF(d)}gb=g+32|0;break a}a=P()|0;O()|0;AF(d);S(a|0);L()}return}if(b>>>0<c>>>0){Zk(a,v[a>>2]+(b<<3)|0)}}function Pea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=b+24|0;o=a+1298224|0;g=a+1074992|0;k=rk(a);p=b+4|0;q=b+12|0;r=b+8|0;s=b+16|0;while(1){if(v[g+104>>2]==(b|0)){if(v[g+16>>2]){v[g+16>>2]=c}if(y[g+4>>2]>d>>>0){v[g>>2]=0;v[g+4>>2]=0}if(v[g+76>>2]){qc(g+76|0,d)}h=kF(g);i=v[(h?q:p)>>2];v[g+84>>2]=v[(h?s:r)>>2];v[g+80>>2]=i;h=v[g+88>>2]|v[e>>2];v[g+88>>2]=h;v[g+88>>2]=h&(v[f>>2]^-1);h=g+704|0;a:{if(!v[g+704>>2]|!v[b+24>>2]){break a}if(Zl(a)){break a}l=v[(k?h:j)>>2];m=nqa(v[(k?j:h)>>2],0,v[g+700>>2],0);n=m+(l>>>1|0)|0;i=jb;t=g,u=Qc(qqa(n,n>>>0<m>>>0?i+1|0:i,l,0),jb),v[t+700>>2]=u}v[h>>2]=v[j>>2]}g=g+872|0;if((o|0)!=(g|0)){continue}break}}function tV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}break a}$B(c+8|0,b);b=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=b;kd(c+16|0,a,c)}gb=c+32|0}function l6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;a:{b:{b=d+16|0;c:{if(!gt(xa(v[a+60>>2],b|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!gt(xa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}gb=d+32|0;return a|0}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)==1){break c}v[22708]=0;_(1962,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;_(1962,c|0);f=v[22708];v[22708]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=uc(d+24|0,b);c=uc(d+16|0,c);v[22708]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;Y(2006,f|0,d+8|0,d|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2599,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}gb=d+32|0;return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=Ge(d+16|0,1,0);KP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22708]=0;v[d+4>>2]=e;e=yf(d+4|0);h=v[22708];v[22708]=0;if((h|0)==1){break c}v[22708]=0;U(75,c|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}KP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22708]=0;R(76,c|0,b-e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;R(86,g|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22708]=0;R(85,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=nqa(d,0,1,1);f=jb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function rm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0;k=gb-16|0;gb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Xm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83408|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83408|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function qm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;k=gb-16|0;gb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=sx(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83408|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83408|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function _na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=0;Hk(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22708]=0;u[d+14>>1]=0;f=W(653,a|0,e|0,255)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!f){break d}v[22708]=0;Q(647,a|0,d+14|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;U(13,d|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}v[22708]=0;f=Q(654,b|0,d+14|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}_f(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;u[d+30>>1]=0;ag(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22708]=0;u[d+14>>1]=0;f=W(655,a|0,e|0,255)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!f){break d}v[22708]=0;Q(647,a|0,d+14|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;U(13,d|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}v[22708]=0;f=Q(654,b|0,d+14|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}_f(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{if(pk(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Pc(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){e=d+8|0;Ce(e,b,c);if(!Cb(e)){v[22708]=0;f=Q(1315,a|0,c&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}if(f){v[22708]=0;f=Q(70,d+8|0,18726)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}vb(f);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}gb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(f);break a}c=P()|0;O()|0}S(c|0);L()}function yI(a,b,c,d,e,f){var g=0;g=gb-80|0;gb=g;a:{if((f|0)>=16384){Ed(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}Ed(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Ed(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}Ed(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Ed(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;gb=g+80|0}function rR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=Ge(d+16|0,1,0);TP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22708]=0;v[d+4>>2]=e;e=yf(d+4|0);h=v[22708];v[22708]=0;if((h|0)==1){break c}v[22708]=0;U(75,c|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}TP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22708]=0;R(76,c|0,b-e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;R(86,g|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22708]=0;R(85,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function mA(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){d=gb-32|0;gb=d;Tq(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;gb=d+32|0;a=a+32|0;if((e|0)!=(a|0)){continue}break}}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46162>>1])+B(u[e-2>>1],u[f+46160>>1])|0)+B(u[e+2>>1],u[f+46164>>1])|0)+B(u[e+4>>1],u[f+46166>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function dL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=gb-16|0;gb=f;c=v[a+4>>2];d=f;a=v[a>>2];v[d>>2]=a;v[d+4>>2]=c;v[d+8>>2]=a;v[d+12>>2]=c;a=gb+-64|0;gb=a;a:{if(!v[d+4>>2]){break a}c=38480;b:{while(1){b=v[d+4>>2];v[a+56>>2]=v[d>>2];v[a+60>>2]=b;b=uc(a+48|0,v[c+8>>2]);e=v[a+60>>2];v[a+24>>2]=v[a+56>>2];v[a+28>>2]=e;e=v[b+4>>2];v[a+16>>2]=v[b>>2];v[a+20>>2]=e;if(dO(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=39044){continue}break}c=39056;while(1){b=v[d+4>>2];v[a+40>>2]=v[d>>2];v[a+44>>2]=b;b=uc(a+32|0,v[c+8>>2]);e=v[a+44>>2];v[a+8>>2]=v[a+40>>2];v[a+12>>2]=e;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;b=dO(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=39104){continue}break}break a}b=1}gb=a- -64|0;gb=f+16|0;return b|0}function Cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-80|0;gb=d;f=1;g=JR(a,1<<b-1);v[a+12>>2]=b;c=1<<b;h=c>>>2|0;a:{if(b>>>0>1){i=-6.283185307179586/+(c>>>0);b=h;while(1){A[d+40>>3]=i*+(b>>>0);e=v[12055];c=d+48|0;v[c+8>>2]=v[12054];v[c+12>>2]=e;e=v[12053];v[c>>2]=v[12052];v[c+4>>2]=e;VA(c,A[d+40>>3]);v[22708]=0;UA(d- -64|0,c);c=v[22708];v[22708]=0;if((c|0)==1){break a}c=Tc(g,f);e=v[d+76>>2];v[c+8>>2]=v[d+72>>2];v[c+12>>2]=e;e=v[d+68>>2];v[c>>2]=v[d+64>>2];v[c+4>>2]=e;f=f<<1;c=b>>>0<2;b=b>>>1|0;if(!c){continue}break}}b=Vm(d+24|0,1,0);c=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;Ez(a,0,h,d+8|0);gb=d+80|0;return a|0}a=P()|0;O()|0;Mq(g);S(a|0);L()}function Jma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0);c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[hr(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Af(c+12|0,c+8|0,c+4|0)>>2]*C(128));z[c+12>>2]=f;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=GV(g);t[v[a>>2]+(B(v[a+4>>2],d)+e|0)|0]=g;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14360,6114,28,6667);L()}aa(14410,6114,27,6667);L()}function Do(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}d=v[a+480180>>2]&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Fq(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Eq(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Lb(c,0,256),v[g+688>>2]=h}function yC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Nb(e);d=c;a:{if(f>>>0<d>>>0){j=gb-32|0;gb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){lr(e,h);break d}i=wb(e);k=kr(e,Nb(e)+h|0);m=Nb(e);f=0;l=gb-16|0;gb=l;v[l+12>>2]=0;d=j+8|0;jf(d+12|0,i);if(k){f=ZV(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=dc(d),o=(k<<2)+f|0,v[n>>2]=o;gb=l+16|0;v[22708]=0;lv(d,h);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(e,d);_V(d)}gb=j+32|0;break b}a=P()|0;O()|0;_V(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Zk(e,v[e>>2]+(d<<2)|0)}}if(Pb(a,c<<2)){bc(g+24|0,v[b>>2],Nb(b)<<2);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;h=g+8|0;j=h;k=c;e=gb-32|0;gb=e;i=b;d=b;b=Xd(b);f=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(Gn(c,d)){if(!v[b>>2]){break b}f=b;break e}if(!Gn(d,c)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=f;break a}v[e+28>>2]=b;b=f;break a}b=fc(d)}v[e+28>>2]=b}f=b;b=v[b>>2];t[e+27|0]=0;if(!b){b=gb-16|0;gb=b;d=fc(i);c=e+8|0;d=Tj(c,Nc(16,4),Uj(b+8|0,d));So(v[d>>2]+14|0,k);l=fc(d),m=1,t[l+4|0]=m;gb=b+16|0;AS(i,v[e+28>>2],f,v[c>>2]);b=be(c);t[e+27|0]=1;f=c;d=v[c>>2];v[c>>2]=0;if(d){c=fc(f);if(d){Yn(v[c>>2],d,1)}}}Vj(j,yc(e+8|0,b),e+27|0);gb=e+32|0;DS(a,h);gb=g+16|0}function Kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0;c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[hr(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Af(c+12|0,c+8|0,c+4|0)>>2]*C(32768));z[c+12>>2]=f;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=Uc(g);j=HV(a,e,d),l=g,u[j>>1]=l;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14360,6114,28,6667);L()}aa(14410,6114,27,6667);L()}function d6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;if(wa(1,d+32|0)|0){Rs(v[115189],10026);L()}a=d+32|0;c=ft(d+16|0,a);g=ft(d+8|0,a|4);e=gb-32|0;gb=e;b=gb-16|0;gb=b;h=gb-16|0;gb=h;a=gb-16|0;gb=a;i=a,j=nqa(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=jb;c=Yl(a+8|0,a);f=v[c+4>>2];c=v[c>>2];gb=a+16|0;gb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;gb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Yl(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=Yl(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];gb=d+48|0;jb=b;return a|0}function UI(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}kb[d|0](a,c)}}function iC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;kh(b,w[ac(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Nb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Mb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=x[Mb(b,e)>>1];h=Mb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Lb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Mb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=g+16|0}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=f>>>21&2040;b=(((B(t[b|0],u[f+46162>>1])+B(t[b-1|0],u[f+46160>>1])|0)+B(t[b+1|0],u[f+46164>>1])|0)+B(t[b+2|0],u[f+46166>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;gb=e+16|0}function eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;c=gb-16|0;gb=c;d=a;k=d;h=b;e=Xd(d);i=fc(d);f=gb-16|0;gb=f;if(e){while(1){j=zu(wb(k),e+16|0,h);i=j?i:e;e=v[(j?4:0)+e>>2];if(e){continue}break}}h=v[yc(f+8|0,i)>>2];gb=f+16|0;v[c+8>>2]=h;l=c,m=Ch(d),v[l>>2]=m;a:{b:{if(!Gb(c+8|0,c)){break b}if(zu(wb(d),b,ue(c+8|0))){break b}b=v[c+8>>2];break a}b=Ch(d)}gb=c+16|0;v[g+24>>2]=b;l=g,m=Ch(a),v[l+16>>2]=m;if(!Qj(g+24|0,g+16|0)){b=v[yc(g+8|0,b)>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;h=gb-16|0;gb=h;e=d+8|0;i=v[e>>2];c=i;f=yc(h+8|0,c);Sj(f);b=a;if((c|0)==v[b>>2]){v[b>>2]=v[f>>2]}f=wb(b);v[f>>2]=v[f>>2]-1;cN(v[fc(b)>>2],c);gb=h+16|0;fc(a);Sm(ue(e));IA(i);gb=d+16|0}gb=g+32|0}function NN(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;t[h+15|0]=b;t[h+14|0]=10;kh(g,w[ac(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Nb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Mb(g,c),j=d>>>4|0,u[i>>1]=j;e=0;a:{if(c){d=c-1|0;if(x[Mb(g,c)>>1]>=x[Mb(g,d)>>1]){break a}e=x[Mb(g,d)>>1]+1|0}i=Mb(g,c),j=e,u[i>>1]=j}b=Fd(w[b+2|0],0,64);i=Mb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Nb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;c=g;if(a&2){b=w[g+15|0];d=Nb(g);b=w[g+12|0]&-5|(b>>>0<=d>>>0)<<2}else{b=b&251}t[c+12|0]=b;c=g;b:{c:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break c}}a=b&253;break b}b=Nb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[c+12|0]=a;gb=h+16|0}function Jca(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=xf(v[a+16>>2]);b=Ac(oqa(nqa(b,b>>31,3840,0),jb,1e3,0),jb);v[a+4316>>2]=b;v[22708]=0;v[c+12>>2]=0;U(1542,a+4264|0,b|0,c+12|0);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[a+4260|0]){break e}b=v[a+4316>>2];v[22708]=0;v[c+12>>2]=0;U(1542,a+4276|0,b|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)!=1){break e}b=V(89104)|0;break c}v[22708]=0;v[c+12>>2]=0;Zy(a+4288|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;v[c+12>>2]=0;Zy(a+4300|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(89104)|0;break c}b=V(89104)|0;break c}b=V(89104)|0}if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4316>>2]=0;$()}gb=c+16|0;return}S(b|0);L()}function nba(a){a=a|0;var b=0;b=5149;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=14659;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=18726;break a}b=5182;break a}b=2107;break a}b=5205;break a}b=5219;break a}b=2480;break a}b=2500;break a}b=5231;break a}b=5163;break a}b=10145;break a}b=9407;break a}b=3111;break a}if((a|0)!=357){break a}b=5116}return ie(b)|0}function XN(a){var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;v[b+12>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+16>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);v[b+28>>2]=3;v[b+20>>2]=c+(a<<2);v[b+24>>2]=b+12;a=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=a;a=v[b>>2];d=gD(b);e=gb-16|0;gb=e;a:{if((a|0)==(d|0)){break a}c=a+4|0;if((d|0)==(c|0)){break a}while(1){a=zn(a,c)?c:a;c=c+4|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+32|0;return v[a>>2]-36|0}function kna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;d=b;f=tc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){i=gb-16|0;gb=i;e=mi(i,d,f);d=v[e+4>>2];f=v[e+8>>2];if((d|0)!=(f|0)){while(1){Ok(d);d=d+2|0;v[e+4>>2]=d;if((d|0)!=(f|0)){continue}break}}$b(e);gb=i+16|0;break d}e=wb(d);e=AD(h+8|0,NY(d,tc(d)+f|0),tc(d),e);v[22708]=0;SV(e,f);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(d,e);qp(e)}gb=h+32|0;break b}a=P()|0;O()|0;qp(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Zk(d,v[d>>2]+(e<<1)|0)}}c=Pb(a,c<<1);if(c){bc(g+24|0,v[b>>2],tc(b)<<1);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function KM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=gb-48|0;gb=c;v[c+8>>2]=542066252;e=c+8|0;d=e|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Nk(b,33);hc(v[b>>2],e,33);Ud(c,b);ne(a,c);gb=c+48|0}function e6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=gb-48|0;gb=b;if(wa(0,b+32|0)|0){Rs(v[115189],9989);L()}d=ft(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;g=ft(b+8|0,b+4|0);e=gb-32|0;gb=e;c=gb-16|0;gb=c;a=gb-16|0;gb=a;h=a,i=nqa(v[d>>2],v[d+4>>2],1e6,0),v[h>>2]=i;v[a+4>>2]=jb;d=Yl(a+8|0,a);f=v[d+4>>2];d=v[d>>2];gb=a+16|0;v[c+8>>2]=d;v[c+12>>2]=f;a=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=a;gb=c+16|0;f=v[e+8>>2];d=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;d=v[a+4>>2]+d|0;c=v[a>>2];f=f+c|0;v[a+16>>2]=f;v[a+20>>2]=c>>>0>f>>>0?d+1|0:d;a=Yl(a+24|0,a+16|0);c=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[b+24>>2]=a;v[b+28>>2]=c;a=Yl(b+40|0,b+24|0);c=v[a+4>>2];a=v[a>>2];gb=b+48|0;jb=c;return a|0}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;ud(b,0);li(e,1,a+33|0);d=e+16|0;Bc(d,e);v[22708]=0;Q(303,b+43|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){f=e+16|0;vb(f);d=a+50|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+54|0;v[b+24>>2]=w[d|0]|w[d+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;g=b,h=w[ac(f,e)|0]<<2,u[g+30>>1]=h;d=a+57|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+61|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!c|!v[b+4>>2])){v[b+8>>2]=v[b>>2]}a:{if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function BZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Rr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Rr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Ju(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}gb=d+16|0}function V9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22708]=0;_(1962,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22708]=0;c=Q(70,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Y(1997,d+16|0,e|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)==1){break d}a=d+16|0;b=ie(Jb(a));vb(a);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,3489,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22708]=0;_(1962,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22708]=0;c=Q(70,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;U(1963,d+16|0,e|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}a=d+16|0;b=ie(Jb(a));vb(a);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22708]=0;Y(1913,10643,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function MM(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;z[d+12>>2]=c;dz(a);Ji(d+12|0);a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];Qt(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);Qt(a);break a;case 4:b=gb-16|0;gb=b;f=b,g=Xh(C(z[d+12>>2]*C(32))),v[f+12>>2]=g;v[b+8>>2]=0;v[b+4>>2]=5;e=v[ej(b+12|0,b+8|0,b+4|0)>>2];gb=b+16|0;v[a+4232>>2]=e;break a;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){bz(a);c=z[d+12>>2]}A[b+4256>>3]=c}gb=d+16|0}function kh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){e=gb-16|0;gb=e;d:{b=Eg(e,a,c);c=v[b+4>>2];f=v[b+8>>2];if((c|0)!=(f|0)){while(1){wb(a);v[22708]=0;Wr(c);g=v[22708];v[22708]=0;if((g|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(f|0)){continue}break}}$b(b);gb=e+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}b=wb(a);b=zp(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22708]=0;R(299,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(300,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}hj(b)}gb=d+32|0;break a}a=P()|0;O()|0;hj(b);S(a|0);L()}return}if(b>>>0<c>>>0){ij(a,v[a>>2]+(b<<2)|0)}}function gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=a+8|0;a:{c=v[a+8>>2];i=dc(a);b:{if((c|0)!=v[i>>2]){break b}h=a+4|0;d=v[a+4>>2];f=v[a>>2];if(d>>>0>f>>>0){f=((d-f>>1)+1|0)/-2<<1;a=f+d|0;if((c|0)!=(d|0)){while(1){DY(a,d);a=a+2|0;d=d+2|0;if((d|0)!=(c|0)){continue}break}}c=a;v[g>>2]=a;v[h>>2]=f+v[h>>2];break b}v[e+24>>2]=c-f;v[e+44>>2]=1;d=e+24|0;c=v[Mc(d,e+44|0)>>2];c=AD(d,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22708]=0;EY(c,d,f);d=v[22708];v[22708]=0;if((d|0)==1){break a}wc(a,c);wc(h,c+4|0);wc(g,c+8|0);wc(i,dc(c));qp(c);c=v[a+8>>2]}Er(c,b);v[g>>2]=v[g>>2]+2;gb=e+48|0;return}a=P()|0;O()|0;qp(c);S(a|0);L()}function n3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}a=f+24|0;Fc(a,c);v[22708]=0;a=T(2483,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}a=f+24|0;g=f,h=zd(a),v[g+16>>2]=h;g=f,h=vi(a),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=v[v[f+16>>2]>>2];v[22708]=0;Q(2502,f+40|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}a=f+16|0;Qe(a);g=f,h=vi(f+24|0),v[g+8>>2]=h;if(Gb(a,f+8|0)){continue}break}b=v[f+40>>2]}Ic(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;Ic(f+24|0)}S(b|0);L()}function se(a,b){var c=0,d=0,e=0;d=gb-32|0;gb=d;a=sh(a,-1,-1);a:{b:{if(w[uj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[22708]=0;c=v[(b+c|0)+24>>2];e=v[22708];v[22708]=0;c:{d:{if((e|0)==1){break d}v[22708]=0;Ga(2313,d+8|0,c|0,0,0,1,8);c=v[22708];v[22708]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;Z(a|0)|0;a=1;tj(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[b>>2]-12>>2]+b|0,a)}gb=d+32|0;return}V(0)|0;O()|0;Bb()}L()}function fA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb-16|0;gb=c;if(!cd(a)){m=c,n=Vb(a),v[m+8>>2]=n;m=c,n=Zb(a),v[m>>2]=n;if(Gb(c+8|0,c)){while(1){d=c+8|0;b=v[d>>2];Fp(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=h;b=f>>>0<g>>>0?b+1|0:b;h=b;Qe(d);if(Gb(d,c)){continue}break}}b=Nb(a);g=Nb(a);m=c,n=Vb(a),v[m+8>>2]=n;m=c,n=Zb(a),v[m>>2]=n;b=qqa(f,h,b,0);d=jb;f=g<<24;h=0;if(Gb(c+8|0,c)){g=b;d=((d&1)<<31|b>>>1)&2147483647;while(1){i=c+8|0;b=v[i>>2];j=b;e=v[b>>2];b=e>>>8|0;e=d+(e<<24)|0;b=b+k|0;b=Qc(qqa(e,d>>>0>e>>>0?b+1|0:b,g,l),jb);v[j>>2]=b;e=f;f=e-b|0;h=h-(b>>>0>e>>>0)|0;Qe(i);if(Gb(i,c)){continue}break}}if(!Nb(a)){_x();L()}a=v[a>>2];v[a>>2]=f+v[a>>2]}gb=c+16|0}function bl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;a:{c=v[a+32>>2];if((c|0)>=(b|0)){f=v[a+28>>2];break a}i=a+36|0;g=v[a+24>>2];e=v[a+20>>2];h=c;while(1){b:{if(e>>>0>=g>>>0){td(d+16|0,i,i+1024|0);c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;c=d+24|0;kd(c,a,d+8|0);g=yb(c);v[a+24>>2]=g;v[a+20>>2]=0;if(!g){break b}e=0;h=v[a+32>>2]}j=e+1|0;v[a+20>>2]=j;e=w[(a+e|0)+36|0];c=h+8|0;v[a+32>>2]=c;f=v[a+28>>2]|e<<h;v[a+28>>2]=f;h=c;e=j;if((b|0)>(c|0)){continue}break a}break}a=ba(8)|0;v[22708]=0;T(205,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ia(a|0,27364,206);L()}v[a+32>>2]=c-b;v[a+28>>2]=f>>>b;gb=d+32|0;return(-1<<b^-1)&f}function $H(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22708]=0;c=Q(2316,d+8|0,a|0)|0;b=v[22708];v[22708]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22708]=0;b=T(2317,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22708]=0;_(2318,a+b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;ZH(c);break c}ZH(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function z3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}a=f+24|0;Fc(a,c);v[22708]=0;a=T(2454,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}a=f+24|0;g=f,h=zd(a),v[g+16>>2]=h;g=f,h=ff(a),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=t[v[f+16>>2]];v[22708]=0;Q(2321,f+40|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}a=f+16|0;Oe(a);g=f,h=ff(f+24|0),v[g+8>>2]=h;if(Gb(a,f+8|0)){continue}break}b=v[f+40>>2]}vb(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;vb(f+24|0)}S(b|0);L()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{if(!He(b,-1)){h=v[a+12>>2];i=v[a+8>>2];g=v[a+24>>2];if((g|0)==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}e=v[a+20>>2];j=v[a+44>>2];v[22708]=0;c=a+32|0;R(61,c|0,0);d=v[22708];v[22708]=0;if((d|0)==1){break b}d=Kc(c);v[22708]=0;R(76,c|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}d=Jb(c);Nx(a,d,Ab(c)+d|0);Zs(a,g-e|0);v[a+44>>2]=v[a+20>>2]+(j-e|0)}v[f+12>>2]=v[a+24>>2]+1;c=a+44|0;e=f+12|0;k=a,l=v[(zn(e,c)?c:e)>>2],v[k+44>>2]=l;if(w[a+48|0]&8){c=Jb(a+32|0);Xn(a,c,c+(h-i|0)|0,v[a+44>>2])}c=aI(a,Wh(b));break a}c=Xs(b);break a}a=V(0)|0;O()|0;Z(a|0)|0;$();c=-1}gb=f+16|0;return c|0}function yZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Fb(d+4|0,d+12|0)>>2];c=gb+-64|0;gb=c;e=c+40|0;Re(e,a,f);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(c+8|0,3,e,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(400,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}gb=d+16|0}function _p(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=d?d:463964;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[22614]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+76800>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115189]=25;e=-1;break a}v[f>>2]=d}gb=h+16|0;return e|0}function jN(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=gb-48|0;gb=f;e=Kb(f+32|0);v[22708]=0;Q(1519,a|0,f+24|0)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)!=1){g=v[f+28>>2];d=v[f+24>>2];Se(e);v[22708]=0;g=!g&d>>>0<255?d:255;R(76,e|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=pc(e,d);v[22708]=0;Q(1520,a|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((sI(e)|0)!=-1){a=sI(e);v[22708]=0;R(76,e|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}}v[22708]=0;U(13,f+8|0,c|0,e|0);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}break a}a=f+8|0;Eb(b,a);vb(a);vb(e);gb=f+48|0;return}a=P()|0;O()|0;vb(e);S(a|0);L()}function d3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=PF(v[v[a>>2]-12>>2]+a|0,10);e=gb-16|0;gb=e;v[22708]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=dj(e,c);v[22708]=0;Q(2321,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){if(!_v(b)){break e}b=v[v[c>>2]-12>>2];v[22708]=0;R(18,b+c|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;ll(d);break d}ll(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;d=v[v[c>>2]-12>>2];v[22708]=0;_(19,c+d|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}$()}gb=e+16|0;break a}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}$s(a);return a|0}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;LQ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;h=wb(a);i=g+8|0;j=a;f=MA(a)+1|0;d=gb-16|0;gb=d;v[d+12>>2]=f;e=gb-16|0;gb=e;v[e+12>>2]=613566756;v[22708]=0;v[e+8>>2]=2147483647;k=Fb(e+12|0,e+8|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){gb=e+16|0;c=v[k>>2];break a}V(0)|0;O()|0;Bb();L()}b:{if(c>>>0>=f>>>0){f=HA(j);if(f>>>0<c>>>1>>>0){v[d+8>>2]=f<<1;c=v[Mc(d+8|0,d+12|0)>>2]}gb=d+16|0;break b}Sc();L()}c=WQ(i,c,MA(a),h);LQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;VQ(a,c);UQ(c);gb=g+32|0}function LP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-112|0;gb=f;v[f+108>>2]=0;d=Qm(a,x[d+70>>1],v[d+48>>2],c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=!w[b+792|0]&(c|0)==15;d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}d=(e?0:w[b+836|0]<<16)+d|0}b:{if((c|0)!=15){break b}c=w[b+792|0];if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Mc(f,f+108|0)>>2]<<3;g=nqa(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=jb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Qc(c,e);break b}gU(f,0);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[Pe(c+68|0,w[b+792|0]-1|0)>>2]+d|0}Om(a,b,d);gb=f+112|0}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-48|0;gb=e;a:{b:{if(v[a+8>>2]!=v[dc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=Rg(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=e,j=v[dc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[e+44>>2]=1;d=e+24|0;c=v[Mc(d,e+44|0)>>2];c=zp(d,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22708]=0;U(1082,c|0,d|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}xc(a,c);xc(h,c+4|0);xc(g,c+8|0);xc(dc(a),dc(c));hj(c)}hn(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;gb=e+48|0;return}a=P()|0;O()|0;hj(c);S(a|0);L()}function Q2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=gb-416|0;gb=h;d=h+416|0;v[h+12>>2]=d;c=gb-144|0;gb=c;v[c+28>>2]=c+132;i=c+32|0;XG(a+8|0,i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;i=e;j=VV(e,v[h+12>>2]);f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];g=wi(f+8|0,f+12|0);v[22708]=0;a=Bx(e,c+12|0,j,c+16|0);j=v[22708];v[22708]=0;a:{if((j|0)!=1){gf(g);gb=f+16|0;break a}a=P()|0;O()|0;gf(g);S(a|0);L()}if((a|0)==-1){Js(9868);L()}v[h+12>>2]=i+(a<<2);gb=c+144|0;c=v[h+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;if((c|0)!=(e|0)){while(1){SH(a+8|0,v[e>>2]);e=e+4|0;if((c|0)!=(e|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=d;return b|0}function Xq(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Ab(b);v[22708]=0;R(60,d|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){a:{if(Ab(b)){while(1){f=v[xk(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[22708]=0;R(61,d|0,a<<24>>24);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[22708]=0;R(61,d|0,a<<24>>24);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[22708]=0;R(61,d|0,63);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;vb(d);S(a|0);L()}function c9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=bq(c,a,1);Gy(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;$b(a);gb=c+16|0;return}e=gb-32|0;gb=e;c=wb(a);c=TI(e+8|0,ey(a,vf(a)+1|0),vf(a),c);Gy(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;b=c;h=c+4|0;f=h;d=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[f>>2];while(1){a=a-16|0;Gy(g-16|0,a);g=v[f>>2]-16|0;v[f>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(d,h);wc(d+4|0,b+8|0);wc(wb(d),dc(b));v[b>>2]=v[b+4>>2];a=c;b=a;d=v[a+8>>2];c=v[a+4>>2];if((d|0)!=(c|0)){while(1){d=d-16|0;v[b+8>>2]=d;Fk(d);d=v[b+8>>2];if((c|0)!=(d|0)){continue}break}}b=v[a>>2];if(b){xK(b,Qx(a))}gb=e+32|0}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;f=Qf(d+48|0);v[22708]=0;e=Q(1172,b|0,f|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{if((g|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1173,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=cn(f);v[22708]=0;U(288,d|0,b|0,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break a}g=kc(d+24|0,d);Vc(f+8|0,g);xb(g);xb(d);d:{if(!c){break d}e=(e>>>0)%(c>>>0)|0;if(!e){break d}v[22708]=0;Q(318,b|0,c-e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}Zj(a,f)}ed(f);gb=d+80|0;return}a=P()|0;O()|0;ed(f);S(a|0);L()}function th(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=ZL(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));f=z[a+4268>>2];e=oe(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/f)*C(-60))/C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(oe(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Pp(c>C(1)?C(3.1415927410125732):C(d*C(C(6.2831854820251465)/f)))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(!(C(D(g))>C(1))){break a}g=C(C(C(-d)-c)/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(c+C(d*C(d*C(e/C(C(1)-C(e*c))))))}function yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;gb=e+32|0}function aV(a){var b=0,c=0,d=0;a:{b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break b}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<1108){break b}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=a+1104|0;if((b-1108|0)!=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|b>>>0>262144){break b}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break b}b=a+1096|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if(!(w[b|0]|c|d)|(d|(c|w[b|0]))>>>0>4){break b}if(!cv(a+8|0)){break b}c=a+1094|0;b=a+40|0;while(1){if(w[b+32|0]>15|w[b+33|0]>64){break b}if(!cv(b)){break b}a=1;b=b+34|0;if((c|0)!=(b|0)){continue}break}break a}a=0}return a}function Ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;b=c+24|0;e=g+8|0;lV(b,e);f=yb(b);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;d=c+16|0;b=a;hd(d,b,c);d=yb(d);if((d|0)==(f|0)){bd(b,yb(c+24|0))}gb=c+32|0;c=(d|0)==(f|0);if(!c){kV(e)}b=-1;a:{if(!c){break a}b=0;if(!uV(g+8|0)){break a}b=-1;if(!Wf(a,1024)){break a}b=0;f=gb-1024|0;gb=f;c=gb-32|0;gb=c;e=c+24|0;$B(e,f);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;if((d|0)==(e|0)){b=cC(f,0)>>>0<17}gb=f+1024|0}gb=g+608|0;return b|0}function V4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=gb+-64|0;gb=g;Kh(g+16|0,c);v[22708]=0;R(144,g+28|0,d|0);d=v[22708];v[22708]=0;c=1;b:{c:{if((d|0)==1){break c}v[22708]=0;R(144,g+40|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){c=2;break c}v[22708]=0;R(144,g+52|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){c=3;break c}c=g+16|0;v[g+8>>2]=c;v[g+12>>2]=c+48;v[22708]=0;c=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=c;U(146,a|0,b|0,g|0);a=v[22708];v[22708]=0;if((a|0)==1){c=P()|0;O()|0;kG(g+16|0);break b}kG(g+16|0);gb=g- -64|0;break a}a=(g+16|0)+B(c,12)|0;c=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(g+16|0)){continue}break}}S(c|0);L()}}function Ala(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;ud(b,0);ZC(d,a+1|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,v[b>>2]);qc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=b;wb(b);e=a;h=tN(a,d+8|0);b:{f=Jg(b);if(!f){break b}v[22708]=0;R(617,e|0,f|0);g=v[22708];v[22708]=0;if((g|0)!=1){g=v[c+4>>2];c=v[c>>2];v[22708]=0;Y(1498,e|0,c|0,g|0,f|0);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}a=P()|0;O()|0;wv(h);S(a|0);L()}gb=d+16|0;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22708]=0;c=Q(1497,a+24|0,b+24|0)|0;d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){v[22708]=0;Q(69,a+36|0,b+36|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Lc(c)}jn(e);S(a|0);L()}}function kB(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function hU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=b,g=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[f>>2]=g;t[d+15|0]=w[a+4|0];t[d+14|0]=64;f=b,g=w[ac(d+15|0,d+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;f=b,g=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;a=a+10|0;a=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0;v[b+8>>2]=a;e=v[b+4>>2];c=v[b>>2];if(e>>>0>=c>>>0){e=c-1|0;v[b+4>>2]=e}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<e>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2;f=Pe(b+68|0,0),g=e,v[f>>2]=g}gb=d+16|0}function AJ(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=gb-16|0;gb=d;a:{b:{c:{d:{if((b|0)>=0){if((ho(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;d=Q(70,d|0,7993)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,d);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}if(c<0|c>1){a=ba(8)|0;v[22708]=0;d=Q(70,d|0,9006)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,d);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=Qo(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;gb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function p4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;a:{if(qH(c)){while(1){if(a>>>d&1){i=(d<<2)+c|0,j=rH(d,b),v[i>>2]=j}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){h=(e+8|0)+(d<<2)|0;f=1<<d&a;if(f|!c){f=rH(d,f?b:18726)}else{f=v[(d<<2)+c>>2]}v[h>>2]=f;g=((f|0)!=0)+g|0;d=d+1|0;if((d|0)!=6){continue}break}c=74848;b:{c:{switch(g|0){case 0:break a;case 1:break c;default:break b}}if(v[e+8>>2]!=74820){break b}c=74872;break a}c=Cd(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}gb=e+32|0;return c|0}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{b:{c:{d:{if(i=gd(b),j=1,k=v[b+12>>2],k?i:j){Kb(a);break d}f=gb-16|0;gb=f;e=Kb(c+16|0);d=Ab(b);g=Nf(11521);h=Jb(b);v[22708]=0;Y(116,e|0,h|0,d|0,d+g|0);d=v[22708];v[22708]=0;e:{if((d|0)!=1){v[22708]=0;W(117,e|0,11521,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);S(a|0);L()}gb=f+16|0;v[22708]=0;R(153,c|0,b+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;U(3,a|0,c+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);S(b|0);L()}function Rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;e=Qf(d+48|0);v[22708]=0;g=Q(1473,b|0,e|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1474,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}g=cn(e);v[22708]=0;U(288,d|0,b|0,g|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}f=kc(d+24|0,d);Vc(e+8|0,f);xb(f);xb(d);d:{if(!((g>>>0)%(c>>>0)|0)){break d}v[22708]=0;Q(318,b|0,c-1|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}Zj(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-80|0;gb=d;e=Qf(d+48|0);v[22708]=0;c=Q(825,b|0,e|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(826,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}c=e+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>=9){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-8|0}else{c=0}v[22708]=0;U(288,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=kc(d+24|0,d);Vc(e+8|0,b);xb(b);xb(d);Zj(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function md(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=v[a+112>>2];b=v[a+116>>2];b:{if(d|b){g=v[a+124>>2];if((b|0)<=(g|0)&d>>>0<=y[a+120>>2]|(b|0)<(g|0)){break b}}h=Wx(a);if((h|0)>-1){break a}}v[a+104>>2]=0;return-1}i=v[a+4>>2];g=a;c=v[a+116>>2];j=c;b=v[a+8>>2];d=b;f=v[a+112>>2];c:{if(!(c|f)){break c}d=b;e=v[a+120>>2]^-1;f=e+f|0;c=(v[a+124>>2]^-1)+j|0;c=f>>>0<e>>>0?c+1|0:c;e=b-i|0;j=e;e=e>>31;if((e|0)<=(c|0)&f>>>0>=j>>>0|(c|0)>(e|0)){break c}d=f+i|0}v[g+104>>2]=d;if(b){d=a;g=(b-i|0)+1|0;c=g;b=c+v[a+120>>2]|0;a=v[a+124>>2]+(c>>31)|0;v[d+120>>2]=b;v[d+124>>2]=b>>>0<c>>>0?a+1|0:a}a=i-1|0;if(w[a|0]!=(h|0)){t[a|0]=h}return h}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function xja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=gb+-64|0;gb=e;d=v[a+28>>2];no(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];f=v[a+12>>2];g=d;d=v[a+8>>2]+d|0;f=g>>>0>d>>>0?f+1|0:f;d=sh(e+48|0,d,f);f=v[d+12>>2];v[e+16>>2]=v[d+8>>2];v[e+20>>2]=f;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;jk(h,e+8|0)}d=e+24|0;se(d,v[a+28>>2]);g=v[d+12>>2];v[e+40>>2]=v[d+8>>2];v[e+44>>2]=g;kS(v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=po(d,lc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22708]=0;da(1528,a|0,c|0,b|0,e+40|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;break a}a=P()|0;O()|0;Hb(b);S(a|0);L()}}function N8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=gb-96|0;gb=d;v[d+88>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=f;v[d+48>>2]=c;v[d+52>>2]=e;a=Td(d+40|0);c=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=c;v[22708]=0;c=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;U(2075,d- -64|0,d+16|0,d+8|0);a=v[22708];v[22708]=0;a:{b:{if((a|0)!=1){a=v[qi(d+32|0,d+88|0)>>2];v[22708]=0;b=+za(2076,d- -64|0,+b,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}xb(d- -64|0);eg(d+88|0);gb=d+96|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(d- -64|0)}eg(d+88|0);S(a|0);L()}function kl(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!w[uj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[22708]=0;d=v[(a+d|0)+24>>2];f=v[22708];v[22708]=0;d:{if((f|0)==1){break d}v[22708]=0;b=W(2312,d|0,b|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;Z(b|0)|0;d=1;tj(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2029);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,d);gb=e+16|0;return}V(0)|0;O()|0;Bb()}L()}function dga(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;if((c|0)!=(b|0)){continue}break}CN(a+484344|0);Se(a+1298268|0);Se(a+1298280|0);Se(a+1298292|0);sD(a+1298368|0);c=a+900380|0;b=a+484380|0;while(1){Ol(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Yb(pv(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){CM(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function Cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);li(d,1,a);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){e=d+16|0;vb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[ac(e,d)|0]<<2,u[f+30>>1]=g;gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];no(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];h=v[a+12>>2];f=v[a+8>>2]+d|0;h=f>>>0<d>>>0?h+1|0:h;f=sh(e+40|0,f,h);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;jk(g,e)}g=e+16|0;se(g,v[a+28>>2]);d=v[g+12>>2];v[e+32>>2]=v[g+8>>2];v[e+36>>2]=d;jN(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=po(g,lc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22708]=0;da(1528,a|0,c|0,b|0,e+32|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];no(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];h=v[a+12>>2];f=v[a+8>>2]+d|0;h=f>>>0<d>>>0?h+1|0:h;f=sh(e+40|0,f,h);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;jk(g,e)}g=e+16|0;se(g,v[a+28>>2]);d=v[g+12>>2];v[e+32>>2]=v[g+8>>2];v[e+36>>2]=d;aN(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=po(g,lc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22708]=0;da(1528,a|0,c|0,b|0,e+32|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function sG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);g=Ab(b);i=Jb(c);j=Ab(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(sp(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=zd(b),v[k+32>>2]=l;c=Gd(e+40|0,e+32|0);k=e,l=zd(b),v[k+8>>2]=l;k=e,l=we(e+8|0,h),v[k+16>>2]=l;d=Gd(e+24|0,e+16|0);eG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}f=Jb(b);h=Ab(b);g=Jb(c);d=-1;i=Ab(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!sp(g,i,c)){continue}break}d=c-f|0}}if((Ab(b)-1|0)!=(d|0)){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function WI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-208|0;gb=f;v[f+204>>2]=c;c=f+160|0;Qb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((cy(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}h=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}i=c&32;b:{if(v[a+48>>2]){b=cy(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;g=f+80|0;v[a+16>>2]=g;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=cy(a,b,f+200|0,g,f+160|0,d,e);b=d;if(!c){break b}kb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|i;b=a&32?-1:b;if(!h){break a}}gb=f+208|0;return b}function Kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function XA(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;h=Nl(a,b);a:{if((h|0)==255){break a}if(vk(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=nqa(1<<20-f,0,c,0)+24858e3|0;f=jb;c=Qc(qqa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),jb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Pc(g+14|0,g+12|0)>>1]}e=Fu(h);b=ic(a+4|0,h);t[b|0]=(i<<10|c)>>>8|(d?0:32);Yh(v[a>>2],e|160,c&255);Yh(v[a>>2],e|176,w[b|0]);t[a+530|0]=1}gb=g+16|0}function SZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);li(d,1,a+33|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=d+16|0;vb(c);e=a+50|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;e=a+52|0;v[b+24>>2]=w[e|0]|w[e+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;f=b,g=w[ac(c,d)|0]<<2,u[f+30>>1]=g;c=a+55|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;if((c|0)!=65535){break b}v[b+4>>2]=0;v[b+8>>2]=0;break a}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0}function wJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb-16|0;gb=e;a:{b:{c:{d=a+8|0;d:{if(!vl(d)){if((b|0)<0|(gq(d)|0)<=(b|0)){break d}a=Ak(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=vl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[22708]=0;b=Q(70,e|0,3092)|0;c=v[22708];v[22708]=0;e:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}gb=e+16|0;return}L()}function qY(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(c,-6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function Uq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;g=Nb(a)-1|0;a:{if((Nb(a)|0)==1){break a}while(1){if(x[Cc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Nb(a)-1>>>0){continue}break}}h=x[Cc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Cc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Cc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Cc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[Cc(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=nqa(d,g,a,a>>31);a=h-e|0;j=f,k=Ac(oqa(b,jb,a,a>>31),jb)+i|0,v[j+12>>2]=k}Yd(f+12|0,0,65536);gb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function zV(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[sc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}Bf(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(lm(a)&-2)){break c}Wc(a,i+(c<<10)|0);if(!eC(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Wc(a,i+((j&65535)<<10)|0);h=eC(a,64,1)?h:j}Wc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(lm(a)|0)){break d}}if(c>>>0>=255){fv(b,254,65534);fv(b,255,65535)}k=h}return k&65535}function uI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;gb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[22614]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+76800>>2];if(d<<B(c,6)-6<0&c>>>0<=3){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[115189]=25;e=-1}return e|0}function sn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=1;j=d&2147483647;n=j;i=(j|0)==2147418112;l=c;a:{if(i&!c?a|b:i&(c|0)!=0|j>>>0>2147418112){break a}i=h&2147483647;o=i;m=(i|0)==2147418112;j=g;if(m&!g?e|f:m&(g|0)!=0|i>>>0>2147418112){break a}if(!(a|e|(j|l)|(b|f|(n|o)))){return 0}l=d&h;if((l|0)>0|(l|0)>=0){k=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}k=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}k=(a^e|c^g)!=0|(b^f|d^h)!=0}return k}function Lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function A$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=gb-32|0;gb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;v[22708]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ka(1929,a|0,b|0,k|0)|0;b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;ja(1924,7685,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();a=-255}gb=l+32|0;break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-48|0;gb=c;f=c+24|0;d=f;g=mc(d+8|0);v[22708]=0;e=T(467,b|0)|0;h=v[22708];v[22708]=0;a:{b:{if((h|0)==1){break b}v[22708]=0;U(393,d|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}d=v[d>>2];v[22708]=0;Q(318,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;gc(g);S(a|0);L()}v[22708]=0;Nr(c+16|0,f);b=v[22708];v[22708]=0;c:{if((b|0)==1){break c}v[22708]=0;b=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=b;R(640,a|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}zc(c+24|0);gb=c+48|0;return}a=P()|0;O()|0;zc(c+24|0);S(a|0);L()}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22708]=0;f=Q(1179,b|0,d|0)|0;e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)!=1){if(f){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1180,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}f=xD(d);v[22708]=0;U(288,c|0,b|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}e=kc(c+24|0,c);Vc(d+8|0,e);xb(e);xb(c);d:{if(!(f&1)){break d}v[22708]=0;Q(318,b|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}Zj(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function Goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Xj(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=gb-16|0;gb=e;c=kY(e,a,c);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){wb(a);QW(b);b=b+48|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=e+16|0;break c}b=wb(a);b=iY(d+8|0,jY(a,Xj(a)+c|0),Xj(a),b);v[22708]=0;RW(b,c);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(485,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hv(b)}gb=d+32|0;break a}a=P()|0;O()|0;Hv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Xj(a);lY(a,b);sY(a)}}function CS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;qc(a,65536);qc(a+4|0,64);qc(a+8|0,256);yg(a+28|0,16384);zf(a+30|0,128);zf(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}zf(a+19|0,64);zf(a+20|0,100);c=224;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<33){break a}}t[a+26|0]=c}zf(a+23|0,64);zf(a+24|0,64);jB(a+48|0,64);jB(a+68|0,64);jB(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[ic(c,b)|0]){if(w[ic(c,b)|0]<121){break b}}e=ic(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!up(w[a+14|0])){t[a+14|0]=5}if(w[a+34|0]>=251){t[a+34|0]=0}}function pR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;n=e,o=$q(b),v[n+16>>2]=o;i=e+24|0;l=i;c=gb-32|0;gb=c;j=dR(a,c+28|0,b);b=v[j>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=fc(a);f=c+8|0;h=Tj(f,cR(),Uj(g+8|0,b));b=v[h>>2];v[22708]=0;b=b+16|0;d=v[22708];v[22708]=0;a:{if((d|0)!=1){d=gb-16|0;gb=d;v[d+8>>2]=v[e+16>>2];k=v[d+8>>2];m=v[k+4>>2];v[b>>2]=v[k>>2];v[b+4>>2]=m;dd(b+8|0);gb=d+16|0;n=fc(h),o=1,t[n+4|0]=o;gb=g+16|0;break a}a=P()|0;O()|0;OA(h);S(a|0);L()}Gk(a,v[c+28>>2],j,v[f>>2]);b=be(f);t[c+27|0]=1;OA(f)}Vj(l,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(i);gb=e+32|0;return a+8|0}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}v[22708]=0;_(1962,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22708]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;Y(2001,c+16|0,d|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)==1){break c}a=c+16|0;b=ie(Jb(a));vb(a);break b}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1913,2627,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=c+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[22708]=0;_(1936,a|0);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22708]=0;_(1962,b|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}f=v[a+24>>2];b=uc(e+8|0,b);v[22708]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ia(2004,f|0,e|0,c|0,d|0,1);c=v[22708];v[22708]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,5773,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();b=0}gb=e+16|0;break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return b|0}function uj(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;t[a|0]=0;f=_f(v[v[b>>2]-12>>2]+b|0);d=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){d=v[d+72>>2];if(d){$s(d)}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=e+24|0;Fc(c,v[v[b>>2]-12>>2]+b|0);v[22708]=0;f=T(21,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Wb(e+24|0);c=dj(e+16|0,b);d=Wi(e+8|0);d:{if(!lk(c,d)){break d}while(1){if(!nh(f,8192,nl(c))){break d}ml(c);if(lk(c,d)){continue}break}}if(!kk(c,d)){break c}ih(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=_f(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}ih(d,4)}gb=e+32|0;return a}a=P()|0;O()|0;Wb(e+24|0);S(a|0);L()}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Hi(a,b,c,d);v[a>>2]=49908;c=mc(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Qb(a+4248|0,0,48);v[22708]=0;d=ga(1285)|0;e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}v[22708]=0;d=T(1286,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}v[a+4296>>2]=d;Qt(a);Pt(a);v[22708]=0;W(1534,a+44|0,2,2)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;Th(b);d=v[22708];v[22708]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;gc(c);kf(b);S(a|0);L()}function D2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=RG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);oj(i,k);Ic(k);Oh(k,a);oj(h,k);Ic(k);l=d,m=sj(a),v[l>>2]=m;l=e,m=rj(a),v[l>>2]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);oj(g,k);Ic(k);a=dl(a);break a}a=QG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);oj(i,k);Ic(k);Oh(k,a);oj(h,k);Ic(k);l=d,m=sj(a),v[l>>2]=m;l=e,m=rj(a),v[l>>2]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);oj(g,k);Ic(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}function lX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,2,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(444,d|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;Q(401,d|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function cJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Me(a)){ec(a,31);return 0}f=a,g=Me(a),t[f+1375|0]=g;d=zj(a);b=zj(a);zj(a);f=a,g=zj(a),v[f+1112>>2]=g;zj(a);c=Me(a);v[a+1116>>2]=c;if(!jy(a,a+1120|0,c)){ec(a,10);return 0}v[a+1404>>2]=-2;a:{if((d|0)==-1&(b|0)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){e=v[a+1116>>2];if((e|0)<1){b=27}else{c=0;b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}v[a- -64>>2]=d;v[a+60>>2]=v[a+56>>2]+(b+e|0)}v[a+1380>>2]=0;return 1}function WC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;kh(b,Fd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Nb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Ke(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Mb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[pd(e+8|0,e+4|0)>>2];h=Mb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=e+16|0}function M2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=UG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=sj(a),t[l|0]=m;l=e,m=rj(a),t[l|0]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=dl(a);break a}a=TG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=sj(a),t[l|0]=m;l=e,m=rj(a),t[l|0]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}
function rt(a,b,c){var d=0,e=0;d=a,e=Aj(C(C(z[c+1792>>2]*C(75038))+C(C(C(C(C(C(C(C(z[c+3584>>2]-z[c>>2])*C(29))+C(C(z[c+256>>2]+z[c+3328>>2])*C(213)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+768>>2]+z[c+2816>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))))),u[d>>1]=e;d=(b<<5)+a|0,e=Aj(C(C(C(C(C(C(C(C(z[c+3592>>2]*C(104))+C(z[c+3080>>2]*C(1567)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-16|0;gb=d;b=x[b>>1];e=d;f=x[a+30>>1];if(f){b=ro(b<<16>>16,f<<16>>16)}u[e+14>>1]=b;a:{if(!gd(c)){gk(oN(a+52|0,d+14|0),c);break a}a=a+52|0;b=iz(a,d+14|0);v[d+8>>2]=b;m=d,n=Dh(a),v[m>>2]=n;if(!og(d+8|0,d)){break a}c=gb-16|0;gb=c;l=c+8|0;b=v[yc(c,b)>>2];e=gb-16|0;gb=e;v[e+8>>2]=b;f=gb-16|0;gb=f;j=e+8|0;k=v[j>>2];h=k;i=yc(f+8|0,h);Sj(i);b=a;g=b;if(v[b>>2]==(h|0)){v[g>>2]=v[i>>2]}g=wb(b);v[g>>2]=v[g>>2]-1;cN(v[fc(b)>>2],h);b=v[i>>2];gb=f+16|0;a=fc(a);Fk(ue(j));Xk(a,k,1);gb=e+16|0;yc(l,b);gb=c+16|0}gb=d+16|0}function Nfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;ES(b,h);i=g,j=uC(b),v[i+8>>2]=j;i=g,j=Ch(b),v[i>>2]=j;while(1){b:{v[22708]=0;b=Gb(g+8|0,g);h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!b){mr(g+16|0);break a}v[22708]=0;b=Xl(g+8|0);h=v[22708];v[22708]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Sj(g+8|0);continue}break}a=P()|0;O()|0;mr(g+16|0);S(a|0);L()}gb=g+32|0}function kla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Kh(g,c);v[22708]=0;R(160,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(144,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22708]=0;us(f+16|0,f+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,24);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function Noa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Kh(g,c);v[22708]=0;R(144,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(144,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22708]=0;us(f+16|0,f+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function wh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb+-64|0;gb=e;a:{b:{if(c-1>>>0>1023){break b}if(me(a,b)){break b}c:{d:{if(Sf(a)>>>0<=b>>>0){d=mz(e+8|0,a);v[22708]=0;U(1491,a|0,b+1|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}Km(d)}d=bf(a,b);v[22708]=0;Q(1492,d|0,c|0)|0;c=v[22708];v[22708]=0;e:{if((c|0)!=1){c=bf(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=bf(a,b);v[22708]=0;_(1493,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break e}}a=V(89104)|0;b=O()|0;break c}g=ii(bf(a,b));break b}a=V(89104)|0;b=O()|0;Km(d)}if((ea(89104)|0)!=(b|0)){break a}Z(a|0)|0;$()}gb=e- -64|0;return g|0}S(a|0);L()}function u0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Pn(g,c);v[22708]=0;R(160,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(160,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22708]=0;us(f+16|0,f+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function z$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22708]=0;_(1962,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break d}c=v[a+24>>2];e=uc(d+8|0,b);v[22708]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=qG(c,d,1);e=v[22708];v[22708]=0;c=jb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,5804,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();b=0;c=0}gb=d+16|0;a=c;break a}b=P()|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}ma(a|0);return b|0}function wZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-32|0;gb=g;d=b;f=oc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>>0){fq(d,f);break d}e=wb(d);e=Zg(h+8|0,qh(d,oc(d)+f|0),oc(d),e);v[22708]=0;R(295,e|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}v[22708]=0;R(296,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}ae(e)}gb=h+32|0;break b}a=P()|0;O()|0;ae(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Em(d,e+v[d>>2]|0)}}c=Pb(a,c);if(c){LD(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function RS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Se(a);Qq(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Fb(f+12|0,f+4|0)>>2];Bp(a,zb(b)+g|0,h);ws(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[pc(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=pc(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Fb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}gb=f+16|0;return(d|0)!=0|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)==1){break c}v[22708]=0;_(1962,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[a+24>>2];b=uc(d+8|0,b);v[22708]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;Y(2003,e|0,d|0,(c|0)!=0|0,1);c=v[22708];v[22708]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,7275,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pm(a,b,c,d){var e=0,f=0,g=0;e=gb-16|0;gb=e;f=e+8|0;g=a+1074312|0;Db(f,g,84);a:{if(Cb(f)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){f=e+8|0;Db(f,g,10);if(!Cb(f)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;a=e+8|0;Db(a,g,10);if(!Cb(a)){break a}t[b+831|0]=0;u[b+778>>1]=0}gb=e+16|0}function vJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{c:{c=a+8|0;d:{if(!vl(c)){if((b|0)<0|(gq(c)|0)<=(b|0)){break d}c=(w[Ak(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=vl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[22708]=0;b=Q(70,d|0,3092)|0;c=v[22708];v[22708]=0;e:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}gb=d+16|0;return c|0}L()}function h$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=c>>>0){break a}d=a+4|0;e=w[d+1|0]<<8;f=w[d+2|0]<<16|w[d+3|0]<<24;if((w[d|0]|e|f)>>>0>c>>>0|c-(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<(f|(e|w[d|0]))>>>0|!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break a}g=1;if(oc(b)>>>0>=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}Qy(b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|0)}return g|0}function ux(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=f+8|0;Fc(g,b);v[22708]=0;b=T(2482,g|0)|0;g=v[22708];v[22708]=0;a:{if((g|0)==1){break a}v[22708]=0;Y(2494,b|0,83408,83440,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;b=T(2483,f+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;c=T(2495,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}v[d>>2]=c;v[22708]=0;c=T(2492,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[e>>2]=c;v[22708]=0;R(2493,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function Mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function _ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;Mk(e,2,a+2|0);d=e+16|0;Bc(d,e);v[22708]=0;Q(301,b+492|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(e+16|0);d=b+236|0;c=c+1|0;while(1){g=w[(a+f|0)+31|0];h=vd(d,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if(f>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;f=a+2|0;d=a+3|0;g=a+4|0;NN(w[a|0]&15,w[c|0]&15,w[f|0]&15,w[d|0]&15,w[g|0]&15,a+5|0,b+48|0);NN(w[a|0]>>>4|0,w[c|0]>>>4|0,w[f|0]>>>4|0,w[d|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function P9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=gb-16|0;gb=e;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}v[22708]=0;_(1962,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(e+8|0,b);v[22708]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Xa(2005,d|0,e|0,+c,1);d=v[22708];v[22708]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3018,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}gb=e+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function J$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Sg(a,v[b+8>>2],f)){dx(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;bx(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;bx(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];f=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=g;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;g=a;e=ee(e);a:{if(D(e)<2147483648){h=~~e;break a}h=-2147483648}i=g,j=Uc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return f<<3}function xx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=f+8|0;Fc(g,b);v[22708]=0;b=T(21,g|0)|0;g=v[22708];v[22708]=0;a:{if((g|0)==1){break a}v[22708]=0;Y(2474,b|0,83408,83440,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;b=T(2454,f+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;c=T(2475,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}t[d|0]=c;v[22708]=0;c=T(2466,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}t[e|0]=c;v[22708]=0;R(2467,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];g=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;a=d;f=fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Uc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return g<<2}function uY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=kY(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;U(484,a|0,e|0,b|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=iY(c+8|0,jY(a,Xj(a)+1|0),Xj(a),e);f=v[a+8>>2];v[22708]=0;U(484,e|0,f|0,b|0);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[22708]=0;R(485,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Hv(a);gb=c+32|0;break b}b=P()|0;O()|0;Hv(a);S(b|0);L()}}function R4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;e=He(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=He(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}f=c,g=Wh(v[a+48>>2]),t[f+19|0]=g;c:{d:{e:{d=c+20|0;switch(Ws(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Ts(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}gb=c+32|0;return b|0}function x_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Kw(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;U(278,a|0,e|0,b|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+36;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=QF(c+8|0,RF(a,al(a)+1|0),al(a),e);f=v[a+8>>2];v[22708]=0;U(278,e|0,f|0,b|0);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+36;v[22708]=0;R(209,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}ls(a);gb=c+32|0;break b}b=P()|0;O()|0;ls(a);S(b|0);L()}}function Mo(a){var b=0,c=0,d=0,e=0,f=0,g=0;e=x[a+24>>1];c=v[a+4>>2];d=!w[a+77|0]<<1;b=(e<<2)+(x[c+28>>1]>>>d|0)|0;v[a+40>>2]=((b&3)<<4)+34128;f=b>>>2|0;b=b>>>0<48;g=b?12-f|0:0;u[a+32>>1]=g;u[a+36>>1]=b?1:1<<f-12;u[a+34>>1]=-1<<g^-1;if((e|0)==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+52>>2]=((b&3)<<4)+34128;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+44>>1]=f;u[a+48>>1]=b?1:1<<e-12;u[a+46>>1]=-1<<f^-1;c=(x[a+30>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+64>>2]=((c&3)<<4)+34128;d=c>>>2|0;c=c>>>0<48;b=c?12-d|0:0;u[a+56>>1]=b;u[a+60>>1]=c?1:1<<d-12;u[a+58>>1]=-1<<b^-1}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(ok(a)>>>0>=b>>>0){h=e,i=Sf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Fb(e+12|0,e+8|0)>>2];if(f){while(1){JN(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){lz(a,b-d|0,c);break a}AN(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){Sf(d);CO(d);xN(d);$z(wb(d),v[d>>2],ok(d));h=wb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=zN(a,b);if(wN()>>>0<f>>>0){Sc();L()}wb(d);g=vN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=B(f,52)+g|0,v[h>>2]=i;uN(d,0);lz(a,b,c)}gb=e+16|0}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46162>>1])+B(u[e-2>>1],u[f+46160>>1])|0)+B(u[e+2>>1],u[f+46164>>1])|0)+B(u[e+4>>1],u[f+46166>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function T9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}v[22708]=0;_(1962,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22708]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(2e3,d|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3055,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}gb=c+16|0;return+e}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bpa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{d=gb+-64|0;gb=d;k=d;g=d+16|0;h=gb-16|0;gb=h;l=dU(h+8|0);while(1){e=gb-48|0;gb=e;b=l;c=v[b+4>>2]-v[b>>2]|0;b:{if(!c){b=v[b>>2];break b}c=c+1|0;if(!c){b=QT(ST(e+8|0,32));break b}f=E(c);f=ST(e+8|0,(c&-1>>>f+1?32:31)-f|0);while(1){j=QT(f);if(c>>>0<=j>>>0){continue}break}b=v[b>>2]+j|0}gb=e+48|0;m=Pe(g,i),n=b,v[m>>2]=n;i=i+1|0;if((i|0)!=12){continue}break}gb=h+16|0;b=kU(k,g,rU(g));v[22708]=0;RB(a,b,0);a=v[22708];v[22708]=0;if((a|0)!=1){Lc(b);gb=d- -64|0;break a}a=P()|0;O()|0;Lc(b);S(a|0);L()}}function Bna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,16);a=v[d>>2];v[22708]=0;d=Rd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,3,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(684,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function lq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;Ai(e+16|0,b);c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;d=gb-32|0;gb=d;c=v[e+4>>2];f=v[e>>2];v[d+8>>2]=f;v[d+12>>2]=c;v[d+16>>2]=f;v[d+20>>2]=c;f=gb-16|0;gb=f;g=v[d+12>>2];c=f;h=v[d+8>>2];v[c>>2]=h;v[c+4>>2]=g;v[c+8>>2]=h;v[c+12>>2]=g;g=gb-16|0;gb=g;h=v[c>>2];i=v[c>>2];c=yb(c);v[22708]=0;ko(d+24|0,h,c+i|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){gb=g+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=f+16|0;c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;c=e+24|0;ry(c,a,d);gb=d+32|0;yb(c);a=e+8|0;Ai(a,b);yb(a);gb=e+32|0}function _Y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,44);a=v[d>>2];v[22708]=0;d=Rd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,2,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(450,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)==1){break c}v[22708]=0;_(1962,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}c=v[a+24>>2];b=uc(d+8|0,b);v[22708]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(1998,c|0,d|0,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,7306,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function sQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Fb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Fb(c,f+4|0)>>2];c=zb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(zb(w[c|0])+h|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(zb(w[c|0])+d|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=f+16|0;return h+i<<1}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function oQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Fb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Fb(c,f+4|0)>>2];c=zb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(zb(w[c+1|0])+h|0)+(zb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(zb(w[c+1|0])+d|0)+(zb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=f+16|0;return h+i<<1}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{b:{c:{if(He(b,-1)){break c}i=c,j=Wh(b),t[i+23|0]=j;if(w[a+44|0]){if((Kk(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Ws(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Kk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((Kk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Xs(b);break a}a=-1}gb=c+32|0;return a|0}function wka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Kh(g,c);v[22708]=0;R(777,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(777,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}c=f+24|0;v[f+16>>2]=c;v[f+20>>2]=c+36;v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(453,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function wM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=Hi(a,b,c,d);t[a+4260|0]=e;v[a>>2]=50952;c=mc(a+4264|0);d=mc(a+4276|0);v[a+4232>>2]=1061997773;e=a+4224|0;v[e>>2]=1061158912;v[e+4>>2]=1059082943;e=a+4216|0;v[e>>2]=1038174126;v[e+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[a+4328>>2]=0;e=a+4320|0;v[e>>2]=0;v[e+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;v[22708]=0;W(1534,a+44|0,2,2)|0;e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}v[22708]=0;Th(b);e=v[22708];v[22708]=0;if((e|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);Lc(c);kf(b);S(a|0);L()}function V7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-32|0;gb=b;e=mc(a);Ld(b+24|0);a=0;c=v[b+28>>2];d=v[b+24>>2];v[22708]=0;R(1422,e|0,Iy(d,c)|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){b:{c:{c=v[b+24>>2];if((Iy(c,v[b+28>>2])|0)>0){while(1){c=v[(a<<3)+c>>2];v[22708]=0;c=Q(70,b+8|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;R(1424,e|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(c);c=v[b+24>>2];a=a+1|0;if((Iy(c,v[b+28>>2])|0)>(a|0)){continue}break}}gb=b+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function M4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;e=He(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=He(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(Ws(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Ts(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}gb=c+32|0;return b|0}function zla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;ud(b,0);ZC(d,a+1|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,v[b>>2]);qc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function fD(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=c;e=w[d+74|0];t[d+74|0]=e-1|e;e=v[d>>2];b:{if(e&8){v[d>>2]=e|32;d=-1;break b}v[d+4>>2]=0;v[d+8>>2]=0;e=v[d+44>>2];v[d+28>>2]=e;v[d+20>>2]=e;v[d+16>>2]=e+v[d+48>>2];d=0}if(d){break a}d=v[c+16>>2]}f=g;g=v[c+20>>2];if(f>>>0>d-g>>>0){return kb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]<0){d=0;break c}f=b;while(1){d=f;if(!d){d=0;break c}f=d-1|0;if(w[f+a|0]!=10){continue}break}f=kb[v[c+36>>2]](c,a,d)|0;if(f>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;g=v[c+20>>2]}hc(g,a,b);v[c+20>>2]=v[c+20>>2]+b;f=b+d|0}return f}function kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=f>>>21&2040;e=(((B(t[e|0],u[f+46162>>1])+B(t[e-1|0],u[f+46160>>1])|0)+B(t[e+1|0],u[f+46164>>1])|0)+B(t[e+2|0],u[f+46166>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Dk(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1|(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+29040>>3];a=a-(e+-26388279066624)-A[b+29048>>3];return ji(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function ZH(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!_f(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(yH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22708]=0;b=T(2317,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22708]=0;_(2318,a+b|0);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function e8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[22708]=0;R(2101,c|0,(d+(a<<5)|0)+480289|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;U(2094,c+16|0,b|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;R(1424,f|0,c+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}vb(c+16|0);vb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+16|0)}vb(c)}yd(f);S(a|0);L()}function it(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=gb-240|0;gb=h;g=v[c>>2];v[h+232>>2]=g;c=v[c+4>>2];v[h>>2]=a;v[h+236>>2]=c;a:{b:{c:{d:{if((g|0)!=1){g=a;i=1;break d}g=a;i=1;if(c){break d}c=a;break c}while(1){c=g-v[(d<<2)+f>>2]|0;if((kb[b|0](c,a)|0)<1){c=g;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=g-4|0;if((kb[b|0](j,c)|0)>-1){break e}if((kb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+h>>2]=c;g=h+232|0;e=KI(g);jt(g,e);i=i+1|0;d=d+e|0;e=0;g=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}JI(h,i);$x(c,b,d,f)}gb=h+240|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Eg(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;kq(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=fn(c+8|0,fh(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22708]=0;kq(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22708]=0;R(1503,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}eh(a);gb=c+32|0;break b}b=P()|0;O()|0;eh(a);S(b|0);L()}}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function xna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-80|0;gb=d;e=Qf(d+48|0);v[22708]=0;c=Q(687,b|0,e|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(688,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}c=e+2|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;U(288,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=kc(d+24|0,d);Vc(e+8|0,b);xb(b);xb(d);oW(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function MU(a,b){var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,4);a=v[d>>2];v[22708]=0;d=Rd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,3,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(869,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function Yna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Mp(c,a,1);wb(a);a=v[d+4>>2];v[22708]=0;R(657,a|0,b|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=ts(c+8|0,_w(a,Ec(a)+1|0),Ec(a),e);e=v[a+8>>2];v[22708]=0;R(657,e|0,b|0);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[22708]=0;Nn(d,a);b=v[22708];v[22708]=0;if((b|0)==1){break c}ss(a);gb=c+32|0;break b}b=P()|0;O()|0;ss(a);S(b|0);L()}}function Xw(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[wb(a)>>2]){b=gb-16|0;gb=b;c=Kw(b,a,1);d=wb(a);e=v[c+4>>2];v[22708]=0;R(208,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+36;$b(c);gb=b+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}d=gb-32|0;gb=d;c=a;e=wb(a);b=QF(d+8|0,RF(a,al(a)+1|0),al(a),e);f=v[b+8>>2];v[22708]=0;R(208,e|0,f|0);e=v[22708];v[22708]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+36;v[22708]=0;R(209,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}ls(b);gb=d+32|0;break b}a=P()|0;O()|0;ls(b);S(a|0);L()}}mj(a)}function VD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=mi(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;xn(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=Fn(c+8|0,Uk(a,tc(a)+1|0),tc(a),e);f=v[a+8>>2];v[22708]=0;xn(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[22708]=0;R(313,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Hh(a);gb=c+32|0;break b}b=P()|0;O()|0;Hh(a);S(b|0);L()}}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function z0(){var a=0;a:{if(t[465440]&1){break a}if(!Qd(465440)){break a}a=465152;while(1){a=Kb(a)+12|0;if((a|0)!=465440){continue}break}Pd(465440)}ld(465152,88408);ld(465164,88440);ld(465176,88476);ld(465188,88500);ld(465200,88524);ld(465212,88540);ld(465224,88560);ld(465236,88580);ld(465248,88608);ld(465260,88648);ld(465272,88680);ld(465284,88716);ld(465296,88752);ld(465308,88768);ld(465320,88784);ld(465332,88800);ld(465344,88524);ld(465356,88816);ld(465368,88832);ld(465380,88848);ld(465392,88864);ld(465404,88880);ld(465416,88896);ld(465428,88912)}function aD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Eg(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;dp(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=fn(c+8|0,fh(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22708]=0;dp(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22708]=0;R(52,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}eh(a);gb=c+32|0;break b}b=P()|0;O()|0;eh(a);S(b|0);L()}}function zP(a,b){var c=0,d=0,e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(!w[b+846|0]|v[a+480180>>2]!=1){break a}c=v[b+104>>2];if(!c){break a}if(!Md(c)){break a}d=x[c+34>>1];if(!(d&10)){break a}e=w[b+847|0]+w[(w[b+846|0]&15)+39680|0]|0;t[b+847|0]=e;if(e<<24>>24>-1){break a}t[b+847|0]=0;e=d&2;d=v[(e?4:12)+c>>2];f=v[b+760>>2]+1|0;v[b+760>>2]=f>>>0<v[(e?8:16)+c>>2]-d>>>0?f:0;e=kj(c);f=g+8|0;bc(f,zb(zb(v[c+20>>2]))+B(e,v[b+760>>2]+d|0)|0,e);b=v[f>>2];d=v[f+4>>2];if((b|0)!=(d|0)){while(1){t[b|0]=w[b|0]^-1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}_h(c,a,0)}gb=g+16|0}function ny(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=C(0),l=C(0);e=gb-32|0;gb=e;jJ(C(-z[a>>2]),C(z[a+24>>2]+z[a+12>>2]),C(z[a+48>>2]+z[a+36>>2]),e+20|0);jJ(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){d=a<<2;h=d+c|0;i=z[h>>2];f=z[d+(e+20|0)>>2];g=z[d+68256>>2];j=z[d+68268>>2];k=z[d+(e+8|0)>>2];z[h>>2]=C(f*g)-C(j*k);h=b+d|0;l=z[(0-a<<2)+68264>>2];f=C(C(f*j)+C(k*g));d=5-a<<2;g=z[d+68256>>2];z[h>>2]=C(i*l)-C(f*g);z[b+d>>2]=C(f*l)+C(i*g);a=a+1|0;if((a|0)!=3){continue}break}gb=e+32|0}function ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,26);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function vj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=gb-16|0;gb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);Lf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;gb=f+16|0}function uQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function qQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=dw(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;Cv(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+20;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=dD(c+8|0,eD(a,Ie(a)+1|0),Ie(a),e);f=v[a+8>>2];v[22708]=0;Cv(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+20;v[22708]=0;Bv(d,a);b=v[22708];v[22708]=0;if((b|0)==1){break c}ip(a);gb=c+32|0;break b}b=P()|0;O()|0;ip(a);S(b|0);L()}}function Gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-48|0;gb=e;v[22708]=0;c=Q(191,a|0,1)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[22708]=0;_(679,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;c=T(374,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[22708]=0;d=Q(680,a|0,e+8|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}hc(yW(b,d),e+8|0,33)}if(c&255){continue}break}}xb(a);gb=e+48|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function kW(a){var b=0,c=0;a:{if(sd(a,11493,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4294966507){break a}b=a+16|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}}a=a+32|0;c=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return c}function Uz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}c=e+8|0;f=a+1074312|0;Db(c,f,21);d=Cb(c);g=a;a=w[b+821|0];a=Qz(g,w[b+828|0],d?a:a+16>>>2|0);Db(c,f,45);b:{if(!(!Cb(c)|w[b+828|0]!=3)){g=b;d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];c=d+1|0;break c}t[b+832|0]=a;c=1}t[g+821|0]=c;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}c=e+8|0;Db(c,f,47);if(!Cb(c)){break a}t[b+831|0]=a}if(a){h=b,i=Lb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[h+684>>2]=i}gb=e+16|0}function _5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=1073741807){i=d,j=Ab(a),v[i+8>>2]=j;e=zm(v[Mc(d+12|0,d+8|0)>>2]);if((e|0)!=(aq(a)|0)){a:{f=1;g=aq(a);h=Ab(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>g>>>0){b=Ui(b,c);break c}v[22708]=0;b=Q(2299,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}f=De(a);c=Jb(a)}yi(b,c,Ab(a)+1|0);if(f){ai(a,c,g+1|0)}d:{if((e|0)!=1){rg(a,e+1|0);de(a,h);df(a,b);break d}_e(a,h)}}}gb=d+16|0;return}bg();L()}function Qq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=4294967279){i=d,j=Ab(a),v[i+8>>2]=j;e=Wk(v[Mc(d+12|0,d+8|0)>>2]);if((e|0)!=(Kc(a)|0)){a:{f=Kc(a);g=Ab(a);b:{if((e|0)==10){h=1;b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>f>>>0){b=pi(b,c);break c}v[22708]=0;b=Q(67,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}h=De(a);c=Jb(a)}Qg(b,c,Ab(a)+1|0);if(h){$k(a,c,f+1|0)}d:{if((e|0)!=10){rg(a,e+1|0);de(a,g);df(a,b);break d}_e(a,g)}}}gb=d+16|0;return}bg();L()}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=vh(a);a:{if(b){v[22708]=0;R(936,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}e=gb-16|0;gb=e;d=Kw(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){c=Qb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0}return a|0}a=P()|0;O()|0;KB(c);S(a|0);L()}function G4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-32|0;gb=c;a:{b:{c:{if(He(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((Kk(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Ws(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Kk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((Kk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Xs(b);break a}a=-1}gb=c+32|0;return a|0}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){c=v[a+20>>2];a=g;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=c;f=fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=e,j=Uc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}gb=d+16|0;return g<<2}function Dt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+12>>2]=b;u[f+10>>1]=0;u[f+8>>1]=65535;a:{if(!Et(f+12|0,f+10|0,f+8|0)){break a}a=a+24|0;if(!me(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0|(x[v[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Yc(b,c,d&65535);b:{switch(e|0){case 0:g=w[a|0];break a;case 1:g=w[a+1|0];break a;case 2:g=w[a+2|0];break a;case 3:g=w[a+3|0];break a;case 4:g=w[a+4|0];break a;case 5:break b;default:break a}}g=w[a+5|0]}gb=f+16|0;return g|0}function yz(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;j=gb-16|0;gb=j;v[j+12>>2]=d;d=a+12|0;i=d;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}i=a+8|0;v[j+8>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);k=b,l=v[Fb(j+8|0,j+12|0)>>2],v[k>>2]=l;b=Fd(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24),v[b>>2],v[j+12>>2]);v[c>>2]=b;if(!(b>>>0>=y[j+12>>2]|h)){v[c>>2]=b+1}u[e>>1]=x[e>>1]|f;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=x[e>>1]|g}gb=j+16|0}function Bf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Pc(28400,d+14|0)>>1];c=tc(a);a:{if(b>>>0>c>>>0){e=gb-32|0;gb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){tp(a,c,f);break d}b=wb(a);b=Fn(e+8|0,Uk(a,tc(a)+c|0),tc(a),b);v[22708]=0;U(312,b|0,c|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;R(313,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Hh(b)}gb=e+32|0;break b}a=P()|0;O()|0;Hh(b);S(a|0);L()}break a}if(b>>>0<c>>>0){yn(a,v[a>>2]+(b<<1)|0)}}gb=d+16|0}function _E(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=w[a+8|0];g=v[a>>2];a=v[a+4>>2];d=Jb(b);b=Ab(b);c=gb-16|0;gb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Fb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=g;break b}b=e;a=g;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{if((f-1&255)>>>0<=1){d=v[c+12>>2];t[c+7|0]=0;Ko(a,((a+d|0)-e|0)+b|0,c+7|0);break c}if((f-3&255)>>>0>1){break c}d=v[c+12>>2];t[c+6|0]=32;Ko(a,((a+d|0)-e|0)+b|0,c+6|0)}d:{switch(f-1|0){case 0:case 3:t[(v[c+12>>2]+g|0)-1|0]=0;break;default:break d}}gb=c+16|0}function r_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=16384;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=bl(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}as(d+4|0,bl(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}as(d+4|0,e-c|0);break b}hF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}hF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}gb=d+16|0}function yl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb-16|0;gb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Uh(a,d+15|0);h=w[d+15|0];v[b>>2]=(h&252)>>>2;v[b+4>>2]=0;c=h&3;if(c){c=-1<<c;l=(c>>>0<4294967294?c:-2)^-1;while(1){t[d+15|0]=0;m=Uh(a,d+15|0);c=b;f=v[c>>2];n=v[c+4>>2];j=w[d+15|0];e=g;g=k+1|0;e=g>>>0<1?e+1|0:e;k=g;g=e;h=c;o=c;p=f;c=(k<<3)-2|0;f=c&31;if((c&63)>>>0>=32){e=j<<f;c=0}else{e=(1<<f)-1&j>>>32-f;c=j<<f}v[o>>2]=p|c;v[h+4>>2]=e|n;i=i&m;if((k|0)!=(l|0)|g){continue}break}}gb=d+16|0;return i|0}function m3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;e=i>>>9&1;g=Gf(f,e+13|0,h,g,a)+f|0;i=Tg(f,g,c);e=f-((e<<3)+107&112)|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2503,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Sn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];h=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;i=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Uc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<2}function q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=32768;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=bl(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}as(d+4|0,bl(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}as(d+4|0,e-c|0);break b}gF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}gF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}gb=d+16|0}function Qka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22708]=0;Ud(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Td(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(926,b|0,d|0,a>>>5|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Uu(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22708]=0;Ud(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Td(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(927,b|0,d|0,a>>>2|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;ci(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22708]=0;Ud(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Td(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(928,b|0,d|0,a>>>8|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Su(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22708]=0;Ud(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Td(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(929,b|0,d|0,a>>>4|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Ru(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function LR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=pq(b);d=a;e=vh(a);v[22708]=0;R(1117,a|0,2048);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[22708]=0;DR(d);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Mf(e);S(a|0);L()}a=0;b:{while(1){c=1;if((a|0)!=1024){v[22708]=0;c=+(a-1024|0);g=pq(K(c*c*-9.5367431640625e-7+1)*b);e=v[22708];v[22708]=0;if((e|0)==1){break b}c=c*.0372006759294457;c=si(c)*g/(f*c)}h=ye(d,a),i=c*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Mf(d);S(a|0);L()}function ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-48|0;gb=d;c=d+24|0;Tm(c,b,1819307379);Vc(a+40|0,c);xb(c);Tm(c,b,1953721961);Vc(a+60|0,c);xb(c);Tm(c,b,543520099);Vc(a+120|0,c);xb(c);Tm(c,b,1414744396);v[22708]=0;c=Q(555,c|0,11095)|0;e=v[22708];v[22708]=0;a:{if((e|0)!=1){b:{if(c){v[22708]=0;U(1430,d|0,d+24|0,2);c=v[22708];v[22708]=0;if((c|0)==1){break b}UN(a+140|0,d);uB(d)}v[22708]=0;U(1431,d|0,b|0,1634890872);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;xb(d+24|0);S(a|0);L()}Vc(a+80|0,d);xb(d);xb(d+24|0);gb=d+48|0}function tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Se(b);e=d+56|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Rd(e);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22708]=0;Xe(d+8|0,2,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;U(13,d+40|0,2,d+24|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=d+40|0;Eb(b,a);vb(a);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,1,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(301,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,3,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(303,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Se(b);e=d+56|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Rd(e);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22708]=0;Xe(d+8|0,3,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;U(13,d+40|0,5,d+24|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=d+40|0;Eb(b,a);vb(a);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Eoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,2,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(399,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function BY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,2,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(301,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function lF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}d=b+80|0;f=a;c=v[b+84>>2];if(c>>>0<=15){c=v[d>>2]}else{v[e+12>>2]=c-16;c=v[Mc(d,e+12|0)>>2]}v[f+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+794|0]){break a}b:{c:{d:{if(!kF(b)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}g=a,h=v[a>>2]+B(kj(c),b)|0,v[g+4>>2]=h}gb=e+16|0}function C0(){var a=0;a:{if(t[465136]&1){break a}if(!Qd(465136)){break a}a=464848;while(1){a=Kb(a)+12|0;if((a|0)!=465136){continue}break}Pd(465136)}Xc(464848,2130);Xc(464860,2121);Xc(464872,8108);Xc(464884,7877);Xc(464896,2357);Xc(464908,8906);Xc(464920,2214);Xc(464932,2701);Xc(464944,6017);Xc(464956,6e3);Xc(464968,6008);Xc(464980,6027);Xc(464992,7343);Xc(465004,10599);Xc(465016,6090);Xc(465028,4778);Xc(465040,2357);Xc(465052,6904);Xc(465064,7748);Xc(465076,8120);Xc(465088,6406);Xc(465100,3520);Xc(465112,2584);Xc(465124,10508)}function Tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-16|0;gb=c;f=x[gj(a,b)>>1];a:{if(!Oo(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=Vb(d),v[j+8>>2]=k;j=c,k=Zb(d),v[j>>2]=k;if(!Gb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=$l(g);if(i){e=0;while(1){if(!((b|0)==(e|0)&(a|0)==(g|0)|x[sc(g,e)>>1]!=(h|0))){d=yN(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=c+8|0;nS(d);if(Gb(d,c)){continue}break a}break}j=gj(a,b),k=d,u[j>>1]=k;f=d}gb=c+16|0;return f&65535}function wP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?(b&240?-16:15)&b:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074456|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Yd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}gb=d+16|0}function gx(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Qb(d+24|0,0,39);a=a+f|0;a:{if(Sg(e,c,0)){v[d+56>>2]=1;kb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}kb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}gb=d- -64|0;return b}function aX(a,b){var c=0,d=0;c=(a|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}d=ng(v[b+8>>2]);c=v[b+8>>2];b:{if(d){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!ng(b)){b=v[b+8>>2];tr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;sr(a);return}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(ng(b)){b=v[b+8>>2];sr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;tr(a);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(a|0)==(b|0);t[c+12|0]=1;if((a|0)!=(b|0)){continue}break}}}function rba(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(!a){a=ie(18726);break b}v[22708]=0;c=Q(70,b|0,a|0)|0;a=v[22708];v[22708]=0;c:{d:{if((a|0)!=1){v[22708]=0;R(1917,b+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}d=b+16|0;a=ie(Jb(d));vb(d);vb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;vb(c)}Z(a|0)|0;a=0;v[22708]=0;Y(1913,8248,0,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=b+32|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{e=gb-32|0;gb=e;a=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;f=Q(191,b|0,8)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(f){v[22708]=0;U(1468,e|0,b|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}v[22708]=0;R(1469,a|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}ed(e);_i(e,JU(a));if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}gb=e+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ed(e);break b}b=P()|0;O()|0}ke(a);S(b|0);L()}}function y3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Gf(f,(i>>>9&1)+13|0,h,g,a)+f|0;i=Tg(f,g,c);e=f-32|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2496,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;h=fg(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{b:{if(!h){d=-1;if(!nd(a,5)){break b}break a}d=v[h+8>>2]}g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 3:bB(g,b);break c;default:break d}}e=gb-32|0;gb=e;v[e+28>>2]=d;u[e+26>>1]=0;v[e+12>>2]=2;d=e+16|0;i=g;g=e+28|0;co(d,i,e+26|0,v[Fb(g,e+12|0)>>2]);yb(d);v[e+16>>2]=2;Fb(g,d);u[e+16>>1]=x[e+26>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;gb=e+32|0}}Zf(a,h,c,f+24|0);gb=f+32|0}function gk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!De(a)){if(!De(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;a:{if(b>>>0<=10){_e(a,b);Qg(a,e,b);t[d+15|0]=0;Bd(a+b|0,d+15|0);break a}c=w[a+11|0];vp(a,10,b-10|0,c,0,c,b,e)}gb=d+16|0;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;c=ek(a);b:{if(c>>>0>b>>>0){c=v[a>>2];de(a,b);Qg(c,e,b);t[d+15|0]=0;Bd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];vp(a,f,g,c,0,c,b,e)}gb=d+16|0}return a|0}function Y9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22708]=0;_(1936,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22708]=0;ja(1994,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1913,7951,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function X9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22708]=0;_(1936,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22708]=0;ja(1995,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1913,7906,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;b=-1;a:{if(!Wf(a,8)){break a}c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;b=wd(c+8|0,c+24|0,8);e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;b=a;e=c+16|0;hd(e,a,c);e=(yb(e)|0)==8&(v[c+24>>2]==1096043343&v[c+28>>2]==1196314451);if(e){bd(b,8)}gb=c+32|0;b=0;if(!e){break a}b=-1;if(!ck(a,d+8|0)){break a}a=d+8|4;b=0;if(!Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}b=!(Xb(w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24))&-2139062144)}gb=d+16|0;return b|0}function v3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Gf(f,i>>>9&1|12,h,g,a)+f|0;i=Tg(f,g,c);e=f-32|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2496,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function j3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Gf(f,i>>>9&1|12,h,g,a)+f|0;i=Tg(f,g,c);e=f-96|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2503,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Sn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function b4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;a=lH(a,e+12|0,d,xe());d=jb;f=v[115189];f:{if(f){if(v[e+12>>2]!=(b|0)){break f}if((f|0)==68){break d}break e}v[115189]=g;if(v[e+12>>2]==(b|0)){break e}}}v[c>>2]=4;a=0;break a}if((d|0)<=-1&a>>>0<=2147483647|(d|0)<-1){v[c>>2]=4;break c}if((d|0)<=0&a>>>0<=2147483647|(d|0)<0){break a}}v[c>>2]=4;if((d|0)>=0&a>>>0>=1|(d|0)>0){break b}}a=-2147483648;break a}a=2147483647}gb=e+16|0;return a|0}function jB(a,b){var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{if(cd(a)){break a}u[v[a>>2]>>1]=0;zf(v[a>>2]+2|0,b);f=c,g=Vb(a),v[f>>2]=g;f=c,g=_o(c,1),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;if(!Gb(c+8|0,c)){break a}while(1){d=c+8|0;e=v[d>>2];f=c,g=_o(d,-1),v[f>>2]=g;e=Ke(e,v[c>>2]);u[v[c+8>>2]>>1]=x[e>>1];zf(v[c+8>>2]+2|0,b);Qe(d);f=c,g=Zb(a),v[f>>2]=g;if(Gb(d,c)){continue}break}}zf(a+14|0,Nb(a)-1&255);zf(a+13|0,w[a+14|0]);zf(a+16|0,Nb(a)-1&255);zf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){zf(a+17|0,Nb(a)-1&255)}gb=c+16|0}function L$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Sg(a,v[b+8>>2],e)){cx(b,c,d);return}a:{if(Sg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];kb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22708]=0;e=Q(870,b|0,d|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(871,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=cn(d);v[22708]=0;U(288,c|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=kc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);Zj(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function om(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function fqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22708]=0;e=Q(454,b|0,d|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(455,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=xD(d);v[22708]=0;U(288,c|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=kc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);Zj(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22708]=0;e=Q(539,b|0,d|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(540,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=xD(d);v[22708]=0;U(288,c|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=kc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);Zj(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function UO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Nb(c);a:{if(d>>>0<b>>>0){f=gb-32|0;gb=f;b:{d=b-d|0;c:{if(d>>>0<=v[wb(c)>>2]-v[c+4>>2]>>2>>>0){tE(c,d,g);break c}b=wb(c);b=fn(f+8|0,fh(c,Nb(c)+d|0),Nb(c),b);v[22708]=0;U(1328,b|0,d|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;R(52,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}eh(b)}gb=f+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}if(b>>>0<d>>>0){ij(c,v[c>>2]+(b<<2)|0)}}fA(a);gb=e+16|0}function Jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;a=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;d=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(d){v[22708]=0;R(863,c|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;R(864,a|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}ed(c);_i(c,JU(a));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}gb=c+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ed(c);break b}b=P()|0;O()|0}ke(a);S(b|0);L()}}
function sZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;a:{b:{if(!Wf(a,7)){break b}c=0;if(!bE(a,14913)){break a}if(!Wf(a,1)){break b}c=-1;if(!bd(a,bw(a))){break a}d=gb-32|0;gb=d;c=d+24|0;g=f+8|0;tn(c,g);h=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;c=a;e=d+16|0;hd(e,a,d);e=yb(e);if((e|0)==(h|0)){bd(c,yb(d+24|0))}gb=d+32|0;d=(e|0)==(h|0);if(!d){Uv(g)}c=-1;if(!d){break a}c=0;if(!ZD(f+8|0)){break a}c=Ne(a,b,YD(f+8|0),jb);break a}c=-1}gb=f+16|0;return c|0}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Rd(e);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22708]=0;Xe(d+8|0,1,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;Q(303,b|0,d+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}}function Qz(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;d=e+8|0;Db(d,a+1074312|0,21);a:{if(Cb(d)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+39888|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=mO(Bo(a))+-64|0;break a}d=t[(c>>>1&31)+38384|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+39760|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+39824|0]}a=d;gb=e+16|0;return a}function Oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-4112|0;gb=d;an(a,b);if(oc(a)>>>0>4095){while(1){f=e<<12;b=0;c=0;while(1){b=zb(w[lc(a,c+f|0)|0])+b|0;g=zb(b&255);i=ic(d+16|0,c<<1|1),j=g,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}g=f|2048;c=0;while(1){b=zb(w[lc(a,c+g|0)|0])+b|0;h=zb(b&255);i=ic(d+16|0,c<<1),j=h,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}i=d,j=Vb(a),v[i+8>>2]=j;b=d+16|0;Tu(b,b+4096|0,we(d+8|0,f));e=e+1|0;if(e>>>0<oc(a)>>>12>>>0){continue}break}}gb=d+4112|0}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;h=fg(a,c);se(f+8|0,v[a+28>>2]);e=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=e;a:{b:{if(!h){e=-1;if(!nd(a,5)){break b}break a}e=v[h+8>>2]}g=v[a+28>>2];c:{d:{switch(e+1|0){case 0:case 2:Vh(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=e;t[d+24|0]=0;v[d+12>>2]=1;e=d+16|0;i=g;g=d+28|0;co(e,i,d+24|0,v[Fb(g,d+12|0)>>2]);yb(e);v[d+16>>2]=1;Fb(g,e);t[d+16|0]=w[d+24|0];t[b|0]=w[e|0];gb=d+32|0}}Zf(a,h,c,f+24|0);gb=f+32|0}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=C(0);e=gb-32|0;gb=e;h=fg(a,c);d=e+8|0;se(d,v[a+28>>2]);f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;a:{if(!h){if(nd(a,5)){break a}}d=gb-32|0;gb=d;f=v[a+28>>2];yl(f,d+24|0);j=d,k=Qc(v[d+24>>2],v[d+28>>2]),v[j+16>>2]=k;v[d+12>>2]=256;Dl(b,v[Fb(d+16|0,d+12|0)>>2]);if(Nb(b)){while(1){v[d+16>>2]=0;lq(f,d+16|0);i=z[d+16>>2];j=Mb(b,g),l=i,z[j>>2]=l;g=g+1|0;if(Nb(b)>>>0>g>>>0){continue}break}}gb=d+32|0}Zf(a,h,c,e+24|0);gb=e+32|0}function CM(a){a=a|0;var b=0,c=0,d=0,e=0;b=v[a>>2];if(b){kb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;xr(a);c=gb-32|0;gb=c;a:{b:{c:{if(dg(a)>>>0<=oc(a)>>>0){break c}b=wb(a);d=oc(a);e=oc(a);v[22708]=0;b=da(1637,c+8|0,d|0,e|0,b|0)|0;d=v[22708];v[22708]=0;d:{e:{if((d|0)!=1){v[22708]=0;R(396,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ae(b);break c}a=V(0)|0;O()|0;break d}a=V(0)|0;O()|0;ae(b)}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}gb=c+32|0;break a}V(0)|0;O()|0;Bb();L()}}function wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=LY(c,a);AC(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=JY(f+8|0,KY(a,$i(a)+1|0),$i(a),c);AC(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;AC(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];IY(d);gb=f+32|0}function Mz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=uq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(uq(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=uq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!uq(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}gb=h+16|0}function vS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;n=c?0:e;f=v[a+12>>2];h=v[a>>2]+B(f,62)|0;d=b?1:-1;o=B(f,d)<<1;c=e;while(1){if((f|0)>0){g=B(c,f);p=v[a+4>>2];b=0;while(1){u[(b<<1)+h>>1]=x[p+(b+g<<1)>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}h=h+o|0;a:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break a}}b=c+d|0;c=!c&(d|0)<0;b=c?n:b;g=c?l:d}d=g;c=b;i=i+1|0;if((j|0)!=(i|0)){continue}break}}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,31);a=v[d>>2];v[22708]=0;d=Rd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,2,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;Q(303,b|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function am(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=LY(c,a);wD(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=JY(f+8|0,KY(a,$i(a)+1|0),$i(a),c);wD(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;wD(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];IY(d);gb=f+32|0}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];f=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=h,j=Uc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<2}function uS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function t8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-32|0;gb=b;a:{b:{if(Bj(a)){zh(b+24|0);break b}c=b+8|0;oo(c,a);v[22708]=0;c=T(2086,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}v[b+24>>2]=c;Yf(b+8|0)}if(Bj(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=Vb(c),v[f+8>>2]=g;f=b,g=Zb(c),v[f>>2]=g;if(!Gb(b+8|0,b)){break c}while(1){a=b+8|0;d=d+A[v[a>>2]>>3];$K(a);if(Gb(a,b)){continue}break}break c}d=A[Wl(c,a)>>3]}wl(b+24|0);gb=b+32|0;return+d}a=P()|0;O()|0;Yf(b+8|0);S(a|0);L()}function Ro(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){Iu(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Pl(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=Ab(a);e=aq(a);g=jr(b,c);a:{if(!g){break a}if(cD(b,Jb(a),Jb(a)+(Ab(a)<<2)|0)){d=gb-16|0;gb=d;kH(f,b,c);gb=d+16|0;b=f;c=Jb(b);d=Ab(b);v[22708]=0;W(2523,a|0,c|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Ic(b);break a}a=P()|0;O()|0;Ic(b);S(a|0);L()}if(e-d>>>0<g>>>0){nI(a,e,(d+g|0)-e|0,d,d)}e=Jb(a)+(d<<2)|0;if((b|0)!=(c|0)){while(1){Fe(e,b);e=e+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f>>2]=0;Fe(e,f);jh(a,d+g|0)}gb=f+16|0}function _9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22708]=0;_(1936,a|0);g=v[22708];v[22708]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22708]=0;ka(1992,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1913,9709,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Z9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22708]=0;_(1936,a|0);g=v[22708];v[22708]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22708]=0;ka(1993,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1913,9609,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Je(d,2,a+6|0);e=d+16|0;Bc(e,d);v[22708]=0;Q(301,b+492|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){e=b+236|0;c=c+1|0;vb(d+16|0);while(1){g=w[(a+f|0)+38|0];h=vd(e,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if((f|0)!=128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;vz(a+180|0,b+48|0,0);vz(a+228|0,b+88|0,2);vz(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){BB(e)}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Jg(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/6>>>0){SC(a,d,c);break c}b=wb(a);b=LW(e+8|0,DC(a,Jg(a)+d|0),Jg(a),b);v[22708]=0;U(643,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}QC(a);c=b+4|0;JW(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];FC(a,Jg(a));rv(b)}gb=e+32|0;break a}a=P()|0;O()|0;rv(b);S(a|0);L()}return}if(b>>>0<d>>>0){RC(a,v[a>>2]+B(b,6)|0)}}function Xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,16);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function U3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115189];v[115189]=0;a=Ax(a,e+12|0,d,xe());d=jb;e:{g=v[115189];if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68){break e}break b}v[115189]=h;if(v[e+12>>2]==(b|0)){break b}break c}v[c>>2]=4;a=-1;b=-1;break a}}v[c>>2]=4;a=0;b=0;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}gb=e+16|0;jb=b;return a|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22708]=0;Q(1168,f|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22708]=0;R(1169,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;Q(1168,f|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function sP(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}f=e+8|0;Db(f,a+1074312|0,3);if(Cb(f)){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){d=e+8|0;Db(d,a+1074312|0,3);if(!Cb(d)){break a}}c=c<<2}if(!c){break a}d=nu(a,b);if(!d){break a}f=d;a=v[(B(b,872)+a|0)+1075648>>2];if(a){a=w[a+33|0]}else{a=13}kb[v[v[d>>2]+84>>2]](f,c,a<<24>>24,b)}gb=e+16|0}function e3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-208|0;gb=a;u[a+204>>1]=w[83451]|w[83452]<<8;v[a+200>>2]=w[83447]|w[83448]<<8|(w[83449]<<16|w[83450]<<24);f=xe();v[a>>2]=e;g=a+176|0;i=Gf(g,20,f,a+200|0,a);e=i+g|0;g=Tg(g,e,c);f=a+8|0;Fc(f,c);v[22708]=0;f=T(2482,f|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;fH(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Sn(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);gb=a+208|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function ND(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Rd(e);f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)==1){break c}e=zb(e);v[22708]=0;Xe(d+8|0,3,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;Q(301,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function Lf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function Vz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=ak(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;em(l+c|0,l,k);break b}Ym(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Hr(f+h|0,c,d);d=b;b=c+g|0;jh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Zn();L()}m=e,n=zd(a),v[m+8>>2]=n;a=we(e+8|0,j);gb=e+32|0;return a|0}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Eg(d,a,1);wb(a);YS(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}f=gb-32|0;gb=f;e=wb(a);d=fh(a,Nb(a)+1|0);i=Nb(a);g=gb-16|0;gb=g;v[g+12>>2]=0;c=f+8|0;jf(c+12|0,e);if(d){h=SW(d)}v[c>>2]=h;e=(i<<2)+h|0;v[c+8>>2]=e;v[c+4>>2]=e;j=dc(c),k=(d<<2)+h|0,v[j>>2]=k;gb=g+16|0;YS(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;XS(a,c);a=c;WS(c);b=v[c>>2];if(b){IC(v[a+16>>2],b,Bk(a))}gb=f+32|0}function N$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22708]=0;Q(113,f|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22708]=0;R(175,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;Q(113,f|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function k3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=Gf(g,e+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2503,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Sn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function i3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=Gf(g,e+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2503,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Sn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function ay(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=OI(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}gb=e+16|0;return c}function YU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!w[b+8|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=8){continue}break}v[c+24>>2]=0;v[c+28>>2]=0;d=wd(c+8|0,c+24|0,8);e=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=e;e=c+16|0;cc(e,a,c);d=0;if(!((yb(e)|0)!=8|(v[c+24>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|v[c+28>>2]!=(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))))){Rb(a,8);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d|0}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function Sn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((un(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=lI(i,b,f);h=Jb(f);v[22708]=0;h=W(2505,a|0,h|0,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}Ic(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((un(a,c,b)|0)!=(b|0)){break b}}SB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;Ic(f);S(a|0);L()}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;_(1947,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22708]=0;b=Q(1948,d|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,7623,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c);a:{if(!g){break a}qc(f+28|0,65535);Bf(a,x[f+28>>1]);i=f,j=Vb(a),v[i+16>>2]=j;i=f,j=Zb(a),v[i+8>>2]=j;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Mg(b,c)){h=gb-16|0;gb=h;If(c);gb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;of(a);if(Gb(a,f+8|0)){continue}break}}gb=f+32|0;return g|0}function O4(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=Tb(b,13845);v[22708]=0;U(138,b+16|0,a|0,c|0);a=v[22708];v[22708]=0;a:{b:{c:{if((a|0)!=1){vb(c);if(Ec(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;vb(c);break b}a=0;while(1){d:{c=Ad(b+16|0,d);v[22708]=0;c=T(139,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Ec(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;sm(b+16|0)}S(d|0);L()}sm(b+16|0);gb=b+32|0;return a|0}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-96|0;gb=a;u[a+92>>1]=w[83451]|w[83452]<<8;v[a+88>>2]=w[83447]|w[83448]<<8|(w[83449]<<16|w[83450]<<24);f=xe();v[a>>2]=e;g=a- -64|0;i=Gf(g,20,f,a+88|0,a);e=i+g|0;g=Tg(g,e,c);f=a+8|0;Fc(f,c);v[22708]=0;f=T(21,f|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;hH(h,a- -64|0,e,f);h=b;b=f+i|0;b=vn(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);gb=a+96|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function Y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115189];v[115189]=0;a=Ax(a,e+12|0,d,xe());d=jb;g=v[115189];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115189]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a&65535}function uK(a){var b=0,c=0,d=0,e=0,f=0;if(v[a+16>>2]){while(1){c=_z(v[a>>2]);d=jb;e=v[a+28>>2];if((d|0)==(e|0)&y[a+24>>2]<=c>>>0|d>>>0>e>>>0){continue}d=b;b=v[a+8>>2];b=(c&v[a+40>>2])+(b>>>0<32?d<<b:0)|0;c=v[a+16>>2];f=f+1|0;if(c>>>0>f>>>0){continue}break}}if(y[a+12>>2]>c>>>0){while(1){d=_z(v[a>>2]);f=jb;e=v[a+36>>2];if((f|0)==(e|0)&y[a+32>>2]<=d>>>0|f>>>0>e>>>0){continue}e=b;b=v[a+8>>2];b=(d&v[a+48>>2])+(b>>>0<31?e<<b+1:0)|0;c=c+1|0;if(c>>>0<y[a+12>>2]){continue}break}}return b}function w_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=-1;c=gb-32|0;gb=c;f=c+24|0;h=e+8|0;cs(f,h);f=yb(f);d=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=d;v[c>>2]=i;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(f|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){Dw(h)}a:{if(!a){break a}g=0;if(!oF(e+8|0)){break a}if(b){c=v[b>>2];a=e+12|0;if(!v[b+4>>2]&c>>>0<Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))-8>>>0){break a}}g=1}gb=e+48|0;return g|0}function Oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function MD(a,b,c){var d=0,e=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Rd(e);e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)==1){break c}c=zb(c);v[22708]=0;Xe(d+8|0,3,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(399,b|0,d+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function Pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){g=g<<8;h=h<<8;while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+B(h,t[e|0]);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function d$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=e;v[d+8>>2]=b;v[d+12>>2]=e;g=gb-16|0;gb=g;h=g+8|0;f=h;i=gb-16|0;gb=i;e=gb-16|0;gb=e;c=gb-16|0;gb=c;b=e;v[b+4>>2]=1;j=b,k=Nc(24,4),v[j+8>>2]=k;gb=c+16|0;c=v[b+8>>2];v[22708]=0;Q(213,c|0,d|0)|0;c=v[22708];v[22708]=0;a:{if((c|0)!=1){c=f;f=Jp(b);Ow(c,dc(f),f);ZF(b);gb=e+16|0;break a}a=P()|0;O()|0;ZF(b);S(a|0);L()}gb=i+16|0;Xf(a,h);Kd(h);gb=g+16|0;gb=d+16|0}function TE(a,b){a=a|0;b=b|0;var c=0,d=0;Qb(b,0,44);if(w[a+2|0]|w[a+3|0]<<8?1:w[a|0]|w[a+1|0]<<8){v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;c=b,d=Lb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[c+16>>2]=d;c=b,d=Lb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[c+12>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)>>>11|0,0,23),v[c+8>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)>>>5&63,0,59),v[c+4>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)<<1&62,0,59),v[c>>2]=d}v[b+44>>2]=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=fg(a,c);d=f+8|0;se(d,v[a+28>>2]);e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;a:{b:{if(!g){d=-1;if(!nd(a,5)){break b}break a}d=v[g+8>>2]}h=v[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=gb-16|0;gb=d;v[d+8>>2]=0;lq(h,d+8|0);z[b>>2]=z[d+8>>2];gb=d+16|0;break c}e=gb-32|0;gb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;co(e+8|0,h,e+28|0,v[Fb(e+24|0,e+20|0)>>2]);v[b>>2]=0;gb=e+32|0}}Zf(a,g,c,f+24|0);gb=f+32|0}function H2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-32|0;gb=f;d=Ab(a);e=Kc(a);g=Zh(b,c);a:{if(!g){break a}if(cD(b,Jb(a),Jb(a)+Ab(a)|0)){b=Nj(f+16|0,b,c);c=Jb(b);d=Ab(b);v[22708]=0;W(2301,a|0,c|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Ym(a,e,(d+g|0)-e|0,d,d,0,0)}e=Jb(a)+d|0;if((b|0)!=(c|0)){while(1){Bd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(e,f+15|0);jh(a,d+g|0)}gb=f+32|0}function _P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b+7|0]);d=zb(w[b+6|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+5|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+4|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+3|0])|(g|i);j=a,k=Jc(d,zb(w[b+2|0])<<8|g|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function T6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[qi(e+16|0,e+40|0)>>2];c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;v[22708]=0;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;da(1934,a+8|0,e|0,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){MJ(a);b=LJ(a+88|0);v[a>>2]=59704;v[b>>2]=59792;eg(e+40|0);gb=e+48|0;return a|0}a=P()|0;O()|0;eg(e+40|0);S(a|0);L()}function $P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b|0]);d=zb(w[b+1|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+2|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+3|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+4|0])|(g|i);j=a,k=Jc(d,zb(w[b+5|0])<<8|g|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function w3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;f=Gf(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-48|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2496,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function u3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;f=Gf(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-48|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2496,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function FQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Fb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(c,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function EQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];c=e+8|0;h=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Fb(c,e+4|0)>>2];c=zb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=zb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=zb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=zb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}gb=e+16|0;return h+i|0}function zO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;jb=v[e+4>>2];return v[e>>2]}function vZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c<<1);a:{if(!g){break a}qc(f+28|0,65535);Bf(a,x[f+28>>1]);h=f,i=Vb(a),v[h+16>>2]=i;h=f,i=Zb(a),v[h+8>>2]=i;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;if(!Dp(b,c)){KD(c)}c=w[f+24|0]|w[f+25|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;of(a);if(Gb(a,f+8|0)){continue}break}}gb=f+32|0;return g|0}function _0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(!e|(c|0)==(d|0))){while(1){a:{g=1;f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];h=wi(f+8|0,f+12|0);v[22708]=0;i=mH(c,d-c|0,b);l=v[22708];v[22708]=0;b:{if((l|0)!=1){gf(h);gb=f+16|0;break b}a=P()|0;O()|0;gf(h);S(a|0);L()}c:{switch(i+2|0){default:g=i;break;case 0:case 1:break a;case 2:break c}}j=g+j|0;k=k+1|0;if(k>>>0>=e>>>0){break a}c=c+g|0;if((d|0)!=(c|0)){continue}}break}return j|0}return 0}function vn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((un(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=Ge(i,b,f);g=Jb(f);v[22708]=0;g=W(28,a|0,g|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}vb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((un(a,c,b)|0)!=(b|0)){break b}}SB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;vb(f);S(a|0);L()}function eG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;v[f+16>>2]=c;v[f+24>>2]=b;k=f,l=zd(a),v[k+8>>2]=l;b=f+24|0;h=f+8|0;i=ak(b,h);e=i;b=ak(f+16|0,b);a:{if(Ab(a)>>>0>=e>>>0){if((b|0)==-1){vE(a,e);break a}d=gb-16|0;gb=d;v[d+12>>2]=b;if(b){c=Ab(a);j=Jb(a);g=c-e|0;v[d+8>>2]=g;b=v[Fb(d+12|0,d+8|0)>>2];v[d+12>>2]=b;g=g-b|0;if(g){e=e+j|0;em(e,b+e|0,g);b=v[d+12>>2]}e=a;a=c-b|0;jh(e,a);t[d+7|0]=0;Bd(a+j|0,d+7|0)}gb=d+16|0;break a}Zn();L()}we(h,i);gb=f+32|0}function mt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Z6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;wy(b,c,yb(d));e=v[b+16>>2];a:{if(e>>>0<=c>>>0){mk(a,d,0);break a}v[f+28>>2]=e-c;i=f,j=yb(d),v[i+24>>2]=j;g=v[Fb(f+28|0,f+24|0)>>2];NB(f+16|0,d,0,g);e=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=e;e=gb-32|0;gb=e;b=b+4|0;i=e,j=Vb(b),v[i+24>>2]=j;h=we(e+24|0,c);i=e,j=Vb(b),v[i+8>>2]=j;i=e,j=we(e+8|0,c),v[i+16>>2]=j;b=f+8|0;Xi(h,we(e+16|0,yb(b)),v[b>>2]);gb=e+32|0;NB(a,d,0,g)}gb=f+32|0}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Md(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;if((g|0)!=(d|0)){continue}break}Ol(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Ro(e,0,c)}gb=c+32|0;return f|0}function Gfa(a,b){a=a|0;b=b|0;var c=0;b=38480;a=dd(a);a:{while(1){b:{if(!cd(a)){if(!xj(v[b+8>>2],v[vo(a)>>2])){break b}}v[22708]=0;R(1414,a|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=39044){continue}break}b=39056;while(1){c:{if(!cd(a)){if(!xj(v[b+8>>2],v[vo(a)>>2])){break c}}v[22708]=0;R(1414,a|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=39104){continue}break}return}b=P()|0;O()|0;Lc(a);S(b|0);L()}function pI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=zm(v[Mc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Ui(l,k);if(e){yi(c,j,e)}if(g){yi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;yi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){ai(a,j,b)}df(a,c);rg(a,k);b=a;a=d+(e+g|0)|0;de(b,a);v[i+4>>2]=0;Fe(c+(a<<2)|0,i+4|0);gb=i+16|0;return}bg();L()}function Ti(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;if(!cd(a)){pS(b+32|0,Zb(a));pS(b+24|0,Vb(a));c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!qS(c,e)){break a}while(1){d=gb-16|0;gb=d;v[d+8>>2]=v[c+4>>2];f=hS(d+8|0);gb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}hS(c+4|0);if(qS(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=vD(Vb(a),v[b+44>>2])}gb=b+48|0;return c&65535}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Fb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(c,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Wh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Wh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function Jaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22708]=0;_(1936,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22708]=0;b=sa(1953,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10292,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function IV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!lf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!lf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}gb=f+16|0}function Gaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22708]=0;_(1936,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22708]=0;b=sa(1956,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10224,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function rf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=nqa(b,c,h,i);i=jb;j=h;h=nqa(d,e,f,g);e=j+h|0;d=jb+i|0;i=e;h=e>>>0<h>>>0?d+1|0:d;j=g;e=0;g=e;k=i;l=c;d=0;i=nqa(j,e,c,d);e=k+i|0;c=jb+h|0;k=e;e=e>>>0<i>>>0?c+1|0:c;h=f;c=0;i=b;f=nqa(h,c,i,0);b=jb;d=nqa(h,c,l,d);b=b+d|0;c=jb;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+k|0;d=c>>>0<h>>>0?e+1|0:e;h=c;c=d;d=nqa(i,m,j,g)+b|0;e=jb;e=b>>>0>d>>>0?e+1|0:e;b=h;h=e;e=b+e|0;v[a+8>>2]=e;v[a+12>>2]=e>>>0<h>>>0?c+1|0:c;v[a>>2]=f;v[a+4>>2]=d}function iH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115189];v[115189]=0;a=Ax(a,e+12|0,d,xe());d=jb;g=v[115189];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115189]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a|0}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=vh(a);a:{if(b){v[22708]=0;R(898,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=d;v[c>>2]=a;e=v[a+4>>2];v[c+4>>2]=e;v[c+8>>2]=e+B(b,9);e=c;b=v[c+4>>2];c=v[c+8>>2];if((b|0)!=(c|0)){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[e+4>>2]=b;if((b|0)!=(c|0)){continue}break}}$b(e);gb=d+16|0}return a|0}a=P()|0;O()|0;QB(c);S(a|0);L()}function pl(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[22614]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115189]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function nc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){d=qt(a);if((d|0)==-1){break b}e=v[a+1396>>2];c=e+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}v[a+1396>>2]=c-b;c=a;a=v[a+1392>>2];v[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}v[a+1396>>2]=-1;return 0}aa(7347,10534,1632,3887);L()}function cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[pc(b,0)|0]==(hg(43)&255)){break b}if(w[pc(b,0)|0]==(hg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=we(d+8|0,e-c|0),v[i+16>>2]=j;Gd(d+24|0,d+16|0);Vz(b,v[d+24>>2],1,hg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function F9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22708]=0;_(2009,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22708]=0;b=Ua(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8588,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function WN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=ak(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;em(l+c|0,l,k);break b}Ym(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Hr(f+h|0,c,d);d=b;b=c+g|0;jh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Zn();L()}m=e,n=zd(a),v[m+8>>2]=n;we(e+8|0,j);gb=e+32|0}function yU(a){var b=0,c=0,d=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>32){break a}b=a+32|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>256){break a}b=a+34|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}d=(w[a|0]|w[a+1|0]<<8)>>>0<129}return d}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[Jb(b)|0]==(hg(43)&255)){break b}if(w[Jb(b)|0]==(hg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=we(d+8|0,e-c|0),v[i+16>>2]=j;Gd(d+24|0,d+16|0);WN(b,v[d+24>>2],1,hg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function Dna(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ie(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/20>>>0){sE(a,c);break c}b=wb(a);b=dD(d+8|0,eD(a,Ie(a)+c|0),Ie(a),b);v[22708]=0;R(683,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;Bv(a,b);a=v[22708];v[22708]=0;if((a|0)==1){break b}ip(b)}gb=d+32|0;break a}a=P()|0;O()|0;ip(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,20)|0;Ie(a);cE(a,b);dm(a);Ie(a)}}function f7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-48|0;gb=e;a:{if(w[b+8|0]){b=b+12|0;i=e,j=oc(b)-c|0,v[i+40>>2]=j;i=e,j=yb(d),v[i+32>>2]=j;f=e+40|0;h=e+32|0;g=v[Fb(f,h)>>2];i=e,j=Vb(b),v[i+40>>2]=j;f=we(f,c);i=e,j=Vb(b),v[i+24>>2]=j;i=e,j=we(e+24|0,c),v[i+32>>2]=j;Xi(f,we(h,g),v[d>>2]);mk(a,d,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;kb[f|0](a,b,c,e+8|0)}gb=e+48|0}function oY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1064>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1072|0,g=bl(a,7),t[f|0]=g;d=bl(a,1);e=bl(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;oY(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Hi(a,b,c,d);v[a>>2]=51824;d=mc(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=xf(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[22708]=0;W(1534,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Th(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);kf(b);S(a|0);L()}function VB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;e=mc(a);f=d,g=Vb(b),v[f+40>>2]=g;f=d,g=Zb(b),v[f+32>>2]=g;a:{if(Gb(d+40|0,d+32|0)){while(1){a=d+8|0;b=v[d+40>>2];_i(a,b);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=d+8|0;rn(a,b);v[22708]=0;R(535,e|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}xb(d+8|0)}a=d+40|0;pn(a);if(Gb(a,d+32|0)){continue}break}}gb=d+48|0;return}a=P()|0;O()|0;xb(d+8|0);jd(e);S(a|0);L()}function I9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22708]=0;_(2009,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22708]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8733,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function H9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22708]=0;_(2009,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22708]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8769,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fG(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1129474426|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1634291279){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function cL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=gb-48|0;gb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=wd(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=hA(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;v[22708]=0;b=Q(70,b+16|0,5190)|0;c=v[22708];v[22708]=0;b:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}gb=b+48|0;return a|0}L()}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22708]=0;_(2009,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22708]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3717,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22708]=0;_(2009,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22708]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3771,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function nP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}qk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}c=d+8|0;Db(c,a+1074312|0,7);if(Cb(c)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function JN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=gb-16|0;gb=e;g=v[d+4>>2];d=v[d>>2];f=(g-d|0)/6|0;a:{if(f>>>0<=Wj(c)>>>0){if(Jg(c)>>>0<f>>>0){v[e+12>>2]=d;h=Jg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);h=d;d=v[e+12>>2];pz(h,d,v[c>>2]);nz(c,d,g,f-Jg(c)|0);break a}RC(c,pz(d,g,v[c>>2]));break a}EN(c);jX(c,DC(c,f));nz(c,d,g,f)}gb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];IN(a+24|0,b+24|0);gk(a+36|0,b+36|0)}function yv(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>17){break a}d=1<<d;b:{if(!(d&63503)){if(d&198144){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{switch(w[a+3|0]){case 16:case 17:c=8;break d;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:c=w[a|0];if(!(c&7)){break d}case 10:c=b+1>>>1|0;b=(w[a+3|0]==10)<<4;break c;case 9:break e;default:break d}}c=16}c=B(c>>>3|0,b);b=(w[a+3|0]==10)<<4}c=b+B(gp(a),c)|0}return c|0}function C$(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[22708]=0;m=a;a=0;a=rG(1927,m|a,b,c,d,a|e,f);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;ja(1924,5974,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function yoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;bD(e+24|0,c);v[22708]=0;R(637,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function bpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;bD(e+24|0,c);v[22708]=0;R(538,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Kh(e+24|0,c);v[22708]=0;R(777,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(453,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function Aoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Pn(e+24|0,c);v[22708]=0;R(144,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function $pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Pn(e+24|0,c);v[22708]=0;R(160,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function nB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=-1;f=d&2147483647;k=f;g=(f|0)==2147418112;h=c;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=f;j=(f|0)==2147418112;if(j?0:j&0|f>>>0>2147418112){break a}if(!(a|h|(g|k|b))){return 0}h=d&e;if((h|0)>0|(h|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}i=(a|c)!=0|(d^e|b)!=0}return i}function aw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;JD(e+24|0,c);v[22708]=0;R(144,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function Y4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Kh(e+24|0,c);v[22708]=0;R(144,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function DZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;hw(e+24|0,c);v[22708]=0;R(365,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Df(e+24|0)}S(a|0);L()}}function rN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Nb(a);if(c>>>0<=127){e=gb-32|0;gb=e;a:{b:{d=128-c|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){gz(a,d,b);break c}c=wb(a);c=fn(e+8|0,fh(a,Nb(a)+d|0),Nb(a),c);v[22708]=0;U(1502,c|0,d|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(1503,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}eh(c)}gb=e+32|0;break a}a=P()|0;O()|0;eh(c);S(a|0);L()}return}if((c|0)!=128){ij(a,v[a>>2]+512|0)}}function uP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}qk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}c=d+8|0;Db(c,a+1074312|0,7);if(Cb(c)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function QS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];a:{b:{if(!v[Fb(c+12|0,c+8|0)>>2]){break b}while(1){e=Yq(t[lc(a,d)|0]);f=Yq(t[lc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];d=d+1|0;if(d>>>0>=y[Fb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(v[a+4>>2]==v[b+4>>2]){break a}d=y[a+4>>2]<y[b+4>>2]?-1:1}gb=c+16|0;return d}function xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=oc(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){Dn(a,d,c);break c}b=wb(a);b=Zg(e+8|0,qh(a,oc(a)+d|0),oc(a),b);v[22708]=0;U(638,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(296,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}ae(b)}gb=e+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<d>>>0){Em(a,v[a>>2]+b|0)}}function cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gb-32|0;gb=d;e=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}if(!a){break d}v[22708]=0;U(1468,d|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(1469,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(d);break b}gb=d+32|0;break a}a=P()|0;O()|0}ke(e);S(a|0);L()}}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gb-32|0;gb=d;e=Ho(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}if(!a){break d}v[22708]=0;U(1159,d|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(1160,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(d);break b}gb=d+32|0;break a}a=P()|0;O()|0}uB(e);S(a|0);L()}}function Nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=-1;a:{if(!ck(a,d+8|0)){break a}c=d+8|0;b:{if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(An(6109)|0)){break b}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<256){break b}e=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<260}c=0;if(!e){break a}c=a;a=d+12|0;c=Ne(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}gb=d+16|0;return c|0}function Kaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22708]=0;_(1936,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22708]=0;b=fa(1952,f|0,b|0,c|0,d|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6840,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Haa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22708]=0;_(1936,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22708]=0;b=fa(1955,f|0,b|0,c|0,d|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6768,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function z9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22708]=0;_(2009,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22708]=0;Wa(f|0,d|0,b|0,+c);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8932,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function hf(a,b,c,d){var e=0,f=0;a:{if(!Ab(a)|(c-b|0)<5){break a}e=b;f=c;b:{if((e|0)==(f|0)){break b}f=f-4|0;if(f>>>0<=e>>>0){break b}while(1){xc(e,f);e=e+4|0;f=f-4|0;if(e>>>0<f>>>0){continue}break}}e=Jb(a);f=Ab(a);a=c-4|0;c:{if(a>>>0>b>>>0){c=e+f|0;while(1){f=w[e|0];if((f-1&255)>>>0<=125&(f|0)!=v[b>>2]){break c}e=((c-e|0)>1)+e|0;b=b+4|0;if(a>>>0>b>>>0){continue}break}}b=w[e|0];if((b-1&255)>>>0>125|b>>>0>v[a>>2]-1>>>0){break a}}v[d>>2]=4}}function Ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=c;c=Pb(b,c<<2);a:{if(!c){break a}qc(d+28|0,65535);Bf(a,x[d+28>>1]);g=d,h=Vb(a),v[g+16>>2]=h;g=d,h=Zb(a),v[g+8>>2]=h;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];e=d+24|0;if(!is(b,e)){f=gb-16|0;gb=f;_j(e);gb=f+16|0}e=w[d+24|0]|w[d+25|0]<<8;u[a>>1]=e;if((e|0)==65535){u[a>>1]=65535}a=d+16|0;of(a);if(Gb(a,d+8|0)){continue}break}}gb=d+32|0;return c|0}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;GC(d+24|0,c);v[22708]=0;R(637,d+36|0,49068);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(d+16|0,d+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;U(146,a|0,b|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Df(d+24|0);gb=d+48|0;break a}a=P()|0;O()|0;vb(d+24|0);break b}a=P()|0;O()|0;Df(d+24|0)}S(a|0);L()}}function Ne(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=xo(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=xo(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Tk(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}gb=e+16|0;return a}function w7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Xg(b,e,f)>>2];c=Ac(oqa(nqa(c,c>>31,g,h),jb,65536,0),jb);i=Xg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;aK(a,d);gb=d+16|0}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){iN(a,c);break c}b=wb(a);b=fn(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22708]=0;R(1544,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(1541,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}eh(b)}gb=d+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}return}if(b>>>0<c>>>0){ij(a,v[a>>2]+(b<<2)|0)}}function F7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Xg(b,e,f)>>2];c=Ac(oqa(nqa(c,c>>31,g,h),jb,65536,0),jb);i=Xg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;hK(a,d);gb=d+16|0}function ie(a){var b=0,c=0,d=0;d=Vp(Nf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function W5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!gt(eb(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}gb=d+32|0;return e|0}function Sr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=wd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);b:{if((yb(e)|0)!=7){break b}if(sd(c+24|0,b,7)){break b}Rb(a,7);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d|0}function wE(a,b){a=a|0;b=b|0;var c=0,d=0;c=tc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){jE(a,c);break c}b=wb(a);b=Fn(d+8|0,Uk(a,tc(a)+c|0),tc(a),b);v[22708]=0;R(338,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(313,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hh(b)}gb=d+32|0;break a}a=P()|0;O()|0;Hh(b);S(a|0);L()}return}if(b>>>0<c>>>0){yn(a,v[a>>2]+(b<<1)|0)}}function U5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[pd(e+12|0,pd(e+8|0,e+4|0))>>2];Qg(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+d;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Wh(d),t[h|0]=i;d=1}b=b+d|0;f=d+f|0;if((f|0)<(c|0)){continue}break}}gb=e+16|0;return f|0}function y8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22708]=0;b=Q(70,h|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,4);c=Ky(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=h+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function Q5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;d=v[pd(e+12|0,pd(e+8|0,e+4|0))>>2];yi(b,v[a+12>>2],d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;if((g|0)<(c|0)){continue}break}}gb=e+16|0;return g|0}function B8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22708]=0;b=Q(70,h|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,4);c=Ly(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=h+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,15);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22708]=0;R(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10094,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ZM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(Cl(a)>>>0<=Vf(a)>>>0){break b}b=wb(a);d=Vf(a);e=Vf(a);v[22708]=0;b=da(1538,c+8|0,d|0,e|0,b|0)|0;d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){v[22708]=0;R(1539,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}Rt(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Rt(b)}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function YM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(pe(a)>>>0<=Nb(a)>>>0){break b}b=wb(a);d=Nb(a);e=Nb(a);v[22708]=0;b=da(1540,c+8|0,d|0,e|0,b|0)|0;d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){v[22708]=0;R(1541,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}eh(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;eh(b)}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function Fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,14);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=da(1958,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10255,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=da(1960,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10181,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22708]=0;R(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6469,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=da(1951,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6608,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Iaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=da(1954,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6577,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function G9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22708]=0;R(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8598,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=da(1957,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6801,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function FZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=-1;a:{if(!Wf(a,7)){break a}d=0;if(!bE(a,9028)){break a}c=gb-32|0;gb=c;d=g;e=c+24|0;SD(e,g);h=yb(e);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;f=c+16|0;e=a;hd(f,e,c);f=yb(f);if((f|0)==(h|0)){bd(e,yb(c+24|0))}gb=c+32|0;e=(f|0)==(h|0);if(!e){RD(d)}d=-1;if(!e){break a}d=0;if(!aE(g)){break a}d=Ne(a,b,$D(g),jb)}gb=g+16|0;return d|0}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1936,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=da(1959,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6723,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22708]=0;ta(e|0,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22708]=0;Y(1913,8970,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Jj(C(C(xf(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Jj(C(C(b>>>0)*C(1.1892070770263672)));d=Jj(C(C(c>>>0)*C(1.1892070770263672)));g=Jj(C(C(d>>>0)*C(1.1892070770263672)));e=Jj(C(C(b+d>>>0)*C(.11546666920185089)));f=Jj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;TL(a);RL(a)}function v9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22708]=0;ta(e|0,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22708]=0;Y(1913,4841,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22708]=0;ta(e|0,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22708]=0;Y(1913,4789,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function PS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a=Kb(a);d=Ab(b);v[22708]=0;R(60,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){a:{e=c,f=zd(b),v[e+8>>2]=f;e=c,f=ff(b),v[e>>2]=f;if(Gb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[22708]=0;R(61,a|0,10);break b}v[22708]=0;R(61,a|0,b<<24>>24)}b=v[22708];v[22708]=0;if((b|0)==1){break a}b=c+8|0;Oe(b);if(Gb(b,c)){continue}break}}gb=c+16|0;return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function Jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){c=gb-16|0;gb=c;f=c+8|0;nW(f,v[d+24>>2]);gb=c+16|0;if(v[d+8>>2]!=(w[f|0]|w[f+1|0]<<8)){c=d+24|0;pn(c);if(Gb(c,d+16|0)){continue}}break}f=v[d+24>>2]}gb=d+32|0;v[e+8>>2]=f;h=e,i=Zb(b),v[h>>2]=i;a:{if(Qj(e+8|0,e)){Jh(a);break a}rn(a,v[e+8>>2])}gb=e+16|0}function Gla(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;t[b+15|0]=128;d=Mv(a,127,b+15|0);v[22708]=0;t[b+14|0]=64;e=W(780,a+12|0,127,b+14|0)|0;c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){v[22708]=0;t[b+13|0]=0;W(862,a+24|0,127,b+13|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;gb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;gc(e)}gc(d);S(a|0);L()}function m2(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[22708]=0;Q(154,a|0,2041)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22708]=0;Q(154,a|0,9784)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}}if(gd(a)){v[22708]=0;Q(154,a|0,7337)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22708]=0;Q(154,a|0,8320)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(536,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(537,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Fc(a,b);v[22708]=0;U(97,d+8|0,b|0,c|0);e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}Wb(d+8|0);v[22708]=0;e=v[b+24>>2];f=v[22708];v[22708]=0;if((f|0)==1){break a}if(e){v[22708]=0;b=v[b+24>>2];e=v[22708];v[22708]=0;if((e|0)==1){break a}v[22708]=0;U(98,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}Wb(d)}gb=d+16|0;return}b=P()|0;O()|0;Wb(a);S(b|0);L()}function fr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[ic(a,0)|0]&15)<<8|w[ic(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=x[(c<<1)+39120>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+39118>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[ic(a,2)|0];g=b,h=w[ic(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[ic(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[ic(a,3)|0],t[g+5|0]=h}function _la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(823,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(824,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,6)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(681,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(682,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(863,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(864,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function A9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22708]=0;d=+Va(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8951,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)-17>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Wk(v[Mc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=pi(l,k);if(e){Qg(c,j,e)}if(g){Qg(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Qg((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){$k(a,j,b)}df(a,c);rg(a,k);b=a;a=d+(e+g|0)|0;de(b,a);t[i+7|0]=0;Bd(a+c|0,i+7|0);gb=i+16|0;return}bg();L()}function bZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(448,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(449,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function Qy(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){fq(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,oc(a)+c|0),oc(a),b);v[22708]=0;R(123,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(120,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}ae(b)}gb=d+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<c>>>0){Em(a,v[a>>2]+b|0)}}function Nk(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){fq(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,oc(a)+c|0),oc(a),b);v[22708]=0;R(395,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(396,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}ae(b)}gb=d+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<c>>>0){Em(a,v[a>>2]+b|0)}}function E9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22708]=0;b=Q(d|0,c|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3744,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function C9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(2009,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22708]=0;b=Q(d|0,c|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3795,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function S5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+28>>2];g=v[a+24>>2];b:{if(d>>>0<=g>>>0){if(((i=a,j=Lg(t[b|0]),h=v[v[a>>2]+52>>2],kb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0;break b}v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[pd(e+12|0,e+8|0)>>2];Qg(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=d+f|0;b=b+d|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function Dl(a,b){var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){iN(a,c);break c}b=wb(a);b=fn(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22708]=0;R(1504,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(1503,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}eh(b)}gb=d+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}return}if(b>>>0<c>>>0){ij(a,v[a>>2]+(b<<2)|0)}}function YO(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){a=gb-16|0;gb=a;f=a,g=Vb(c),v[f+8>>2]=g;f=a,g=Zb(c),v[f>>2]=g;if(Gb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[22708]=0;_(b|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Gl(c);Bb();L()}Hb(b+20|0);Hb(b+8|0);Yb(b);b=a+8|0;Qe(b);if(Gb(b,a)){continue}break}}Gl(c);gb=a+16|0;Yb(c)}}function $9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22708]=0;_(1936,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22708]=0;b=Dt(f,b,c,d,e);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,9662,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function bE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=wd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;hd(e,a,c);b:{if((yb(e)|0)!=7){break b}if(sd(c+24|0,b,7)){break b}bd(a,7);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d}function LT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;f=v[c>>2];v[d+8>>2]=6553600;e=b+4|0;i=d,j=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[i+4>>2]=j;g=+(f>>>0)/6553600;f=d+8|0;e=d+4|0;h=gr(g*+y[Fb(f,e)>>2]);v[d+12>>2]=h;v[d+4>>2]=6553600;b=b+8|0;i=d,j=Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[i>>2]=j;i=d,j=gr(g*+y[Fb(e,d)>>2]),v[i+8>>2]=j;v[d+4>>2]=v[c>>2]-h;Pu(a,d+12|0,Fb(e,f));gb=d+16|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Hi(a,b,c,d);v[a>>2]=51212;c=mc(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22708]=0;W(1534,a+44|0,2,2)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;Th(b);d=v[22708];v[22708]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(c);kf(b);S(a|0);L()}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;gk(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Jb(c)+Ab(c)|0,v[d+44>>2]=e;Xn(a,Jb(c),Jb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Ab(c);d=a,e=b+Jb(c)|0,v[d+44>>2]=e;vu(c,Kc(c));Nx(a,Jb(c),Jb(c)+Ab(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;Zs(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}Zs(a,b)}}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;PW(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;gb=c+16|0}return a|0}function bQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(f|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[g>>1]=h;f=zb(w[b+4|0]);g=a,h=id(f|zb(w[b+5|0])<<8|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function aQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+3|0]);g=a,h=id(f|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+7|0]);g=a,h=id(f|zb(w[b+6|0])<<8|zb(w[b+5|0])<<16|zb(w[b+4|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function Ez(a,b,c,d){var e=0,f=0,g=0;f=gb-48|0;gb=f;a:{if(!c){c=Tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;Ez(a,b,g,e+16|0);Ni(e+32|0,d,Tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Ez(a,b|c,g,e)}gb=f+48|0}function ON(a){var b=0,c=0,d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if((w[b|0]|c|d)!=-1346458146&(d|(c|w[b|0]))!=-1095062050){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;e=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return e}function Mr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;e=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=e;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){c=gb-16|0;gb=c;e=c+8|0;_i(e,v[d+24>>2]);e=GY(e);gb=c+16|0;if(v[d+8>>2]!=(e|0)){c=d+24|0;pn(c);if(Gb(c,d+16|0)){continue}}break}e=v[d+24>>2]}gb=d+32|0;v[f+8>>2]=e;h=f,i=Zb(b),v[h>>2]=i;a:{if(Qj(f+8|0,f)){Jh(a);break a}rn(a,v[f+8>>2])}gb=f+16|0}function Maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22708]=0;U(1950,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,7591,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function _I(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function Vha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;u[e+12>>1]=c;u[e+14>>1]=b;yg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=gb-16|0;gb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Og(a)>>>0>=d>>>0){g=b,h=tc(a),v[g+8>>2]=h;mv(v[a>>2],v[Fb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){tp(a,d-f|0,c);break a}yn(a,v[a>>2]+(d<<1)|0);break a}rS(a);XB(a,Uk(a,d));tp(a,d,c)}gb=b+16|0;gb=e+16|0}function Paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22708]=0;e=+oa(1946,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2442,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ud(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Ol(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Tb(d,18726);v[22708]=0;Q(303,a+43|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(b);Iu(a);gb=d+16|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=b;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;b=ov(d,d+8|0);gb=d+16|0;a:{b=Sk(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[22708]=0;hn(c,d,f);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;Qe(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}_c(b);gb=e+32|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function wy(a,b,c){var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{if(w[a+20|0]){break a}e=b;b=-1-b|0;b=e+(b>>>0<c>>>0?b:c)|0;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=vy(b,4096);NJ(a,b-c|0);b=wd(d+16|0,lc(a+4|0,v[a+16>>2]),b-v[a+16>>2]|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;b=d+24|0;kb[c|0](b,a,d+8|0);f=a,g=yb(b)+v[a+16>>2]|0,v[f+16>>2]=g;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}gb=d+32|0}function UC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=gb-16|0;gb=c;if(Pb(a,b)){while(1){t[c+11|0]=0;b:{if(b>>>0>d>>>0){Mg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;c=d;break a}c=sg(a);Rb(a,b-4|0)}t[f|0]=c}function Qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function B$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22708]=0;a=La(1928,a|0,b|0,c|0,d|0)|0;b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;ja(1924,8355,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function y9(a){a=a|0;var b=0,c=0,d=0;v[22708]=0;_(2009,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22708]=0;c=+pa(d|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8988,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w9(a){a=a|0;var b=0,c=0,d=0;v[22708]=0;_(2009,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22708]=0;c=+pa(d|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4858,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function u9(a){a=a|0;var b=0,c=0,d=0;v[22708]=0;_(2009,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22708]=0;c=+pa(d|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4806,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Gh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=wd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);if(!((yb(e)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){Rb(a,4);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d|0}function ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b>>2];f=gD(b);d=gb-16|0;gb=d;e=jr(c,f);a:{if(e>>>0<=pe(a)>>>0){if(Nb(a)>>>0<e>>>0){v[d+12>>2]=c;YV(d+12|0,Nb(a));b=v[d+12>>2];Rg(c,b,v[a>>2]);XV(a,b,f,e-Nb(a)|0);break a}ij(a,Rg(c,f,v[a>>2]));break a}WV(a);b=a;g=fh(a,e);if(g>>>0>jC(a)>>>0){Sc();L()}h=SE(wb(b),g);v[b>>2]=h;v[b+4>>2]=h;i=wb(b),j=(g<<2)+h|0,v[i>>2]=j;dn(b,0);XV(a,c,f,e)}gb=d+16|0}function epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;a=mc(a);f=d,g=Vb(b),v[f+40>>2]=g;f=d,g=Zb(b),v[f+32>>2]=g;a:{if(Gb(d+40|0,d+32|0)){while(1){b=d+8|0;e=v[d+40>>2];_i(b,e);if((GY(b)|0)==(c|0)){b=d+8|0;rn(b,e);v[22708]=0;R(535,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}xb(d+8|0)}b=d+40|0;pn(b);if(Gb(b,d+32|0)){continue}break}}gb=d+48|0;return}b=P()|0;O()|0;xb(d+8|0);jd(a);S(b|0);L()}function cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=gb-32|0;gb=d;e=gb-16|0;gb=e;f=e,g=Ib(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;c=d+16|0;kR(c,e+14|0);gb=e+16|0;v[22708]=0;nj(d+8|0,c);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function qj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(kk(a,g+8|0)){break b}f=4;h=nl(a);if(!nh(d,2048,h)){break b}b=Rn(d,h);ml(a);b=b-48|0;c:{if(!lk(a,g+8|0)|(e|0)<2){break c}while(1){f=nl(a);if(!nh(d,2048,f)){break a}f=Rn(d,f);ml(a);b=(f+B(b,10)|0)-48|0;if(!lk(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!kk(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function pj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(il(a,g+8|0)){break b}f=4;h=vm(a);if(!jl(d,2048,h)){break b}b=Qn(d,h);um(a);b=b-48|0;c:{if(!wm(a,g+8|0)|(e|0)<2){break c}while(1){f=vm(a);if(!jl(d,2048,f)){break a}f=Qn(d,f);um(a);b=(f+B(b,10)|0)-48|0;if(!wm(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!il(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function fga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=gb-880|0;gb=d;b=Qb(a,0,76);v[b+84>>2]=0;v[b+88>>2]=0;v[b+80>>2]=256;u[b+76>>1]=65535;v[b+92>>2]=0;v[b+96>>2]=0;t[b+100|0]=1;e=b+223848|0;c=b+616|0;a=c;while(1){a=JB(a)+872|0;if((e|0)!=(a|0)){continue}break}a=d+8|0;Qb(a,0,872);e=JB(a);a=c;c=((a+223232|0)-a|0)/872|0;if((c|0)>=1){while(1){ou(a,e);a=a+872|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}gb=d+880|0;return b|0}function z8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22708]=0;b=Q(70,f|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,2);c=Ky(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function gy(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!pt(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}ec(a,32);return 0}aa(12858,10534,1564,3128);L()}function C8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22708]=0;b=Q(70,f|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,2);c=Ly(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function Sz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;t[e+15|0]=!d|y[c+20>>2]<2?0:v[b+480180>>2]==1;d=!v[c+52>>2]|d;t[e+14|0]=d;if(!(!x[b+480188>>1]|((d|0)!=1|v[b+480180>>2]!=2))){d=0;while(1){v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=v[c+52>>2];u[c+72>>1]=x[c+74>>1];t[a|0]=w[e+15|0];t[a+1|0]=w[e+14|0];gb=e+16|0}function Nu(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=d+16|0;qT(c,a,a+1|0,a+2|0,a+3|0);qT(d,b,b+1|0,b+2|0,b+3|0);gb=d+32|0;a=d;b=1;a:{if(w[v[c>>2]]<w[v[a>>2]]){break a}b=0;if(w[v[a>>2]]<w[v[c>>2]]){break a}b=1;b:{if(t[v[c+4>>2]]<t[v[a+4>>2]]){break b}b=0;if(t[v[a+4>>2]]<t[v[c+4>>2]]){break b}b=1;c:{if(w[v[c+8>>2]]<w[v[a+8>>2]]){break c}b=0;if(w[v[a+8>>2]]<w[v[c+8>>2]]){break c}b=w[v[c+12>>2]]<w[v[a+12>>2]]}}}return b}function mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;Se(b);e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Rd(e);e=v[22708];v[22708]=0;b:{if((e|0)==1){break b}c=zb(c);v[22708]=0;Xe(d+8|0,1,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break b}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}a=d+24|0;Eb(b,a);vb(a);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;zc(d+40|0);S(a|0);L()}}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=Hi(a,b,c,d);v[a>>2]=50720;d=mc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22708]=0;W(1534,a+44|0,2,2)|0;b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}v[22708]=0;Th(c);b=v[22708];v[22708]=0;if((b|0)==1){break a}Lt(a);return a|0}a=P()|0;O()|0;Lc(d);kf(c);S(a|0);L()}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;xe();d=gb-16|0;gb=d;Ux(d,a,e+12|0,0);f=vI(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115189];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115189]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return C(f)}function pba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;a:{b:{if(!a){break b}a=uc(b+8|0,a);v[22708]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=dL(b);c=v[22708];v[22708]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1913,9791,0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}a=0}gb=b+16|0;return a|0}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;d=lH(a,e+12|0,d,xe());a=jb;f=v[115189];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[115189]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>=0&d>>>0>=1|(a|0)>0){d=-1;a=2147483647;break a}d=0;a=-2147483648}gb=e+16|0;jb=a;return d|0}function Waa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1939,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8133,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Du(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){FR(b,A[ye(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Vb(c),v[g+8>>2]=h;g=d,h=Zb(c),v[g>>2]=h;if(Gb(d+8|0,d)){while(1){e=d+8|0;f=v[e>>2];g=f,i=FR(b,A[f>>3]),A[g>>3]=i;Cu(e);if(Gb(e,d)){continue}break}}OB(a,c);gb=d+16|0}function B2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;d=v[fc(a)>>2];i=v[b>>2];g=v[a>>2];f=(d|0)==2509;j=f?0:g;d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}h=d?d:4;d=Up(j,h);if(d){if(!f){be(a)}v[e+4>>2]=2458;d=ge(e+8|0,d,e+4|0);Ee(a,be(d));f=v[fc(d)>>2];k=fc(a),l=f,v[k>>2]=l;Hc(d);v[b>>2]=v[a>>2]+(i-g|0);v[c>>2]=v[a>>2]+(h&-4);gb=e+16|0;return}Ss();L()}function foa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;v[e+24>>2]=d;g=fg(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(nd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=gb-16|0;gb=f;d=Kb(f);v[22708]=0;da(629,b|0,h|0,d|0,i|0)|0;b=v[22708];v[22708]=0;b:{if((b|0)!=1){vb(d);gb=f+16|0;break b}a=P()|0;O()|0;vb(d);S(a|0);L()}}Zf(a,g,c,e+16|0);gb=e+32|0}function dW(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;v[f+12>>2]=a;a:{b:{if(!(!c|b)){e=+(B(a,d)>>>0)*.25*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}if(!(!b|!a)){qc(f+12|0,10);a=B(w[v[f+12>>2]+29024|0],1e4);break a}e=+(a>>>0);if(a-1>>>0<=9){e=733.8401379310345/e*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}e=e/.264*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}a=0}gb=f+16|0;return a}function Rga(a){a=a|0;var b=0;a=Kb(a);v[22708]=0;R(60,a|0,4);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[22708]=0;R(61,a|0,32);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(61,a|0,10);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(61,a|0,13);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(61,a|0,9);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;d=Rc(c+8|0,16,1,1,0);v[c+4>>2]=0;ud(a,0);vc(b);a:{b:{if(Sr(b,11087)){Wc(b,12);if(!Jr(b)){Ap(d,2)}Wc(b,24);break b}if(Gh(b,10969)){vc(b);v[c+4>>2]=4;e=1;break a}Zi(d,8)}e=0}f=a,g=(nf(b)>>>0)/(B(gp(d),w[d|0])>>>3>>>0)|0,v[f>>2]=g;b=Cg(d,a,b);if(!(!e|!b)){d=v[a+20>>2];f=c,g=bj(a),v[f>>2]=g;Qb(d,0,v[Fb(c+4|0,c)>>2])}gb=c+16|0;return(b|0)!=0|0}function jA(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;hO(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(kb[v[v[b>>2]+136>>2]](b)|0){b=v[b+16>>2];e=b+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[b+480232>>2])/z[e+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function G$(a){a=a|0;var b=0;a=Kb(a);v[22708]=0;R(65,a|0,4);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[22708]=0;R(66,a|0,32);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(66,a|0,10);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(66,a|0,13);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(66,a|0,9);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function saa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=OK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6534,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function raa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=NK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3286,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=MK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3187,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function paa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=LK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3329,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function oaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=KK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3231,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function lfa(a){a=a|0;var b=0,c=0,d=0;b=gb-48|0;gb=b;while(1){c=c+1|0;if((c|0)!=15){continue}break}t[b+39|0]=0;t[b+40|0]=0;t[b+41|0]=0;t[b+42|0]=0;t[b+43|0]=0;t[b+44|0]=0;t[b+45|0]=0;t[b+46|0]=0;v[b+32>>2]=0;v[b+36>>2]=0;c=wd(b+16|0,b+32|0,15);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;d=b+24|0;cc(d,a,b+8|0);c=0;a:{if((yb(d)|0)!=15){break a}if(sd(b+32|0,5672,15)){break a}Rb(a,15);c=1}gb=b+48|0;return c|0}function Wq(a,b,c){var d=0,e=0;a=Kb(a);d=Ab(b);v[22708]=0;R(62,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){a:{if(Ab(b)){while(1){d=w[pc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[22708]=0;R(63,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){break b}break a}v[22708]=0;R(63,a|0,65533);d=v[22708];v[22708]=0;if((d|0)==1){break a}}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Ic(a);S(b|0);L()}function ry(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;e=d+24|0;yc(e,v[v[b>>2]-12>>2]+b|0);v[e+4>>2]=b;b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;v[d+16>>2]=c;v[d+20>>2]=b;b=d+8|0;kl(v[d+28>>2],zb(v[b>>2]),yb(b));c=gb-16|0;gb=c;v[c+12>>2]=v[v[d+28>>2]+4>>2];v[22708]=0;v[c+8>>2]=0;e=Hf(c+8|0,c+12|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=c+16|0;c=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}mk(a,b,c);gb=d+32|0}function OY(a,b,c){var d=0,e=0,f=0;e=gb+-64|0;gb=e;Se(b);d=e+40|0;Re(d,a,c);a=v[d>>2];v[22708]=0;d=Rd(d);f=v[22708];v[22708]=0;a:{if((f|0)==1){break a}d=zb(d);v[22708]=0;Xe(e+8|0,2,d,a);d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;R(324,e+24|0,e+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=b;b=e+24|0;Eb(d,b);vb(b);zc(e+40|0);gb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(e+40|0);S(a|0);L()}function OD(a,b,c){var d=0,e=0,f=0;e=gb+-64|0;gb=e;Se(b);d=e+40|0;Re(d,a,c);a=v[d>>2];v[22708]=0;d=Rd(d);f=v[22708];v[22708]=0;a:{if((f|0)==1){break a}d=zb(d);v[22708]=0;Xe(e+8|0,3,d,a);d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;R(324,e+24|0,e+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=b;b=e+24|0;Eb(d,b);vb(b);zc(e+40|0);gb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(e+40|0);S(a|0);L()}function L9(a){a=a|0;var b=0;v[22708]=0;_(2009,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){kb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Yb(b);v[a+20>>2]=0}Yb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2147,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;f=zb(w[b+3|0]);g=a,h=id(zb(w[b+4|0])<<16|f<<8|zb(w[b+5|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function eQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+5|0]);g=a,h=id(zb(w[b+4|0])<<16|f<<8|zb(w[b+3|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function cP(a,b){a=a|0;b=b|0;var c=0;_O(a);_O(a+368680|0);if(b){bO(a,1);return a|0}b=a;a:{if(t[459704]&1){break a}if(!Qd(459704)){break a}v[22708]=0;Q(1416,91e3,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Pd(459704);break a}a=P()|0;O()|0;$e(459704);S(a|0);L()}au(222112,287648,b+131112|0);au(287648,353184,b+196648|0);au(353184,418720,b+262184|0);au(91024,222112,b+24|0);hc(b+327720|0,418720,40960);return a|0}function zJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((ho(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;b=Q(70,c|0,7993)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}gb=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function qU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=wd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;hd(e,a,c);if(!((yb(e)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){bd(a,4);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;ZK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2876,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function TY(){var a=0,b=0;a=gb-16|0;gb=a;a:{if(cb(a+12|0,a+8|0)|0){break a}b=Cd((v[a+12>>2]<<2)+4|0);v[115992]=b;if(!b){break a}b=Cd(v[a+8>>2]);if(b){v[v[115992]+(v[a+12>>2]<<2)>>2]=0;if(!(bb(v[115992],b|0)|0)){break a}}v[115992]=0}gb=a+16|0;b:{if(t[463952]&1){break b}if(!Qd(463952)){break b}v[22708]=0;X(2403);a=v[22708];v[22708]=0;if((a|0)!=1){Pd(463952);break b}a=P()|0;O()|0;$e(463952);S(a|0);L()}}function Raa(a,b){a=a|0;b=+b;var c=0;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;b=+Ya(1944,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;Z(c|0)|0;v[22708]=0;Y(1913,4650,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;xe();d=gb-16|0;gb=d;Ux(d,a,e+12|0,1);f=dy(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115189];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115189]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return+f}function Le(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Qp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(uG(a,b)&3){case 0:c=Qp(A[b>>3],A[b+8>>3]);break a;case 1:c=-Rp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Qp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Rp(A[b>>3],A[b+8>>3],1)}a=c;gb=b+16|0;return a}function $I(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){ec(a,21);return-1}if(v[a+1396>>2]<=9){rl(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Cm(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>-1)){ec(a,21)}return c}aa(4610,10534,1793,2842);L()}function O5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if((c|0)<1){break a}while(1){e=v[a+24>>2];g=v[a+28>>2];b:{if(e>>>0>=g>>>0){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}f=f+1|0;b=b+4|0;break b}v[d+12>>2]=g-e>>2;v[d+8>>2]=c-f;e=v[pd(d+12|0,d+8|0)>>2];yi(v[a+24>>2],b,e);g=e<<2;v[a+24>>2]=g+v[a+24>>2];f=f+e|0;b=b+g|0}if((c|0)>(f|0)){continue}break}}gb=d+16|0;return f|0}function xJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((ho(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;b=Q(70,c|0,7993)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}gb=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function LE(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((w[a|0]|w[a+1|0]<<8)!=26217){if((w[a|0]|w[a+1|0]<<8)!=20042){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){e=0;d=a+c|0;b=t[d+113|0];f=(b|0)>-1;if(!f&(b&255)>>>0<254){break a}b=w[d+241|0];if(!b&f|b>>>0>15|w[d+369|0]>=64){break a}e=1;c=c+1|0;if((c|0)!=128){continue}break}}return e}function St(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,1);c=Ly(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,1);c=Ky(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=FU(a,b);v[22708]=0;e=Q(872,a+12|0,b+12|0)|0;d=v[22708];v[22708]=0;b:{c:{if((d|0)!=1){v[22708]=0;Q(873,a+24|0,b+24|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;gc(e)}gc(c);S(a|0);L()}}function naa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=T(1976,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4322,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function XY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+28>>2]=c;a:{if(!Pb(b,c<<1)){break a}qc(d+28|0,65535);Bf(a,x[d+28>>1]);e=d,f=Vb(a),v[e+16>>2]=f;e=d,f=Zb(a),v[e+8>>2]=f;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];c=d+24|0;if(!Dp(b,c)){KD(c)}c=Ib(w[d+24|0]|w[d+25|0]<<8);u[a>>1]=c;if((c|0)==65535){u[a>>1]=65535}a=d+16|0;of(a);if(Gb(a,d+8|0)){continue}break}}gb=d+32|0}function Tm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;a:{if(!Gb(d+24|0,d+16|0)){break a}while(1){if(kD(d+8|0,v[d+24>>2])){break a}c=d+24|0;v[c>>2]=v[c>>2]+28;if(Gb(c,d+16|0)){continue}break}}gb=d+32|0;v[e+8>>2]=v[d+24>>2];h=e,i=Zb(b),v[h>>2]=i;b:{if(Qj(e+8|0,e)){Jh(a);break b}rn(a,v[e+8>>2])}gb=e+16|0}function rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=b;d=gb-16|0;gb=d;g=d+8|0;e=b+1074376|0;c=hc(tf(223848),e,614);b=0;while(1){f=B(b,872);ou((c+f|0)+616|0,(e+f|0)+616|0);b=b+1|0;if((b|0)!=256){continue}break}b=v[Yi(g,c)>>2];gb=d+16|0;v[a+4>>2]=b;b=Ik(a+8|0);d=dd(a+20|0);v[22708]=0;_(1254,a|0);c=v[22708];v[22708]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;jP(d);iP(b);hP(a+4|0);S(c|0);L()}function baa(a,b){a=a|0;b=b|0;var c=0;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;b=FK(c,b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6943,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function aaa(a,b){a=a|0;b=b|0;var c=0;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;b=EK(c,b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3681,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Saa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;c=+pa(1943,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4722,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Ls(a){var b=0,c=0;lo(a,1,10906);v[22708]=0;b=ga(147)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22708]=0;b=ga(148)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22708]=0;b=ga(149)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22708]=0;_(150,a+20|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function J8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-32|0;gb=b;c=wd(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=hA(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;v[22708]=0;b=Q(70,b+8|0,5190)|0;c=v[22708];v[22708]=0;b:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}gb=b+32|0;return a|0}L()}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,2);c=fL(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,4);c=fL(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,2);c=eL(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,4);c=eL(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function mda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;b=d+8|0;KM(b,a,0);if(yb(b)){a=v[a+20>>2];v[a+148>>2]=-1;b=gb-16|0;gb=b;c=v[d+8>>2];f=v[d+12>>2];e=Zh(c,f);a=a+4|0;a:{if(e>>>0<=dg(a)>>>0){if(oc(a)>>>0<e>>>0){v[b+12>>2]=c;xO(b+12|0,oc(a));g=c;c=v[b+12>>2];Rg(g,c,v[a>>2]);qr(a,c,f,e-oc(a)|0);break a}Em(a,Rg(c,f,v[a>>2]));break a}Ev(a);Cn(a,qh(a,e));qr(a,c,f,e)}gb=b+16|0}gb=d+16|0}function iV(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=w[b+1|0]<<8;if((w[b|0]|c)>>>0<512|(c|w[b|0])>>>0>767){break a}b=a+112|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return d}function Vaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=v[b+8>>2];c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,8163,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a+4>>2]=0;a:{if(b){b:{if(Mu(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}wb(a);e=xB(d+16|0);v[22708]=0;f=Q(951,a|0,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}v[22708]=0;R(952,e|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}v[e+4>>2]=b;wB(a,e);Ye(e)}zk(d,a);xp(d,b,w[c|0])}gb=d+32|0;return}a=P()|0;O()|0;Ye(e);S(a|0);L()}function tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb+-64|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;cW(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){bW(g)}d=-1;a:{if(!c){break a}d=0;if(!kW(f+8|0)){break a}d=Ne(a,b,jW(f+8|0),jb)}gb=f- -64|0;return d|0}function iz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;i=f+8|0;d=gb-16|0;gb=d;c=a;j=b;e=Xd(a);g=fc(a);h=gb-16|0;gb=h;if(e){wb(c);while(1){c=eN(e+16|0,j);g=c?g:e;e=v[(c?4:0)+e>>2];if(e){continue}break}}c=v[yc(h+8|0,g)>>2];gb=h+16|0;v[d+8>>2]=c;k=d,l=Ch(a),v[k>>2]=l;a:{if(Gb(d+8|0,d)){if(!fN(wb(a),b,ue(d+8|0))){break a}}c=Ch(a)}gb=d+16|0;a=v[yc(i,c)>>2];gb=f+16|0;return a}function c1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[e>>2]=c;c=2;a=mx(f+12|0,0,b,v[a+8>>2]);a:{if(a+1>>>0<2){break a}c=1;b=v[e>>2];g=d-b|0;d=a-1|0;if(g>>>0<d>>>0){break a}c=0;if(!d){break a}d=w[f+12|0];v[e>>2]=b+1;t[b|0]=d;a=a-2|0;if(!a){break a}b=f+12|0;while(1){d=w[b+1|0];g=v[e>>2];v[e>>2]=g+1;t[g|0]=d;b=b+1|0;a=a-1|0;if(a){continue}break}}gb=f+16|0;return c|0}function Qaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;c=A[b+16>>3];b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4686,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function si(a){var b=0,c=0;b=gb-16|0;gb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Rp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(uG(a,b)&3){case 0:a=Rp(A[b>>3],A[b+8>>3],1);break a;case 1:a=Qp(A[b>>3],A[b+8>>3]);break a;case 2:a=-Rp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Qp(A[b>>3],A[b+8>>3])}gb=b+16|0;return a}function _oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-112|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;JX(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){IX(g)}d=-1;a:{if(!c){break a}d=0;if(!MX(f+8|0)){break a}d=Ne(a,b,LX(f+8|0),jb)}gb=f+112|0;return d|0}function z7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;cK(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){j=z[a+24>>2];f=hr(h,d,i);z[f>>2]=j*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function yaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=VK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10112,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function c_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-512|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;FE(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){EE(g)}d=-1;a:{if(!c){break a}d=0;if(!LE(f+8|0)){break a}d=Ne(a,b,KE(f+8|0),jb)}gb=f+512|0;return d|0}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ze(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>5>>>0){fB(a,d,c);break c}b=wb(a);b=bS(e+8|0,Zq(a,ze(a)+d|0),ze(a),b);v[22708]=0;U(1102,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}aS(a,b);cB(b)}gb=e+32|0;break a}a=P()|0;O()|0;cB(b);S(a|0);L()}return}if(b>>>0<d>>>0){lS(a,v[a>>2]+(b<<5)|0)}}function xaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=UK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6487,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function waa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=TK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,5927,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=RK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6908,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function uaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=QK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2411,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function to(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;a:{while(1){g=h&255;if(Xt(b,c,g>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;hB(a,f+15|0,f+14|0);break a}gi(b,d);gi(c,e);h=h+1|0;if(g>>>0<3){continue}break}h=f;g=w[b|0];if(uo(g)>>>0>uo(w[d|0])>>>0){gi(b,d);gi(c,e);g=w[b|0]}t[h+11|0]=g;hB(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}gb=f+16|0}function taa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=PK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4167,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function maa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=ho(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4135,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function laa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=JK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3942,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=IK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4010,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=vl(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,3844,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function iaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=gq(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,4524,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Taa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=YK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2908,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function $Z(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-48|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;oE(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){nE(g)}d=-1;a:{if(!c){break a}d=0;if(!BE(f+8|0)){break a}d=Ne(a,b,AE(f+8|0),jb)}gb=f+48|0;return d|0}function zaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;c=WK(b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,7419,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+5|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=5){continue}break}d=0;t[c+28|0]=0;v[c+24>>2]=0;e=wd(c+8|0,c+24|0,5);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);b:{if((yb(e)|0)!=5){break b}if(sd(c+24|0,b,5)){break b}Rb(a,5);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d}function fZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-1968|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;FD(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){ED(g)}d=-1;a:{if(!c){break a}d=0;if(!ID(f+8|0)){break a}d=Ne(a,b,1024,0)}gb=f+1968|0;return d|0}function qV(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function WB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Hi(a,b,c,d);v[a>>2]=49672;d=mc(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=xf(c),v[e+4232>>2]=f;PY(a+4260|0,80,150,80,255);v[22708]=0;W(1534,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Th(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);kf(b);S(a|0);L()}function F0(){var a=0;a:{if(t[464840]&1){break a}if(!Qd(464840)){break a}a=464672;while(1){a=Kb(a)+12|0;if((a|0)!=464840){continue}break}Pd(464840)}ld(464672,88068);ld(464684,88096);ld(464696,88124);ld(464708,88156);ld(464720,88196);ld(464732,88232);ld(464744,88260);ld(464756,88296);ld(464768,88312);ld(464780,88328);ld(464792,88344);ld(464804,88360);ld(464816,88376);ld(464828,88392)}function oB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-32|0;gb=f;v[f+8>>2]=c;g=f,h=nf(b),v[g+28>>2]=h;c=f+8|0;Re(c,b,v[Fb(c,f+28|0)>>2]);v[22708]=0;b=Rd(c);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[22708]=0;a=fa(361,a|0,b|0,c|0,d|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}zc(f+8|0);gb=f+32|0;return a|0}a=P()|0;O()|0;zc(f+8|0);S(a|0);L()}function Nda(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22708]=0;R(440,b+4|0,8);b=v[22708];v[22708]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(89104)|0;if((O()|0)==(ea(89104)|0)){Z(b|0)|0;xr(v[a+20>>2]+4|0);$();return}S(b|0);L()}function lI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;h=c;d=gb-16|0;gb=d;c=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){_e(c,b);e=c;break b}f=zm(b)+1|0;e=Ui(c,f);df(c,e);rg(c,f);de(c,b)}c=e;f=b;c:{d:{if(b){v[22708]=0;DI(c,h,f);c=v[22708];v[22708]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}v[d+12>>2]=0;Fe((b<<2)+e|0,d+12|0);gb=d+16|0;break a}bg();L()}gb=g+16|0;return a}function dG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=v[b>>2];g=v[b+8>>2];e=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=e;v[d+24>>2]=c;v[d+28>>2]=e;rh(d+32|0,d+16|0);c=v[v[f>>2]+28>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;kb[c|0](d+40|0,f,g,d+8|0);c=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=c;rh(a,d);h=b,i=yb(a)+v[b+8>>2]|0,v[h+8>>2]=i;gb=d+48|0}function Ks(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}b=c&16384;a:{b:{if((d|0)!=256){if((d|0)!=4){break b}c=b?70:102;break a}c=b?69:101;break a}c=b?65:97;if((d|0)==260){break a}c=b?71:103}t[a|0]=c;return(d|0)!=260}function Fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=b;wb(b);d=a;f=vh(a);b:{c:{e=tc(b);if(e){v[22708]=0;R(814,d|0,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break c}cS(d,v[c>>2],v[c+4>>2],e)}break b}a=P()|0;O()|0;bs(f);S(a|0);L()}v[22708]=0;Q(4,a+12|0,b+12|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;Ze(d);S(a|0);L()}}function wH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;c=Tb(d,c);v[22708]=0;U(2435,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){v[22708]=0;Q(2436,a|0,d+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(d+16|0);vb(c);v[a>>2]=79180;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;gb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d+16|0)}vb(c);S(a|0);L()}function Apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;PD(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){Wv(g)}d=-1;a:{if(!c){break a}d=0;if(!YX(f+8|0)){break a}d=Ne(a,b,72,0)}gb=f+32|0;return d|0}function q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;YJ(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){f=Xg(h,d,i);z[f>>2]=z[a+24>>2]*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}
function oF(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>27}return c}function cba(a){a=a|0;var b=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Yb(Ft(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Yb(b);v[a+20>>2]=0}Yb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2174,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[22708]=0;c=Q(70,c|0,7993)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;vU(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){uU(f)}f=-1;a:{if(!d){break a}f=0;if(!yU(g)){break a}f=Ne(a,b,xU(g),jb)}gb=g+608|0;return f|0}function iZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;e=a;if(!Pb(b,c)){c=nf(b)}v[e>>2]=c;c=v[b>>2];a:{if(kb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];f=c,g=(kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[f+4>>2]=g;break a}c=a+8|0;Nk(c,v[a>>2]);if(cd(c)){break a}Ud(d+24|0,c);a=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=a;cc(d+16|0,b,d+8|0)}gb=d+32|0}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-576|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;uX(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){tX(f)}f=-1;a:{if(!d){break a}f=0;if(!xX(g)){break a}f=Ne(a,b,wX(g),jb)}gb=g+576|0;return f|0}function NF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;g=gb-16|0;gb=g;e=d+8|0;h=e;f=gb-16|0;gb=f;b=gb-16|0;gb=b;c=f;v[c+4>>2]=1;i=c,j=Nc(16,4),v[i+8>>2]=j;gb=b+16|0;b=v[c+8>>2];v[22708]=0;MF(b);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=Jp(c);Ow(h,dc(b),b);LF(c);gb=f+16|0;break a}a=P()|0;O()|0;LF(c);S(a|0);L()}gb=g+16|0;Xf(a,e);Kd(e);gb=d+16|0;v[a+8>>2]=0;Td(a+12|0)}function Loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-192|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;Pr(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){UW(f)}f=-1;a:{if(!d){break a}f=0;if(!sX(g)){break a}f=Ne(a,b,rX(g),jb)}gb=g+192|0;return f|0}function G8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-48|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+16>>2]=b;v[d+20>>2]=e;v[d+32>>2]=b;v[d+36>>2]=e;rh(d+40|0,d+16|0);b=Xf(d+24|0,c);v[22708]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(207,a|0,d+8|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Kd(c);gb=d+48|0;return}a=P()|0;O()|0;Kd(c);S(a|0);L()}function xX(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function sJ(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+60144>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+60144>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+60144>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+60144>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+60144>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function opa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=Bi(d,a,1);wb(a);lp(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Zg(d+8|0,qh(a,oc(a)+1|0),oc(a),c);lp(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+1;v[22708]=0;R(396,a|0,c|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){ae(c);gb=d+32|0;break a}a=P()|0;O()|0;ae(c);S(a|0);L()}}function Vca(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[v[a+20>>2]+148>>2]=-1;v[22708]=0;tn(c+8|0,a+4228|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+20>>2];d=c+8|0;e=v[d>>2];d=v[d+4>>2];v[22708]=0;U(1669,b+4|0,e|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;xr(v[a+20>>2]+4|0);$()}gb=c+16|0;return}S(b|0);L()}function GJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[22708]=0;c=Q(70,c|0,4918)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Ah(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;xq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function EJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[22708]=0;c=Q(70,c|0,4939)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Ah(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;xq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-80|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;$V(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){tC(f)}f=-1;a:{if(!d){break a}f=0;if(!dT(g)){break a}f=Ne(a,b,cT(g),jb)}gb=g+80|0;return f|0}function sma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-128|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;fV(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){eV(f)}f=-1;a:{if(!d){break a}f=0;if(!iV(g)){break a}f=Ne(a,b,256,0)}gb=g+128|0;return f|0}function oG(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=gb-16|0;gb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=sp(d,g+i|0,f+15|0);if(!d){break a}if(!Vo(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}gb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function Yaa(a,b){a=a|0;b=b|0;var c=0;v[22708]=0;_(1936,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Yb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2752,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;c=tf(64);v[22708]=0;e=T(1317,c|0)|0;f=v[22708];v[22708]=0;a:{if((f|0)!=1){c=ns(d,e);e=v[c>>2];v[22708]=0;a=W(1532,e|0,a|0,b|0)|0;b=v[22708];v[22708]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}cA(d+8|0);break b}a=P()|0;O()|0;Ig(c);break a}qi(d+8|0,c)}Ig(c);gb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Yb(c)}S(a|0);L()}function JH(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=gb-16|0;gb=c;b=ba(16)|0;a=gb-16|0;gb=a;a:{if(t[460840]&1){break a}if(!Qd(460840)){break a}Pd(460840)}td(a+8|0,1,90512);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;gb=a+16|0;v[22708]=0;Q(2388,b|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,78492,2389);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;wb(a);v[c+12>>2]=268435455;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}wb(a);c=b;if(c>>>0>268435455){rd(8445);L()}c=Nc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<4)|0,v[f>>2]=g;dI(a,0)}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Hi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=51448;v[22708]=0;W(1534,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Th(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;kf(b);S(a|0);L()}function aZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,10);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;MU(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))==1414807888){MU(a,c+11|0);t[b|0]=1;a=0}else{a=1}b=gb-16|0;gb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Tb(b,a);v[22708]=0;d=T(865,a|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(a)}gb=b+16|0;break a}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=c+16|0;return d|0}function a4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){tG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=ts(c+8|0,_w(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22708]=0;On(d,f,b);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22708]=0;Nn(e,a);b=v[22708];v[22708]=0;if((b|0)==1){break b}ss(a);gb=c+32|0;break a}b=P()|0;O()|0;ss(a);S(b|0);L()}}function SQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){tG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=ts(c+8|0,_w(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22708]=0;On(d,f,b);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22708]=0;Nn(e,a);b=v[22708];v[22708]=0;if((b|0)==1){break b}wu(a);gb=c+32|0;break a}b=P()|0;O()|0;wu(a);S(b|0);L()}}function wda(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Tla(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=dw(d,a,1);wb(a);XU(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+20;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=dD(d+8|0,eD(a,Ie(a)+1|0),Ie(a),c);XU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;v[22708]=0;Bv(a,c);a=v[22708];v[22708]=0;a:{if((a|0)!=1){ip(c);gb=d+32|0;break a}a=P()|0;O()|0;ip(c);S(a|0);L()}}function OJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;if(!w[a+20|0]){if(!(kb[v[v[a>>2]+40>>2]](a)|0)){d=a+4|0;while(1){NJ(a,65536);c=wd(b+16|0,lc(d,v[a+16>>2]),65536);e=v[v[a>>2]+44>>2];f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;c=b+24|0;kb[e|0](c,a,b+8|0);g=a,h=yb(c)+v[a+16>>2]|0,v[g+16>>2]=h;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){continue}break}}t[a+20|0]=1}gb=b+32|0}function Ona(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[22708]=0;EC(f,b,c);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}_c(d);gb=e+16|0;return}a=P()|0;O()|0;_c(d);S(a|0);L()}function I0(){var a=0;a:{if(t[464664]&1){break a}if(!Qd(464664)){break a}a=464496;while(1){a=Kb(a)+12|0;if((a|0)!=464664){continue}break}Pd(464664)}Xc(464496,2336);Xc(464508,2343);Xc(464520,2309);Xc(464532,2317);Xc(464544,2300);Xc(464556,2350);Xc(464568,2327);Xc(464580,6900);Xc(464592,7234);Xc(464604,8584);Xc(464616,10177);Xc(464628,2595);Xc(464640,8051);Xc(464652,3644)}function vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,20);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[22708]=0;R(342,e|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[c>>2]+20|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0;return}a=P()|0;O()|0;_c(c);S(a|0);L()}function eca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Ji(d+12|0);a:{b:{switch(b-1|0){default:c=z[d+12>>2];break a;case 0:c=fe(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4212>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b}}c=C(fe(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;_y(a)}gb=d+16|0}function cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;a:{a=v[a+1298424>>2];b:{if(a){kb[v[v[a>>2]+8>>2]](a,b,c);break b}v[d+8>>2]=0;if(!GF(gu(d+8|0),b)){break b}v[d+8>>2]=0;e=d+8|0;gu(e);v[d+24>>2]=0;a=gu(d+24|0);WO(e,6310,8124,133,42);v[22708]=0;ha(33,a|0,e|0,b|0,10590,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}}gb=d+32|0;return}a=P()|0;O()|0;S(a|0);L()}function Lca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Ji(d+12|0);a:{b:{switch(b-3|0){default:c=z[d+12>>2];break a;case 0:c=fe(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4220>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b}}c=C(fe(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;_y(a)}gb=d+16|0}function rA(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Mm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298260|0;if(!Dd(a)){break a}Qi(v[a>>2],b,0)}}function rD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){if(!kD(d+8|0,v[d+24>>2])){c=d+24|0;pn(c);if(Gb(c,d+16|0)){continue}}break}f=v[d+24>>2]}gb=d+32|0;v[e+8>>2]=f;h=e,i=Zb(b),v[h>>2]=i;a:{if(Qj(e+8|0,e)){Jh(a);break a}rn(a,v[e+8>>2])}gb=e+16|0}function jq(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){lM(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=Zg(c+8|0,qh(a,oc(a)+1|0),oc(a),d);f=v[a+8>>2];v[22708]=0;ql(d,f,b);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+1;v[22708]=0;R(120,e|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}ae(a);gb=c+32|0;break a}b=P()|0;O()|0;ae(a);S(b|0);L()}}function Xaa(a){a=a|0;var b=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Yb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,6047,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Oq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;e=Vb(a);f=Zb(a);b=gb-16|0;gb=b;v[b>>2]=f;v[b+8>>2]=e;if(Gb(b+8|0,b)){while(1){e=b+8|0;d=d+A[v[e>>2]>>3];Cu(e);if(Gb(e,b)){continue}break}}gb=b+16|0;g=c,h=Vb(a),v[g+8>>2]=h;g=c,h=Zb(a),v[g>>2]=h;if(Gb(c+8|0,c)){d=-d;while(1){a=c+8|0;b=v[a>>2];d=d+A[b>>3];A[b>>3]=d;Cu(a);if(Gb(a,c)){continue}break}}gb=c+16|0}function tl(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=gb-32|0;gb=c;f=uc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Gc(c+8|0,c);gb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=e+16|0;return a}function pB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+8>>2]=c;f=e,g=nf(b),v[f+28>>2]=g;c=e+8|0;Re(c,b,v[Fb(c,e+28|0)>>2]);v[22708]=0;b=Rd(c);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[22708]=0;da(908,a|0,b|0,c|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}zc(e+8|0);gb=e+32|0;return 1}a=P()|0;O()|0;zc(e+8|0);S(a|0);L()}function lN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!_f(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Hk(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}Dl(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;lq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=_f(v[v[a>>2]-12>>2]+a|0)}d=e;gb=c+16|0;return d}function kN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!_f(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;ag(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}Dl(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;lq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=_f(v[v[a>>2]-12>>2]+a|0)}a=e;gb=c+16|0;return a}function ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=gb-1120|0;gb=f;d=gb-32|0;gb=d;c=d+24|0;ZU(c,f+8|0);g=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;e=d+16|0;c=a;hd(e,c,d);e=yb(e);if((e|0)==(g|0)){bd(c,yb(d+24|0))}gb=d+32|0;c=-1;a:{if((e|0)!=(g|0)){break a}c=0;if(!aV(f+8|0)){break a}c=Ne(a,b,$U(f+8|0),jb)}gb=f+1120|0;return c|0}function zA(a,b,c,d){var e=0,f=0;e=gb-32|0;gb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e+31|0]=0;u[a>>1]=w[(b&15)+39104|0];t[a+2|0]=w[e+31|0];break a}t[e+30|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+30|0]=1;f=f<<1}c=e+16|0;Db(c,b+1074312|0,66);if(!(!Cb(c)|!d)){u[e+14>>1]=0;vC(a,e+14|0,e+30|0);break a}u[e+12>>1]=f<<4;vC(a,e+12|0,e+30|0)}gb=e+32|0}function Dm(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+69696|0]}if((a|0)<=511){return t[(a>>>5|0)+69696|0]+5|0}return t[(a>>>10|0)+69696|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+69696|0]+15|0}return t[(a>>>20|0)+69696|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+69696|0]+25|0}a=t[(a>>>30|0)+69696|0]+30|0}else{a=0}return a}function Zaa(a){a=a|0;var b=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return ie(a)|0}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,9429,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();return 0}return ie(18726)|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+f;a:{a=v[d>>2];if((a|0)!=v[d+4>>2]){while(1){v[22708]=0;R(1490,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}a=v[d>>2]+52|0;v[d>>2]=a;if(v[d+4>>2]!=(a|0)){continue}break}}_c(d);gb=e+16|0;return}a=P()|0;O()|0;_c(d);S(a|0);L()}function _y(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(xf(v[a+16>>2])>>>0);c=C(C(C(kb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(kb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Xh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(kb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(kb[v[v[a>>2]+192>>2]](a)|0)){b=vG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Up((f|0)==2509?0:v[a>>2],d);if(g){if((f|0)!=2509){be(a)}v[e+4>>2]=2458;f=ge(e+8|0,g,e+4|0);SG(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);gb=e+16|0;return}Ss();L()}function d7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Ip(a);v[a>>2]=59216;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=dc(a);Hp(c);v[c>>2]=59580;mc(c+4|0);t[c+20|0]=0;v[c+16>>2]=0;v[c>>2]=59380;b=v[d+4>>2];v[c+24>>2]=v[d>>2];v[c+28>>2]=b;b=v[d+12>>2];v[c+32>>2]=v[d+8>>2];v[c+36>>2]=b;t[c+40|0]=0;gb=d+16|0;return a|0}function RF(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=119304647;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=_k(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function KU(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|w[a+65|0]!=16&w[a+65|0]!=1)){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=gb-16|0;gb=c;d=pE(b,a);gb=c+16|0;a=d?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=119304647;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=119304648){rd(8445);L()}c=Nc(B(c,36),4);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,36)|0,v[f>>2]=g}function jY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=89478485;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=mn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Fq(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function qpa(a){a=a|0;var b=0,c=0,d=0,e=0;c=vh(a);v[22708]=0;_(516,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=gb-16|0;gb=d;c=d;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+32768;b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return a|0}a=P()|0;O()|0;hD(c);S(a|0);L()}function K2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Up((f|0)==2509?0:v[a>>2],d);if(g){if((f|0)!=2509){be(a)}v[e+4>>2]=2458;f=ge(e+8|0,g,e+4|0);SG(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];gb=e+16|0;return}Ss();L()}function vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=4925421;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=4925422){rd(8445);L()}c=Nc(B(c,872),8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,872)|0,v[f>>2]=g}function oL(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=Nf(e);if((f|0)==(Ab(c)|0)){v[22708]=0;c=fa(551,c|0,0,-1,e|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Bb();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=d+16|0;return a}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=477218588;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=477218589){rd(8445);L()}c=Nc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,9)|0,v[f>>2]=g}function RI(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}
function Ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=715827882;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=715827883){rd(8445);L()}c=Nc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,6)|0,v[f>>2]=g}function CJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<0|b>1){a=ba(8)|0;v[22708]=0;c=Q(70,c|0,9006)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Ah(b*256);v[v[a+32>>2]+1074456>>2]=d;gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Dg(c+24|0,a);_U(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;b=gb-16|0;gb=b;a=1;d=c;e=c+8|0;if(v[e+4>>2]==v[c+4>>2]){f=v[d+4>>2];a=b;d=v[d>>2];v[a>>2]=d;v[a+4>>2]=f;v[a+8>>2]=d;v[a+12>>2]=f;a=(IW(e,a)|0)!=0}gb=b+16|0;gb=c+32|0;return a|0}function OE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<5){a:{if(!b){break a}if(!Pb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Mg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;return d}aa(8513,6236,136,11437);L()}function NY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=2147483647;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Og(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function IJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-32>>>0>=481){b=ba(8)|0;v[22708]=0;c=Q(70,c|0,6520)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function rO(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075785|0];if((c|0)>=0){kP(a,b,(d|0)==32,((w[(B(b,872)+a|0)+1075836|0]<<5)+a|0)+901692|0,c&255);return}kP(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function PB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=357913941;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function KY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=153391689;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=aj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=gb-224|0;gb=f;d=gb-32|0;gb=d;c=d+24|0;BX(c,f);g=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;e=d+16|0;c=a;hd(e,c,d);e=yb(e);if((e|0)==(g|0)){bd(c,yb(d+24|0))}gb=d+32|0;c=-1;a:{if((e|0)!=(g|0)){break a}c=0;if(!FX(f)){break a}c=Ne(a,b,EX(f),jb)}gb=f+224|0;return c|0}function $D(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=nqa(w[a+3|0],0,18,0);d=d+c|0;b=jb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}jb=a;return b}function qz(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function aL(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;f=d;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<=-1){break a}if((kb[c|0](b,0,0,2)|0)<=-1){break a}d=kb[a|0](b)|0;a=jb;kb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=KA(d,a)}return g}kb[c|0](b,e,f,0)|0;return 0}function JJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-1>>>0>=65535){b=ba(8)|0;v[22708]=0;c=Q(70,c|0,2940)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(b,c);v[22708]=0;U(186,b|0,54936,1938);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074416>>2]=b;gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<11)+e;a:{if(v[c>>2]!=v[c+4>>2]){while(1){a=v[c>>2];v[22708]=0;cz(a);a=v[22708];v[22708]=0;if((a|0)==1){break a}a=v[c>>2]+2048|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0;return}a=P()|0;O()|0;_c(c);S(a|0);L()}function y7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;bK(a,c);gb=c+16|0}function v7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;$J(a,c);gb=c+16|0}function tea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;u[a>>1]=0;c=mc(a+4|0);d=mc(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=Ik(a+52|0);Fg(c);u[a+28>>1]=65472;v[22708]=0;v[b+12>>2]=1065353216;R(1500,c|0,b+12|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Fg(d);gb=b+16|0;return a|0}a=P()|0;O()|0;YW(f);vb(e);Lc(d);Lc(c);S(a|0);L()}function p7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;XJ(a,c);gb=c+16|0}function Tn(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e+8|0;Fc(d,b);v[22708]=0;b=T(2483,d|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;d=T(2492,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}v[c>>2]=d;v[22708]=0;R(2493,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(e+8|0);gb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;gK(a,c);gb=c+16|0}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10383,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{e=Ae(a);b:{if(e>>>0>1){break b}c:{if(e){v[22708]=0;U(506,d|0,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){np(b,d);gc(d);break c}a=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break a}Z(a|0)|0;$();break b}if(!Pb(a,c)){break b}XX(a,b,c)}f=oc(b)>>>0>=c>>>0}gb=d+16|0;return f|0}S(a|0);L()}function lQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b|0])+g|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+2|0])+d|0)+(zb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function iQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b+1|0])+g|0)+(zb(w[b|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+3|0])+d|0)+(zb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b>>2];e=v[b>>2]+yb(b)|0;f=Hg(a);v[22708]=0;b=Zh(d,e);c=v[22708];v[22708]=0;a:{b:{if((c|0)==1){break b}if(!b){break a}v[22708]=0;R(517,a|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;Y(665,a|0,d|0,e|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;km(f);S(a|0);L()}}function Ym(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;if(-17-b>>>0>=c>>>0){i=Jb(a);k=a;a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Wk(v[Mc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=pi(k,j);if(e){Qg(c,i,e)}d=d-(e+f|0)|0;if(d){Qg((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){$k(a,i,b)}df(a,c);rg(a,j);gb=h+16|0;return}bg();L()}function Vn(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e+8|0;Fc(d,b);v[22708]=0;b=T(2454,d|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;d=T(2466,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[c|0]=d;v[22708]=0;R(2467,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(e+8|0);gb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function UA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=A[b+8>>3];d=$g(A[b>>3]);e=A[b>>3];a:{if(d){if(e<0){c=AR(c)?c:1;break a}if(c!=0){if(AR(c)){break a}}d=$g(c);Vm(a,A[b>>3],d?M:c);return}if(!Pi(e)|A[b+8>>3]!=0){break a}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;return}e=$w(A[b>>3]);f=si(c);Vm(a,e*Le(c),f*e)}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Hi(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=52832;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22708]=0;W(1534,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Th(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;kf(b);S(a|0);L()}function lz(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){wb(a);v[22708]=0;R(1490,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=f+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[pc(b,0)|0]!=(hg(43)&255)){if(w[pc(b,0)|0]!=(hg(45)&255)){break b}}c=c+1|0;Oe(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Gd(d,d+8|0);f=Ab(b);Vz(b,v[e>>2],c-f|0,hg(48))}Dc(a,b);gb=d+16|0}function O_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;f=gb-16|0;gb=f;e=gb-16|0;gb=e;v[f+4>>2]=1;i=f,j=Nc(32,4),v[i+8>>2]=j;gb=e+16|0;e=f;h=v[e+8>>2];v[22708]=0;da(223,h|0,b|0,c|0,d|0)|0;b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=a;a=Jp(e);Ow(b,dc(a),a);yF(e);gb=f+16|0;break a}a=P()|0;O()|0;yF(e);S(a|0);L()}gb=g+16|0}function Mda(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((oc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}$y(a,b)}St(a)}function Ema(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22708]=0;_(779,a|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}a=a+24|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function $5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Ab(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Fb(f+12|0,f)>>2],v[g+4>>2]=h;b=Vo(Jb(a)+b|0,d,v[Fb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}gb=f+16|0;return b|0}Zn();L()}function Eq(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function nI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;if(1073741807-b>>>0>=c>>>0){g=Jb(a);i=a;a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=zm(v[Mc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Ui(i,h);if(e){yi(c,g,e)}d=d-e|0;if(d){e=e<<2;yi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){ai(a,g,b)}df(a,c);rg(a,h);gb=f+16|0;return}bg();L()}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;c=a;a:{if(!De(b)){v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;break a}g=v[b>>2];b:{c:{d=v[b+4>>2];d:{if(d>>>0<=10){b=c;_e(c,d);break d}if(d>>>0>4294967279){break c}f=Wk(d)+1|0;b=pi(c,f);df(c,b);rg(c,f);de(c,d)}Qg(b,g,d+1|0);break b}bg();L()}}gb=e+16|0;return a|0}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22708]=0;FT(a);e=v[22708];v[22708]=0;if((e|0)==1){break a}a=a+872|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+2|0])|zb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function jQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+3|0])|zb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function dx(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Rq(a,b){var c=0,d=0;if(a-1>>>0<=268435455){a=a+208|0;nqa(b,0,a,0);a=jb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[22708]=0;b=T(2434,a|0)|0;c=v[22708];v[22708]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}if(!b){break a}d=Qb(b,0,a)- -64|0}return d}function mU(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function dt(a,b,c,d){var e=0,f=0;e=gb-160|0;gb=e;hc(e+8|0,74296,144);a:{b:{if((b|0)<=0){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=WI(e+8|0,c,d,2290,2291);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[115189]=61;a=-1}gb=e+160|0;return a}function Tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[Jb(b)|0]!=(hg(43)&255)){if(w[Jb(b)|0]!=(hg(45)&255)){break b}}c=c+1|0;Oe(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Gd(d,d+8|0);f=Ab(b);WN(b,v[e>>2],c-f|0,hg(48))}Dc(a,b);gb=d+16|0}function Ll(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c|0]&32)){break a}g=d,h=zd(b),v[g+8>>2]=h;g=d,h=ff(b),v[g>>2]=h;if(!Gb(d+8|0,d)){break a}while(1){e=v[d+8>>2];c=t[e|0];f=hg(97);b:{if((c|0)<(f|0)){break b}if((hg(122)|0)<(c|0)){break b}g=e,h=hg(65)+(c-f|0)|0,t[g|0]=h}c=d+8|0;Oe(c);if(Gb(c,d)){continue}break}}Dc(a,b);gb=d+16|0}function bV(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=nqa(w[a+30|0],0,37,0);c=jb;d=b;b=a+24|0;b=nqa(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=jb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}jb=a;return b}function R8(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a=mc(a);v[22708]=0;R(2070,c+16|0,0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=c+16|0;d=Vb(b);b=Zb(b);e=v[yc(c+8|0,a)>>2];v[22708]=0;U(2071,d|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Lc(c+16|0);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Lc(c+16|0)}yd(a);S(b|0);L()}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Hi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=53064;v[22708]=0;W(1534,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Th(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;kf(b);S(a|0);L()}function aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22708]=0;_(1936,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1921;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,10413,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function W4(a){a=a|0;a:{v[22708]=0;T(2409,463096)|0;a=v[22708];v[22708]=0;b:{if((a|0)==1){break b}v[22708]=0;T(2410,463180)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}v[22708]=0;T(2409,463432)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}v[22708]=0;T(2410,463516)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Bb();L()}}function Sw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+8>>2]=b;v[d+12>>2]=e;v[d+16>>2]=b;v[d+20>>2]=e;rh(d+24|0,d+8|0);v[22708]=0;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;R(212,a|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[a+8>>2]=0;Xf(a+12|0,c);Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function K7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a:{b:{if((Hy(a)|0)!=1){break b}if((zK(a)|0)!=(b|0)){break b}d=a+120|0;Ci(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[13842];v[a+8>>2]=v[13841];v[a+12>>2]=e;e=v[13840];v[a>>2]=v[13839];v[a+4>>2]=e;kb[v[Rh(a,Yg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break a}yK(a,1,b)}gb=c+16|0}function tK(a,b,c){var d=0,e=0,f=0;a:{d=v[c>>2];c=a;e=vh(c);b:{if(!d){break b}v[22708]=0;R(2111,c|0,d|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;sK(c,d);d=v[22708];v[22708]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;Gl(e);S(a|0);L()}v[22708]=0;b=rK(b);d=v[22708];v[22708]=0;if((d|0)!=1){v[a+12>>2]=b;break a}a=P()|0;O()|0;Gl(c);S(a|0);L()}}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;a:{if(Mu(a)>>>0<b>>>0){wb(a);d=xB(c+32|0);v[22708]=0;R(955,d|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=c+16|0;zk(b,a);e=c+8|0;Ul(e,a);v[22708]=0;U(956,d|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}wB(a,d);Ye(d)}gb=c+48|0;return}a=P()|0;O()|0;Ye(d);S(a|0);L()}function ji(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function R$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb+-64|0;gb=e;d=1;a:{if(Sg(a,b,0)){break a}d=0;if(!b){break a}b=gx(b,89644,89692);d=0;if(!b){break a}d=e+8|0;Qb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;kb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}gb=e- -64|0;return d|0}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;f=fg(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!f){if(nd(a,5)){break a}}g=v[a+28>>2];d=0;wE(b,v[e+24>>2]);if(v[e+24>>2]){while(1){bB(g,sc(b,d));d=d+1|0;if(d>>>0<y[e+24>>2]){continue}break}}}Zf(a,f,c,e+16|0);gb=e+32|0}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;AU(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){zU(g)}if(a){f=KU(b+8|0)}gb=b+160|0;return f|0}function r5(a,b){a=a|0;b=b|0;var c=0;c=v[a+24>>2];if(c>>>0>y[a+44>>2]){v[a+44>>2]=c}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(He(b,-1)){Xn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Xs(b)|0}if(!(w[a+48|0]&16)){if(!He(Wh(b),t[v[a+12>>2]-1|0])){break a}}Xn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Wh(b);t[v[a+12>>2]]=c;return b|0}return-1}function p2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=gb-16|0;gb=d;b=a;a:{if(!De(f)){v[b+8>>2]=v[f+8>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){_e(a,c);break d}if(c>>>0>1073741807){break c}f=zm(c)+1|0;b=Ui(a,f);df(a,b);rg(a,f);de(a,c)}yi(b,e,c+1|0);break b}bg();L()}}gb=d+16|0}function bqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-624|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;AY(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){zY(g)}if(a){f=CY(b+8|0)}gb=b+624|0;return f|0}function WA(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function E_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;a:{if(y[b+16>>2]<=c>>>0){mk(a,d,0);break a}f=v[b+4>>2];g=v[b+12>>2];h=e,i=yb(d),v[h+20>>2]=i;v[e+16>>2]=v[b+16>>2]-c;mk(e+24|0,d,v[Fb(e+20|0,e+16|0)>>2]);b=v[v[f>>2]+28>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kb[b|0](a,f,c+g|0,e+8|0)}gb=e+32|0}function zH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=kb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((Kk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=lt(v[a+32>>2])?-1:0}gb=b+16|0;return d|0}function No(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;t[d+15|0]=b;a:{b:{c:{d:{if(De(a)){c=ek(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Ym(a,c,1,c,c,0,0);b=c;if(De(a)){break b}}c=a;_e(a,b+1|0);break a}c=v[a>>2];de(a,b+1|0)}a=b+c|0;Bd(a,d+15|0);t[d+14|0]=0;Bd(a+1|0,d+14|0);gb=d+16|0}function $ma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22708]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(772,a|0,d+8|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;Ek(a);i=v[b+4>>2];f=b+4|0;Ck(wb(a),v[a>>2],c,f);j=wb(a);g=b+8|0;d=g;h=v[a+4>>2];if((h|0)!=(c|0)){e=v[d>>2];while(1){hn(j,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((h|0)!=(c|0)){continue}break}}xc(a,f);xc(a+4|0,g);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a));return i|0}function os(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22708]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(207,a|0,d+8|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;Dv(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){PX(g)}if(a){f=SX(b+8|0)}gb=b+32|0;return f|0}function X5(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(De(a)){c=ek(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=1;b=w[a+11|0];if((b|0)!=1){break c}}nI(a,c,1,c,c);b=c;if(De(a)){break b}}c=a;_e(a,b+1|0);break a}c=v[a>>2];de(a,b+1|0)}a=(b<<2)+c|0;Fe(a,d+12|0);v[d+8>>2]=0;Fe(a+4|0,d+8|0);gb=d+16|0}function WX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22708]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(515,a|0,d+8|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function Mna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;Xv(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){qW(g)}if(a){f=BW(b+8|0)}gb=b+16|0;return f|0}function Au(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=d+8|0;b=gb-16|0;gb=b;v[22708]=0;c=a;PQ(c+4|0);f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){v[22708]=0;v[b+12>>2]=0;ef(c+8|0,b+12|0,e);e=v[22708];v[22708]=0;if((e|0)!=1){break c}break b}break b}g=c,h=fc(c),v[g>>2]=h;gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=d+16|0;return a}function uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;GC(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Pn(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function nma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Lq(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Kh(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function yG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Kh(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function vY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;JD(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function XZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;hw(e,c);v[22708]=0;nj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Zr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;d=Jb(b);e=Jb(b);g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;Rg(d,e+v[Fb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Fb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Ko(b+d|0,e+f|0,c+7|0);gb=c+16|0;return a|0}function NE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<3){a:{if(!b){break a}if(!Pb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Mg(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}gb=c+16|0;return d}aa(8513,6236,136,11437);L()}function hK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14076];v[c+8>>2]=v[14075];v[c+12>>2]=g;g=v[14074];v[c>>2]=v[14073];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function gK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14080];v[c+8>>2]=v[14079];v[c+12>>2]=g;g=v[14078];v[c>>2]=v[14077];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function dma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=Pb(a,6);a:{if(!e){a=gb-16|0;gb=a;d=gb-16|0;gb=d;f=b+6|0;while(1){If(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,6);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return e|0}function cK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14281];v[c+8>>2]=v[14280];v[c+12>>2]=g;g=v[14279];v[c>>2]=v[14278];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14285];v[c+8>>2]=v[14284];v[c+12>>2]=g;g=v[14283];v[c>>2]=v[14282];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function aK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14488];v[c+8>>2]=v[14487];v[c+12>>2]=g;g=v[14486];v[c>>2]=v[14485];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function YJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14695];v[c+8>>2]=v[14694];v[c+12>>2]=g;g=v[14693];v[c>>2]=v[14692];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function XJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14699];v[c+8>>2]=v[14698];v[c+12>>2]=g;g=v[14697];v[c>>2]=v[14696];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function MN(a,b,c,d){var e=0,f=0,g=0;e=gb-32|0;gb=e;g=v[a+20>>2];f=x[a+34>>1];v[22708]=0;f=f&65;v[e+16>>2]=f;v[e+8>>2]=f^65;ka(1475,d|0,a|0,b|0,c|0,e+16|0,e+8|0);d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[a>>2]=c;v[a+20>>2]=b;v[22708]=0;Sq(g);a=v[22708];v[22708]=0;if((a|0)==1){break a}gb=e+32|0;return}a=P()|0;O()|0;S(a|0);L()}function $J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14492];v[c+8>>2]=v[14491];v[c+12>>2]=g;g=v[14490];v[c>>2]=v[14489];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-208|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;bU(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){aU(h)}if(a){f=jU(b)}gb=b+208|0;return f|0}function Woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;zX(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){yX(h)}if(a){f=AX(b)}gb=b+160|0;return f|0}function Iz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=F(c,.999);h=c*3.141592653589793;i=pq(b);while(1){j=a;k=c;f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=si(g)*pq(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}l=j,m=KT(k*d*32768),u[l>>1]=m;a=a+2|0;e=e+1|0;if((e|0)!=32768){continue}break}}function $ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,40);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,40);gb=c+16|0}return a|0}function qX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,80);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,80);gb=c+16|0}return a|0}function nQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+2|0])|zb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function l7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=aL(d);Hp(a);t[a+8|0]=0;v[a+4>>2]=c;v[a>>2]=59164;mc(a+12|0);v[a>>2]=58972;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;gb=d+16|0;return a|0}function kQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+3|0])|zb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function UE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Rc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){Ap(a,3)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=10;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){Cf(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}Cf(a,b)}}function AX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>9){break a}b=(w[a|0]|w[a+1|0]<<8)!=0}return b}function gM(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function Wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Se(b);v[d+12>>2]=0;a:{if(!Hk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Uh(a,d+11|0)){break b}No(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}gb=d+16|0;return e|0}function Ac(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[22708]=0;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=Or(c+24|0,c+8|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}v[22708]=0;a=My(c+16|0,a);b=v[22708];v[22708]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function ZZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-48|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;mE(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){lE(h)}if(a){f=yE(b)}gb=b+48|0;return f|0}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Se(b);t[d+15|0]=0;a:{if(!Uh(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Uh(a,d+14|0)){break b}No(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}gb=d+16|0;return e|0}function oM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=(xf(v[a+16>>2])|0)/5|0;b=Ac(b,b>>31);v[a+4272>>2]=b;v[22708]=0;v[c+12>>2]=0;U(1542,a+4256|0,b<<1,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;gb=c+16|0;return}S(b|0);L()}function hQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function gQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function Kf(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(y[b+8>>2]<c>>>0){v[22708]=0;Y(2118,14456,6267,394,3438);a=v[22708];v[22708]=0;if((a|0)==1){break a}L()}v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;gb=d+16|0;return}V(0)|0;O()|0;Bb();L()}function $x(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((kb[b|0](a,f)|0)>=0){if((kb[b|0](a,e)|0)>-1){break a}}j=f;f=(kb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}JI(g,h);gb=g+240|0}function Lla(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!jD(a,b+16|0)){break a}c=0;if(!QU(b+16|0)){break a}c=-1;if(!ck(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;gb=b+32|0;return a|0}function JI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=gb-256|0;gb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;hc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;hc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}gb=e+256|0}function dQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=id(zb(w[b|0])|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function cQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=id(zb(w[b+3|0])|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Xka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Md(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Ol(b);ap(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Pl(b)){break a}if(v[a>>2]!=(d|0)){Dw(b+68|0)}hc(zb(v[b+20>>2]),zb(v[a+20>>2])+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function dY(){var a=0,b=0;a=gb-240|0;gb=a;a:{b:{if(t[90992]&1){break b}if(!Qd(90992)){break b}v[22708]=0;X(43);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;_(44,a+120|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}hc(90872,hc(a,a+120|0,120),116);Pd(90992)}gb=a+240|0;return 90872}a=P()|0;O()|0;$e(90992);S(a|0);L()}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=gg(d,b);v[22708]=0;U(1165,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){v[22708]=0;U(71,a|0,d+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function n8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Hg(a);a:{c=v[b+4>>2];if(!c){break a}v[22708]=0;R(2089,a|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[22708]=0;Y(2090,a|0,c|0,e+f|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;sF(d);S(a|0);L()}return a|0}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Sk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;kq(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=zy(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;ql(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Sk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;dp(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hu(a+60|0);v[a>>2]=78196;v[d>>2]=78216;v[22708]=0;e=a+8|0;W(106,a|0,78228,e|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){a:{v[a>>2]=78196;v[d>>2]=78216;v[22708]=0;W(107,e|0,b|0,c|8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;oh(d);S(a|0);L()}function mu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;if(b){e=f+8|0;Db(e,a+1074312|0,73);k=Cb(e)?c- -64|0:c;i=rk(a);l=i^1;c=120;g=1;while(1){e=c>>>1|0;j=e+g|0;h=_g(a,j,k,d);a:{if(!((h>>>0<=b>>>0|i)==1&((h|0)!=0&l|b>>>0<=h>>>0))){g=j+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}gb=f+16|0;return g}function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=En(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;xn(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Yfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;d=a+1298260|0;if(!Dd(d)){f=b;c=gb-16|0;gb=c;e=tf(532);a=v[a+24620>>2];v[22708]=0;g=Q(1314,e|0,a|0)|0;a=v[22708];v[22708]=0;a:{if((a|0)!=1){a=v[Yi(c+8|0,g)>>2];gb=c+16|0;break a}a=P()|0;O()|0;Yb(e);S(a|0);L()}v[f+8>>2]=a;a=b+8|0;XO(d,be(a));iu(a)}gb=b+16|0}function kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=33;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;BC(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);BC(e,b);Qb(v[e>>2]+c|0,0,33-c|0);Rb(a,v[d+44>>2]);gb=d+48|0;return c|0}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+28>>2]){break a}if((kb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}c=v[d>>2];f=yb(d);if(!f){break a}while(1){b:{e=kb[v[b+28>>2]](v[b+24>>2],c,f)|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;if(!e){break b}c=c+e|0;f=f-e|0;if(f){continue}}break}e=g}mk(a,d,e)}function aA(a,b){var c=0,d=0,e=0;WV(a);kp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function D$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=gg(d,b);v[22708]=0;U(176,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){v[22708]=0;U(5,a|0,d+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function gO(a,b,c,d,e){var f=0,g=0,h=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;g=d;break a}f=f-1|0;g=(d>>>0)/(e>>>0)|0;t[f|0]=w[(d-B(g,e)|0)+1991|0];h=d>>>0>=e>>>0;d=g;if(h){continue}}break}b:{if(!g){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=yh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}FA(a,b,c,d)}function K$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Sg(a,v[b+8>>2],e)){cx(b,c,d);return}a:{if(!Sg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+12;VT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Wu(d+8|0,PB(a,Ec(a)+1|0),Ec(a),c);VT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;fU(a,c);eU(c);gb=d+32|0}function Ux(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;f=e+16|0;Qb(f,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;zi(f,0,0);xI(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+24>>2]|0)+b}v[a>>2]=g;v[a+4>>2]=h;v[a+8>>2]=d;v[a+12>>2]=f;gb=e+160|0}function tp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=mi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;xn(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function tE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Eg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;dp(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function ld(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=oI(b);e=gb-16|0;gb=e;c=aq(a);a:{if(c>>>0>=b>>>0){f=Jb(a);g=f;c=b;b:{c:{if(b){v[22708]=0;FI(g,d,c);d=v[22708];v[22708]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Fe((b<<2)+f|0,e+12|0);jh(a,b);break a}f=a;a=Ab(a);pI(f,c,b-c|0,a,0,a,b,d)}gb=e+16|0}function jU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==50}return c}function eO(a,b,c,d,e){var f=0,g=0;a:{f=a;if((e|0)!=10){a=c;while(1){b:{if((a|0)==(b|0)){a=b;break b}g=d&255;d=(g|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(g-B(d,e)|0)+1991|0];if(d&255){continue}}break}c:{if(!(d&255)){d=c-a|0;if(d){break c}}v[f+4>>2]=61;v[f>>2]=c;break a}a=yh(b,a,d);v[f+4>>2]=0;v[f>>2]=a+d;break a}XP(f,b,c,d)}}function SC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Ar(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;EC(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Dn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Bi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;ql(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function nY(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Ar(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+4|0]=6;t[a+5|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=8;t[a+3|0]=4;a=a+6|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function gka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{b:{c:{d:{e:{f:{if((b|0)<=28590){if((b|0)==437){break c}if((b|0)==1252){break b}if((b|0)!=20127){break f}e=1;break a}if((b|0)==28591){break e}if((b|0)==28605){break d}e=0;if((b|0)==65001){break a}}e=c;break a}e=2;break a}e=3;break a}e=5;break a}e=8}tT(a,e,d)}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=_l(a);d=_l(b);b=gb-32|0;gb=b;v[b+24>>2]=c;b:{if((a|0)!=(d|0)){while(1){c=Tb(b+8|0,v[a>>2]);v[22708]=0;R(2119,b+24|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(c);a=a+4|0;if((d|0)!=(a|0)){continue}break}}gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}}function sE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=dw(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=wb(a);v[22708]=0;R(342,e|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Qt(a){var b=0,c=0,d=0,e=0;b=Dk(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){d=a;if(b>45e-5){c=Sp(b)/.6931471805599453;b=c-H(c);e=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Dk(e+c)*.5}else{b=0}A[d+4248>>3]=b}Pt(a)}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=4896;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;HC(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);HC(e,b);Qb(v[e>>2]+c|0,0,4896-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function YX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=320012546|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=184619540|w[a+8|0]>1){break a}b=a+9|0;if(!w[b|0]|w[b|0]>8){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function xC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;iW(a,b);e=b+8|0;Wc(a,Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);hW(a,d);a:{b=b+32|0;if(!Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}if(!Wc(a,Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){break a}zC(a,c);return}Qb(c,0,80)}function _pa(a,b){a=a|0;b=b|0;var c=0;gv(a,b);Of(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=263;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;_S(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);_S(e,b);Qb(v[e>>2]+c|0,0,263-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function V6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c>>2];e=yb(c);b:{if(!e){break b}while(1){f=kb[v[b+28>>2]](v[b+24>>2],d,e)|0;if(!f){t[b+40|0]=1;break b}d=d+f|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;e=e-f|0;if(e){continue}break}}d=g}mk(a,c,d)}function Pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=gb-16|0;gb=e;d=gb-16|0;gb=d;_e(c,1);Hr(c,1,b<<24>>24);t[d+15|0]=0;Bd(c+1|0,d+15|0);gb=d+16|0;gb=e+16|0;b=c;d=Jb(c);e=Ab(c);v[22708]=0;W(117,a|0,d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(b);gb=c+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function ES(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=Ik(a);a=b+236|0;b=Lu(a);a:{if((a|0)!=(b|0)){while(1){d=x[a>>1];u[c+14>>1]=d;if(d){v[22708]=0;U(1084,c|0,e|0,c+14|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}gb=c+16|0;return}a=P()|0;O()|0;mr(e);S(a|0);L()}function X2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=v[20911];v[g+24>>2]=v[20910];v[g+28>>2]=h;h=v[20909];v[g+16>>2]=v[20908];v[g+20>>2]=h;h=v[20907];v[g+8>>2]=v[20906];v[g+12>>2]=h;h=v[20905];v[g>>2]=v[20904];v[g+4>>2]=h;h=a;a=g+32|0;b=hk(h,b,c,d,e,f,g,a);gb=a;return b|0}function Uo(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];if(e|v[d>>2]){if(!b){break a}while(1){e=id((id(0-e|0,31)&255)+e|0,8);f=v[d>>2];f=id((id(0-f|0,31)&255)+f|0,8);v[c>>2]=v[c>>2]-e;v[d>>2]=v[d>>2]-f;e=(g<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}e=v[c>>2];continue}}Qb(a,0,b<<3)}}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Ab(b);v[22708]=0;R(65,a|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){a:{if(Ab(b)){while(1){c=t[pc(b,d)|0];v[22708]=0;R(66,a|0,hg(c)|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}d=d+1|0;if(Ab(b)>>>0>d>>>0){continue}break}}return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function KA(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[22708]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=Or(c+24|0,c+8|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}v[22708]=0;a=My(c+16|0,a);b=v[22708];v[22708]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function IW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;v[d+12>>2]=v[a+4>>2];c=v[b+4>>2];v[22708]=0;v[d+8>>2]=c;c=Fb(d+12|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)!=1){c=Vo(v[a>>2],v[b>>2],v[c>>2]);a:{if(c){break a}c=0;if(v[a+4>>2]==v[b+4>>2]){break a}c=y[a+4>>2]<y[b+4>>2]?-1:1}gb=d+16|0;return c}V(0)|0;O()|0;Bb();L()}function pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=22;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;Dv(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);Dv(e,b);Qb(v[e>>2]+c|0,0,22-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=40;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;qC(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);qC(e,b);Qb(v[e>>2]+c|0,0,40-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function _aa(a){a=a|0;var b=0;v[22708]=0;_(1936,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,2782,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=gb-96|0;gb=d;TU(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=d+e|0;e=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;gb=d+96|0;v[a+112>>2]=0;return a|0}function IN(a,b){var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){d=gb-16|0;gb=d;c=v[b>>2];e=v[b+4>>2];b=jr(c,e);a:{if(b>>>0<=pe(a)>>>0){if(Nb(a)>>>0<b>>>0){v[d+12>>2]=c;YV(d+12|0,Nb(a));f=c;c=v[d+12>>2];Rg(f,c,v[a>>2]);oz(a,c,e,b-Nb(a)|0);break a}ij(a,Rg(c,e,v[a>>2]));break a}FN(a);iw(a,fh(a,b));oz(a,c,e,b)}gb=d+16|0}}function kS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{switch(c+1|0){case 0:case 3:bB(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;c=d+16|0;e=a;a=d+28|0;co(c,e,d+26|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=2;Fb(a,c);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[c|0]|w[c+1|0]<<8;gb=d+32|0}function h8(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(Bj(a)){zh(b+24|0);break b}c=b+8|0;oo(c,a);v[22708]=0;c=T(2086,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[b+24>>2]=c;Yf(b+8|0)}if(Bj(a)){a=a+36|0}else{a=v[b+24>>2]}a=jo(a);wl(b+24|0);gb=b+32|0;return a|0}a=P()|0;O()|0;Yf(b+8|0);S(a|0);L()}function XM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22708]=0;v[c+12>>2]=0;U(1542,a+4208|0,b<<1,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;gb=c+16|0;return}S(b|0);L()}function RZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=65;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;ew(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);ew(e,b);Qb(v[e>>2]+c|0,0,65-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function sba(){var a=0,b=0;v[22708]=0;a=v[22708];v[22708]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1913,7167,0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}else{a=19923026}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kw(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,256)){a=gb-16|0;gb=a;d=gb-16|0;gb=d;e=b+256|0;while(1){If(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,256);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function eC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-1024|0;gb=g;d=gb-32|0;gb=d;f=d+24|0;$B(f,g);f=yb(f);e=v[d+28>>2];h=v[d+24>>2];v[d+8>>2]=h;v[d+12>>2]=e;v[d>>2]=h;v[d+4>>2]=e;e=d+16|0;cc(e,a,d);e=yb(e);if((e|0)==(f|0)){Rb(a,yb(d+24|0))}gb=d+32|0;if((e|0)==(f|0)){i=cC(g,c)>>>0<=b>>>0}gb=g+1024|0;return i}function R2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=gb-128|0;gb=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;XG(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;if((a|0)!=(e|0)){while(1){TH(d+8|0,t[a|0]);a=a+1|0;if((e|0)!=(a|0)){continue}break}b=v[d+8>>2]}gb=d+16|0;gb=c+128|0;return b|0}function K9(a){a=a|0;var b=0;v[22708]=0;_(2009,a|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1913,9228,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);Lf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;gb=d+16|0}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{if((oc(v[a+20>>2]+4|0)|0)!=7){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=Vb(v[a+20>>2]+4|0);c=Zb(v[a+20>>2]+4|0);tn(d+8|0,a+4228|0);Xi(b,c,v[d+8>>2]);break a}$y(a,b)}Lt(a);gb=d+16|0}function Eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{b=zT(d,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){v[22708]=0;R(1090,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=d+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;b=-1;a:{if(!Wf(a,1084)){break a}Vl(a,1080);e=d+60|0;EV(a,e);c=e;e=DV(d+40|0);b=0;if(!CV(c,e)){break a}Vl(a,20);b=1;while(1){c=d+8|0;BV(a,c);f=gC(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=y[e+4>>2]>=f>>>0}gb=d- -64|0;return b|0}function uba(){var a=0,b=0;v[22708]=0;a=v[22708];v[22708]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1913,7139,0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}else{a=393216}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function QY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Pb(a,8);a:{if(!d){a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+8|0;while(1){If(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0;break a}uD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function LM(a){a=a|0;var b=0,c=0,d=0,e=0;c=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(c)<0x8000000000000000){b=c;e=~~b>>>0;d=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}d=-2147483648}A[a+4256>>3]=c-(+(e>>>0)+ +(d|0)*4294967296)}function Foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;HC(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,4896);gb=c+16|0}return a|0}function xl(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;$f(c,b);v[22708]=0;R(2043,c+16|0,c|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){v[22708]=0;U(2044,a|0,0,c+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(c+16|0);vb(c);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ic(c+16|0)}vb(c);S(b|0);L()}function uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=bq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;zR(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function rP(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+851|0]=w[b+851|0]|32;g=b;d=a?w[b+813|0]:0;h=v[b+852>>2]+((c|0)>-1?0-d|0:d)|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+852>>2]=h+d;c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+813|0]=a^a+c}function nN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(pe(a)>>>0>=b>>>0){f=d,g=Nb(a),v[f+8>>2]=g;mN(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){gz(a,b-e|0,c);break a}ij(a,v[a>>2]+(b<<2)|0);break a}FN(a);iw(a,fh(a,b));gz(a,b,c)}gb=d+16|0}function jK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=Nc(b,1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=b+c|0,v[f>>2]=g}function bL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=v[a>>2];a:{if(!b){break a}d=v[a+8>>2];if(!d){break a}e=v[a+12>>2];if(!e){break a}f=kb[e|0](b)|0;a=jb;if((a|0)<0){break a}c=0;b:{if((kb[d|0](b,0,0,0)|0)<0){break b}c=0;if((kb[d|0](b,0,0,2)|0)<0){break b}kb[e|0](b)|0;c=(jb|0)>-1}kb[d|0](b,f,a,0)|0}return c|0}function NJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a+4|0;a:{if(oc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!oc(c)){Nk(c,vy(v[a+16>>2]+b|0,65536));break a}f=d,g=oc(c),v[f+12>>2]=g;e=yf(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Nk(c,vy(a,65536));break a}f=d,g=oc(c),v[f+8>>2]=g;Nk(c,yf(d+8|0))}gb=d+16|0}function CQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;f=a,g=zb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function BQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=zb(w[b|0])+g|0;t[a|0]=g;d=zb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function lx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;h=b;c=oI(b);d=gb-16|0;gb=d;b=a;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){_e(b,c);e=b;break b}g=zm(c)+1|0;e=Ui(b,g);df(b,e);rg(b,g);de(b,c)}yi(e,h,c);v[d+12>>2]=0;Fe((c<<2)+e|0,d+12|0);gb=d+16|0;break a}bg();L()}gb=f+16|0;return a|0}function kH(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=jr(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){_e(a,e);d=a;break a}g=zm(e)+1|0;d=Ui(a,g);df(a,d);rg(a,g);de(a,e)}if((b|0)!=(c|0)){while(1){Fe(d,b);d=d+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f+12>>2]=0;Fe(d,f+12|0);gb=f+16|0;return}bg();L()}function iba(){var a=0,b=0;v[22708]=0;a=v[22708];v[22708]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1913,8398,0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}else{a=2048}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fB(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=DB(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){wb(a);v[22708]=0;R(1090,b|0,c|0);g=v[22708];v[22708]=0;if((g|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function FS(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=Zh(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){_e(a,e);d=a;break a}g=Wk(e)+1|0;d=pi(a,g);df(a,d);rg(a,g);de(a,e)}if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(d,f+15|0);gb=f+16|0;return}bg();L()}function jE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=mi(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;fw(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function fv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=Vb(a);c=Zb(a);a=gb-16|0;gb=a;v[a>>2]=c;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}b=a+8|0;of(b);if(Gb(b,a)){continue}break}}gb=a+16|0}gb=d+16|0}function fq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Bi(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;If(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Zf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=gb-48|0;gb=c;a:{if(!b){b=1;if(nd(a,5)){break a}b=JL(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;se(c,v[a+28>>2]);e=c+16|0;WL(e,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[e+8>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}gb=c+48|0;return b|0}function Tr(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;c=f+12|0;qc(c,256);qc(c,65535);h=x[f+12>>1];Bf(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=gj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}gb=f+16|0}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;b=c+16|0;Bn(b,d);b=zb(v[b>>2]);e=c+8|0;Bn(e,d);b=Nj(c+24|0,b,zb(v[e>>2]+2|0));v[22708]=0;Q(1101,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function tI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=Ab(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Jb(a);h=e;f=d;if(d){em(c+e|0,e,f);b=(b>>>0>=e>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}em(h,b,c);b=c+d|0;jh(a,b);t[g+15|0]=0;Bd(b+e|0,g+15|0);break a}vp(a,f,(c+d|0)-f|0,d,0,0,c,b)}gb=g+16|0;return a}function ska(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Ql(a,0,c);return;case 1:Ql(a,1,c);return;case 2:Ql(a,2,c);return;case 3:Ql(a,3,c);return;case 4:Ql(a,4,c);return;case 5:Ql(a,5,c);return;case 6:zS(a,24992,c);return;case 7:zS(a,26016,c);return;case 8:Ql(a,6,c);return;default:break a}}Kb(a)}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(dg(a)>>>0>=b>>>0){f=d,g=oc(a),v[f+8>>2]=g;oi(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){Dn(a,b-e|0,c);break a}Em(a,b+v[a>>2]|0);break a}Ev(a);Cn(a,qh(a,b));Dn(a,b,c)}gb=d+16|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Ab(b);f=Ab(c);b=Jb(b);v[22708]=0;Y(116,a|0,b|0,e|0,e+f|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=Jb(c);v[22708]=0;W(117,a|0,b|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function R6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;v[f+8>>2]=d;d=v[qi(f,f+8|0)>>2];v[22708]=0;fa(1935,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){MJ(a);b=LJ(a+88|0);v[a>>2]=59704;v[b>>2]=59792;eg(f+8|0);gb=f+16|0;return a|0}a=P()|0;O()|0;eg(f+8|0);S(a|0);L()}function T_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;JF(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-36|0;IF(h,e-36|0,c);e=v[d>>2]-36|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];al(a);_k(a);_k(a)}function RQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;gT(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;yu(h,e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];$i(a);aj(a);aj(a)}function KQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=zb(w[b|0])+d|0;d=g+zb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;wb(b);e=a;f=vh(a);a:{c=Nb(b);if(!c){break a}v[22708]=0;R(333,e|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22708]=0;Y(1499,e|0,b|0,d|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;sv(f);S(a|0);L()}return a|0}function kf(a){a=a|0;var b=0,c=0;v[a>>2]=50140;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;GM(a+44|0);return a|0}function kM(a,b,c){var d=0,e=0,f=0,g=0;g=(b|0)<1;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!(g|(e|0)<0)){while(1){d=b-1|0;e=e<<1;if((b|0)<2){break a}b=d;if((e|0)>-1){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function gz(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Eg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;kq(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function dR(a,b,c){var d=0,e=0,f=0;d=Xd(a);e=fc(a);a:{if(d){f=wb(a);b:{while(1){c:{a=d+16|0;d:{if(Ml(f,c,a)){if(!v[d>>2]){break a}a=d;break d}if(!Ml(f,a,c)){break b}a=d+4|0;if(!v[d+4>>2]){break c}d=a;a=d}e=a;d=v[d>>2];continue}break}v[b>>2]=d;return a}v[b>>2]=d;return e}d=fc(a)}v[b>>2]=d;return d}function ls(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-36|0;v[b+8>>2]=d;v[22708]=0;R(214,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){ks(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/36|0)}}function ip(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-20|0;v[b+8>>2]=d;v[22708]=0;R(348,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){dE(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/20|0)}}function Dr(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Bf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==65535){e=65535;break a}if((e|0)!=65535){break a}e=65534}g=gj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function sN(a){var b=0,c=0,d=0,e=0;c=a;d=v[a+4>>2];a:{while(1){b=v[c+8>>2];if((b|0)==(d|0)){break a}e=v[c+16>>2];b=b-52|0;v[c+8>>2]=b;v[22708]=0;R(1326,e|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}c=v[a>>2];if(c){$z(v[a+16>>2],c,(v[dc(a)>>2]-v[a>>2]|0)/52|0)}}function Hm(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;mc(a+32|0);dd(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Wh(w[b|0]),t[f|0]=g;f=a,g=Wh(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function sd(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(v[a>>2]!=v[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function fe(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function MS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){if(c){while(1){h=id((id(0-d|0,31)&255)+d|0,8);i=id((id(0-e|0,31)&255)+e|0,8);f=(g<<3)+b|0;d=d-h|0;v[f>>2]=d+v[f>>2];e=e-i|0;v[f+4>>2]=e+v[f+4>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}v[a+96>>2]=e;v[a+92>>2]=d}}function EP(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}To(b,e,a);c=f+8|0;Db(c,a+1074312|0,10);if(!Cb(c)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}gb=f+16|0}function Zd(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;Kn(a);a=Yi(d+8|0,a);a:{if(Nb(465840)>>>0<=b>>>0){v[22708]=0;_(2562,b+1|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}}c=v[Mb(465840,b)>>2];if(c){Mn(c)}c=be(a);e=Mb(465840,b),f=c,v[e>>2]=f;LG(a);gb=d+16|0;return}b=P()|0;O()|0;LG(a);S(b|0);L()}function SX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<14){break a}if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>256){break a}a=a+8|0;c=!Ib(w[a|0]|w[a+1|0]<<8)}return c}function rB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Ab(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=Vo(Jb(a),v[c+8>>2],v[Fb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}gb=c+16|0;return a|0}function mI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Nf(b);f=Ab(c);v[22708]=0;Y(2300,a|0,b|0,e|0,e+f|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=Jb(c);v[22708]=0;W(2301,a|0,b|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Hi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=52312;v[22708]=0;W(1534,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Th(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;kf(b);S(a|0);L()}function Nn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Zp(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;On(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Zw(a,Ec(a))}function KX(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);f=x[d+12>>1];Bf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=gj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function JE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Bf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=gj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function Bv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;qE(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-20|0;Cv(h,e-20|0,c);e=v[d>>2]-20|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];eE(a,Ie(a))}function $na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{switch(c+1|0){case 0:case 2:Vh(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;c=d+16|0;e=a;a=d+28|0;co(c,e,d+24|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=1;Fb(a,c);t[d+16|0]=w[d+24|0];t[b|0]=w[c|0];gb=d+32|0}function xL(a,b){var c=0;c=gb-32|0;gb=c;$f(c,b);v[22708]=0;U(2049,c+16|0,0,c|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){v[22708]=0;R(2050,a|0,c+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(c+16|0);vb(c);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ic(c+16|0)}vb(c);S(b|0);L()}function UD(a,b,c){var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=192;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;Pr(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);Pr(e,b);Qb(v[e>>2]+c|0,0,192-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Mw(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}
function zQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function wQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function oP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}qk(a,b,b+700|0,c<<2,0)}}function fM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22708]=0;v[c+12>>2]=0;U(1542,a+4208|0,b<<2,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;gb=c+16|0;return}S(b|0);L()}function Rz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[_b(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;c=d+8|0;Db(c,a+1074312|0,63);if(!Cb(c)){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}gb=d+16|0}function PX(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function k4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a:{if((d|0)!=(e|0)){f=d;a=b;while(1){g=-1;if((a|0)==(c|0)){break a}h=t[a|0];i=t[f|0];if((h|0)<(i|0)){break a}if((h|0)>(i|0)){return 1}a=a+1|0;f=f+1|0;if((f|0)!=(e|0)){continue}break}}g=((e-d|0)+b|0)!=(c|0)}return g|0}function iN(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Eg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;Yo(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function bw(a){var b=0,c=0,d=0,e=0,f=0;e=gb-16|0;gb=e;b=gb-32|0;gb=b;d=b+24|0;Vr(d,e+15|0);d=yb(d);c=v[b+28>>2];f=v[b+24>>2];v[b+8>>2]=f;v[b+12>>2]=c;v[b>>2]=f;v[b+4>>2]=c;c=b+16|0;hd(c,a,b);c=yb(c);if((c|0)==(d|0)){bd(a,yb(b+24|0))}gb=b+32|0;gb=e+16|0;return((c|0)==(d|0)?w[e+15|0]:0)&255}function Un(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Fc(d,a);v[22708]=0;a=T(2482,d|0)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)==1){break b}v[22708]=0;Y(2494,a|0,83408,83434,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Wb(c+8|0);gb=c+16|0;break a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}return b}function Ge(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){_e(d,b);f=d;break b}h=Wk(b)+1|0;f=pi(d,h);df(d,f);rg(d,h);de(d,b)}Hr(f,b,c);t[e+15|0]=0;Bd(b+f|0,e+15|0);gb=e+16|0;break a}bg();L()}gb=g+16|0;return a|0}function yQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b|0])+d|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function vQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b+1|0])+d|0)+(zb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function Rna(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Sk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;_j(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function IH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=ct(a);v[a+32>>2]=b;v[a>>2]=78756;b=d+8|0;Ys(b,e);v[22708]=0;b=T(2407,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Wn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);ym(e);S(a|0);L()}function HH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=gI(a);v[a+32>>2]=b;v[a>>2]=78860;b=d+8|0;Ys(b,e);v[22708]=0;b=T(2408,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Wn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);$p(e);S(a|0);L()}function tP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}qk(a,b,b+700|0,c,0)}}function i_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Sk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Wr(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function hN(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Sk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Yo(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function _n(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);Lf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;gb=c+16|0}function LZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=En(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;fw(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function JZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=En(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Ok(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function Fy(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=zy(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;If(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+1|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function rz(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function Jc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}e=b;d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=e-d|0;jb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function OF(a){a=a|0;var b=0,c=0;b=Kb(a);v[22708]=0;T(215,a+12|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){b=gb-16|0;gb=b;v[b+12>>2]=0;v[22708]=0;ef(a+32|0,b+12|0,b+8|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function vv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=fg(a,c);e=f+8|0;se(e,v[a+28>>2]);h=v[e+12>>2];v[f+24>>2]=v[e+8>>2];v[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!nd(a,5)){break b}break a}e=v[g+8>>2]}kb[d|0](v[a+28>>2],b,e)}a=Zf(a,g,c,f+24|0);gb=f+32|0;return a|0}function oD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[qf(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[qf(d+13|0,d+12|0)|0]}gb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function ema(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,1030);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,1030)}return a|0}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=DB(d,a,1);wb(a);dB(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=bS(d+8|0,Zq(a,ze(a)+1|0),ze(a),c);dB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;aS(a,c);cB(c);gb=d+32|0}function oZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,120);a:{if(!d){a=gb-16|0;gb=a;e=b+120|0;while(1){If(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}bc(c+24|0,b,120);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function xQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function _ma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,422);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,422)}return a|0}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,326);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,326)}return a|0}function We(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;GE(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];gb=b+32|0}function Uma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,826);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,826)}return a|0}function Spa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;fY(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function Nf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=Zh(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Ab(a);Ym(a,g,h,d,0,d,0)}d=Jb(a);if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Bd(d,e+15|0);jh(a,f);gb=e+16|0}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,225);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,225)}return a|0}function yO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=Zh(b,c);a:{if(e>>>0<=dg(a)>>>0){if(oc(a)>>>0<e>>>0){v[d+12>>2]=b;xO(d+12|0,oc(a));Rg(b,v[d+12>>2],v[a>>2]);qr(a,v[d+12>>2],c,e-oc(a)|0);break a}Em(a,Rg(b,c,v[a>>2]));break a}Ev(a);Cn(a,qh(a,e));qr(a,b,c,e)}gb=d+16|0}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[b>>2]){if(!gd(c)){qx(c,14864)}e=v[b+4>>2];kb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[22708]=0;Q(1168,c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}vb(d)}Dc(a,c);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function rX(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=vh(a);a:{b=b+4|0;c=vf(b);if(!c){break a}v[22708]=0;R(2045,a|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22708]=0;Y(2046,a|0,b|0,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jt(e);S(a|0);L()}}function Sla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,8)){u[c+16>>1]=0;b=4;while(1){d=w[c+16|0]|w[c+17|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;a=a+2|0;b=b-1|0;if(b){continue}break}break a}uD(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function rh(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;d=gb-16|0;gb=d;b=c+8|0;e=v[b>>2];b=v[b>>2]+yb(b)|0;v[22708]=0;ko(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){gb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=c+32|0}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,64);a:{if(!d){a=gb-16|0;gb=a;e=b- -64|0;while(1){Ok(b);b=b+2|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}tD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,73);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,73)}return a|0}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,60);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,60)}return a|0}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,71);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,71)}return a|0}function Ina(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,91);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,91)}return a|0}function DT(a,b,c){a:{switch(b|0){case 0:yk(a,0,c);return;case 1:yk(a,1,c);return;case 2:yk(a,2,c);return;case 3:yk(a,3,c);return;case 4:yk(a,4,c);return;case 5:yk(a,5,c);return;case 6:yS(a,24992,c);return;case 7:yS(a,26016,c);return;case 8:yk(a,6,c);return;default:break a}}Kb(a)}function dk(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){g=v[a+8>>2];c=v[a>>2];while(1){a:{if(c){d=v[a+4>>2];break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=8}c=c-1|0;v[a>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function K4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if(((g=a,h=Lg(t[b|0]),f=v[v[a>>2]+52>>2],kb[f](g|0,h|0)|0)|0)==-1){return d|0}b=b+1|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Kk(b,1,c,v[a+32>>2])|0}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;d=c+40|0;t[d|0]=w[b|0];b=c+16|0;Vr(b,d);b=zb(v[b>>2]);e=c+8|0;Vr(e,d);b=Nj(c+24|0,b,zb(v[e>>2]+1|0));v[22708]=0;Q(1101,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function ida(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=4104;d=v[b+8>>2];c=0;a:{if(d>>>0<4096){break a}a=v[b+12>>2];e=a+7&-8;a=e-a|0;c=0;if(a>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-a;c=e}a=c;if(!a){aa(3145,6145,88,4444);L()}gb=b+16|0;return a|0}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+8>>2]=b;b=0;a:{if(Nb(a)>>>0>511){break a}if(!Dd(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[22708]=0;R(1530,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Ig(c+8|0);S(a|0);L()}Ig(c+8|0);gb=c+16|0;return b|0}function Uc(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[22708]=0;v[b+4>>2]=32767;a=pd(b+12|0,b+4|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;a=Hf(b+8|0,a);c=v[22708];v[22708]=0;if((c|0)==1){break a}gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function Ts(a,b){var c=0,d=0;c=-1;a:{if((a|0)==-1){break a}d=v[b+76>>2]>=0;b:{c:{c=v[b+4>>2];d:{if(!c){BI(b);c=v[b+4>>2];if(!c){break d}}if(v[b+44>>2]-8>>>0<c>>>0){break c}}c=-1;if(d){break b}break a}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a;if(!d){break a}}}return c}function $d(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Mm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Ij(f)){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}kb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;v[d+44>>2]=b;b=d+8|0;xl(b,c);c=d+24|0;v[c>>2]=v[d+44>>2];Dc(c+4|0,b);v[22708]=0;R(2048,a+4|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){Fk(d+24|0);vb(d+8|0);gb=d+48|0;return}a=P()|0;O()|0;Fk(d+24|0);vb(d+8|0);S(a|0);L()}function ao(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=qqa(a,b,10,0);e=jb;f=e;e=nqa(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function VZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;ew(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,65)}return a|0}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0;b=gb-16|0;gb=b;c=-1;a:{if(!ck(a,b+8|0)){break a}c=0;if(!UT(b+8|0)){break a}c=-1;if(!Wf(a,4)){break a}c=gb-16|0;gb=c;if(ET(a,c+8|0)){a=c+8|0;d=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=c+16|0;c=d>>>31|0}gb=b+16|0;return c|0}function zM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[v[a+16>>2]+1074404>>2];v[22708]=0;v[c+12>>2]=0;U(1542,a+4208|0,B(b,254)|0,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;$()}v[a+4220>>2]=0;gb=c+16|0;return}S(b|0);L()}function m7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Ip(a);v[a>>2]=58808;v[22708]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Q(2122,dc(a)|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function b1(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[22708]=0;b=T(2576,b|0)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=v[a+8>>2];if(!a){return 1}v[22708]=0;a=T(2577,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}V(0)|0;O()|0;Bb();L()}function Rpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=vh(a);a:{if(!b){break a}v[22708]=0;R(486,c|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;nY(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mD(d);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function QL(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;PL(a+60|0);PL(a+52|0);zq(a+49956|0);zq(a+58148|0);zq(a+66340|0);zq(a+74532|0);Qb(a+228|0,0,32768);qB(a+32996|0);Qb(a+33508|0,0,16384)}function sX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function hF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;u[(v[a+1068>>2]<<1)+d>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=fd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function N_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;Ip(a);v[a>>2]=28048;f=dc(a);b=im(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Hp(f);v[f>>2]=28184;b=e+8|0;im(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;Kd(b);gb=e+32|0;return a|0}function wu(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22708]=0;R(279,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){mm(v[a+16>>2],v[a>>2],Lp(a))}}function ss(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22708]=0;R(181,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){mm(v[a+16>>2],v[a>>2],Lp(a))}}function QQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-28|0;v[b+8>>2]=d;v[22708]=0;R(957,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){tB(v[a+16>>2],v[a>>2],HY(a))}}function GV(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[22708]=0;v[b+4>>2]=127;a=pd(b+12|0,b+4|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;a=Hf(b+8|0,a);c=v[22708];v[22708]=0;if((c|0)==1){break a}gb=b+16|0;return t[a|0]}V(0)|0;O()|0;Bb();L()}function yna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;BC(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){CC(b)}return a|0}function yf(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;b=gb-16|0;gb=b;d=2;e=v[a>>2];if(e>>>0>=2){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Fb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Fb(b+12|0,b+8|0)>>2]}gb=b+16|0;gb=c+16|0;return d|0}function hR(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-12|0;v[b+8>>2]=c;v[22708]=0;R(1133,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){mm(v[a+16>>2],b,Lp(a))}}function cB(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-32|0;v[b+8>>2]=c;v[22708]=0;R(1103,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Xk(v[a+16>>2],b,CB(a))}}function aS(a,b){var c=0,d=0,e=0,f=0,g=0;ev(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;dB(e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];eB(a,ze(a))}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;NR(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){WA(b)}return a|0}function xE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;mE(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){lE(b)}return a|0}function cw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;SD(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){RD(b)}return a|0}function bv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;RU(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){SU(b)}return a|0}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;oo(c,a);a=b;if(v[a>>2]){Od(a);Ey(v[a>>2],hv(a));d=wb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=wb(c);d=wb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Yf(c);gb=c+16|0}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Nc(52,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22708]=0;Q(2120,e|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){b=a;a=Jp(d);WJ(b,dc(a),a);VJ(d);gb=c+16|0;break a}a=P()|0;O()|0;VJ(d);S(a|0);L()}}function K8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Nc(56,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22708]=0;Q(2121,e|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){b=a;a=Jp(d);WJ(b,dc(a),a);RJ(d);gb=c+16|0;break a}a=P()|0;O()|0;RJ(d);S(a|0);L()}}function FU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wb(b);d=vh(a);a:{c=oc(b);if(c){v[22708]=0;R(488,a|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}d=v[b>>2];e=v[b+4>>2];b=gb-16|0;gb=b;c=Bi(b,a,c);wb(a);kv(d,e,c+4|0);$b(c);gb=b+16|0}return a|0}a=P()|0;O()|0;km(d);S(a|0);L()}function pD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[qf(d+15|0,d+14|0)|0]}a=e;gb=d+16|0;return a&255}function ei(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[22708]=0;v[b+4>>2]=255;a=pd(b+12|0,b+4|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;a=Hf(b+8|0,a);c=v[22708];v[22708]=0;if((c|0)==1){break a}gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function ee(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function by(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}kb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;kb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(!Md(b)){break a}if(v[b+20>>2]==(zb(v[a+20>>2])|0)){v[a+20>>2]=0}qc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Pl(a)){break a}hc(zb(v[a+20>>2]),v[b+20>>2],bj(a));d=1}return d|0}function kz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Sf(a)){break a}while(1){if(!ii(bf(a,e))){break a}d=d+1|0;e=d&65535;if(Sf(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=wh(a,d&65535,b)?d:-1}return c&65535}function P_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-32|0;gb=e;v[e+24>>2]=d;v[e+28>>2]=c;v[22708]=0;Y(222,e+8|0,b|0,e+28|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;Gw(c,d);Xf(a,c);Kd(c);Kd(d);Kd(b);gb=e+32|0;return}a=P()|0;O()|0;Kd(b);S(a|0);L()}function JT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-16|0;gb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jb(d);Nj(b,a,Ab(d)+a|0);break c}DT(e,c,d);v[22708]=0;U(57,a|0,b|0,e|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(e)}gb=e+16|0;break a}a=P()|0;O()|0;Ic(e);S(a|0);L()}}function gca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;wM(a,b,c,d,e^1);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=52052;return a|0}function gF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=fd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function ah(a,b){var c=0,d=0,e=0,f=0;c=Ab(a);a:{if((c|0)!=(Ab(b)|0)){break a}d=Jb(a);b=Jb(b);b:{if(!De(a)){if(c){break b}return 1}return!Vo(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function Rp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(e*.16666666666666632+(d*(b*.5-e*f)-b))}function sm(a){var b=0,c=0,d=0,e=0;Zp(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=wb(d);v[22708]=0;b=b-12|0;R(181,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[d+4>>2]=e;mm(wb(a),v[a>>2],ug(a))}}function oma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,274);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,274)}}function kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,106);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,106)}}function hqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,136);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,136)}}function g4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+4|0;d=d+4|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=Gu(a+8|0,d);v[22708]=0;Q(1653,a+20|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Lt(a){var b=0,c=C(0),d=0;if(w[a+4232|0]>=5){t[a+4232|0]=0}if(t[a+4233|0]<=-1){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<=-1){t[a+4234|0]=127;b=127}d=a;a:{if((BM(a)|0)==3){c=C(C(1)-oe(C(2),C(-C((b&255)+1|0))));break a}c=oe(C(2),C(-C((b&255)>>>0)))}z[d+4224>>2]=c}function zK(a){var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;b=a+120|0;Ci(b);c=gb-16|0;gb=c;v[c+8>>2]=d+8;a=gb-16|0;gb=a;e=v[13838];v[a+8>>2]=v[13837];v[a+12>>2]=e;e=v[13836];v[a>>2]=v[13835];v[a+4>>2]=e;b=kb[v[Rh(a,Yg(b))>>2]](c+8|0,b)|0;gb=a+16|0;gb=c+16|0;gb=d+16|0;return b}function hW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,284);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,284)}}function ZS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=zd(b);f=ff(b);e=zd(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=d;v[c+8>>2]=e;if(Gb(c+24|0,c+16|0)){while(1){d=c+24|0;f=Yq(t[v[d>>2]]);e=c+8|0;t[v[e>>2]]=f;Oe(d);Oe(e);if(Gb(d,c+16|0)){continue}break}}gb=c+32|0;Dc(a,b)}function PF(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Fc(d,a);v[22708]=0;a=T(21,d|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;a=Q(22,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}Wb(c+8|0);gb=c+16|0;return a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=vh(a);a:{d=sf(b);if(d){v[22708]=0;R(1117,a|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}c=gb-16|0;gb=c;e=v[b>>2];f=v[b+4>>2];b=fs(c,a,d);kv(e,f,b+4|0);$b(b);gb=c+16|0}return a|0}a=P()|0;O()|0;Mf(c);S(a|0);L()}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,42);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,42)}}function jma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,72);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,72)}}function fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,34);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,34)}}function hl(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function UN(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){$i(c);fT(c);aj(c);$i(c);tB(wb(c),v[c>>2],aj(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}kp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function TZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,59);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,59)}}function OK(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function IQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function ER(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[e+16>>2]=b;b=MT(c-+(b<<2));v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=b;v[a+12>>2]=jb}function CD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,50);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,50)}}function yka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){t[c+16|0]=0;a=4;while(1){t[b|0]=w[c+16|0];b=b+1|0;a=a-1|0;if(a){continue}break}break a}nC(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function xh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function sF(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(e);v[22708]=0;b=b-12|0;R(279,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[e+4>>2]=d;mm(wb(a),v[a>>2],ug(a))}}function Zpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,64)){a=gb-16|0;gb=a;d=b- -64|0;while(1){If(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}tD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function QM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){d=b;if(b>>>0>2097151){rd(8445);L()}f=Nc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<11)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function rl(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=qt(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Wh(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function HQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=zb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f|0}function Rs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=ba(16)|0;xH();a=td(c+8|0,a,90816);v[22708]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2437,d|0,c|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(d|0,79216,2438);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function Fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-32|0;gb=e;f=fg(a,c);d=e+8|0;se(d,v[a+28>>2]);g=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=g;a:{b:{if(!f){d=-1;if(!nd(a,5)){break b}break a}d=v[f+8>>2]}EO(v[a+28>>2],b,d)}Zf(a,f,c,e+24|0);gb=e+32|0}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,27)){a=gb-16|0;gb=a;d=b+27|0;while(1){If(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}NR(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function hV(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,32)){a=gb-16|0;gb=a;d=b+32|0;while(1){If(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}dV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function hC(a){var b=0,c=0,d=0;if(v[a>>2]){c=a;b=v[a+4>>2];d=v[a>>2];if((b|0)!=(d|0)){while(1){b=b-24|0;xb(b);if((b|0)!=(d|0)){continue}break}}v[c+4>>2]=d;c=v[a>>2];a=hv(a);v[22708]=0;Oc(c,B(a,24),4);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function ST(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=90840;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function Qha(a){a=a|0;var b=0,c=0,d=0;c=gb-32|0;gb=c;b=255;a:{if(Ri(a)>>>0<=49){b=gB(c,v[a+12>>2]);v[22708]=0;R(1091,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}Zm(b);Si(a,Ri(a)-1&255);b=Ri(a)-1|0}gb=c+32|0;return b&255}a=P()|0;O()|0;Zm(b);S(a|0);L()}function O$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Sg(a,v[b+8>>2],0)){fx(b,c,d);return}e=v[a+12>>2];f=a+16|0;wG(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){wG(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function Hv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-48;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){gY(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/48|0)}}function yY(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;Iv(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){lD(b)}return a}function nU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;GX(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){HX(b)}return a}function jD(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;$X(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){aY(b)}return a}function iW(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;cW(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){bW(b)}return a}function gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;QV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Ok(b)}}function gG(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;TF(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Mw(b)}return a}function dO(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=c;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=f;v[a+8>>2]=e;v[a+12>>2]=d;v[a>>2]=b;v[a+4>>2]=f;d=!QS(a+8|0,a)}gb=c+32|0;return d}function ck(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;es(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){jm(b)}return a}function _C(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;GX(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){HX(b)}return a}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=aq(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);yi(d+(e<<2)|0,b,c);b=c+e|0;jh(a,b);v[f+12>>2]=0;Fe(d+(b<<2)|0,f+12|0);break a}pI(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function Wma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,2)){a=gb-16|0;gb=a;d=b+2|0;while(1){If(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}QV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function WU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;RU(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){SU(b)}return a}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;an(a,b);e=c,f=Vb(a),v[e+8>>2]=f;e=c,f=Zb(a),v[e>>2]=f;if(Gb(c+8|0,c)){b=0;while(1){a=c+8|0;d=v[a>>2];b=zb(w[d|0])+(b&255)|0;e=d,f=zb(b&255),t[e|0]=f;Oe(a);if(Gb(a,c)){continue}break}}gb=c+16|0}function BV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;pV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){qV(b)}return a}function rv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-6;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){JC(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/6|0)}}function kd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b>>2];g=v[b+8>>2];f=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=f;h=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=f;kb[h|0](a,e,g,d);i=b,j=yb(a)+v[b+8>>2]|0,v[i+8>>2]=j;gb=d+16|0}function dv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;dV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){WB(b)}}function yt(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=12;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){e=zo(a);v[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}}gb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,1100);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Rt(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-2048;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){NM(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]>>11)}}function Qu(a){var b=0,c=0;a:{if(w[a+4|0]|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1414687062){break a}b=a+6|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function Pz(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=mw(f,c);d=e+8|0;g=a+1074312|0;Db(d,g,31);a=0;if(!Cb(d)){Db(e,g,93);a=Cb(e)^1}if(!(t[lO(b,c)+6|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=cd(f)^1}gb=e+16|0;return d}function Pq(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=Nl(a,b);if((e|0)==255){break a}if(vk(a)){break a}b=YA(a+314|0,e);e=SR(e);if(f=1,g=t[ic(b,10)|0]&1,h=d,h?f:g){Yh(v[a>>2],e- -64&65535,RR(c,w[ic(b,2)|0]))}if(d){break a}Yh(v[a>>2],e+67&65535,RR(c,w[ic(b,3)|0]))}}function GG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83728;b=v[a+8>>2];v[22708]=0;c=ga(2478)|0;d=v[22708];v[22708]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[22708]=0;Dx(b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Bb();L()}return a|0}function YD(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}jb=a;return b}function V2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(2482,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);_G(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function U2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(2482,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);ZG(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function PI(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=PI(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function EK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;u[c+10>>1]=0;u[c+8>>1]=65535;a:{if(Et(c+12|0,c+10|0,c+8|0)){a=a+24|0;d=0;if(!me(v[a>>2]+484344|0,b&65535)){break a}d=v[_b(v[a>>2]+484344|0,b)+12>>2];break a}d=0}a=d;gb=c+16|0;return a|0}function $M(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;c=d+16|0;e=a;a=d+28|0;co(c,e,d+24|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=4;Fb(a,c);v[d+16>>2]=v[d+24>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gb=d+32|0}function zka(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=wd(b+8|0,b+24|0,6);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);a:{if((yb(c)|0)!=6){break a}if(sd(b+24|0,1024,6)){break a}Rb(a,6);e=1}gb=b+32|0;return e|0}function roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;e=d+8|0;VE(e,a);HW(c+24|0,e);gb=d+16|0;Dg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function Sna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-2496|0;gb=c;TU(b,c,c+2496|0);b=hc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}gb=c+2496|0;return a|0}function Joa(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;t[b+30|0]=0;u[b+28>>1]=0;c=wd(b+8|0,b+28|0,3);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);a:{if((yb(c)|0)!=3){break a}if(sd(b+28|0,11950,3)){break a}Rb(a,3);e=1}gb=b+32|0;return e|0}function zE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,37);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,37)}}function mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(814,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(815,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bs(d);S(a|0);L()}return a|0}function kx(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[22708]=0;c=ga(2478)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[22708]=0;Dx(b);b=v[22708];v[22708]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Bb();L()}return a|0}function a3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(21,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);bH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,16);a:{if(!d){a=b+16|0;while(1){t[b|0]=0;b=b+1|0;if((a|0)!=(b|0)){continue}break}break a}gw(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function $2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(21,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);aH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function wW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,33)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){CC(a);a=v[c>>2]+33|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function wT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<8)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){BB(a);a=v[c>>2]+256|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function s5(a){a=a|0;var b=0,c=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<c>>>0){Xn(a,v[a+8>>2],v[a+12>>2],c)}b=v[a+16>>2];a=v[a+12>>2];if(b>>>0<=a>>>0){break a}return Lg(t[a|0])|0}return-1}function nX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(617,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(618,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;wv(d);S(a|0);L()}return a|0}function UZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(333,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(334,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;sv(d);S(a|0);L()}return a|0}function TD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(389,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(390,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(d);S(a|0);L()}return a|0}function Mv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(488,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(489,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(d);S(a|0);L()}return a|0}function Az(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;c=vf(a);e=b,f=Vb(a),v[e+8>>2]=f;e=b,f=Zb(a),v[e>>2]=f;if(Gb(b+8|0,b)){d=+(c>>>0);while(1){c=b+8|0;a=v[c>>2];A[a>>3]=A[a>>3]/d;A[a+8>>3]=A[a+8>>3]/d;Zo(c);if(Gb(c,b)){continue}break}}gb=b+16|0}function AP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075080>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,872)+a|0)+1075778>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function en(a){var b=0,c=0,d=0,e=0;ev(a);if(v[a>>2]){c=a;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}wb(c);v[22708]=0;b=b-32|0;e=v[22708];v[22708]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[c+4>>2]=d;mV(wb(a),v[a>>2],bi(a))}}function ag(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;u[c+30>>1]=0;d=c+30|0;v[c+8>>2]=d;v[c+12>>2]=d+2;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;nt(d,a,c);a=yb(d);u[c+16>>1]=x[c+30>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;gb=c+32|0;return(a|0)==2|0}function ae(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-1;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){$k(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]|0)}}function Zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;qC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;uD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function BI(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){kb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function pW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;OX(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function lj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;es(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function kT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Nj(b,a,Ab(c)+a|0);break c}iT(d,c);v[22708]=0;U(57,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(d)}gb=d+16|0;break a}a=P()|0;O()|0;Ic(d);S(a|0);L()}}function RW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,48)+e;if(v[c>>2]!=v[c+4>>2]){while(1){QW(v[c>>2]);a=v[c>>2]+48|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0}function Lm(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{switch(c|0){case 2:e=BP(a,b,d);if((e-1&255)>>>0<250){break a}case 0:return AP(a,b,d);case 3:e=AP(a,b,d);if((e-1&255)>>>0<250){break a}break;case 1:break b;default:break a}}e=BP(a,b,d)}return e}function Jw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<3)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){jm(a);a=v[c>>2]+8|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function cC(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[ic(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;e=ct(a);v[a>>2]=77316;f=Kb(a+32|0);v[a+48>>2]=c;v[a+44>>2]=0;v[22708]=0;R(108,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){gb=d+16|0;return a|0}a=P()|0;O()|0;vb(f);ym(e);S(a|0);L()}function HD(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,512)){a=gb-16|0;gb=a;d=b+512|0;while(1){_j(b);b=b+4|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}Sv(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function EY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=En(d+8|0,a+8|0,vD(b,c));c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){b=d+24|0;Er(c,v[b>>2]);v[a>>2]=v[a>>2]+2;Qv(b);c=v[a>>2];if((c|0)!=v[a+4>>2]){continue}break}}_c(a);gb=d+32|0}function tT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Nj(b,a,Ab(c)+a|0);break c}DT(d,b,c);v[22708]=0;R(58,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(d)}gb=d+16|0;break a}a=P()|0;O()|0;Ic(d);S(a|0);L()}}function eoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=fg(a,c);se(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}iX(v[a+28>>2],b,v[e+24>>2],0)}Zf(a,d,c,e+16|0);gb=e+32|0}function lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);e=x[d+12>>1];Bf(a,e);if(e){c=0;while(1){f=w[b+c|0];g=gj(a,c),h=f,u[g>>1]=h;c=c+1|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0}function hX(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=zb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+18848|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Ft(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22708]=0;T(1292,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){yd(a+68|0);Yf(a+36|0);hq(a+32|0);Fi(b);Ei(a+4|0);eg(a);return a}V(0)|0;O()|0;yd(a+68|0);Yf(a+36|0);hq(a+32|0);Fi(b);Ei(a+4|0);eg(a);Bb();L()}function Bp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Kc(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Qg(d+e|0,b,c);b=c+e|0;jh(a,b);t[f+15|0]=0;Bd(b+d|0,f+15|0);break a}vp(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=fg(a,c);se(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}jN(v[a+28>>2],b,v[e+24>>2])}Zf(a,d,c,e+16|0);gb=e+32|0}function JP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=Uc(Qm(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=tk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Uc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function Hk(a,b){var c=0,d=0;c=gb-32|0;gb=c;v[c+28>>2]=0;cX(c+8|0,c+28|0);d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;nt(d,a,c);a=yb(d);v[c+16>>2]=v[c+28>>2];v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);gb=c+32|0;return(a|0)==4}function vV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;pV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){qV(b)}}function qO(a,b){var c=0,d=0,e=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}d=b;c=v[c>>2];b:{if(c){e=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[e+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[d>>2]=a}}function T2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22708]=0;b=T(2482,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(a);YG(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function OC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=mc(a+8|0);v[22708]=0;d=T(467,b|0)|0;e=v[22708];v[22708]=0;b:{if((e|0)==1){break b}v[22708]=0;U(393,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;gc(c);S(a|0);L()}}function H4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}b=b+4|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Kk(b,4,c,v[a+32>>2])|0}function _A(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(w[a+530|0]){while(1){d=c&65535;Qi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;oi(a+4|0,18,b+15|0);mv(a+22|0,18,35498);t[b+14|0]=255;oi(a+58|0,256,b+14|0);gb=b+16|0}function Ku(a){a=a|0;var b=0,c=0,d=0,e=0;c=TS(a);if((c|0)!=(a|0)){while(1){b=0;e=a;gX(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Qb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function Epa(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!jD(a,b+16|0)){break a}c=0;if(!cY(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!bd(a,4)){break a}}c=-1;if(!ck(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}gb=b+32|0;return c|0}function g7(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=a;if(!w[c+8|0]){d=c+12|0;Nk(d,v[c+4>>2]);Ud(b+24|0,d);d=v[v[c>>2]+40>>2];e=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=e;kb[d|0](b+16|0,c,0,b+8|0);t[c+8|0]=1}gb=b+32|0;return v[a+12>>2]}function _2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22708]=0;b=T(21,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(a);$G(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function Qp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function DF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=wi(e,e+12|0);v[22708]=0;a=W(2499,a|0,c|0,v[e+8>>2])|0;c=v[22708];v[22708]=0;if((c|0)!=1){gf(b);gb=e+16|0;return a|0}a=P()|0;O()|0;gf(b);S(a|0);L()}function bN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){_e(a,c);d=a;break a}f=Wk(d)+1|0;d=pi(a,f);df(a,d);rg(a,f);de(a,c)}Qg(d,b,c);t[e+15|0]=0;Bd(c+d|0,e+15|0);gb=e+16|0;return}bg();L()}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){yO(e,v[d+4>>2],v[d+8>>2])}hc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function AL(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;v[b>>2]=0;t[c+15|0]=0;Uh(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;d=d&3;if(d){while(1){t[c+15|0]=0;Uh(a,c+15|0);e=e+1|0;v[b>>2]=v[b>>2]|w[c+15|0]<<(e<<3)-2;if((d|0)!=(e|0)){continue}break}}gb=c+16|0}function xe(){var a=0,b=0;a:{b:{if(t[464228]&1){break b}if(!Qd(464228)){break b}v[22708]=0;a=W(2480,2147483647,11509,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}v[116056]=a;Pd(464228)}return v[116056]}a=P()|0;O()|0;$e(464228);S(a|0);L()}function ppa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(517,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(518,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(c);S(a|0);L()}return a|0}function Wu(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){d=b;if(b>>>0>=357913942){rd(8445);L()}f=Nc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Sma(a,b){a=a|0;b=b|0;var c=0,d=0;c=vh(a);a:{if(!b){break a}v[22708]=0;R(775,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(776,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;hC(c);S(a|0);L()}return a|0}function RP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Mc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=FP(c&255),v[e+44>>2]=f}gb=d+16|0}function JY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){d=b;if(b>>>0>=153391690){rd(8445);L()}f=Nc(B(d,28),4)}v[a>>2]=f;c=B(c,28)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,28)+f|0,v[g>>2]=h;gb=e+16|0;return a}function pX(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(488,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(606,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(c);S(a|0);L()}return a|0}function QF(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){d=b;if(b>>>0>119304647){rd(8445);L()}f=Nc(B(d,36),4)}v[a>>2]=f;c=B(c,36)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,36)+f|0,v[g>>2]=h;gb=e+16|0;return a}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(335,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(336,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;rE(c);S(a|0);L()}return a|0}function mW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,18);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=gb-32|0;gb=e;c=b+4|0;b=v[c+48>>2];a:{if(b&16){b=v[c+44>>2];d=v[c+24>>2];if(b>>>0<d>>>0){v[c+44>>2]=d;b=d}Nj(a,v[c+20>>2],b);break a}if(b&8){Nj(a,v[c+8>>2],v[c+16>>2]);break a}Kb(a)}gb=e+32|0}function iY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){d=b;if(b>>>0>89478485){rd(8445);L()}f=Nc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,48)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Vt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;a:{e=!b|!c;if(!e){b=Tb(d,b);v[22708]=0;U(1478,d+16|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}c=a+36|0;a=d+16|0;Eb(c,a);vb(a);vb(b)}gb=d+32|0;return!e}a=P()|0;O()|0;vb(b);S(a|0);L()}function TX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=zy(d+8|0,a+8|0,UX(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){b=d+24|0;lp(v[a>>2],v[b>>2]);v[a>>2]=v[a>>2]+1;Oe(b);if(v[a>>2]!=v[a+4>>2]){continue}break}}_c(a);gb=d+32|0}function Re(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a+8|0);v[22708]=0;U(393,a|0,b|0,c|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){a=v[a>>2];v[22708]=0;Q(318,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;gc(d);S(a|0);L()}}function LQ(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function EF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,20);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function WQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){d=b;if(b>>>0>=613566757){rd(8445);L()}f=Nc(B(d,7),1)}v[a>>2]=f;c=B(c,7)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,7)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=-1;a:{if(!gG(a,c+8|0)){break a}d=0;if(!ON(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}gb=c+32|0;return d|0}function ME(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,1);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function M7(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=v[v[b>>2]+(a<<2)>>2]+(c<<3)|0;v[d>>2]=0;v[d+4>>2]=0;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function FI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function NG(a){var b=0,c=0,d=0;d=gb-16|0;gb=d;b=d;v[b>>2]=465840;c=v[116461];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);c=b;a=v[b+4>>2];b=v[b+8>>2];if((a|0)!=(b|0)){while(1){Yo(a);a=a+4|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(c);gb=d+16|0}function oV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;nV(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function mY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Iv(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function mF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;cs(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function is(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Ai(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function eY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;gw(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function aW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;$V(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function __(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[b+8>>2];if(f>>>0>c>>>0){v[e+12>>2]=f-c;h=e,i=yb(d),v[h+8>>2]=i;f=Fb(e+12|0,e+8|0);b=v[b+4>>2]+c|0;g=v[f>>2];Rg(b,b+g|0,v[d>>2])}mk(a,d,g);gb=e+16|0}function _X(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;$X(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function ZX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;tD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Yv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Xv(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Tv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;tn(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function SF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;TF(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function RV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;nC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function QD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;PD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Mg(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Vr(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function ET(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;nC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(b|0)){bd(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Dp(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Bn(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=0;a:{if(!Nb(a)){break a}while(1){gg(d,v[Mb(a,e)>>2]+40|0);c=ur(d,b);vb(d);if(c){c=v[Mb(a,e)>>2];break a}e=e+1|0;if(Nb(a)>>>0>e>>>0){continue}break}c=0}gb=d+16|0;return c|0}function Uh(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;t[c+24|0]=0;d=c+24|0;v[c+8>>2]=d;v[c+12>>2]=d+1;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;nt(d,a,c);a=yb(d);t[c+16|0]=w[c+24|0];t[b|0]=w[d|0];gb=c+32|0;return(a|0)==1|0}function Nq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=131072/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-ee(f*A[ye(a,c)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Pe(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function Fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;hY(a);wb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Xj(a);mn(a);mn(a)}function jO(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ac(oqa(nqa(d,d>>31,g,h),jb,256,0),jb);v[a+4>>2]=f-d;v[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function bna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22708]=0;R(296,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}
function aka(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(333,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;aT(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;sv(c);S(a|0);L()}return a|0}function Vma(a,b){a=a|0;b=b|0;var c=0,d=0;c=vh(a);a:{if(!b){break a}v[22708]=0;R(773,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;lr(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ci(c);S(a|0);L()}return a|0}function LI(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-16;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Yn(v[a+16>>2],b,Qx(a))}}function vpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22708]=0;R(396,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function Tg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function QA(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-8;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){PA(v[a+16>>2],b,zF(a))}}function eW(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Og(a)>>>0<b>>>0){d=wb(a);b=Fn(c+8|0,b,tc(a),d);v[22708]=0;R(313,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Hh(b)}gb=c+32|0;return}a=P()|0;O()|0;Hh(b);S(a|0);L()}function WE(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=v[a+4>>2];d=e+b|0;v[a+4>>2]=d;a:{b:{if(!e){g=d-1|0;break b}g=d-1|0;if((g^e-1)>>>0<32){break a}}v[v[a>>2]+((d>>>0<33?0:g>>>5|0)<<2)>>2]=0}d=f+8|0;yp(d,a,e);xp(d,b,c);gb=f+16|0}function Id(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){u[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function ig(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Pe(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function fn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=Ui(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function cH(){var a=0,b=0,c=0;b=gb-16|0;gb=b;a=Tb(b,12535);a:{if(!Ab(a)){break a}c=1;if((vg(a,11846)|0)!=-1){break a}if((vg(a,13873)|0)!=-1){break a}if((vg(a,11038)|0)!=-1){break a}c=(vg(a,11081)|0)!=-1}vb(a);gb=b+16|0;return c|0}function AD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){d=b;if((b|0)<=-1){rd(8445);L()}f=Nc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function _B(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);h=b,i=yb(a)+v[b+12>>2]|0,v[h+12>>2]=i;gb=d+16|0}function Xc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Nf(b);e=gb-16|0;gb=e;c=Kc(a);a:{if(c>>>0>=d>>>0){c=Jb(a);em(c,b,d);t[e+15|0]=0;Bd(d+c|0,e+15|0);jh(a,d);break a}f=c;g=d-c|0;c=Ab(a);vp(a,f,g,c,0,c,d,b)}gb=e+16|0;return a|0}function Qd(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;a=ix(c,a);d=gb-16|0;gb=d;if(!w[v[yc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}gb=d+16|0;gb=c+16|0;return b}function JR(a,b){var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(1119,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(1120,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;BR(c);S(a|0);L()}return a}function DU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=BU(c+8|0,c);gb=c+32|0;return a}function yfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(ug(a)>>>0<b>>>0){d=wb(a);b=ts(c+8|0,b,Ec(a),d);v[22708]=0;Nn(a,b);a=v[22708];v[22708]=0;if((a|0)==1){break a}wu(b)}gb=c+32|0;return}a=P()|0;O()|0;wu(b);S(a|0);L()}function ws(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;if(b){e=Kc(a);d=Ab(a);g=d+b|0;if(e-d>>>0<b>>>0){Ym(a,e,g-e|0,d,d,0,0)}e=d;d=Jb(a);Hr(e+d|0,b,c);jh(a,g);t[f+15|0]=0;Bd(d+g|0,f+15|0)}gb=f+16|0;return a|0}function vA(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[a+104>>2];if(d){v[a+88>>2]=v[a+88>>2]&-131|128;d=v[d>>2];v[a+76>>2]=d;v[c+12>>2]=b<<8;v[c+8>>2]=d-1;b=d+(v[Fb(c+12|0,c+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}gb=c+16|0}function mO(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){d=zo(a);v[b+12>>2]=7;v[b+8>>2]=32;c=c+15|0;if(c>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}gb=b+16|0;return c}function Upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;es(d,b);d=yb(d);b=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=b;v[c>>2]=e;v[c+4>>2]=b;b=c+16|0;cc(b,a,c);if((yb(b)|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0}function LK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function KK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function l4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=dt(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Cd(c);v[f>>2]=a;if(!a){break a}e=dt(a,c,b,v[d+12>>2])}gb=d+16|0;return e|0}function fu(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=49516;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=49532;break a;case 2:c=49528;break a;case 1:break b;case 0:break c}}c=49524;break a}c=49520}v[a>>2]=v[c>>2]}function cY(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function LN(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=Vb(a),v[e+8>>2]=f;c=d+24|0;b=b+B(Wt(c,d+8|0),6)|0;if(Gb(c,d+16|0)){RC(a,pz(b+B(Wt(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}Gg(b);gb=d+32|0}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[a+480180>>2]=b;kA(c,yq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;fu(a+8|0,yq(a));gb=c+16|0}function NK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function MK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function GO(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function uma(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+30>>1]=0;c=wd(b+8|0,b+30|0,2);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);if(!((yb(c)|0)!=2|x[b+30>>1]!=21584)){Rb(a,2);e=1}gb=b+32|0;return e|0}function fP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;b=fs(d,a,b);a=v[b+4>>2];e=v[b+8>>2];if((a|0)!=(e|0)){while(1){f=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=f;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(e|0)){continue}break}}$b(b);gb=d+16|0}function PU(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){MY(c);yD(v[c>>2],aj(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);d=wb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function ys(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){_e(a,c);e=a;break a}f=Wk(c)+1|0;e=pi(a,f);df(a,e);rg(a,f);de(a,c)}Qg(e,b,c);t[d+15|0]=0;Bd(c+e|0,d+15|0);gb=d+16|0;return}bg();L()}function qt(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!gy(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Me(a)}return b}aa(12806,10534,1578,2521);L()}function oU(a,b,c){var d=0;d=gb-16|0;gb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|b>>>0>=c>>>0|b>>>0>=109|c>>>0>=109)){t[d+14|0]=(x[(b<<1)+39070>>1]-x[(c<<1)+39070>>1]|0)/5;a=w[ac(d+15|0,d+14|0)|0]}gb=d+16|0;return a&255}function nu(a,b){var c=0,d=0;c=B(b,872)+a|0;a:{if(v[c+1075080>>2]&134218752){break a}if(!sk(c+1074992|0)){break a}b=w[v[(B(b,872)+a|0)+1075648>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function cT(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function Zg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=pi(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=b+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Mt(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22708]=0;R(120,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function Kca(a){a=a|0;var b=0;kb[v[v[a>>2]+128>>2]](a);_y(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=kb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function BA(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=v[a+480208>>2];d=c,e=(Sp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;WP(c+8|0,127);a=gn(A[c+8>>3]);gb=c+16|0;return a|0}function lW(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function To(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=d+8|0;Db(e,c+1074312|0,102);a:{if(!Cb(e)){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;gb=d+16|0}function PV(a){var b=0,c=0;a:{if(sd(a,12213,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function MG(){var a=0;a:{b:{if(t[464240]&1){break b}if(!Qd(464240)){break b}v[22708]=0;X(2564);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116059]=464232;Pd(464240)}return v[116059]}a=P()|0;O()|0;$e(464240);S(a|0);L()}function E1(){var a=0;a:{b:{if(t[464252]&1){break b}if(!Qd(464252)){break b}v[22708]=0;X(2565);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116062]=464244;Pd(464252)}return v[116062]}a=P()|0;O()|0;$e(464252);S(a|0);L()}function x0(a){a=a|0;a:{b:{if(t[464352]&1){break b}if(!Qd(464352)){break b}v[22708]=0;X(2589);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116087]=465456;Pd(464352)}return v[116087]}a=P()|0;O()|0;$e(464352);S(a|0);L()}function t0(a){a=a|0;a:{b:{if(t[464360]&1){break b}if(!Qd(464360)){break b}v[22708]=0;X(2591);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116089]=465488;Pd(464360)}return v[116089]}a=P()|0;O()|0;$e(464360);S(a|0);L()}function sU(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function UR(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function J0(a){a=a|0;a:{b:{if(t[464320]&1){break b}if(!Qd(464320)){break b}v[22708]=0;X(2581);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116079]=464496;Pd(464320)}return v[116079]}a=P()|0;O()|0;$e(464320);S(a|0);L()}function G0(a){a=a|0;a:{b:{if(t[464328]&1){break b}if(!Qd(464328)){break b}v[22708]=0;X(2583);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116081]=464672;Pd(464328)}return v[116081]}a=P()|0;O()|0;$e(464328);S(a|0);L()}function D0(a){a=a|0;a:{b:{if(t[464336]&1){break b}if(!Qd(464336)){break b}v[22708]=0;X(2585);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116083]=464848;Pd(464336)}return v[116083]}a=P()|0;O()|0;$e(464336);S(a|0);L()}function A0(a){a=a|0;a:{b:{if(t[464344]&1){break b}if(!Qd(464344)){break b}v[22708]=0;X(2587);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116085]=465152;Pd(464344)}return v[116085]}a=P()|0;O()|0;$e(464344);S(a|0);L()}function wk(a){a=a|0;qc(a+16|0,v[a>>2]);qc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=dd(a);e=Ik(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22708]=0;R(1124,a|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;sR(e);xR(d);S(a|0);L()}function nqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;jb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function fT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22708]=0;b=b-28|0;R(957,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function cG(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22708]=0;b=b-36|0;R(214,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function c6(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{if(wr(b,7535)){mI(c,14678,b);a=Jb(c);v[22708]=0;R(2294,44,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);S(a|0);L()}gb=c+16|0;return a|0}L()}function bA(a,b,c){var d=0;a:{if(x[a+480192>>1]){if(!ve(b)|x[a+480192>>1]<c>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[vd(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=Te(b);c=lT(d+8|0,c);v[22708]=0;Y(949,a|0,b|0,e-1&65535,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){Ye(c);gb=d+32|0;return}a=P()|0;O()|0;Ye(c);S(a|0);L()}function hy(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!pt(a)){break a}if(!(t[a+1375|0]&1)){continue}break}ec(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Sca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){v[d+8>>2]=0;v[d+4>>2]=1065353216;e=(a+b|0)+4232|0,f=ch(C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(127))),t[e|0]=f;Lt(a)}gb=d+16|0}function MT(a){a=+a;a=a*4294967296;if(D(a)<0x8000000000000000){jb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0|0}jb=-2147483648;return 0}function GL(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=tf(12);b=v[b>>2];a=v[a>>2];v[22708]=0;a=FL(d,a,b);b=v[22708];v[22708]=0;if((b|0)!=1){a=v[Yi(c+8|0,a)>>2];gb=c+16|0;return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Tna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Gb(d+16|0,d+24|0)){while(1){b=d+16|0;v[d+12>>2]=v[v[b>>2]>>2];aD(a,d+12|0);Qe(b);if(Gb(b,d+24|0)){continue}break}}gb=d+32|0}function QX(a){var b=0,c=0,d=0;b=v[a>>2];c=gD(a);d=gb-16|0;gb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=zn(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}gb=d+16|0;return v[b>>2]}function Nba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=12){Ji(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(fe(C(c*C(3)))/C(3));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}gb=d+16|0}function N7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=hr(b,a,c),e=0,v[d>>2]=e;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function Coa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,12);a:{if(!d){t[c+16|0]=0;oi(b,12,c+16|0);break a}PW(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function $n(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function tG(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Mp(d,a,1);a=wb(a);e=v[c+4>>2];v[22708]=0;On(a,e,b);a=v[22708];v[22708]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function o0(a){a=a|0;a:{b:{if(t[464392]&1){break b}if(!Qd(464392)){break b}v[22708]=0;Q(2594,464380,83892)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464392)}return 464380}a=P()|0;O()|0;$e(464392);S(a|0);L()}function k0(a){a=a|0;a:{b:{if(t[464424]&1){break b}if(!Qd(464424)){break b}v[22708]=0;Q(2594,464412,83928)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464424)}return 464412}a=P()|0;O()|0;$e(464424);S(a|0);L()}function f0(a){a=a|0;a:{b:{if(t[464456]&1){break b}if(!Qd(464456)){break b}v[22708]=0;Q(2594,464444,83964)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464456)}return 464444}a=P()|0;O()|0;$e(464456);S(a|0);L()}function b0(a){a=a|0;a:{b:{if(t[464488]&1){break b}if(!Qd(464488)){break b}v[22708]=0;Q(2594,464476,84048)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464488)}return 464476}a=P()|0;O()|0;$e(464488);S(a|0);L()}function YQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=En(d,a+8|0,_q(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){So(v[a>>2],b);c=v[a>>2]+2|0;v[a>>2]=c;b=b+2|0;if(v[a+4>>2]!=(c|0)){continue}break}}_c(a);gb=d+16|0}function SH(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=kb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!He(b,-1)){break a}v[a>>2]=0}return a|0}function PP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;c=d+8|0;Db(c,a+1074312|0,80);if(!(!Cb(c)|!e)){t[b+824|0]=w[b+824|0]<<2}gb=d+16|0}function FR(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=A[a>>3]*b+c*A[a+8>>3]+e*A[a+16>>3]-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function $v(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function rW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Eg(d,a,1);a=wb(a);e=v[c+4>>2];v[22708]=0;hn(a,e,b);a=v[22708];v[22708]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function oqa(a,b,c,d){var e=0,f=0,g=0;f=(b^d)>>31;e=b>>31;a=a^e;g=a-e|0;a=(b^e)-((a>>>0<e>>>0)+e|0)|0;e=d>>31;b=c^e;a=qqa(g,a,b-e|0,(e^d)-((e>>>0>b>>>0)+e|0)|0)^f;b=a-f|0;jb=(f^jb)-((a>>>0<f>>>0)+f|0)|0;return b}function lM(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Bi(d,a,1);a=wb(a);e=v[c+4>>2];v[22708]=0;ql(a,e,b);a=v[22708];v[22708]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Xz(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}hc(a+24604|0,b,40);tO(a,c)}function PC(a,b){var c=0,d=0,e=0,f=0;c=a<<8&16711680|a<<24;d=b<<24|a>>>8;e=d&65280;d=b<<8|a>>>24;c=d&255|e|c;a=((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|f;jb=c;return a}function tk(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=v[a+24>>2];d=v[a+40>>2];v[22708]=0;v[b+12>>2]=1;a=Mc(a+20|0,b+12|0);e=v[22708];v[22708]=0;if((e|0)!=1){gb=b+16|0;return B(v[a>>2],c+d|0)}V(0)|0;O()|0;Bb();L()}function o2(){var a=0;a=gb-16|0;gb=a;v[116460]=0;v[116461]=0;v[a+12>>2]=0;Yo(465848);t[465976]=0;gb=a+16|0;v[22708]=0;X(2560);a=v[22708];v[22708]=0;if((a|0)!=1){NG(30);return}a=P()|0;O()|0;px(465840);S(a|0);L()}function m0(a){a=a|0;a:{b:{if(t[464408]&1){break b}if(!Qd(464408)){break b}v[22708]=0;Q(70,464396,11031)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464408)}return 464396}a=P()|0;O()|0;$e(464408);S(a|0);L()}function h0(a){a=a|0;a:{b:{if(t[464440]&1){break b}if(!Qd(464440)){break b}v[22708]=0;Q(70,464428,10825)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464440)}return 464428}a=P()|0;O()|0;$e(464440);S(a|0);L()}function Fw(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,3)){t[c+16|0]=0;oi(a,3,c+16|0);break a}d=gb-16|0;gb=d;bc(c+24|0,a,3);gb=d+16|0;a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=nk(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=kb[e|0](a,c)|0}else{a=1}gb=c+16|0;return a|0}function q0(a){a=a|0;a:{b:{if(t[464376]&1){break b}if(!Qd(464376)){break b}v[22708]=0;Q(70,464364,2361)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464376)}return 464364}a=P()|0;O()|0;$e(464376);S(a|0);L()}function d0(a){a=a|0;a:{b:{if(t[464472]&1){break b}if(!Qd(464472)){break b}v[22708]=0;Q(70,464460,6410)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464472)}return 464460}a=P()|0;O()|0;$e(464472);S(a|0);L()}function Wz(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;sO(a+24648|0);LO(a)}function lt(a){var b=0;if(a){if(v[a+76>>2]<=-1){return by(a)}return by(a)}if(v[22702]){b=lt(v[22702])}a=v[115188];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=by(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function lo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{if(c){Tb(d,c);break a}Kb(d)}v[22708]=0;U(13,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function fx(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function HU(a){var b=0,c=0,d=0;c=a;b=v[a+8>>2];d=v[a+4>>2];if((b|0)!=(d|0)){while(1){b=b-56|0;v[c+8>>2]=b;$u(b);b=v[c+8>>2];if((d|0)!=(b|0)){continue}break}}c=v[a>>2];if(c){Zu(c,(v[dc(a)>>2]-v[a>>2]|0)/56|0)}}function xd(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Mg(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}gb=c+16|0;break a}aa(8513,6236,136,11437);L()}return d}function wg(a){var b=0;v[22708]=0;a=T(1291,a|0)|0;b=v[22708];v[22708]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Bb();L()}function l8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Mp(e,a,d);wb(a);v[22708]=0;U(2091,b|0,c|0,d+4|0);a=v[22708];v[22708]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function PE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Mg(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}gb=c+16|0;break a}aa(8513,6236,136,11437);L()}return d}function G6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;kb[g|0](a,b,e,d);gb=e+16|0}function DR(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=fs(c,a,2048);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;v[a+4>>2]=0;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function iS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e>>2]=c;v[e+8>>2]=b;if(Gb(e+8|0,e)){while(1){b=e+8|0;xn(a,v[d>>2],v[b>>2]);of(b);v[d>>2]=v[d>>2]+2;if(Gb(b,e)){continue}break}}gb=e+16|0}function eP(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function dC(a,b,c){var d=0;d=gb-16|0;gb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Gb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}a=d+8|0;of(a);if(Gb(a,d)){continue}break}}gb=d+16|0;return v[d+8>>2]}function Wv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Lx(a){a=a|0;var b=0;v[a>>2]=78428;v[22708]=0;R(2387,a|0,0);b=v[22708];v[22708]=0;if((b|0)!=1){Wb(a+28|0);Yb(v[a+32>>2]);Yb(v[a+36>>2]);Yb(v[a+48>>2]);Yb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Bb();L()}function LO(a){var b=0,c=0;b=gb-544|0;gb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){ER(b,xf(a));c=a+1298224|0;a=a+1074992|0;while(1){hc(a+112|0,b,538);a=a+872|0;if((c|0)!=(a|0)){continue}break}}gb=b+544|0}function ts(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=hG(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function lR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-12|0;R(1133,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function fS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-32|0;R(1103,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function dD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=fE(v[a+16>>2],b)}v[a>>2]=f;c=B(c,20)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,20)+f|0,v[g>>2]=h;gb=e+16|0;return a}function XG(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-16|0;gb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){gi(g+13|0,g+14|0)}h=c,i=(ab(b|0,oS(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;gb=g+16|0}function Kv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Lb(128/(B(v[Hf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[qf(c+7|0,c+6|0)|0];gb=c+16|0;return a|b<<4&240}function BO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-52|0;R(1326,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){while(1){a=d;if(y[b>>2]<=127){e=x[Xp()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function ufa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){fO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=wo(d+8|0,kr(a,Nb(a)+1|0),Nb(a),c);wq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;VN(a,c);Gz(c);gb=d+32|0}function ou(a,b){a=hc(a,b,88);v[a+88>>2]=v[b+88>>2];hc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];hc(a+672|0,b+672|0,52);yo(a+724|0,b+724|0);yo(a+732|0,b+732|0);yo(a+740|0,b+740|0);hc(a+748|0,b+748|0,123)}function hla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;_U(c+24|0,a);Dg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function cE(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-20|0;R(348,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function aB(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){Mo(d);VR(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){fO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=wo(d+8|0,kr(a,Nb(a)+1|0),Nb(a),c);wq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;XS(a,c);Gz(c);gb=d+32|0}function zp(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=SE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function cg(a,b,c,d,e){var f=0;f=gb-256|0;gb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Qb(f,b&255,d?c:256);if(!d){while(1){uf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}uf(a,f,c)}gb=f+256|0}function Sba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;b=Ac(oqa(nqa(d,d>>31,b,0),jb,1e3,0),jb);v[a+16>>2]=0;v[a+12>>2]=b+c;aM(a,e);b=v[a+12>>2];v[f+12>>2]=0;nN(a,b,f+12|0);gb=f+16|0}function OS(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Dg(c+24|0,a);Dg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=QS(c+8|0,c);gb=c+32|0;return a|0}function LW(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=MW(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,6)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Fn(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=dF(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function wX(a){var b=0,c=0;b=a+36|0;c=nqa(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}jb=a;return b}function sK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Eg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;Wi(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function lP(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22708]=0;v[c>>2]=2147483647;v[c+4>>2]=0;a=Tk(c+8|0,c);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function jC(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=1073741823;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function eF(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=2147483647;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function aT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Eg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);Yo(b);b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function _d(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Cd(b)}return c}function GN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Ar(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);hi(b);b=b+6|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function CN(a){var b=0,c=0,d=0;if(Sf(a)){while(1){b=a;d=c&65535;if(Sf(b)>>>0>d>>>0){b=bf(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;KN(b);Se(b+36|0)}c=c+1|0;if(Sf(a)>>>0>(c&65535)>>>0){continue}break}}}function x1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]>127){break a}if(!(x[Xp()+(v[c>>2]<<1)>>1]&b)){break a}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function iG(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=357913941;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function gE(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=214748364;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=bq(e,a,d);v[22708]=0;U(2047,b|0,c|0,a+4|0);b=v[22708];v[22708]=0;if((b|0)!=1){$b(a);gb=e+16|0;return}b=P()|0;O()|0;$b(a);S(b|0);L()}function NW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=715827882;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function mp(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=1073741823;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}
function nt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;v[d+16>>2]=c;v[d+20>>2]=e;rh(d+24|0,d+8|0);c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;ry(a,b,d);gb=d+32|0}function lka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=RE(a);if(d>>>0>=b>>>0){a=Mu(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Mc(c+12|0,c+8|0)>>2]}gb=c+16|0;return d|0}Sc();L()}function a9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=v[a+24>>2];xL(d,c);v[22708]=0;U(560,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function a1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=wi(b+8|0,b+12|0);v[22708]=0;c=uI(0,0,4);d=v[22708];v[22708]=0;if((d|0)!=1){gf(a);gb=b+16|0;return c|0}b=P()|0;O()|0;gf(a);S(b|0);L()}function UU(a){var b=0,c=0,d=0,e=0;jb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function Qoa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=tf(2500);v[22708]=0;a=Q(48,c|0,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){a=v[Yi(b+8|0,a)>>2];gb=b+16|0;return a|0}a=P()|0;O()|0;Yb(c);S(a|0);L()}function tU(a){var b=0,c=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;b=w[a+1|0]<<8;if((w[a|0]|b)!=1&(b|w[a|0])!=2){break a}c=1}return c}function eR(a){var b=0,c=0,d=0;c=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;b=b-8|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=c}function dN(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break b}Fk(b+16|0)}if(b){Xk(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function OL(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(Dk(b-+(a|0)))}else{d=C(0)}return d}function OA(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break b}jR(b+16|0)}if(b){ks(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function MO(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break a}kb[v[v[b>>2]+96>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function Iw(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=536870911;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function FV(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=178956970;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function AT(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=134217727;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function AI(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=268435455;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function zi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?b>>>0<e>>>0&(c|0)<=(f|0)|(c|0)<(f|0)?b+g|0:d:d}function wN(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=82595524;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function EO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-16|0;gb=c;ag(a,c+14|0);UO(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Hk(a,Mb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}fA(b);gb=c+16|0}function uL(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=tf(1298432);v[22708]=0;c=T(2053,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){b=v[Yi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Yb(b);S(a|0);L()}function Jd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function GR(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function rk(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;b=c+8|0;Db(b,a+1074312|0,7);a:{if(Cb(b)){v[22708]=0;a=Zl(a);b=v[22708];v[22708]=0;if((b|0)==1){break a}d=a^1}gb=c+16|0;return d}V(0)|0;O()|0;Bb();L()}function Us(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Wx(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Wx(a)}return a}function BP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075648>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,872)+a|0)+1075096>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function Aj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function vF(a){var b=0;if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){b=(w[a+7|0]-9&255)>>>0<7}return b}function mS(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[a+16|0]=0;c=gB(b,v[a+12>>2]);v[22708]=0;R(1089,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){Zm(c);gb=b+32|0;return}a=P()|0;O()|0;Zm(c);S(a|0);L()}function lh(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ia(a|0,28304,206);L()}function dK(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=-1;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Qc(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22708]=0;v[c>>2]=-1;v[c+4>>2]=0;a=Tk(c+8|0,c);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Gv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function $0(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=wi(b+8|0,b+12|0);v[22708]=0;c=nH();d=v[22708];v[22708]=0;if((d|0)!=1){gf(a);gb=b+16|0;return c|0}b=P()|0;O()|0;gf(a);S(b|0);L()}function c$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Ip(a);v[a>>2]=27480;e=dc(a);d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;YF(e,c+8|0);gb=c+32|0;return a|0}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<oc(a)>>>0){a=po(d,lc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=Uy(c,a);Hb(a);e=b^1}gb=d+16|0;return e|0}function RK(a){a=a|0;var b=0;a=a+24|0;b=SK(v[a>>2]);if(Ti(Sb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074446>>1]}b=x[sc(Sb(v[a>>2]+484360|0),b)>>1];return(cm(v[a>>2]+484344|0,b)?b:-1)|0}function FG(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=e;e=wi(f+8|0,f+12|0);v[22708]=0;a=_p(a,b,c,d);b=v[22708];v[22708]=0;if((b|0)!=1){gf(e);gb=f+16|0;return a}a=P()|0;O()|0;gf(e);S(a|0);L()}function zg(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb+-64|0;gb=c;d=mz(c+8|0,a);v[22708]=0;U(1491,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){Km(d);gb=c- -64|0;return}a=P()|0;O()|0;Km(d);S(a|0);L()}function y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]<=127){if(x[Xp()+(v[c>>2]<<1)>>1]&b){break a}}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function wo(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){f=Yz(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function lr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Eg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){_j(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function lha(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=XT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){gR(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function dpa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,6)){t[c+16|0]=0;oi(a,6,c+16|0);break a}OX(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function bz(a){var b=0,c=0,d=0,e=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=zo(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}A[c+4280>>3]=C(C(a|0)*C(-4.656612873077393e-10))}function bS(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){f=dS(b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<5)+f|0,v[g>>2]=h;gb=e+16|0;return a}function TI(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){f=RH(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<4)+f|0,v[g>>2]=h;gb=e+16|0;return a}function SA(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;jf(a+12|0,d);if(b){f=CR(b)}v[a>>2]=f;c=(c<<3)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<3)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Mla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,5)){t[c+16|0]=0;oi(a,5,c+16|0);break a}Xv(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function yT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=rI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Gv(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function wn(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,4)){t[c+16|0]=0;oi(a,4,c+16|0);break a}Ai(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22708]=0;a=fa(1803,d|0,a|0,b|0,c|0,0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22708]=0;a=fa(1803,d|0,a|0,b|0,c|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function fU(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function ZT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=XT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){WT(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function QI(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=rI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){_H(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22708]=0;a=fa(1698,d|0,a|0,b|0,c|0,0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Nh(a,b){var c=0,d=0;a=v[a>>2];b=Vd(b);c=b;d=a+8|0;if(Nb(d)>>>0>b>>>0){c=v[Mb(d,c)>>2]!=0}else{c=0}if(!c){a=ba(4)|0;Fm(a);v[a>>2]=89548;ia(a|0,89596,2322);L()}return v[Mb(a+8|0,b)>>2]}function Mi(a){var b=0,c=0,d=0,e=0;e=Ae(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=Ae(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function CT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=zT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){WB(a);a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function AO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];if((b|0)>=11){e=a;b=378;while(1){zO(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}b=0}v[d+112>>2]=b+1;a=zO(a);return a|0}function lv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Sk(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){_j(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function cc(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;g=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=b;kb[g|0](a,e,f,d);gb=d+16|0}function SV(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=En(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Ok(a);a=v[b>>2]+2|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function EC(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(86224);if(!d){return 0}v[22708]=0;a=da(1889,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function BD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4304);if(!d){return 0}v[22708]=0;a=da(1596,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function wR(a,b){var c=0,d=0;c=v[a+24>>2];v[22708]=0;c=me(c+484344|0,b);d=v[22708];v[22708]=0;if((d|0)!=1){if(c){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}V(0)|0;O()|0;Bb();L()}function vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4276);if(!d){return 0}v[22708]=0;a=da(1756,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4268);if(!d){return 0}v[22708]=0;a=da(1779,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function mx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=wi(e+8|0,e+12|0);v[22708]=0;a=pl(a,b,c);b=v[22708];v[22708]=0;if((b|0)!=1){gf(d);gb=e+16|0;return a}a=P()|0;O()|0;gf(d);S(a|0);L()}function jw(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,2)){t[c+16|0]=0;kE(a,c+16|0);break a}Bn(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function hp(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){EW(b);break a}Ai(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function b9(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=v[a+24>>2];xL(c,b);v[22708]=0;U(560,a|0,1,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function _z(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;yc(b+8|0,a+116|0);v[22708]=0;c=Na(1329,a|0)|0;a=O()|0;c=c|0;d=v[22708];v[22708]=0;if((d|0)!=1){gb=b+16|0;jb=a;return c}a=P()|0;O()|0;S(a|0);L()}function Yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4236);if(!d){return 0}v[22708]=0;a=da(1667,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function VQ(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4268);if(!d){return 0}v[22708]=0;a=da(1533,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Rba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(5048);if(!d){return 0}v[22708]=0;a=da(1839,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Qpa(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=tf(1);v[22708]=0;c=T(39,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){b=v[Yi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Yb(b);S(a|0);L()}function PM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-2048|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4276);if(!d){return 0}v[22708]=0;a=da(1866,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Dca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4280);if(!d){return 0}v[22708]=0;a=da(1732,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function $ba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4228);if(!d){return 0}v[22708]=0;a=da(1816,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function uH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function ffa(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!ck(a,b+8|0)){break a}c=0;if(!QN(b+8|0)){break a}c=b;a=ET(a,b);if(!a){_j(c)}c=-1;if(!a){break a}c=PN(b)}gb=b+16|0;return c|0}function WL(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4228|0,c,yb(b));Lt(a)}}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4260|0,c,yb(b));St(a)}}function FX(a){var b=0,c=0;a:{if(sd(a,18715,11)){break a}b=a+215|0;a=a+63|0;while(1){if(w[a+16|0]>3|w[a+17|0]>3|w[a+18|0]>=16){break a}a=a+19|0;if((b|0)!=(a|0)){continue}break}c=1}return c}function wpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=Tb(b,7535);v[22708]=0;a=Q(46,a|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(c);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(c);S(a|0);L()}function v1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Es()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Ds()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function lY(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-48|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function kca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Ji(d+12|0);c=z[d+12>>2];if((b|0)==4){c=fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;gM(a)}gb=d+16|0}function jz(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Xba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=1){Ji(d+12|0);c=z[d+12>>2];if((b|0)==1){c=fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;bM(a)}gb=d+16|0}function Vx(a,b,c,d,e,f,g,h,i){var j=0;j=gb-16|0;gb=j;xg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;gb=j+16|0}function Vi(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function II(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-16|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;TT(b,c);if(Pb(a,c<<8)){bc(d+24|0,v[b>>2],dh(b)<<8);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0}function xB(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22708]=0;ef(a+8|0,b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function wU(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-4|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function qK(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-1|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;CF(b,c);c=Pb(a,c<<3);if(c){BF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function gH(a){var b=0;a:{b:{a=v[a>>2];if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a|0)!=(a&-256)}return b}function fF(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-2|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function dqa(){var a=0;a:{b:{if(t[90868]&1){break b}if(!Qd(90868)){break b}v[22708]=0;X(34);a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(90868)}return}a=P()|0;O()|0;$e(90868);S(a|0);L()}function WW(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-6|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function VS(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function Hg(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22708]=0;Pf(a+8|0,b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Ct(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=gb-16|0;gb=a;if(Nb(b)){while(1){v[a+8>>2]=0;Wi(a+8|0);d=Mb(b,c),e=v[a+8>>2],v[d>>2]=e;c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}gb=a+16|0}function xj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function r4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=mt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;hc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function hba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=DL(f,b,c,d,0,0,0,0,e);gb=f+16|0;return a|0}function cF(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-2;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function bC(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-4;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function YT(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-12|0;v[b+8>>2]=c;_T(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){Vu(b,Lp(a))}}function WS(a){var b=0,c=0;c=v[a+4>>2];a:{while(1){b=v[a+8>>2];if((b|0)==(c|0)){break a}v[a+8>>2]=b-4;v[22708]=0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function Im(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Nb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Nb(c)<<16)-65536>>16<(b|0)){break a}d=z[Mb(c,b-u[a+28>>1]|0)>>2]}return d}function IY(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-28|0;v[b+8>>2]=c;ed(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){yD(b,HY(a))}}function qe(a,b){var c=0;a:{c=Nf(b);if((c|0)==(Ab(a)|0)){v[22708]=0;a=fa(551,a|0,0,-1,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Bb();L()}function c3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=ik(h,b,c,d,e,f,g+8|0,a);gb=a;return b|0}function ZQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Rc(a,8,1,0,10);return}d=a;a=b+31|0;Rc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function XX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;Nk(b,c);c=Pb(a,c);if(c){LD(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function Gda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=gb-16|0;gb=d;e=d,f=C(C(kb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Ji(d+12|0);kb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);gb=d+16|0}function z_(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a=Jn(c+8|0,a);v[22708]=0;a=W(272,a|0,b|0,10441)|0;b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function qN(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=32767;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Es()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function k1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Ds()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Xh(a){var b=0;a=fe(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Nv(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=65535;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return x[a>>1]}V(0)|0;O()|0;Bb();L()}function w0(){var a=0;a:{if(t[465480]&1){break a}if(!Qd(465480)){break a}a=465456;while(1){a=Kb(a)+12|0;if((a|0)!=465480){continue}break}Pd(465480)}Xc(465456,11162);Xc(465468,11141)}function s0(){var a=0;a:{if(t[465512]&1){break a}if(!Qd(465512)){break a}a=465488;while(1){a=Kb(a)+12|0;if((a|0)!=465512){continue}break}Pd(465512)}ld(465488,88928);ld(465500,88940)}function qh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=dK(a);if(d>>>0<=b>>>0){a=dg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function hd(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);gb=d+16|0}function fh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=jC(a);if(d>>>0<=b>>>0){a=pe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function eD(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gE(a);if(d>>>0<=b>>>0){a=dm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function _w(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=iG(a);if(d>>>0<=b>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Uk(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=eF(a);if(d>>>0<=b>>>0){a=Og(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function IL(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=HL(f,b,c,d,e,0,0,0,0);gb=f+16|0;return+c}function Fv(a){var b=0,c=0;b=gb-16|0;gb=b;u[b+14>>1]=a;v[22708]=0;u[b+12>>1]=255;a=Pc(b+14|0,b+12|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(FV()>>>0<b>>>0){Sc();L()}c=b;if(c>>>0>=178956971){rd(8445);L()}c=Nc(B(c,24),4);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+B(b,24)|0,v[d>>2]=e}function DC(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=NW(a);if(d>>>0<=b>>>0){a=Wj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function zN(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=wN();if(d>>>0<=b>>>0){a=ok(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function toa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;lX(b,c,32);kX(a,c);gb=c+32|0}function kr(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=mp();if(d>>>0<=b>>>0){a=pe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function gs(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=Iw();if(d>>>0<=b>>>0){a=tg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function go(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(pK(a)){break a}v[22708]=0;R(2113,b+8|0,a|0);c=v[22708];v[22708]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Bb();L()}t[a+20|0]=255;gb=b+16|0}function ey(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=AI();if(d>>>0<=b>>>0){a=xi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Zq(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=AT();if(d>>>0<=b>>>0){a=bi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function W_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=kb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function TO(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;PO(c,b+80|0);v[22708]=0;U(13,a|0,0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function PN(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function OQ(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[fc(a)+4|0]){v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break b}Sm(b+16|0)}if(b){IA(b)}break a}V(0)|0;O()|0;Bb();L()}}}function Ns(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=Ab(b);if(d>>>0<c>>>0){Zn();L()}b=Jb(b);v[e+4>>2]=d-c;ys(a,b+c|0,v[Fb(e+12|0,e+4|0)>>2]);gb=e+16|0}function NL(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=Le(31415.926535897932/+b);d=Qo(32768/(1-e)*(1-(c*e+K((1-c)*+C(a+a)-(1-c*c)*+C(a*a)))))}return d}function L7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){v[d>>2]=v[a>>2];gg(d+4|0,a+4|0);d=v[c>>2]+16|0;v[c>>2]=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}}function JO(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function sS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=mi(e,a,d);a=wb(a);v[22708]=0;iS(a,b,c,d+4|0);a=v[22708];v[22708]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function fm(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=255;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Ty(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22708]=0;T(1949,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ia(a|0,54776,1938);L()}function BL(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22708]=0;T(1937,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ia(a|0,54720,1938);L()}function nW(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function mJ(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;h=a+2304|0;while(1){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;if((d|0)!=(b|0)){continue}break}}function KG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83656;b=a+8|0;if(Nb(b)){while(1){d=v[Mb(b,c)>>2];if(d){Mn(d)}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}vb(a+152|0);px(b);return a|0}function oj(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){ai(a,v[a>>2],ek(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;_e(b,0);v[c+12>>2]=0;Fe(b,c+12|0);gb=c+16|0}function nz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Ar(e,a,d);wb(a);a=c-b|0;if((a|0)>=1){hc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}$b(d);gb=e+16|0}function JS(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=ei(w[a+797|0]-u[a+770>>1]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[ic(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function q4(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;kT(b,0,a);v[22708]=0;a=T(143,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(b);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function VU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}c=w[a+4|0]>95}return c}function Sy(a,b){var c=0,d=0;c=gb-16|0;gb=c;u[b>>1]=0;t[c+15|0]=0;Uh(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Uh(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}gb=c+16|0}function MX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(sd(a+44|0,14921,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Eb(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){$k(a,v[a>>2],ek(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;_e(b,0);t[c+15|0]=0;Bd(b,c+15|0);gb=c+16|0}function D4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=d+8|0;kb[v[v[a>>2]+12>>2]](e,a,b);if(He(v[e+4>>2],v[c+4>>2])){a=v[e>>2]==v[c>>2]}else{a=0}gb=d+16|0;return a|0}function yN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!me(a,b)){break a}c=kz(a,v[bf(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=bf(a,b);JN(bf(a,c),b);d=c}return d|0}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Nb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=pN(a,b,c,d+8|0);gb=d+16|0;return a|0}function ipa(a,b){a=a|0;b=b|0;if(!_X(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function e4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return a|0}function X6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;wy(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+8|0,d+12|0)>>2]}gb=d+16|0;return c|0}function LC(a,b){var c=0;a:{if(b){LC(a,v[b>>2]);LC(a,v[b+4>>2]);a=fc(a);v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Fk(b+16|0);Xk(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function Jq(a,b){var c=0;a:{if(b){Jq(a,v[b>>2]);Jq(a,v[b+4>>2]);a=fc(a);v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break a}jR(b+16|0);ks(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function H7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[13846];v[c+8>>2]=v[13845];v[c+12>>2]=d;d=v[13844];v[c>>2]=v[13843];v[c+4>>2]=d;kb[v[Rh(c,Yg(b))>>2]](a,b);gb=c+16|0}function qi(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=be(b),v[d+12>>2]=e;v[22708]=0;ef(a,c+12|0,b);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function fR(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;if(c){a=wb(a);while(1){f=Ml(a,c+16|0,b);d=f?d:c;c=v[(f?4:0)+c>>2];if(c){continue}break}}a=v[yc(e+8|0,d)>>2];gb=e+16|0;return a}function LA(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Dg(d,b);v[22708]=0;a=rB(a,d);b=v[22708];v[22708]=0;a:{if((b|0)!=1){gb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}return a>>>31|0}function Tp(a){var b=0,c=0;b=v[22706];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(ax()>>>0<a>>>0){if(!(va(a|0)|0)){break a}}v[22706]=a;return b}v[115189]=48;return-1}function LU(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;$u(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;Zu(v[a>>2],IU(a))}}function Jt(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;Fk(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;xK(v[a>>2],xi(a))}}function hma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;CF(b,c);if(Pb(a,c<<3)){BF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0}function e5(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;wH(a,c,6074);v[a>>2]=78408;gb=c+16|0;return a|0}function tr(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){fp(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ng(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;fp(a,c)}function sr(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){fp(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ng(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;fp(a,c)}function nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+8>>2]=b;d=c,e=Vb(a),v[d>>2]=e;b=ov(c+8|0,c);b=v[a>>2]+(b<<2)|0;ij(a,Rg(b+4|0,v[a+4>>2],b));Gg(b);gb=c+16|0}function yE(a){var b=0,c=0;a:{if(sd(a,11426,3)){break a}b=a+3|0;if(w[b|0]<=7&w[b|0]!=1|w[b|0]>14){break a}a=a+40|0;if(!(w[a|0]<33?w[a|0]:0)&w[b|0]>8){break a}c=1}return c}function Vp(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=nqa(a,0,b,0);e=jb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Cd(b);if(!(!a|!(w[a-4|0]&3))){Qb(a,0,b)}return a}function Sha(a,b){a=a|0;b=b|0;var c=0;c=dd(a);t[a+16|0]=0;v[a+12>>2]=b;v[22708]=0;_(1088,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Hu(c);S(a|0);L()}function p1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function X_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function GT(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/872|0;v[22708]=0;Oc(b,B(a,872),8);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Bm(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function zl(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;d=e+8|0;Al(d,a+24|0,b);a=v[d+4>>2];a:{if(c){b=v[d>>2];v[b>>2]=a|v[b>>2];break a}b=v[d>>2];v[b>>2]=v[b>>2]&(a^-1)}gb=e+16|0}function yA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[b+56>>2]=0;d=b,e=Qm(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(v[a+480180>>2]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function vW(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-33>>>0)/33^-1,33)+c}b=v[a>>2];if(b){uW(b,(v[dc(a)>>2]-v[a>>2]|0)/33|0)}}function cv(a){var b=0,c=0,d=0;d=a+32|0;a:{while(1){c=w[a|0];if(!((c-1&255)>>>0<31|((b^1)&1?0:c))){b=!c|b;a=a+1|0;if((d|0)!=(a|0)){continue}break a}break}b=0}return b&1}function FW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];aD(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}gb=d+16|0}function pt(a){var b=0,c=0;b=a;a:{if((Me(b)|0)!=79){break a}if((Me(b)|0)!=103){break a}if((Me(b)|0)!=103){break a}c=(Me(b)|0)==83}if(!c){ec(a,30);return 0}return cJ(a)}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Vi(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[ej(c+12|0,c+8|0,49656)>>2],v[d+36>>2]=e;mq(a);gb=c+16|0}function nJ(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function lma(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=sg(b);sg(b);break a}a=Ng(b);Ng(b)}if(a){while(1){if(a&1){Rb(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function l_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;ef(a+8|0,d+12|0,d+8|0);if(b){Xr(a,b);WE(a,b,w[c|0])}gb=d+16|0;return a|0}function h1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function a5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Yp(d,a);JG(a,c);v[22708]=0;R(2387,b|0,1);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Wb(d);S(a|0);L()}}function Gc(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;d=!IW(a,c)}gb=c+16|0;return d}function FK(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Ti(Sb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[sc(Sb(v[a>>2]+484360|0),b)>>1]}return c|0}function wG(a,b,c,d){var e=0,f=0,g=0;f=v[a+4>>2];e=0;a:{if(!c){break a}g=f>>8;e=g;if(!(f&1)){break a}e=ex(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}LL(a,i,h,g,e,f,b,c,d)}function Fj(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function tf(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Cd(a);if(!b){b=v[116502];if(!b){break a}kb[b|0]();continue}break}return b|0}a=ba(4)|0;nm(a);ia(a|0,89104,1930);L()}function _D(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=OD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function UT(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1299020115){a=a+4|0;a=(Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}else{a=0}return a}function QB(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/9|0;v[22708]=0;Oc(b,B(a,9),1);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=mc(a+8|0);v[22708]=0;U(393,a|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gc(d);S(a|0);L()}}function C_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=ND(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function k6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=gt(Qa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);gb=e+16|0;jb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function _i(a,b){var c=0;c=v[b+4>>2];b=v[b>>2];t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=c;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function Y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;wy(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function UQ(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-7>>>0)/7^-1,7)+c}b=v[a>>2];if(b){MQ(b,(v[dc(a)>>2]-v[a>>2]|0)/7|0)}}function Sfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[22708]=0;a=Q(1315,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function SS(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function QU(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function Kx(a,b){var c=0;c=hu(a+4|0);v[a>>2]=77232;v[c>>2]=77252;v[22708]=0;R(2405,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){return}a=P()|0;O()|0;oh(c);S(a|0);L()}function Jx(a,b){var c=0;c=EH(a+4|0);v[a>>2]=77280;v[c>>2]=77300;v[22708]=0;R(2406,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){return}a=P()|0;O()|0;oh(c);S(a|0);L()}function Ee(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[fc(a)>>2];v[22708]=0;_(a|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function EX(a){var b=0,c=0;c=nqa(w[a+217|0],0,9,0);b=w[a+216|0];a=b>>>31|0;b=b<<1;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;if(b>>>0<11){a=a+1|0}jb=a;return b}function wA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=4){if((EA(d)|0)>(e|0)){break b}}g=a,h=DA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function aI(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Lg(b),d=v[v[a>>2]+52>>2],kb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Lg(b)}function XP(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=2){if((EA(d)|0)>(e|0)){break b}}g=a,h=DA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function FA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=9){if((EA(d)|0)>(e|0)){break b}}g=a,h=DA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function np(a,b){var c=0,d=0,e=0;Ev(a);kp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function du(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Qb(a+32|0,0,40);ox(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function Yu(a,b){var c=0,d=0,e=0;wb(b);c=vh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[wb(b)>>2];d=wb(c),e=a,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Rb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Pb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function JB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;ER(a+112|0,48e3);v[a+668>>2]=0;IB(a+724|0);IB(a+732|0);IB(a+740|0);cj(a+788|0);return a}function Cha(a,b){a=a|0;b=b|0;var c=0;c=zh(a);t[a+530|0]=0;v[22708]=0;R(1104,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;ln(c);S(a|0);L()}function BS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=on(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Vq(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function JA(a,b){a:{if(b){JA(a,v[b>>2]);JA(a,v[b+4>>2]);fc(a);v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Sm(b+16|0);IA(b)}return}V(0)|0;O()|0;Bb();L()}function F$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=v[c>>2];a=kb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}gb=d+16|0;return a|0}function h2(){var a=0,b=0;a:{Wd(465568);v[116392]=83728;v[22708]=0;a=ga(2478)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[116394]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function cma(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-80|0;gb=d;c=-1;a:{if(!yY(a,d+8|0)){break a}c=0;if(!cV(d+8|0)){break a}c=Ne(a,b,bV(d+8|0),jb)}gb=d+80|0;return c|0}function x4(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){xH();c=90816;break a}b:{if(t[463956]&1){break b}if(!Qd(463956)){break b}Pd(463956)}c=90812}td(a,b,c)}function vT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-256>>>8^-1)<<8)+c}b=v[a>>2];if(b){EB(b,v[dc(a)>>2]-v[a>>2]>>8)}}function Uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a);v[22708]=0;U(47,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Lc(d);S(a|0);L()}function Sj(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!ng(a)){while(1){a=v[a+8>>2];if(!ng(a)){continue}break}}a=v[a+8>>2];break a}a=TV(b)}v[c>>2]=a}function Be(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function wK(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function vE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(De(a)){d=v[a>>2];t[c+15|0]=0;Bd(b+d|0,c+15|0);de(a,b);break a}t[c+14|0]=0;Bd(a+b|0,c+14|0);_e(a,b)}gb=c+16|0}function uF(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=zb((kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0);a=v[b>>2];wd(c,d,(kb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function s4(a,b){a=a|0;b=b|0;Fm(a);v[a>>2]=89144;b=Jb(b);v[22708]=0;Q(2449,a+4|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function ns(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[22708]=0;ef(a,c+12|0,c+8|0);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function EV(a,b){var c=0;c=gb-32|0;gb=c;a:{if(!Wf(a,4)){EW(b);break a}Ai(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;_B(c+16|0,a,c+8|0)}gb=c+32|0}function DA(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=Zx(b,a);break a}c=(a>>>0)/1e8|0;d=a-B(c,1e8)|0;a=(d>>>0)/1e4|0;a=wj(wj(HI(b,c),a),d-B(a,1e4)|0)}return a}function UL(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function OB(a,b){var c=0,d=0,e=0,f=0;d=vh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);e=wb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Js(a){a=a|0;var b=0;b=ba(8)|0;v[22708]=0;Q(1983,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,89452,206);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function Cda(a,b){a=a|0;b=b|0;var c=0;OM(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Vf(a);Cl(a);Cl(a)}function xv(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;td(c,a,0);v[22708]=0;xp(c,114,0);a=v[22708];v[22708]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function W2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return hk(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0)|0}function U6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){$f(d,a);d=v[c>>2]+12|0;v[c>>2]=d;a=a+12|0;if((b|0)!=(a|0)){continue}break}}}function mB(a,b,c,d,e){var f=0;if(d){while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function hm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;gb=d+16|0}function gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;gb=d+16|0}function xA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=Qm(a,x[b+70>>1],v[b+48>>2],c,0)}return d|0}function ui(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function cA(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;v[22708]=0;ef(a,b+12|0,b+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function Y7(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=gg(a,b);v[22708]=0;Q(69,a+12|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);S(a|0);L()}}function D_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function AS(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}aX(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function xt(a){var b=0,c=0,d=0;c=v[a+4>>2];b=((c<<2)+(tw(v[a>>2],1)^270549120)|0)+2019860093|0;d=tw(b,16);v[a>>2]=b;b=a;a=B(d,5)+c|0;v[b+4>>2]=a;return a}function oy(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+62816>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function jg(a,b,c){a:{switch(b-1|0){case 0:if(c){return Hj(a,1)}return Hj(a,0);case 1:if(c){return Hj(a,3)}return Hj(a,2);default:break a}}return Hj(a,4)}function ch(a){a=C(a);var b=0;a=fe(a);b=255;a:{if(a>=C(255)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function b5(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];if(c){while(1){c=c-1|0;d=c<<2;kb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);if(c){continue}break}}}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Kk(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=fD(a,e,d);break a}a=fD(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function bo(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Cd(b)}return c}function VI(a){var b=0,c=0,d=0;if(Qh(t[v[a>>2]])){while(1){b=v[a>>2];d=t[b|0];v[a>>2]=b+1;c=(B(c,10)+d|0)-48|0;if(Qh(t[b+1|0])){continue}break}}return c}function gU(a,b){a=a|0;b=b|0;var c=0,d=0;u[a+34>>1]=0;c=gb-16|0;gb=c;t[c+15|0]=0;d=a+43|0;Ko(d,d+22|0,c+15|0);gb=c+16|0;v[a+20>>2]=0;ud(a,b);return a|0}function b3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return ik(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0)|0}function Z0(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[22708]=0;a=T(2577,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Bb();L()}function Wc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(kb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function U4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Mx(b);v[a+36>>2]=b;c=a,d=xo(b),v[c+44>>2]=d;c=a,d=Wn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Js(2655);L()}}function QR(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function Q4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Ix(b);v[a+36>>2]=b;c=a,d=xo(b),v[c+44>>2]=d;c=a,d=Wn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Js(2655);L()}}function vH(a,b){a=a|0;b=b|0;Fm(a);v[a>>2]=89144;v[22708]=0;Q(2449,a+4|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function ir(a,b){a=a|0;b=b|0;var c=0;Ek(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a))}function Xy(a,b){a=a|0;b=b|0;var c=0;ut(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];tt(a,oc(a))}function W7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-32|0;gb=h;i=h+8|0;BK(i,b,c,d,e,f,g);Dc(a,h+20|0);Sm(i);gb=h+32|0}function Pd(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;a=ix(b,a);c=gb-16|0;gb=c;d=v[yc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;gb=c+16|0;gb=b+16|0}function KT(a){var b=0;a=ee(a);b=32767;a:{if(a>=32767){break a}b=-32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b}function Jj(a){var b=0;a=fe(a);b=-1;a:{if(a>=C(4294967296)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function Gk(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=a;d=v[v[a>>2]>>2];if(d){v[b>>2]=d}aX(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function DE(a,b){a=a|0;b=b|0;var c=0;Ep(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_r(a,tc(a))}function zca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=5){Ji(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];pM(a)}gb=d+16|0}function xba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=3){Ji(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];TL(a)}gb=d+16|0}function t4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Nf(b);d=tf(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=hc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function rca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Ji(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];jM(a)}gb=d+16|0}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(iG(a)>>>0<b>>>0){Sc();L()}c=hG(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,12)+c|0,v[d>>2]=e;Zw(a,0)}function io(a){var b=0;b=ba(8)|0;v[22708]=0;Q(126,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,89384,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function dj(a,b){var c=0;c=v[v[b>>2]-12>>2];v[22708]=0;b=v[(b+c|0)+24>>2];c=v[22708];v[22708]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function Xr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(RE(a)>>>0<b>>>0){Sc();L()}b=(b-1>>>5|0)+1|0;c=Ui(wb(a),b);v[a+4>>2]=0;v[a>>2]=c;d=wb(a),e=b,v[d>>2]=e}function QO(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=wb(a);c=wo(d+8|0,kr(a,Nb(a)+1|0),Nb(a),c);wq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Yk(a,c);uO(c);gb=d+32|0}function MZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(gE(a)>>>0<b>>>0){Sc();L()}c=fE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,20)+c|0,v[d>>2]=e;eE(a,0)}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=d;b=wi(c,c+12|0);a=tH(a,6419,v[c+8>>2]);gf(b);gb=c+16|0;return a|0}function Eba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){Ji(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];VL(a)}gb=d+16|0}function Dba(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Go(C(C(C(C(xf(v[a+16>>2])>>>0)/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;VL(a);UL(a)}function zZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];MD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function rka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!nU(a,d)){break a}c=0;if(!pT(d)){break a}c=Ne(a,b,oT(d),jb)}gb=d+48|0;return c|0}function rd(a){var b=0;b=ba(8)|0;v[22708]=0;Q(23,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,89332,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function nla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!WU(a,d)){break a}c=0;if(!tU(d)){break a}c=Ne(a,b,sU(d),jb)}gb=d+96|0;return c|0}function jX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(NW(a)>>>0<b>>>0){Sc();L()}c=MW(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,6)+c|0,v[d>>2]=e;FC(a,0)}function iw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(jC(a)>>>0<b>>>0){Sc();L()}c=Ui(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e;dn(a,0)}function gla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!nU(a,d)){break a}c=0;if(!mU(d)){break a}c=Ne(a,b,lU(d),jb)}gb=d+48|0;return c|0}function gC(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;a=a+22|0;return c+(Ib(w[b|0]|w[b+1|0]<<8)>>>0>Ib(w[a|0]|w[a+1|0]<<8)<<1>>>0)|0}function XB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(eF(a)>>>0<b>>>0){Sc();L()}c=dF(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<1)+c|0,v[d>>2]=e;_r(a,0)}function UY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(ME(a,d+8|0)){v[d+4>>2]=w[d+8|0];OY(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function Se(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(De(a)){c=v[a>>2];t[b+15|0]=0;Bd(c,b+15|0);de(a,0);break a}t[b+14|0]=0;Bd(a,b+14|0);_e(a,0)}gb=b+16|0}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!WU(a,d)){break a}c=0;if(!VU(d)){break a}c=Ne(a,b,UU(d),jb)}gb=d+96|0;return c|0}function P1(){var a=0;a:{Wd(465784);v[22708]=0;T(2563,465792)|0;a=v[22708];v[22708]=0;if((a|0)!=1){v[116446]=86432;break a}a=P()|0;O()|0;S(a|0);L()}}function N1(){var a=0;a:{Wd(465800);v[22708]=0;T(2563,465808)|0;a=v[22708];v[22708]=0;if((a|0)!=1){v[116450]=86588;break a}a=P()|0;O()|0;S(a|0);L()}}function OO(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function Jn(a,b){var c=0;v[a>>2]=27764;v[a>>2]=27616;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function I$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Sg(a,v[b+8>>2],f)){dx(b,c,d,e);return}a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function BR(a){var b=0;if(v[a>>2]){fX(a);wb(a);b=v[a>>2];a=xi(a);v[22708]=0;Oc(b,a<<4,8);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function rV(a){return(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165&(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878}function pqa(a,b,c){var d=0;d=b>>31;a=a^d;lqa(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);jb=ib;a=d^hb;b=a-d|0;jb=(d^jb)-((a>>>0<d>>>0)+d|0)|0;return b}function aY(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function ZA(a,b,c){var d=0,e=0,f=0;d=Nl(a,b);if((d|0)!=255){e=vd(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=ic(a,b),f=255,t[e|0]=f;e=ic(a,c),f=d,t[e|0]=f}}function P7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;ys(a,v[c+8>>2],v[c+12>>2]);gb=c+32|0;return a|0}function sx(a,b,c){a:{if((a|0)==(b|0)){break a}c=v[c>>2];while(1){if((c|0)==v[a>>2]){break a}a=a+4|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function s1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function eU(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-12>>>0)/12^-1,12)+c}b=v[a>>2];if(b){Vu(b,Lp(a))}}function bM(a){var b=0;b=(xf(v[a+16>>2])>>>0)/(Jj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;qc(a+4224|0,b)}function X7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-32|0;gb=h;i=h+8|0;BK(i,b,c,d,e,f,g);Dc(a,i);Sm(i);gb=h+32|0}function RN(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Rc(a,8,1,0,10);return}c=a;a=b+14|0;Rc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function RD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function y5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(_f(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){$H(b)}t[a|0]=1}return a|0}function ox(a){var b=0,c=0;v[22708]=0;c=ga(2566)|0;b=v[22708];v[22708]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Kn(a);return}V(0)|0;O()|0;Bb();L()}function j1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function eq(a,b){var c=0;a:{if(!nJ(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Wx(a){var b=0,c=0;b=gb-16|0;gb=b;c=-1;a:{if(BI(a)){break a}if((kb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}gb=b+16|0;return c}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;du(v[v[a>>2]-12>>2]+a|0,c);return a|0}function RA(a,b){var c=0;qR(a);wb(a);c=b+4|0;ol(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];sf(a);tg(a);tg(a)}function N5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(_f(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){$s(b)}t[a|0]=1}return a|0}function KB(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=_k(a);v[22708]=0;Oc(b,B(a,36),4);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function uk(a,b){var c=0,d=0;a:{b=Nl(a,b);if((b|0)==255){break a}if(vk(a)){break a}c=ic(a+4|0,b);d=w[c|0]&223;t[c|0]=d;Yh(v[a>>2],Fu(b)|176,d)}}function rx(a,b){a:{if((a|0)==(b|0)){break a}b=b-4|0;if(b>>>0<=a>>>0){break a}while(1){wc(a,b);a=a+4|0;b=b-4|0;if(a>>>0<b>>>0){continue}break}}}function pm(a,b){a:{if((a|0)==(b|0)){break a}b=b-1|0;if(b>>>0<=a>>>0){break a}while(1){gi(a,b);a=a+1|0;b=b-1|0;if(a>>>0<b>>>0){continue}break}}}function mD(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=Wj(a);v[22708]=0;Oc(b,B(a,6),1);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Xm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function Tpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;u[b+14>>1]=1;c=b,d=$l(a),u[c+12>>1]=d;a=x[Ke(b+14|0,b+12|0)>>1];gb=b+16|0;return a-1&65535}function TA(a){var b=0,c=0,d=0;c=w[a+32|0];d=Ri(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Sb(b)}return Rj(b,w[a+32|0])}function FM(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Fb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])/C(-127))+C(1);gb=c+16|0}function EW(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+4|0;while(1){If(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function Cn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dK(a)>>>0<b>>>0){Sc();L()}c=pi(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=b+c|0,v[d>>2]=e;tt(a,0)}function cV(a){var b=0;a:{if(sd(a,11130,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}b=w[a|0]!=0}return b}function ZI(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function xT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-16>>>4^-1)<<4)+c}b=v[a>>2];if(b){GB(b,Qx(a))}}function hD(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=pe(a);v[22708]=0;Oc(b,a<<2,2);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function a6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;hc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function YL(a){a=a|0;var b=0,c=0;v[a>>2]=52544;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Lc(b);if((b|0)!=(c|0)){continue}break}kf(a);return a|0}function Mf(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=tg(a);v[22708]=0;Oc(b,a<<3,8);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Jr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(is(a,b+8|0)){c=Xb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}gb=b+16|0;return c|0}function BT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-32>>>5^-1)<<5)+c}b=v[a>>2];if(b){HB(b,CB(a))}}function qp(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-2>>>1^-1)<<1)+c}b=v[a>>2];if(b){FY(b,yw(a))}}function dP(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function Z7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=g+8|0;CK(h,b,c,d,e,f);Dc(a,g+20|0);Sm(h);gb=g+32|0}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Xm(d,d+e|0,c+15|0);Nj(a,v[b>>2],d);gb=c+16|0}function UB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Ml(a,b,c){var d=0,e=0;a=x[b>>1];e=x[c>>1];d=1;a:{if(a>>>0<e>>>0){break a}d=0;if(a>>>0>e>>>0){break a}d=y[b+4>>2]<y[c+4>>2]}return d}function KE(a){var b=0,c=0;c=nqa(w[a+111|0],0,1536,0);b=jb;a=nqa(w[a+110|0],0,25,0);c=c+a|0;b=jb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;jb=b;return a}function HW(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Xm(d,d+e|0,c+15|0);e=a;a=v[b>>2];td(e,a,d-a|0);gb=c+16|0}function AF(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-8>>>3^-1)<<3)+c}b=v[a>>2];if(b){FF(b,zF(a))}}function gn(a){a=+a;var b=0;a=ee(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function aea(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Ry(a)}c=b,d=Vb(a+44|0),v[c>>2]=d;a=v[Gd(b+8|0,b)>>2];gb=b+16|0;return a|0}function Bb(){var a=0;a=v[22705];v[22708]=0;X(a|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;L()}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;L()}function $da(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Ry(a)}c=b,d=Zb(a+44|0),v[c>>2]=d;a=v[Gd(b+8|0,b)>>2];gb=b+16|0;return a|0}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(pe(a)>>>0<b>>>0){d=wb(a);e=a;a=wo(c+8|0,b,Nb(a),d);VN(e,a);Gz(a)}gb=c+32|0}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(tg(a)>>>0<b>>>0){d=wb(a);e=a;a=SA(c+8|0,b,sf(a),d);RA(e,a);QA(a)}gb=c+32|0}function kU(a,b,c){var d=0;d=mc(a);v[22708]=0;U(55,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a}a=P()|0;O()|0;Lc(d);S(a|0);L()}function g1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gb-16|0;gb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Fb(a+12|0,a+8|0);gb=a+16|0;return v[b>>2]}function aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(HA(a)>>>0<b>>>0){d=wb(a);e=a;a=WQ(c+8|0,b,MA(a),d);VQ(e,a);UQ(a)}gb=c+32|0}function XS(a,b){var c=0;Ek(a);wb(a);c=b+4|0;ol(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a))}function VN(a,b){var c=0;Ek(a);wb(a);c=b+4|0;ol(v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a))}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;if(b>>>0>=114){io(9396);L()}e=d+8|0;Db(e,a,b);Uf(e,c);gb=d+16|0;return a|0}function MY(a){var b=0,c=0;c=a;b=v[a+4>>2];a=v[a>>2];if((b|0)!=(a|0)){while(1){b=b-28|0;ed(b);if((a|0)!=(b|0)){continue}break}}v[c+4>>2]=a}function Dy(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=dg(a);v[22708]=0;Oc(b,a,1);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(ug(a)>>>0<b>>>0){d=wb(a);e=a;a=Wu(c+8|0,b,Ec(a),d);fU(e,a);eU(a)}gb=c+32|0}function ti(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function eu(a,b){a=a|0;b=b|0;var c=0;c=b>>>0>126;if(!c){We(((b<<5)+a|0)+480280|0);$m((B(b,872)+a|0)+1074992|0,7,a,b,134217728)}return c|0}function Yga(a){a=a|0;var b=0;b=v[a>>2];if(kb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=kb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Qi(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((Nl(a,b)|0)==255){break a}uk(a,b);Pq(a,b,0,0);if(!c){break a}a=ic(a+58|0,b);t[a|0]=w[a|0]|128}}function PT(a){var b=0,c=0;b=gb-16|0;gb=b;if(RV(a,b+8|0)){a=b+8|0;c=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=b+16|0;return c}function FP(a){a=50-(B(w[(a>>>4|0)+37792|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ac((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function vea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;Tt(a,b,c);gb=c+32|0}function qea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;Tt(a,b,c);gb=c+32|0}function poa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Tt(a,b,c);gb=c+32|0}function pla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Zv(a,b,c);gb=c+32|0}function oea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Tt(a,b,c);gb=c+32|0}function Wja(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;LV(a,b,c);gb=c+32|0}function VX(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;b=c+8|0;Fw(b,a);a=w[ic(b,0)|0];d=w[ic(b,1)|0];b=w[ic(b,2)|0];gb=c+16|0;return a|d<<8|b<<16}function EI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function C1(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}kb[a|0](d)}function pZ(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Zv(a,b,c);gb=c+32|0}function kC(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;LV(a,b,c);gb=c+32|0}function i6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=dy(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function c5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Nw(a,b,c);gb=c+32|0}function bd(a,b){var c=0,d=0,e=0;c=Wf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function _m(a){if(a>=2147483647){return 2147483647}if(a<=-2147483648){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function _7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=g+8|0;CK(h,b,c,d,e,f);Dc(a,h);Sm(h);gb=g+32|0}function Yx(a,b){var c=0;if(b>>>0<=99){return HI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return et(GI(c,a),b-B(a,100)|0)}return wj(a,b)}function Vk(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Iw()>>>0<b>>>0){Sc();L()}c=CR(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<3)+c|0,v[d>>2]=e}function tw(a,b){var c=0,d=0;if((b|0)<=-1){b=0-b|0;c=0-b&31;d=(a&-1>>>c)<<c;c=a;a=b&31;return d|(c&-1<<a)>>>a}return rqa(a,(b|0)%32|0)}function pda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!ve(c&255)|!d)){MM(a,8,C(0))}a=nk(a);if(a){kb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function n6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;Nw(a,b,c);gb=c+32|0}function kD(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=d+8|0;_i(c,b);gb=d+16|0;return v[a>>2]==(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}function jt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function j5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;Nw(a,b,c);gb=c+32|0}function YI(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}aa(11456,10534,1180,2826);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Qs(a,b){Fm(a);v[a>>2]=89124;v[22708]=0;Q(2449,a+4|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function Kb(a){var b=0,c=0;b=gb-16|0;gb=b;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){NA(a);gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function $Y(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;Zv(a,b,c);gb=c+32|0}function sg(a){var b=0,c=0;b=gb-16|0;gb=b;if(is(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=b+16|0;return c}function sI(a){var b=0,c=0,d=0;c=Jb(a);b=Ab(a);a=gb-16|0;gb=a;t[a+15|0]=0;d=-1;if(b){b=sp(c,b,a+15|0);d=b?b-c|0:-1}gb=a+16|0;return d}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(AI()>>>0<b>>>0){Sc();L()}c=RH(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<4)+c|0,v[d>>2]=e}function dA(a,b){a=a|0;b=b|0;var c=0;c=18726;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c|0}function bx(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=ex(v[d>>2],h)}a=v[a>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function KV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(mp()>>>0<b>>>0){Sc();L()}c=ZV(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function I7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(mp()>>>0<b>>>0){Sc();L()}c=Yz(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function EG(a){a=a|0;var b=0;a=Kb(a);v[22708]=0;Q(157,a|0,10989)|0;b=v[22708];v[22708]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);S(b|0);L()}}function bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];du(v[v[a>>2]-12>>2]+a|0,c);return a|0}function Rr(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function Gf(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=wi(f,f+12|0);a=dt(a,b,d,v[f+8>>2]);gf(c);gb=f+16|0;return a}function $ga(a,b){a=a|0;b=b|0;a=Tv(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function yb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22708]=0;a=Zh(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function vs(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22708]=0;a=Op(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function r1(){var a=0,b=0;a=gb-16|0;gb=a;v[a+8>>2]=19923026;a:{if(gH(a+8|0)){break a}if(dH()){break a}b=cH()^1}gb=a+16|0;return b|0}function npa(a){a=a|0;var b=0,c=0,d=0;if(mp()>>>0<=8191){Sc();L()}b=Nc(32768,2);v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+32768|0,v[c>>2]=d}function ht(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function Rx(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Lg(t[b|0])|0}function LB(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22708]=0;a=_q(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function eda(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;b=c+12|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;DM(a,b);gb=c+16|0}function UM(a){a=a|0;a=gb-16|0;gb=a;v[a+12>>2]=1869112133;gb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function Rf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;if(b>>>0>=114){io(9361);L()}d=c+8|0;Db(d,a,b);Uf(d,0);gb=c+16|0;return a|0}function ada(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;if(pe(a)>>>0<=12){c=wb(a);d=a;a=wo(b+8|0,13,Nb(a),c);Yk(d,a);uO(a)}gb=b+32|0}function Bs(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=ex(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function tL(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=tf(8);iL(b);v[b+4>>2]=a;v[b>>2]=55396;a=v[Yi(c+8|0,b)>>2];gb=c+16|0;return a|0}function Tj(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;Fe(a,d+12|0);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;gb=d+16|0;return a}function TB(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=wb(b),d=0,v[c>>2]=d}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Dt(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+49584|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function N6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Dt(a+8|0,b,c,d,3);if(a>>>0<=44){a=w[a+49536|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function nk(a){var b=0,c=0;b=Vk(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function jy(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}hc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function aH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Os(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function ZG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ms(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function LS(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=nqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(oqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function Kd(a){var b=0;a=v[a+4>>2];if(a){if(Mn(a)){a:{b=a+8|0;if(v[b>>2]){if((Qw(b)|0)!=-1){break a}}kb[v[v[a>>2]+16>>2]](a)}}}}function KS(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=nqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(oqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function dH(){var a=0,b=0,c=0;a=gb-16|0;gb=a;b=Tb(a,12535);if(Ab(b)){c=(vg(b,11163)|0)!=-1}else{c=0}vb(b);gb=a+16|0;return c|0}function Ik(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;vr(a+4|0);v[b+12>>2]=0;Fe(a+8|0,b+12|0);c=a,d=fc(a),v[c>>2]=d;gb=b+16|0;return a}function $R(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){de(b,a)}if(c){de(c,a)}if(d){de(d,a)}if(e){de(e,a)}}function Vl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(kb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function T5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Lg(t[a|0])|0}function P$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Sg(a,v[b+8>>2],0)){fx(b,c,d);return}a=v[a+8>>2];kb[v[v[a>>2]+28>>2]](a,b,c,d)}function Jl(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];td(a,c,v[Fb(d+12|0,d+8|0)>>2]);gb=d+16|0}function s6(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}kb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function qg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=lh(d,a);return((lh(d,a+1|0)<<8|e<<16|lh(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function lU(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;jb=c;return a}function gI(a){v[a>>2]=77076;ox(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function ct(a){v[a>>2]=77012;ox(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function co(a,b,c,d){var e=0;e=gb-16|0;gb=e;bc(e+8|0,zb(c),d);c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;ry(a,b,e);gb=e+16|0}function bH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Os(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function _G(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ms(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Ub(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function QN(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){a=cn(a)>>>0>80}else{a=0}return a}function Pt(a){var b=0;b=A[a+4248>>3]/+(xf(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function At(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=Bi(c,a,b);b=v[a+8>>2];if((b|0)!=v[a+4>>2]){v[a+4>>2]=b}$b(a);gb=c+16|0}function wp(a,b){var c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=OE(a,b);break a}c=sg(a);Rb(a,b-4|0)}return c}function pq(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return+b}function nw(a,b){var c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=1){c=NE(a,1);break a}c=Ng(a);Rb(a,b-2|0)}return c}function nq(a){a=a|0;var b=0,c=0;b=Te(a);while(1){c=b;if(c&65535){b=c-1|0;if(!me(a,b&65535)){continue}}break}return c&65535}function gf(a){a:{a=v[a>>2];if(a){v[22708]=0;Cx(a);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function lB(a){a=a|0;v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function YB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Hz(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function Hfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=rQ(d);b=b+1|0}gO(a,b,c,d,e)}function DI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function $T(a,b){var c=0;c=v[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-12|0;_T(c);if((b|0)!=(c|0)){continue}break}}v[a+4>>2]=b}function yi(a,b,c){a:{if(c){v[22708]=0;EI(a,b,c);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function ve(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=a;t[b+14|0]=1;t[b+13|0]=120;a=Jv(b+15|0,b+14|0,b+13|0);gb=b+16|0;return a}function je(a,b){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function Yd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function YS(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function Fp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function xS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){vS(a,1);vS(a,0)}}function wS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){uS(a,1);uS(a,0)}}function tZ(a){a=a|0;var b=0;a:{if(!He(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=PF(a,32);v[b+76>>2]=a}return a<<24>>24}function hw(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=gb-16|0;gb=c;t[c+15|0]=w[b|0];rR(a,c+15|0);gb=c+16|0;gb=d+16|0}function WH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function P5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function Fl(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;Cz(a,c)}function XQ(a){var b=0;a:{if(w[a|0]<24){break a}b:{if(!w[a+3|0]){b=15;break b}b=14;if(w[a+3|0]!=3){break a}}t[a+3|0]=b}}function Ko(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function v$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return kb[a|0](h|b,c,d,e,b|f,g)|0}function mga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;if(b>>>0>=250){io(9396);L()}d=c+8|0;Db(d,a,b);dr(d);gb=c+16|0}function dT(a){var b=0,c=0,d=0;b=a+68|0;c=w[b+1|0]<<8;if(!(!(w[b|0]|c)|(c|w[b|0])>>>0>127)){d=!sd(a,14778,17)}return d}function Qma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}gb=b+16|0;return c|0}function Me(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function CY(a){var b=0,c=0;a:{if(sd(a,28564,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}c=t[a+47|0]>-1}return c}function rc(a,b){var c=0;Fm(a);v[a+4>>2]=0;v[a>>2]=54900;c=a;a=Cd(Ab(b)+1|0);v[c+4>>2]=a;if(a){hc(a,Jb(b),Ab(b)+1|0)}}function gga(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=_z(a),v[d>>2]=e;zo(c);gb=b+16|0;return v[c>>2]}function Vv(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){bc(a,c,v[b>>2]);return}b=b+8|0;if(!cd(b)){Ud(a,b);return}Td(a)}function uo(a){var b=0;a:{while(1){if(w[b+49600|0]==(a|0)){break a}b=b+1|0;if((b|0)!=45){continue}break}b=0}return b}function jV(a){var b=0,c=0;b=gb-16|0;gb=b;c=a+512|0;while(1){If(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}gb=b+16|0}function MF(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;Ip(a);v[a>>2]=27812;c=dc(a);Hp(c);v[c>>2]=27944;gb=b+16|0;return a|0}function $U(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;jb=b;return a}function zI(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function qr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Bi(e,a,d);GW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function oz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Eg(e,a,d);GW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function Iu(a){a=a|0;var b=0,c=0;b=a+68|0;a=0;while(1){c=Pe(b,a);a=a+1|0;v[c>>2]=a<<11;if((a|0)!=9){continue}break}}function tB(a,b,c){a:{v[22708]=0;Oc(b,B(c,28),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function mm(a,b,c){a:{v[22708]=0;Oc(b,B(c,12),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ks(a,b,c){a:{v[22708]=0;Oc(b,B(c,36),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function gY(a,b,c){a:{v[22708]=0;Oc(b,B(c,48),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function er(a,b,c){if(v[b>>2]<=(Ib(w[a|0]|w[a+1|0]<<8)|0)){a=(Ib(w[a|0]|w[a+1|0]<<8)|0)<=v[c>>2]}else{a=0}return a}function dE(a,b,c){a:{v[22708]=0;Oc(b,B(c,20),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Yk(a,b){var c=0;c=b+4|0;ol(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Th(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function PY(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Kda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=ch(C(c*C(255))),t[d|0]=e;St(a)}}function $z(a,b,c){a:{v[22708]=0;Oc(b,B(c,52),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function rS(a){var b=0,c=0;if(v[a>>2]){bm(a);zw(wb(a),v[a>>2],Og(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function iM(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function fO(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=Zz(d,a);wb(a);wq(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0}function WV(a){var b=0,c=0;if(v[a>>2]){Fg(a);pw(wb(a),v[a>>2],pe(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function TH(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!He(aI(c,b),-1)){break a}v[a>>2]=0}return a|0}function OP(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function JC(a,b,c){a:{v[22708]=0;Oc(b,B(c,6),1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Hl(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function FN(a){var b=0,c=0;if(v[a>>2]){Fg(a);ai(wb(a),v[a>>2],pe(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function Ev(a){var b=0,c=0;if(v[a>>2]){xr(a);$k(wb(a),v[a>>2],dg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function EN(a){var b=0,c=0;if(v[a>>2]){KN(a);JC(wb(a),v[a>>2],Wj(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function yD(a,b){a:{v[22708]=0;Oc(a,B(b,28),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function uW(a,b){a:{v[22708]=0;Oc(a,B(b,33),1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ce(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=1;t[b+14|0]=120;a=Jv(a,b+15|0,b+14|0);gb=b+16|0;return a|0}function Zu(a,b){a:{v[22708]=0;Oc(a,B(b,56),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function XF(a,b){a:{v[22708]=0;Oc(a,B(b,24),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Vu(a,b){a:{v[22708]=0;Oc(a,B(b,12),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function UJ(a,b){a:{v[22708]=0;Oc(a,B(b,52),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function SN(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function SI(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function NM(a,b,c){a:{v[22708]=0;Oc(b,c<<11,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Ey(a,b){a:{v[22708]=0;Oc(a,B(b,24),8);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function zw(a,b,c){a:{v[22708]=0;Oc(b,c<<1,2);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function xu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=rQ(d);b=b+1|0}FA(a,b,c,d)}function uu(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function pw(a,b,c){a:{v[22708]=0;Oc(b,c<<2,2);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function mV(a,b,c){a:{v[22708]=0;Oc(b,c<<5,8);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function iE(a,b,c){a:{v[22708]=0;Oc(b,c<<1,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ai(a,b,c){a:{v[22708]=0;Oc(b,c<<2,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Yn(a,b,c){a:{v[22708]=0;Oc(b,c<<4,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Xk(a,b,c){a:{v[22708]=0;Oc(b,c<<5,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function PA(a,b,c){a:{v[22708]=0;Oc(b,c<<3,8);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Mh(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function MQ(a,b){a:{v[22708]=0;Oc(a,B(b,7),1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Lr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){c=Ib(w[b+8|0]|w[b+9|0]<<8)}gb=b+16|0;return c|0}function L4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Mx(b);v[a+36>>2]=b;c=a,d=Wn(b),t[c+44|0]=d}function IC(a,b,c){a:{v[22708]=0;Oc(b,c<<2,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function I4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Ix(b);v[a+36>>2]=b;c=a,d=Wn(b),t[c+44|0]=d}function An(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function rK(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=AO(a),v[d>>2]=e;zo(c);gb=b+16|0;return v[c>>2]}function qS(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Gb(c+8|0,c);gb=c+16|0;return a}function bba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,9765);rc(a,c);vb(c);v[a>>2]=54860;gb=b+16|0;return a|0}function Uf(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function Sg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!xj(v[a+4>>2],v[b+4>>2])}function Naa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,5324);rc(a,c);vb(c);v[a>>2]=54880;gb=b+16|0;return a|0}function Lv(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Yd(c+12|0,0,15);gb=c+16|0;return w[c+12|0]}function xK(a,b){a:{v[22708]=0;Oc(a,b<<4,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function wf(a){a=a|0;var b=0;b=v[19556];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19559];cu(a+8|0);oh(a+60|0);return a|0}function sC(a,b){a:{v[22708]=0;Oc(a,b<<2,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function p9(a,b){a=a|0;b=b|0;if(a){b=kb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=ie(b);break a}b=ie(18726)}v[a>>2]=b}}function lO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function gP(a,b){a:{v[22708]=0;Oc(a,b<<3,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function HB(a,b){a:{v[22708]=0;Oc(a,b<<5,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function GB(a,b){a:{v[22708]=0;Oc(a,b<<4,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function FY(a,b){a:{v[22708]=0;Oc(a,b<<1,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function FF(a,b){a:{v[22708]=0;Oc(a,b<<3,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function EB(a,b){a:{v[22708]=0;Oc(a,b<<8,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Bq(a){a=a|0;var b=0;b=v[19511];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19514];cu(a+4|0);oh(a+56|0);return a|0}function $S(a,b){var c=0;c=v[a+4>>2]+b|0;v[a+4>>2]=c&31;v[a>>2]=v[a>>2]+(((b|0)>=0?c>>>5|0:(c-31|0)/32|0)<<2)}function rC(a){var b=0,c=0;c=a;b=v[a+8>>2];a=v[a+4>>2];if((b|0)!=(a|0)){v[c+8>>2]=(((b-a|0)-4>>>2^-1)<<2)+b}}function fW(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;if(($l(a)|0)!=65535){VD(a,c+14|0)}gb=c+16|0}function bI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return Lg(t[b|0])}function YG(a,b,c,d,e){b=pj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function VR(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+22>>1]<<4|x[b+20>>1]>>>6)&65535)+35360|0]>>>x[a+68>>1]}function Oo(a,b){a=a|0;b=b|0;if(tc(a)>>>0>b>>>0){a=me(v[a+24>>2]+484344|0,x[gj(a,b)>>1])}else{a=0}return a|0}function HN(a){a=a|0;var b=0;b=v[v[a>>2]-12>>2]+a|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;return a|0}function $k(a,b,c){a:{v[22708]=0;Oc(b,c,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function $G(a,b,c,d,e){b=qj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function wV(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function qna(a,b){a=a|0;b=b|0;if(!pW(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function jJ(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function ej(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!ot(a,b)){b=ot(c,a)?c:a}gb=d+16|0;return b|0}function Zx(a,b){var c=0;if(b>>>0<=9999){return Yx(a,b)}c=a;a=(b>>>0)/1e4|0;return wj(Yx(c,a),b-B(a,1e4)|0)}function Sh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Cc(c,(b>>31&a)+b|0)>>2]}function J1(){var a=0;if(mp()>>>0<=29){Sc();L()}a=AG(jx(465840),30);v[116460]=a;v[116461]=a;v[116462]=a+120}function Af(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!uv(a,b)){b=uv(c,a)?c:a}gb=d+16|0;return b|0}function zo(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=zb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function sy(a,b){var c=0;c=(B(B(py(a),qy(a)),125)>>>0)/(qJ(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function qJ(a){var b=0;b=v[(w[a+2|0]&12)+61712>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function mw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function dna(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(ck(a,b+8|0)){c=PV(b+8|0)}gb=b+16|0;return c|0}function Yt(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=251;t[b+14|0]=255;a=Jv(a,b+15|0,b+14|0);gb=b+16|0;return a}function Xpa(a,b){a=a|0;b=b|0;var c=0;b=gb-80|0;gb=b;c=-1;if(yY(a,b+8|0)){c=xY(b+8|0)}gb=b+80|0;return c|0}function xY(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179468868&(w[a+4|0]-1&255)>>>0<10}function uw(a,b){a=a|0;b=b|0;if((a&4088)>>>0>=520){b=tw(0-rqa(b^1230262859,25)|0,4)^1247037516}return b|0}function mz(a,b){mc(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Ho(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function l$(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;if(gG(a,b+8|0)){c=fG(b+8|0)}gb=b+32|0;return c|0}function hL(a){var b=0;while(1){if(!v[(b<<2)+a>>2]){return b}b=b+1|0;if((b|0)!=4){continue}break}return 4}function gv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;wn(c+8|0,a);v[c+4>>2]=v[c+8>>2];fr(c+4|0,b);gb=c+16|0}function dZ(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(ck(a,b+8|0)){c=DD(b+8|0)}gb=b+16|0;return c|0}function b6(a){a=a|0;a=gb-16|0;gb=a;if(fb(a+12|0,4)|0){Rs(v[115189],9957);L()}gb=a+16|0;return v[a+12>>2]}function Xp(){var a=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)!=1){return v[19882]}V(0)|0;O()|0;Bb();L()}function XH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function QP(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=0-(d&65535)&65535;b=b+1|0}wA(a,b,c,d&65535)}function Ng(a){var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}gb=b+16|0;return c}function HG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function Es(){var a=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)!=1){return v[20464]}V(0)|0;O()|0;Bb();L()}function Ds(){var a=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)!=1){return v[20076]}V(0)|0;O()|0;Bb();L()}function B_(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(ck(a,b+8|0)){c=vF(b+8|0)}gb=b+16|0;return c|0}function vO(a,b){v[22708]=0;Oc(a,b<<2,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function iq(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=be(b),v[d+12>>2]=e;Fe(a,c+12|0);gb=c+16|0;return a}function gr(a){if(a>=4294967295){return-1}if(a<=0){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function eX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){YW(c+52|0);vb(c+40|0);Lc(c+16|0);Lc(c+4|0);Yb(c)}}function Pg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];jb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function xc(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];gb=c+16|0}function j_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Rk(d,a,22);Zr(d,b);gb=c+16|0;return a|0}function hZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Rk(d,a,20);Zr(d,b);gb=c+16|0;return a|0}function WP(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function SO(a,b){var c=0;c=gb-16|0;gb=c;a=Zz(c,a);wq(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;$b(a);gb=c+16|0}function Ow(a,b,c){var d=0;d=gb-16|0;gb=d;a=Td(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;gb=d+16|0}function Nz(a,b){var c=0;c=gb-16|0;gb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];gb=c+16|0}function NB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=v[b>>2]+c|0;if((d|0)==-1){d=yb(b)-c|0}wd(a,e,d)}function Cx(a){a=a|0;var b=0;b=v[22614];if(a){v[22614]=(a|0)==-1?460800:a}return((b|0)==460800?-1:b)|0}function Cq(a,b,c){a=tk(a+1074376|0)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function vh(a){var b=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Yo(a+8|0);gb=b+16|0;return a}function qy(a){var b=0;b=w[a+1|0];return w[(B(b>>>3&1,45)+B(b>>>1&3,15)+(w[a+2|0]>>>4)|0)+61713|0]<<1}function uT(a){v[22708]=0;Oc(a,48,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function o_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;$E(d,a);Zr(d,b);gb=c+16|0;return a|0}function jv(a){v[22708]=0;Oc(a,20,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function jm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function hT(a){uB(a+140|0);xb(a+120|0);xb(a+100|0);xb(a+80|0);xb(a+60|0);xb(a+40|0);xb(a+20|0);xb(a)}function aO(a){v[22708]=0;Oc(a,28,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function _W(a){v[22708]=0;Oc(a,32,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Uv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Ji(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(!(b>C(1))){break a}}z[a>>2]=c}}function IA(a){v[22708]=0;Oc(a,40,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function DV(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function sw(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function nda(a,b,c){a=a|0;b=b|0;c=c|0;a=nk(a);if(!a){return 0}return kb[v[v[a>>2]+100>>2]](a,b,c)|0}function OR(a,b,c){if((b|0)!=(c|0)){while(1){MR(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Ld(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=54976;v[b+8>>2]=55080;Pu(a,b+12|0,b+8|0);gb=b+16|0}function DK(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)<=(d|0)&y[b>>2]>y[a>>2]|(c|0)<(d|0)}function AE(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}jb=a;return b}function wma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(jD(a,b)){c=rV(b)}gb=b+16|0;return c|0}function n9(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Jb(b);if(c){kb[c|0](b,v[a+8>>2]);return}Kt(b,a)}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Yp(d,a);JG(a,c)}function f_(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=ME(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Pl(a){a=a|0;var b=0;Ol(a);b=Rq(v[a>>2],kj(a));v[a+20>>2]=b;if(!b){return 0}return bj(a)|0}function B1(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[Xp()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function qI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ab(a);if(d>>>0<b>>>0){ws(a,b-d|0,c);return}vE(a,b)}function or(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;mv(a+236|0,128,c+14|0);gb=c+16|0}function gi(a,b){var c=0;c=gb-16|0;gb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];gb=c+16|0}function _fa(a,b){a=a|0;b=b|0;ct(a);v[a>>2]=77316;Kb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function NQ(a,b,c){a=a|0;b=b|0;c=c|0;Fe(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function Ag(a){a=a|0;var b=0,c=0;while(1){c=b&65535;eu(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function we(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];lw(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function uR(a,b){var c=0;c=gb-16|0;gb=c;a=v[yc(c+8|0,fR(a,b,Xd(a),fc(a)))>>2];gb=c+16|0;return a}function oT(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}jb=a;return b}function gV(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function _o(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];UV(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function Tq(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=0;Ko(a,a+32|0,b+15|0);gb=b+16|0;return a|0}function K5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function I5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function G5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function E5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function DX(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];CX(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function C5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function A5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function xfa(a,b){a=a|0;b=b|0;Mi(a);Mi(a);a:{if(b>>>0>=60){Rb(a,4);break a}Mi(a)}return Mi(a)|0}function uq(a,b,c){a=v[a>>2]+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function tN(a,b){b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Yo(a+8|0);gb=b+16|0;return a}function s8(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[Yi(b+8|0,OB(tf(12),a))>>2];gb=b+16|0;return a|0}function n5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function mZ(a,b){a=a|0;b=b|0;if(!Yv(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function lda(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;Ud(b,v[a+20>>2]+4|0);JM(a,ne(b+8|0,b),0);gb=b+16|0}function jca(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=xf(v[a+16>>2]),v[b+4256>>2]=c;gM(a);fM(a)}function g_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Mg(a,b+8|0)){c=w[b+8|0]}gb=b+16|0;return c|0}function fJ(a){var b=0;b=+((a&2097151)>>>0);return C(ji(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function Xna(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=is(a,b+8|0);gb=b+16|0;return C(a?z[b+8>>2]:C(0))}function Jda(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=xf(v[a+16>>2]),v[b+4232>>2]=c;St(a);XM(a)}function H$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Sg(a,v[b+8>>2],f)){dx(b,c,d,e)}}function vD(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=rp(c,c+8|0);gb=c+16|0;return a}function rY(a,b){return(Lb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Lb((B(a&15,b)>>>0)/15|0,1,15))&255}function UX(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=ak(c,c+8|0);gb=c+16|0;return a}function S6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function Po(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Ah(Dk(b)*+(c>>>0)),v[d+24>>2]=e}function EA(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+27040>>2]>a>>>0)|0)+1|0}function vi(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+(Ab(a)<<2)|0)>>2];gb=b+16|0;return a}function o$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb[a|0](b,c,d,e)|0;ma(jb|0);return a|0}function nd(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Al(d,a+24|0,b);a=Cb(d);gb=c+16|0;return a}function XT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Ef(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=a;a=Tb(c,b);Dc(d,a);vb(a);gb=c+16|0}function C4(a,b,c){a=a|0;b=b|0;c=c|0;if(He(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function BW(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1279544644&w[a+4|0]<32}function zT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function v5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return kb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function uE(a){var b=0;b=gb-16|0;gb=b;a=Mg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function rI(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function oI(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function d8(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;rw(d,b,20);Yr(a,d);gb=c+16|0}function Sk(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function IG(a){a=a|0;var b=0;v[a>>2]=83676;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Yb(b)}return a|0}function En(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function Dma(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;c=a;a=Jh(b+8|0);OV(c,a,0,0);xb(a);gb=b+32|0}function ur(a,b){var c=0;c=Ab(a);if((c|0)==(Ab(b)|0)){a=Vo(Jb(a),Jb(b),c)}else{a=1}return!a}function uA(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function qf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=jL(a,b);gb=c+16|0;return(d?b:a)|0}function pd(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=ot(b,a);gb=c+16|0;return(d?b:a)|0}function jba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;LL(a,b,c,d,e,0,0,f,g)}function gma(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=lj(a,b+8|0);gb=b+16|0;return+(a?A[b+8>>3]:0)}function cS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=mi(e,a,d);wb(a);kv(b,c,d+4|0);$b(d);gb=e+16|0}function ac(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=jL(b,a);gb=c+16|0;return(d?b:a)|0}function aM(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function _O(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function XV(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=Eg(e,a,d);wb(a);kv(b,c,d+4|0);$b(d);gb=e+16|0}function Tk(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=sw(b,a);gb=c+16|0;return(d?b:a)|0}function Pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Gn(b,a);gb=c+16|0;return(d?b:a)|0}function Pb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return kb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Or(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=DK(b,a);gb=c+16|0;return(d?b:a)|0}function My(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=DK(a,b);gb=c+16|0;return(d?b:a)|0}function Mc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=zn(a,b);gb=c+16|0;return(d?b:a)|0}function Ke(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Gn(a,b);gb=c+16|0;return(d?b:a)|0}function Hf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=ot(a,b);gb=c+16|0;return(d?b:a)|0}function Fb(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=zn(b,a);gb=c+16|0;return(d?b:a)|0}function FL(a,b,c){a=a|0;b=b|0;c=c|0;Oy(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=54796;return a|0}function DD(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==810369604&w[a+4|0]<4}function zoa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13290);Dc(c,a);vb(a);gb=b+16|0}function xz(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+18828>>2]}else{b=6884}Tb(a,b)}function voa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1580);Dc(c,a);vb(a);gb=b+16|0}
function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nk(a);if(a){kb[v[v[a>>2]+76>>2]](a,b,c,d)}}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nk(a);if(a){kb[v[v[a>>2]+84>>2]](a,b,c,d)}}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nk(a);if(a){kb[v[v[a>>2]+88>>2]](a,b,c,d)}}function gh(a){var b=0;b=a+44|0;Tx(b);if(v[b>>2]){fX(b);Yn(wb(b),v[b>>2],xi(b))}gc(a+32|0)}function YF(a,b){var c=0,d=0;Hp(a);v[a>>2]=27616;v[a+4>>2]=v[b>>2];c=a,d=yb(b),v[c+8>>2]=d}function Wk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Ov(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Je(c,1,a);_E(c,b);gb=c+16|0;return a|0}function Nj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;FS(a,b,c);gb=d+16|0;return a|0}function MH(a){var b=0;b=v[a>>2];if(b){if(!He(bI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function LH(a){var b=0;b=v[a>>2];if(b){if(!He(XH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function JW(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function Ir(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Fr(c,1,a);_E(c,b);gb=c+16|0;return a|0}function Gma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13893);Dc(c,a);vb(a);gb=b+16|0}function Dc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];NA(b)}function $N(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){Hb(b+16|0)}if(b){aO(b)}}}function rqa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function rpa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1040);Dc(c,a);vb(a);gb=b+16|0}function qZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1467);Dc(c,a);vb(a);gb=b+16|0}
function p$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;kb[a|0](b,c,d,e,f,g)}function m_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;ww(d,b);Yr(a,d);gb=c+16|0}function lla(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1274);Dc(c,a);vb(a);gb=b+16|0}function kt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function iU(a){var b=0;b=443250/+(a>>>0)*1e4;if(b<4294967296&b>=0){return~~b>>>0}return 0}function Zma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1983);Dc(c,a);vb(a);gb=b+16|0}function Yma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1031);Dc(c,a);vb(a);gb=b+16|0}function Xx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;a=dt(a,b,c,d);gb=e+16|0;return a}function T$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13920);Dc(c,a);vb(a);gb=b+16|0}function Py(a){a=a|0;var b=0;v[a>>2]=54900;b=v[a+4>>2];if(b){Yb(b);v[a+4>>2]=0}return a|0}function Hma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1116);Dc(c,a);vb(a);gb=b+16|0}function uda(a,b){a=a|0;b=b|0;a=nk(a);if(!a){return 1}return kb[v[v[a>>2]+68>>2]](a,b)|0}function qP(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|32;v[a+852>>2]=v[a+852>>2]+b}}function mv(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function mN(a,b,c){if(b){while(1){z[a>>2]=z[c>>2];a=a+4|0;b=b-1|0;if(b){continue}break}}}function ge(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;eH(a,d+12|0,c);gb=d+16|0;return a}function ff(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+Ab(a)|0)>>2];gb=b+16|0;return a}function f5(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){Hx(a,c);return}Tb(a,5018)}function Ww(){var a=0,b=0;a=gb-16|0;gb=a;b=ns(a+8|0,mc(tf(12)));gb=a+16|0;return v[b>>2]}function Rd(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;Nr(c,a);gb=b+16|0;return v[c>>2]}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=4&(c|0)!=-1)){Hk(a,b);return}$M(a,b,c)}function Ci(a){if(pK(a)){a=ba(4)|0;v[a>>2]=0;Fm(a);v[a>>2]=79404;ia(a|0,79440,1930);L()}}function Ae(a){var b=0;b=gb-16|0;gb=b;a=Mg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)&255}function $$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1628);Dc(c,a);vb(a);gb=b+16|0}function zy(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function hn(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function cj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function bh(a,b,c){var d=0;d=gb-16|0;gb=d;if(!eT(a,b)){b=eT(c,a)?c:a}gb=d+16|0;return b}function OT(a,b,c){var d=0;d=v[b>>2];if((c|0)==-1){c=ar(b)}v[a>>2]=d;v[a+4>>2]=(c<<2)+d}function Mn(a){var b=0;b=Qw(a+4|0);if((b|0)==-1){kb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function KI(a){var b=0;b=mqa(v[a>>2]-1|0);if(!b){a=mqa(v[a+4>>2]);b=a?a+32|0:0}return b}function G_(a){a=a|0;var b=0;b=v[a+4>>2];return(kb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function sH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a=tH(a,8351,b);gb=c+16|0;return a}function ol(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>=1){hc(c,a,b)}}function oi(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function kG(a){var b=0;b=a+48|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function jH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;eH(a,c+12|0,b);gb=c+16|0;return a}function dB(a,b){Yu(a,b);Dc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function cl(a){var b=0;b=a+36|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Tb(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;ys(a,b,Nf(b));gb=c+16|0;return a|0}function RR(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function GE(a){var b=0,c=0;b=gb-16|0;gb=b;c=Wp(a);t[b+15|0]=0;Ko(a,c,b+15|0);gb=b+16|0}function GD(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+28512|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function Df(a){var b=0;b=a+24|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function $e(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=v[ix(b,a)+8>>2],d=0,t[c|0]=d;gb=b+16|0}function $O(a){Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function zm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function y0(a){a=a|0;a=465440;while(1){a=Ic(a-12|0);if((a|0)!=465152){continue}break}}function v0(a){a=a|0;a=465480;while(1){a=vb(a-12|0);if((a|0)!=465456){continue}break}}function r0(a){a=a|0;a=465512;while(1){a=Ic(a-12|0);if((a|0)!=465488){continue}break}}function o6(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function m6(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function bu(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){Oz(a,b,0);Oz(a,b,1);Oz(a,b,2)}}function _u(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function L2(a,b){a=a|0;b=b|0;var c=0;c=Rx(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function Kt(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;v[b>>2]=a;XI(14929,b);lt(90144);gb=b+16|0}function H0(a){a=a|0;a=464664;while(1){a=vb(a-12|0);if((a|0)!=464496){continue}break}}function E0(a){a=a|0;a=464840;while(1){a=Ic(a-12|0);if((a|0)!=464672){continue}break}}function B0(a){a=a|0;a=465136;while(1){a=vb(a-12|0);if((a|0)!=464848){continue}break}}function nf(a){a=a|0;var b=0;b=v[a>>2];return(kb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function n1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Es()+((b&255)<<2)>>2]}return b<<24>>24}function l1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Ds()+((b&255)<<2)>>2]}return b<<24>>24}function hi(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;cj(a)}function dba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return CL(a,b,c,d,0,0,0,0,e)|0}function Yi(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;wq(a,c+12|0);gb=c+16|0;return a}function Xja(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;ys(a,b,12);gb=c+16|0;return a|0}function VT(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Tca(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function Lda(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function Gg(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,a)>>2];gb=b+16|0;return a|0}function AG(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Yz(b)}return a}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kb[a|0](b,c,d)|0;ma(jb|0);return a|0}function Xf(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function zh(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;wq(a,b+12|0);gb=b+16|0;return a}function uC(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,v[a>>2])>>2];gb=b+16|0;return a}function sT(a,b,c,d,e,f){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e);yc(a+16|0,f)}function gj(a,b){a=a|0;b=b|0;if(tc(a)>>>0<=b>>>0){_x();L()}return v[a>>2]+(b<<1)|0}function gJ(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function bX(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;ZW(c,a);gb=b+16|0;return v[c>>2]}function Ui(a,b){a=a|0;b=b|0;if(b>>>0>1073741823){rd(8445);L()}return Nc(b<<2,4)|0}function NP(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function kY(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function dw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function ap(a,b){a=hc(a,b,34);u[a+34>>1]=x[b+34>>1];hc(a+36|0,b+36|0,68);return a}function Mp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function Kw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,36);return a}function Gw(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){Kn(a)}}function zd(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a))>>2];gb=b+16|0;return a}function xD(a){a=a+4|0;return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function nr(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,uC(a))>>2];gb=b+16|0;return a}function mi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function fs(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function bq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function bP(a){a=a|0;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;GE(a+9|0);return a|0}function Zj(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;js(a+8|0,b+8|0)}function XI(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;WI(90144,a,b,0,0);gb=c+16|0}function IF(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c);js(b+12|0,c+12|0);qi(b+32|0,c+32|0)}function Eg(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function Dh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Ch(a))>>2];gb=b+16|0;return a}function DB(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function Ch(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,fc(a))>>2];gb=b+16|0;return a}function Ar(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[a|0](b,c,d,e,f)}function pT(a){if((w[a+14|0]-49&255)>>>0<=3){a=sd(a,12667,14)}else{a=1}return!a}function f4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-16|0;gb=b;kH(a,c,d);gb=b+16|0}function Zca(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[wb(a)>>2]){SO(a,b);return}QO(a,b)}function MR(a,b){var c=0;c=a;a=v[a>>2];v[c>>2]=a<<8^v[((a>>>24^b)<<2)+35500>>2]}function HJ(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function x6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return uJ(a-88|0,b,c,d,e)|0}function u$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kb[a|0](b,c,d,e)|0}function mP(a,b){a=a|0;b=b|0;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[b>>2];return a|0}function Wfa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[wb(a)>>2]){SO(a,b);return}QO(a,b)}function Oba(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function Ju(a,b){return Ah(Dk((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function $o(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function yj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Yb(b)}function yba(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function y4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,4984);return}Hx(a,c)}function sca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function ro(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function rF(a,b){var c=0;c=gb-16|0;gb=c;b=im(c+8|0,b);_F(b,a);Kd(b);gb=c+16|0}function lca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function im(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){Kn(b)}return a}function hz(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function aR(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function _U(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;ww(d,b);HW(a,d);gb=c+16|0}function Yy(a){a=a|0;v[a>>2]=50952;Lc(a+4276|0);Lc(a+4264|0);kf(a);return a|0}function Yba(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function UP(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Al(d,a,b);dr(d);gb=c+16|0}function Q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Sg(a,v[b+8>>2],0)){fx(b,c,d)}}function Mca(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function MB(a){return(+y[a>>2]+ +v[a+4>>2]*4294967296)*2.3283064365386963e-10}function Il(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Db(d,a,b);dr(d);gb=c+16|0}function Fba(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function Aca(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function AA(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function A4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,5054);return}Hx(a,c)}function $F(a,b){var c=0;c=gb-16|0;gb=c;b=Xf(c+8|0,b);_F(b,a);Kd(b);gb=c+16|0}function xH(){a:{if(t[463960]&1){break a}if(!Qd(463960)){break a}Pd(463960)}}function wj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return et(et(c,a),b-B(a,100)|0)}function hH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function fH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function eg(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b?b:0){kb[v[v[b>>2]+4>>2]](b)}}function eA(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:18726)|0}function cn(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function az(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=uv(a,b);gb=c+16|0;return d?b:a}function _l(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0;return v[b+8>>2]}function Sd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Rb(b,c);Tw(a,b,d,c)}function SG(a,b){var c=0,d=0;Ee(a,be(b));b=v[fc(b)>>2];c=fc(a),d=b,v[c>>2]=d}function Gm(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=uv(b,a);gb=c+16|0;return d?b:a}function GW(a,b,c,d){a=c-b|0;if((a|0)>=1){hc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function Ck(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function $q(a){var b=0;b=gb-16|0;gb=b;a=v[rT(b+8|0,a)>>2];gb=b+16|0;return a}function tz(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function sz(a,b){a=a|0;b=b|0;return(b>>>0<=44?t[v[a+84>>2]+b|0]:63)<<24>>24}function rw(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12826,6210,85,7806);L()}}function qs(a,b){a=a|0;b=b|0;a=v[a>>2];return kb[v[v[a>>2]+32>>2]](a,0,b)|0}function lT(a,b){EU(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Ws(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function Tu(a,b,c){var d=0;d=gb-16|0;gb=d;yc(d+8|0,Ln(a,b,_l(c)));gb=d+16|0}function TV(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Rk(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12826,6210,48,7806);L()}}function PH(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function KR(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);GR(a,b,0,0,b+-1,0)}function Bi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function w1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Es()+(b<<2)>>2]}return b|0}function u1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Ds()+(b<<2)>>2]}return b|0}function sh(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function qo(a,b){a=v[a+4316>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function pg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function me(a,b){a=a|0;b=b|0;if(cm(a,b)){a=ii(bf(a,b))}else{a=0}return a|0}function kv(a,b,c){b=b-a|0;if((b|0)>=1){hc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function ix(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function et(a,b){b=x[(b<<1)+74096>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function _Q(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;$S(a,c)}function LY(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function z5(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+32>>2]](a,b,c)|0}function xV(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function un(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+48>>2]](a,b,c)|0}function rL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){go(c+120|0);Yb(c)}}function moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=wp(a,b),v[d>>2]=e}function joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=nw(a,b),u[d>>1]=e}function jl(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+12>>2]](a,b,c)|0}function hda(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function bR(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function Zz(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function Yl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function Rc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function R_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Yn(b+8|0,a,1);gb=b+16|0}function L_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Xk(b+8|0,a,1);gb=b+16|0}function Jea(a,b,c){a=a|0;b=b|0;c=c|0;if(Ab(b)>>>0>c>>>0){vu(b,c)}Dc(a,b)}function pE(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function jI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;sh(a,-1,-1)}function GY(a){return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function uc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Nf(b),v[c+4>>2]=d;return a}function nx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function le(a,b){im(a,b);v[a+8>>2]=v[b+8>>2];im(a+12|0,b+12|0);return a}function fy(a){return((ph(a)+(ph(a)<<8)|0)+(ph(a)<<16)|0)+(ph(a)<<24)|0}function _R(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Yf(a){var b=0;b=a;if(v[b>>2]){Od(b);Ey(v[b>>2],hv(b))}return a}function Vc(a,b){$F(a,b);v[a+8>>2]=v[b+8>>2];$F(a+12|0,b+12|0);return a}function SR(a){if(a>>>0<=8){return w[a+35488|0]}return w[a+35479|0]|256}function JL(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function DJ(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function yo(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function tF(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function hG(a,b){if(b>>>0>357913941){rd(8445);L()}return Nc(B(b,12),4)}function gl(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function fE(a,b){if(b>>>0>214748364){rd(8445);L()}return Nc(B(b,20),4)}function cx(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function _4(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){ua();L()}}function KC(a,b){if(b){KC(a,v[b>>2]);KC(a,v[b+4>>2]);Fk(b+16|0);_W(b)}}function Fz(a,b){if(b){Fz(a,v[b>>2]);Fz(a,v[b+4>>2]);Hb(b+16|0);aO(b)}}function Cz(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function Cc(a,b){if(Nb(a)>>>0<=b>>>0){_x();L()}return v[a>>2]+(b<<2)|0}function $h(a){a=a|0;a=vB(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function nh(a,b,c){return(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0&(c|0)>=0}function kF(a){return(w[v[a+104>>2]+34|0]&8)>>>3&(v[a+88>>2]&2050)==2}function WO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function Pj(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function MW(a,b){if(b>>>0>715827882){rd(8445);L()}return Nc(B(b,6),1)}function LD(a,b){var c=0;c=gb-16|0;gb=c;bc(a,v[b>>2],oc(b));gb=c+16|0}function Kh(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;$f(a,b);gb=c+16|0}function GC(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;kR(a,b);gb=c+16|0}function E$(a){a=a|0;if(!a){return 0}return(gx(a,89644,89788)|0)!=0|0}function A1(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;QH(a,b);gb=c+16|0}function zs(a,b,c,d,e){b=Fa(a|0,b|0,c|0,d|0,e|0)|0;jb=O()|0;return b}function zG(a,b,c){a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}vO(b,c)}}function wB(a,b){xc(a,b);xc(a+4|0,b+4|0);xc(wb(a),wb(b));wb(a);wb(b)}function vN(a){if(a>>>0>=82595525){rd(8445);L()}return Nc(B(a,52),4)}function tm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function t$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kb[a|0](b,c,d)|0}function q2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gg(a,f)}function pz(a,b,c){b=b-a|0;if(b){yh(c,a,b)}return B((b|0)/6|0,6)+c|0}function oW(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];js(a+8|0,b+8|0)}function mC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fc(a);if(b){jv(b)}}}function gB(a,b){mc(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function dF(a,b){if(b>>>0>2147483647){rd(8445);L()}return Nc(b<<1,2)}function SE(a,b){if(b>>>0>1073741823){rd(8445);L()}return Nc(b<<2,2)}function Gz(a){var b=0;WS(a);b=v[a>>2];if(b){ai(v[a+16>>2],b,Bk(a))}}function D1(a){a=a|0;var b=0;b=v[116064]+1|0;v[116064]=b;v[a+4>>2]=b}function uz(a,b){a=a|0;b=b|0;return w[v[a+88>>2]+b|0]!=63&b>>>0<=15}function rG(a,b,c,d,e,f,g){return Ma(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function qW(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function qT(a,b,c,d,e){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e)}function pP(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|32}function pC(a,b){if(b){pC(a,v[b>>2]);pC(a,v[b+4>>2]);Yn(fc(a),b,1)}}function oq(a,b){a=a|0;b=b|0;return w[v[a+84>>2]+b|0]!=63&b>>>0<=44}function ly(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function koa(a,b){a=a|0;b=b|0;Nj(a,zb(v[b>>2]),zb(v[b>>2])+oc(b)|0)}function a$(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);XF(a,1);gb=b+16|0}function ZV(a){if(a>>>0>=1073741824){rd(8445);L()}return Nc(a<<2,1)}function Yz(a){if(a>>>0>=1073741824){rd(8445);L()}return Nc(a<<2,4)}function XO(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){ln(c);Yb(c)}}function PO(a,b){var c=0;c=gb-16|0;gb=c;Fr(c,1,b);Bc(a,c);gb=c+16|0}function Dfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;gO(a,b,c,d,e)}function q1(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function oja(a,b){a=a|0;b=b|0;if(!v[22708]){v[22709]=b;v[22708]=a}}function mH(a,b,c){a=a|0;b=b|0;c=c|0;return _p(0,a,b,c?c:463984)|0}function jT(a,b){TB(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function fo(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function dS(a){if(a>>>0>=134217728){rd(8445);L()}return Nc(a<<5,4)}function Yc(a,b,c){a=a|0;b=b|0;c=c|0;return ad(a,B(Li(a),b)+c|0)|0}function SW(a){if(a>>>0>1073741823){rd(8445);L()}return Nc(a<<2,1)}function RH(a){if(a>>>0>=268435456){rd(8445);L()}return Nc(a<<4,4)}function CR(a){if(a>>>0>=536870912){rd(8445);L()}return Nc(a<<3,8)}function xU(a){a=a+34|0;a=nqa(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function wi(a,b){var c=0,d=0;c=a,d=Cx(v[b>>2]),v[c>>2]=d;return a}function rE(a){if(v[a>>2]){cE(a,v[a>>2]);dE(wb(a),v[a>>2],dm(a))}}function py(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function nn(a){a=a|0;return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function bG(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){Yb(gc(c))}}function Oc(a,b,c){a=a|0;b=b|0;c=c|0;if(aF(c)){Yb(a);return}Yb(a)}function LX(a){jb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function Kp(a,b){a=a|0;b=b|0;kc(a,b);Qb(a+20|0,0,1040);return a|0}function Kj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function I_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+12>>2]](a)|0}function H_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+16>>2]](a)|0}function BJ(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function yM(a){a=a|0;v[a>>2]=50720;Lc(a+4208|0);kf(a);return a|0}function nM(a){a=a|0;v[a>>2]=51212;Lc(a+4256|0);kf(a);return a|0}function ku(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function kba(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function id(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function eM(a){a=a|0;v[a>>2]=51824;Lc(a+4208|0);kf(a);return a|0}function _$(a){a=a|0;var b=0,c=0;b=a,c=xe(),v[b>>2]=c;return a|0}function WM(a){a=a|0;v[a>>2]=49672;Lc(a+4208|0);kf(a);return a|0}function J_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function IM(a){a=a|0;v[a>>2]=49908;gc(a+4208|0);kf(a);return a|0}function Et(a,b,c){a=v[a>>2];return(a|0)>=x[b>>1]&(a|0)<=x[c>>1]}function $Q(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function yx(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+12>>2]](a,b)|0}function xR(a){Zp(a);if(v[a>>2]){mR(a);mm(wb(a),v[a>>2],ug(a))}}function wl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b?b:0){Yb(Yf(b))}}function w$(a,b){a=a|0;b=b|0;a=kb[a|0](b)|0;ma(jb|0);return a|0}function uB(a){gT(a);if(v[a>>2]){fT(a);tB(wb(a),v[a>>2],aj(a))}}function sM(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function qn(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+28>>2]](a,b)|0}function nA(a){hY(a);if(v[a>>2]){tY(a);gY(wb(a),v[a>>2],mn(a))}}function mg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function lm(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+24>>2]](a)|0}function lA(a){DO(a);if(v[a>>2]){CO(a);$z(wb(a),v[a>>2],ok(a))}}function jfa(a,b){a=a|0;b=b|0;a=eY(a,b);if(!a){Gv(b)}return a|0}function gA(a){JF(a);if(v[a>>2]){cG(a);ks(wb(a),v[a>>2],_k(a))}}function di(a){Ek(a);if(v[a>>2]){br(a);IC(wb(a),v[a>>2],pe(a))}}function cp(a){Ek(a);if(v[a>>2]){br(a);pw(wb(a),v[a>>2],pe(a))}}function bha(a,b){a=a|0;b=b|0;a=mW(a,b);if(!a){lW(b)}return a|0}function Xi(a,b,c){a=a|0;b=b|0;c=c|0;return Ln(_l(a),_l(b),c)|0}function Vs(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+44>>2]](a,b)|0}function Pk(a){Ep(a);if(v[a>>2]){Aw(a);iE(wb(a),v[a>>2],Og(a))}}function OV(a,b,c,d){le(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Nt(a){OM(a);if(v[a>>2]){SM(a);NM(wb(a),v[a>>2],Cl(a))}}function Kq(a){qR(a);if(v[a>>2]){eR(a);PA(wb(a),v[a>>2],tg(a))}}function Hw(a,b,c){Xf(a,b);v[a+8>>2]=0;Xf(a+12|0,c);Kd(c);Kd(b)}function Hu(a){ev(a);if(v[a>>2]){gS(a);Xk(wb(a),v[a>>2],bi(a))}}function Fx(a,b){a=a|0;b=b|0;return(Qh(a)|0)!=0|(a|32)-97>>>0<6}function x$(a,b){a=a|0;b=+b;a=kb[a|0](b)|0;ma(jb|0);return a|0}function wC(a,b){a=a|0;b=b|0;a=RV(a,b);if(!a){_j(b)}return a|0}function vL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function nF(a,b){a=a|0;b=b|0;a=mF(a,b);if(!a){Dw(b)}return a|0}function hj(a){bC(a);if(v[a>>2]){pw(v[a+16>>2],v[a>>2],Bk(a))}}function hE(a){cF(a);if(v[a>>2]){iE(v[a+16>>2],v[a>>2],yw(a))}}function eh(a){bC(a);if(v[a>>2]){ai(v[a+16>>2],v[a>>2],Bk(a))}}function ds(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function cu(a){a=a|0;v[a>>2]=77316;vb(a+32|0);ym(a);return a|0}function as(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function aC(a,b){a=a|0;b=b|0;a=ZX(a,b);if(!a){iD(b)}return a|0}function Yw(a,b){a=a|0;b=b|0;a=SF(a,b);if(!a){Mw(b)}return a|0}function Xb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function XD(a,b){a=a|0;b=b|0;a=Tv(a,b);if(!a){Uv(b)}return a|0}function Wf(a,b){return kb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function Uw(a,b){a=a|0;b=b|0;a=EF(a,b);if(!a){DF(b)}return a|0}function TW(a){bC(a);if(v[a>>2]){IC(v[a+16>>2],v[a>>2],Bk(a))}}function Rw(a,b){Xf(a,b);v[a+8>>2]=v[b+8>>2];Xf(a+12|0,b+12|0)}function Nl(a,b){a=t[ic(a+58|0,b)|0];return((a|0)>-1?a:-1)&255}function Jv(a,b,c){a=w[a|0];return a>>>0>=w[b|0]&a>>>0<=w[c|0]}function Ih(a,b){a=a|0;b=b|0;a=lj(a,b);if(!a){jm(b)}return a|0}function Hh(a){cF(a);if(v[a>>2]){zw(v[a+16>>2],v[a>>2],yw(a))}}function HC(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4896);gb=c+16|0}function Ew(a,b){rF(a,b);v[a+8>>2]=v[b+8>>2];rF(a+12|0,b+12|0)}function Av(a){a=a|0;a=w[a|0];return ve(a)^1|(a-49&255)>>>0<36}function vy(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function qG(a,b,c){b=Ja(1999,a|0,b|0,c|0)|0;jb=O()|0;return b}function p_(a,b){a=a|0;b=b|0;Qs(a,b);v[a>>2]=89300;return a|0}function ne(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function nR(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function iO(a){a=a|0;v[a+12>>2]=1065353216;hO(a,4);return a|0}function hna(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,tI(c,Jb(b),Ab(b)))}function ft(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function f8(a,b){a=a|0;b=b|0;Qs(a,b);v[a>>2]=89352;return a|0}function Um(a,b,c){u[a>>1]=x[b>>1];v[a+4>>2]=v[c>>2];return a}function Si(a,b){a=a|0;b=b|0;if(ze(a)>>>0>b>>>0){t[a+16|0]=b}}function RX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c?c:0){Yb(c)}}function Pu(a,b,c){v[a>>2]=v[b>>2];v[a+4>>2]=v[c>>2];return a}function NS(a,b){a=a|0;b=b|0;Qs(a,b);v[a>>2]=89164;return a|0}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;return vv(a,b,c,1096)|0}function Gea(a,b,c){a=a|0;b=b|0;c=c|0;return vv(a,b,c,1487)|0}function Er(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function $8(a,b,c){a=a|0;b=b|0;c=c|0;JT(a,0,Jk(v[b+24>>2]),c)}function wc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function sp(a,b,c){if(!b){return 0}return mt(a,Lg(t[c|0]),b)}function pF(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,36);gb=c+16|0}function oda(a){a=a|0;a=nk(a);if(a){kb[v[v[a>>2]+96>>2]](a)}}function hoa(a,b,c){a=a|0;b=b|0;c=c|0;return vv(a,b,c,644)|0}function dz(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function aP(a){v[a>>2]=0;mc(a+4|0);Qb(a+16|0,0,144);return a}function Ss(){var a=0;a=ba(4)|0;nm(a);ia(a|0,89104,1930);L()}function PW(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,12);gb=c+16|0}function FJ(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function zB(a,b){if(b){zB(a,v[b>>2]);zB(a,v[b+4>>2]);jv(b)}}function yF(a){var b=0;b=v[a+8>>2];if(b){Xk(a,b,v[a+4>>2])}}function uD(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,8);gb=c+16|0}function oC(a,b){if(b){oC(a,v[b>>2]);oC(a,v[b+4>>2]);jv(b)}}function lu(a,b){if(b){lu(a,v[b>>2]);lu(a,v[b+4>>2]);jv(b)}}function iB(a){dd(a);v[a+12>>2]=0;u[a+16>>1]=65280;return a}function i1(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function cU(a){if(v[a>>2]){$T(a,v[a>>2]);Vu(v[a>>2],ug(a))}}function Vr(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,1);gb=c+16|0}function Qw(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function LF(a){var b=0;b=v[a+8>>2];if(b){Yn(a,b,v[a+4>>2])}}function HI(a,b){if(b>>>0<=9){return GI(a,b)}return et(a,b)}function Bn(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,2);gb=c+16|0}function Ai(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4);gb=c+16|0}function AB(a,b){if(b){AB(a,v[b>>2]);AB(a,v[b+4>>2]);uT(b)}}function xG(a){a=v[a>>2]-12|0;if((Qw(a+8|0)|0)<=-1){Yb(a)}}function vB(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function qF(a){var b=0;b=gb-16|0;gb=b;Qb(a,0,36);gb=b+16|0}function lg(a,b){a=oqa(v[a>>2],v[a+4>>2],b,b>>31);return a}function dr(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function aga(a){a=a|0;Qs(a,18726);v[a>>2]=89244;return a|0}function _8(a){a=a|0;wL(a,2,100);Si(v[a+24>>2]+484360|0,0)}function Zl(a){a=a|0;return(v[a+480180>>2]&740327453)!=0|0}function Z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb=0;return 0}function Xn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function Ud(a,b){a=a|0;b=b|0;td(a,v[b>>2],v[b>>2]+oc(b)|0)}function UK(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function Ab(a){if(De(a)){return v[a+4>>2]}return w[a+11|0]}function yp(a,b,c){td(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function wv(a){if(v[a>>2]){XW(a);JC(wb(a),v[a>>2],Wj(a))}}function uO(a){var b=0;rC(a);b=v[a>>2];if(b){wO(b,Bk(a))}}function t_(a){a=a|0;aG(a,10671);v[a>>2]=28324;return a|0}function sv(a){if(v[a>>2]){br(a);ai(wb(a),v[a>>2],pe(a))}}function sk(a){a=v[a+656>>2];if(!a){return 0}return Ij(a)}function qL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){zL(c)}}function px(a){if(v[a>>2]){Od(a);zG(jx(a),v[a>>2],pe(a))}}function oX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){GU(c)}}function ky(a,b){return v[((a>>>24^b)<<2)+459712>>2]^a<<8}function km(a){if(v[a>>2]){HF(a);$k(wb(a),v[a>>2],dg(a))}}function eJ(a){while(1){if((qt(a)|0)!=-1){continue}break}}function bs(a){if(v[a>>2]){Aw(a);zw(wb(a),v[a>>2],Og(a))}}function _V(a){var b=0;rC(a);b=v[a>>2];if(b){sC(b,Bk(a))}}function ZF(a){var b=0;b=v[a+8>>2];if(b){XF(b,v[a+4>>2])}}function Yq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Ye(a){if(v[a>>2]){ai(wb(a),v[a>>2],v[wb(a)>>2])}}function Xg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Wg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function VJ(a){var b=0;b=v[a+8>>2];if(b){UJ(b,v[a+4>>2])}}function RJ(a){var b=0;b=v[a+8>>2];if(b){Zu(b,v[a+4>>2])}}function Nx(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function JK(a){a=a|0;return Ti(Sb(v[a+24>>2]+484360|0))|0}function JD(a,b){var c=0;c=gb-16|0;gb=c;rR(a,b);gb=c+16|0}function HV(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function Ce(a,b,c){td(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function zj(a){return Me(a)|Me(a)<<8|Me(a)<<16|Me(a)<<24}function zb(a){var b=0;b=gb-16|0;gb=b;gb=b+16|0;return a}function v6(a,b,c){a=a|0;b=b|0;c=c|0;return Cd(B(b,c))|0}function tA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;FA(a,b,c,d)}function pv(a){cp(a+88|0);cp(a+68|0);cp(a+48|0);return a}function m$(a){a=a|0;NS(a,5089);v[a>>2]=27324;return a|0}function ioa(a,b){a=a|0;b=b|0;Tb(a,b?b:18726);return a|0}function iI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sh(a,-1,-1)}function h9(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,tI(c,b,Nf(b)))}function g$(a,b,c){a=a|0;b=b|0;c=c|0;Tw(a,b,v[b+8>>2],c)}function e$(a){a=a|0;aG(a,5835);v[a>>2]=27432;return a|0}function _j(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function Xe(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pf(a,c,d,b)}function XC(a){a=a|0;if(!w[a|0]){return 1}return ce(a)|0}function Vba(a){a=a|0;bM(a);t[a+4202|0]=1;v[a+4224>>2]=0}function VA(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function SJ(a){a=a|0;v[a>>2]=59164;gc(a+12|0);return a|0}function Opa(a,b,c){a=a|0;b=b|0;c=c|0;return ND(a,b,c)|0}function JG(a,b){Kn(v[b>>2]);Mn(v[a>>2]);v[a>>2]=v[b>>2]}function In(a,b,c){a=oqa(v[a>>2],v[a+4>>2],b,c);return a}function DG(a){a=a|0;v[a>>2]=83776;vb(a+12|0);return a|0}function CG(a){a=a|0;v[a>>2]=83816;vb(a+16|0);return a|0}function zv(a,b,c){a=a|0;b=b|0;c=c|0;return mt(a,b,c)|0}function ym(a){a=a|0;v[a>>2]=77012;Wb(a+4|0);return a|0}function wF(a){a=a|0;v[a>>2]=28184;Kd(a+4|0);return a|0}function qH(a){return(a|0)!=0&(a|0)!=74848&(a|0)!=74872}function pJ(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function lH(a,b,c,d){a=CI(a,b,c,0,-2147483648);return a}function lG(a,b,c){a=a|0;b=b|0;c=c|0;return ws(a,b,c)|0}function k5(a,b){a=a|0;b=b|0;return UF(a,Jb(b),Ab(b))|0}function hx(a){a=a|0;v[a>>2]=89124;xG(a+4|0);return a|0}function hr(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(c<<2)|0}function hP(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){GU(b)}}function ef(a,b,c){a=a|0;b=b|0;c=c|0;Fe(a,b);return a|0}function _L(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function ZL(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function TC(a,b,c){a=a|0;b=b|0;c=c|0;return OD(a,b,c)|0}function Rv(a,b,c){a=a|0;b=b|0;c=c|0;return OY(a,b,c)|0}function Ps(a,b,c){return oG(Jb(a),Ab(a),Jb(b),c,Ab(b))}function PJ(a){a=a|0;v[a>>2]=59580;gc(a+4|0);return a|0}function Ln(a,b,c){b=b-a|0;if(b){yh(c,a,b)}return b+c|0}function LG(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Mn(b)}}function Kc(a){if(De(a)){a=ek(a)-1|0}else{a=10}return a}function Jp(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Ht(a){a=a|0;v[a>>2]=55124;Jt(a+4|0);return a|0}function Fd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function Dj(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){zL(b)}}function Cs(a){a=a|0;v[a>>2]=89144;xG(a+4|0);return a|0}function $p(a){a=a|0;v[a>>2]=77076;Wb(a+4|0);return a|0}function tj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function qM(a){a=a|0;return Jj(C(z[a+4224>>2]*C(4)))|0}function q$(a){a=a|0;a=kb[a|0]()|0;ma(jb|0);return a|0}function ph(a){var b=0;b=qt(a);v[a+1396>>2]=0;return b}function m5(a){a=a|0;return Bq(v[v[a>>2]-12>>2]+a|0)|0}function j4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Nj(a,c,d)}function i5(a){a=a|0;return wf(v[v[a>>2]-12>>2]+a|0)|0}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function fI(a){a=a|0;return at(v[v[a>>2]-12>>2]+a|0)|0}function dq(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function aq(a){if(De(a)){a=ek(a)-1|0}else{a=1}return a}function ZK(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function WR(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;$A(a)}function VH(a){a=a|0;return _s(v[v[a>>2]-12>>2]+a|0)|0}function Ug(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+20>>2]](a,b)}function SP(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,b+4228|0,7)}function Q_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mk(a,d,0)}function Ph(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+24>>2]](a,b)}function Oh(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+28>>2]](a,b)}function Lb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Ida(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,b+4260|0,8)}function Hq(a,b){v[a>>2]=b;v[a+4>>2]=b+223232;return a}function Cw(a,b){a=nqa(v[a>>2],v[a+4>>2],b,0);return a}function C2(a,b){a=a|0;b=b|0;td(a,WH(v[b>>2]),v[b>>2])}function xo(a){a=a|0;return kb[v[v[a>>2]+24>>2]](a)|0}function vda(a){a=a|0;t[a+4202|0]=1;Pt(a);bz(a);LM(a)}function vb(a){if(De(a)){$k(a,v[a>>2],ek(a))}return a}function us(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function sj(a){a=a|0;return kb[v[v[a>>2]+12>>2]](a)|0}function rj(a){a=a|0;return kb[v[v[a>>2]+16>>2]](a)|0}function ri(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function pf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function nj(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function fma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function cm(a,b){a=a|0;b=b|0;return Te(a)>>>0>b>>>0|0}function Rn(a,b){return kb[v[v[a>>2]+36>>2]](a,b,0)|0}function Qn(a,b){return kb[v[v[a>>2]+52>>2]](a,b,0)|0}function Pf(a,b,c){a=a|0;b=b|0;c=c|0;Yo(a);return a|0}function KD(a){var b=0;b=gb-16|0;gb=b;Ok(a);gb=b+16|0}function Ic(a){if(De(a)){ai(a,v[a>>2],ek(a))}return a}function IK(a){a=a|0;return nq(v[a+24>>2]+484344|0)|0}function GM(a){Lc(a+36|0);Lc(a+24|0);Nt(a+12|0);Nt(a)}function Eca(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function xn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function rM(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function pka(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,Gs(b,c))}
function mqa(a){if(a){return 31-E(a-1^a)|0}return 32}function kq(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function jP(a){if(v[a>>2]){Od(a);gP(v[a>>2],tg(a))}}
function dp(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function aca(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function VK(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function QK(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function Eea(a,b){a=a|0;b=b|0;a=a+24|0;IN(a,b);fA(a)}function z6(a,b,c){a=a|0;b=b|0;c=c|0;wJ(a-88|0,b,c)}function wd(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function vl(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function vX(a){a=a|0;return rz(w[a+3|0],w[a+5|0])|0}function nD(a,b){le(a,b);Qb(a+20|0,0,1040);return a}function ms(a){if(v[a>>2]){Od(a);FF(v[a>>2],tg(a))}}function l9(a){a=a|0;a=v[a+4>>2];return(a?a:2107)|0}function ke(a){if(v[a>>2]){MY(a);yD(v[a>>2],aj(a))}}function ho(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function gu(a){v[a>>2]=38364;v[a>>2]=18736;return a}function gt(a){if(!a){return 0}v[115189]=a;return-1}function gq(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function ep(a){if(v[a>>2]){Od(a);uW(v[a>>2],sW(a))}}function ci(a){if(v[a>>2]){Od(a);sC(v[a>>2],pe(a))}}function be(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function _T(a){if(v[a>>2]){Od(a);Vu(v[a>>2],ug(a))}}function Yp(a,b){b=v[b>>2];v[a>>2]=b;Kn(b);return a}function YK(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function Y5(a,b){a=a|0;b=b|0;return UF(a,b,Nf(b))|0}function Vpa(a){a=a|0;ln(90864);qD(90856);vb(90844)}function Vo(a,b,c){if(!c){return 0}return sd(a,b,c)}function Uu(a){if(v[a>>2]){Od(a);HB(v[a>>2],bi(a))}}function TQ(a){if(v[a>>2]){Od(a);MQ(v[a>>2],HA(a))}}function Su(a){if(v[a>>2]){Od(a);EB(v[a>>2],FB(a))}}function Ru(a){if(v[a>>2]){Od(a);GB(v[a>>2],xi(a))}}function PK(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function Kea(a,b){a=a|0;b=b|0;gk(a+36|0,b);return 1}function IR(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function IB(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function Gs(a,b){a=a|0;b=b|0;return Bp(a,b,Nf(b))|0}function Gr(a){if(v[a>>2]){Od(a);FY(v[a>>2],Og(a))}}function Gq(a){a=a|0;return qu(w[a+2|0],w[a+4|0])|0}function Gp(a){a=a|0;a=dc(a);kb[v[v[a>>2]>>2]](a)|0}function Gl(a){if(v[a>>2]){Od(a);wO(v[a>>2],pe(a))}}function Fo(a){a=a|0;return qu(w[a+3|0],w[a+5|0])|0}function Db(a,b,c){td(a,(c>>>3&536870908)+b|0,1<<c)}function B6(a,b,c){a=a|0;b=b|0;c=c|0;yJ(a-88|0,b,c)}function y6(a,b){a=a|0;b=b|0;return vJ(a-88|0,b)|0}function vC(a,b,c){u[a>>1]=x[b>>1];t[a+2|0]=w[c|0]}function ql(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function on(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function cD(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function Vj(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function Rl(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function Ot(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,OG(b,c))}function Nm(a){Gj(a+724|0);Gj(a+732|0);Gj(a+740|0)}function MP(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function Lj(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function Io(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function D6(a,b,c){a=a|0;b=b|0;c=+c;AJ(a-88|0,b,c)}function A6(a,b){a=a|0;b=b|0;return xJ(a-88|0,b)|0}function $t(a){a=a|0;Jh(a);v[a+20>>2]=0;return a|0}function vg(a,b){return oG(Jb(a),Ab(a),b,0,Nf(b))}function ug(a){return(v[wb(a)>>2]-v[a>>2]|0)/12|0}function td(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function sW(a){return(v[wb(a)>>2]-v[a>>2]|0)/33|0}function pma(a,b){a=a|0;b=b|0;if(!Tv(a,b)){Uv(b)}}function ok(a){return(v[wb(a)>>2]-v[a>>2]|0)/52|0}function mn(a){return(v[wb(a)>>2]-v[a>>2]|0)/48|0}function kfa(a,b){a=a|0;b=b|0;if(!SF(a,b)){Mw(b)}}function jh(a,b){if(De(a)){de(a,b);return}_e(a,b)}function hv(a){return(v[wb(a)>>2]-v[a>>2]|0)/24|0}function fna(a,b){a=a|0;b=b|0;if(!mF(a,b)){Dw(b)}}function dm(a){return(v[wb(a)>>2]-v[a>>2]|0)/20|0}function aj(a){return(v[wb(a)>>2]-v[a>>2]|0)/28|0}function _k(a){return(v[wb(a)>>2]-v[a>>2]|0)/36|0}function Yj(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,20,b)}function Vm(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Qk(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,22,b)}function Npa(a,b){a=a|0;b=b|0;if(!eY(a,b)){Gv(b)}}function NI(a,b){if(!a){return 0}return pl(a,b,0)}function Mk(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,28,b)}function Lp(a){return(v[dc(a)>>2]-v[a>>2]|0)/12|0}function Lk(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,12,b)}function Kr(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,30,b)}function Je(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,32,b)}function IU(a){return(v[wb(a)>>2]-v[a>>2]|0)/56|0}function He(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function HY(a){return(v[dc(a)>>2]-v[a>>2]|0)/28|0}function Fr(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,64,b)}function Cp(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,26,b)}function Cna(a,b){a=a|0;b=b|0;if(!mW(a,b)){lW(b)}}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function BN(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function BE(a){return!sd(a,28402,25)&w[a+34|0]<65}function AW(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,16,b)}function $C(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,40,b)}function zz(a){return B(Lj(a),Rl(a))+7>>>3&65535}function zr(a,b){a=_X(a,b);if(!a){aY(b)}return a}function zC(a,b){a=a|0;b=b|0;if(!aW(a,b)){tC(b)}}function yy(a,b,c){return Xg(a,b,v[a+12>>2]+c|0)}function yR(a){return(v[a+4>>2]-v[a>>2]|0)/872|0}function wY(a,b){a=mY(a,b);if(!a){lD(b)}return a}function pr(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function ni(a){return(Vf(a)|0)!=(0-Vf(a+12|0)|0)}function kX(a,b){a=a|0;b=b|0;return Vt(a,b,32)|0}function hB(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function h4(a,b){a=a|0;b=b|0;return kb[b|0](a)|0}function eo(a,b,c){return HV(a,b,v[a+12>>2]+c|0)}function cca(a){a=a|0;return z[a+4212>>2]<C(1)|0}function bY(a,b){a=a|0;b=b|0;if(!ZX(a,b)){iD(b)}}function Yg(a){a=w[a+20|0];return(a|0)==255?-1:a}function Wj(a){return(v[wb(a)>>2]-v[a>>2]|0)/6|0}function WJ(a,b,c){a=Td(a);v[a+4>>2]=c;v[a>>2]=b}function WD(a,b){a=a|0;b=b|0;if(!EF(a,b)){DF(b)}}function Ol(a){a=a|0;Sq(v[a+20>>2]);v[a+20>>2]=0}function Oi(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function NA(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Jb(a){if(De(a)){return v[a>>2]}return a}function HA(a){return(v[wb(a)>>2]-v[a>>2]|0)/7|0}function Gy(a,b){v[a>>2]=v[b>>2];Dc(a+4|0,b+4|0)}function Gpa(a,b,c){a=a|0;b=b|0;c=c|0;hc(b,c,48)}function Gca(a){a=a|0;return z[a+4220>>2]<C(1)|0}function DY(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function DS(a,b){yc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function CZ(a,b){a=a|0;b=b|0;if(!QD(a,b)){Wv(b)}}function C6(a,b){a=a|0;b=b|0;return+zJ(a-88|0,b)}function By(a,b,c){return hr(a,b,v[a+12>>2]+c|0)}function Br(a,b){a=a|0;b=b|0;if(!lj(a,b)){jm(b)}}function $A(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function yr(a,b,c){b=b-a|0;if(b){yh(c-b|0,a,b)}}function yca(a){a=a|0;t[a+4202|0]=1;oM(a);pM(a)}function qv(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function qca(a){a=a|0;t[a+4202|0]=1;jM(a);iM(a)}function nl(a){a=a|0;return bI(v[a>>2])<<24>>24}function kn(a,b,c){v[a>>2]=b;v[a+4>>2]=(c<<1)+b}function jo(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function dl(a){return kb[v[v[a>>2]+36>>2]](a)|0}function cr(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function al(a){return(v[a+4>>2]-v[a>>2]|0)/36|0}function Xj(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function Wn(a){return kb[v[v[a>>2]+28>>2]](a)|0}function Wm(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Tf(a,b){a=a|0;b=b|0;return Yc(a,b,0)|0}function Sf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function Op(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Mba(a){a=a|0;$L(a);Vy(a);t[a+4202|0]=1}function MV(a){var b=0;b=v[a>>2];Oe(a);return b}function Ie(a){return(v[a+4>>2]-v[a>>2]|0)/20|0}function Gu(a,b){a=a|0;b=b|0;gg(a,b);return a|0}function Ec(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function Ax(a,b,c,d){a=CI(a,b,c,-1,-1);return a}function $i(a){return(v[a+4>>2]-v[a>>2]|0)/28|0}function ul(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function uf(a,b,c){if(!(w[a|0]&32)){fD(b,c,a)}}function ko(a,b,c){a=a|0;b=b|0;c=c|0;td(a,b,c)}function gp(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function gD(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function bc(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,b,c)}function ZR(a,b){UR(v[a>>2],b);UR(v[a+4>>2],b)}function Wt(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function Uj(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function T8(a,b){a=a|0;b=b|0;Dc(a,Gs(b,14738))}function PR(a){WA(a);Qb(a+27|0,0,255);return a}function Md(a){return v[a+20>>2]!=0&v[a>>2]!=0}function MA(a){return(v[a+4>>2]-v[a>>2]|0)/7|0}function Li(a){a=a|0;return x[so(a)+480188>>1]}function Jg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function Ip(a){WF(a);v[a+8>>2]=0;v[a>>2]=79020}function Fu(a){return(a>>>0<9?a:a-9|256)&65535}function E4(a,b,c){a=a|0;b=b|0;c=c|0;td(a,c,b)}function Ak(a,b){return(B(b,104)+a|0)+484380|0}function yg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function xF(a){a=a|0;v[a>>2]=28048;return a|0}function wm(a,b){a=a|0;b=b|0;return YH(a,b)^1}function qx(a,b){a=a|0;b=b|0;return Gs(a,b)|0}function qqa(a,b,c,d){a=lqa(a,b,c,d);return a}function qc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function pi(a,b){a=a|0;b=b|0;return Nc(b,1)|0}function pY(a){t[a+12|0]=w[a+12|0]|2;return a}function og(a,b){a=a|0;b=b|0;return Gb(a,b)|0}function lk(a,b){a=a|0;b=b|0;return cI(a,b)^1}function l5(a){a=a|0;OH(v[v[a>>2]-12>>2]+a|0)}function kk(a,b){a=a|0;b=b|0;return cI(a,b)|0}function ki(a,b){a=a|0;b=b|0;return mw(a,b)|0}function il(a,b){a=a|0;b=b|0;return YH(a,b)|0}function h5(a){a=a|0;NH(v[v[a>>2]-12>>2]+a|0)}function eI(a){a=a|0;Sx(v[v[a>>2]-12>>2]+a|0)}function bk(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function Zh(a,b){a=a|0;b=b|0;return oS(a,b)|0}function VF(a){a=a|0;v[a>>2]=27480;return a|0}function Ut(a,b){a=a|0;b=b|0;return OG(a,b)|0}function UH(a){a=a|0;Ox(v[v[a>>2]-12>>2]+a|0)}function Td(a){v[a>>2]=0;v[a+4>>2]=0;return a}function TJ(a){a=a|0;v[a>>2]=58808;return a|0}function QJ(a){a=a|0;v[a>>2]=59216;return a|0}function PG(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Oy(a){a=a|0;v[a>>2]=54956;return a|0}function KF(a){a=a|0;v[a>>2]=27812;return a|0}function Ij(a){return(w[a+31|0]-1&255)>>>0<17}function HP(a){jP(a+20|0);iP(a+8|0);hP(a+4|0)}function Gb(a,b){a=a|0;b=b|0;return Qj(a,b)^1}function Cl(a){return v[wb(a)>>2]-v[a>>2]>>11}function CW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function zL(a){if(a){kb[v[v[a>>2]+4>>2]](a)}}function zF(a){return v[dc(a)>>2]-v[a>>2]>>3}function yw(a){return v[dc(a)>>2]-v[a>>2]>>1}function yu(a,b,c){a=a|0;b=b|0;c=c|0;Zj(b,c)}function xi(a){return v[wb(a)>>2]-v[a>>2]>>4}function tg(a){return v[wb(a)>>2]-v[a>>2]>>3}function pe(a){return v[wb(a)>>2]-v[a>>2]>>2}function pG(a){a=Ha(a|0)|0;jb=O()|0;return a}function ng(a){return v[v[a+8>>2]>>2]==(a|0)}function h6(a){a=a|0;return Ea(v[a+60>>2])|0}function ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function bi(a){return v[wb(a)>>2]-v[a>>2]>>5}function bca(a){a=a|0;return C(z[a+4220>>2])}function _6(a){a=a|0;OJ(a);return v[a+16>>2]}function Wy(a){return C(C(a*C(7900))+C(100))}function Wo(a){a=a|0;qB(a+288|0);Xo(a+800|0)}function TK(a){a=a|0;return SK(v[a+24>>2])|0}function Qx(a){return v[dc(a)>>2]-v[a>>2]>>4}function On(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c)}function Og(a){return v[wb(a)>>2]-v[a>>2]>>1}function Jf(a){return v[a+8>>2]-v[a+12>>2]|0}function GF(a,b){a=a|0;b=b|0;return(b|0)<6|0}function Fca(a){a=a|0;return C(z[a+4212>>2])}function FB(a){return v[wb(a)>>2]-v[a>>2]>>8}function Cv(a,b,c){a=a|0;b=b|0;c=c|0;js(b,c)}function CB(a){return v[dc(a)>>2]-v[a>>2]>>5}function Bk(a){return v[dc(a)>>2]-v[a>>2]>>2}function zf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function vM(a){a=a|0;kb[v[v[a>>2]+4>>2]](a)}function um(a){a=a|0;WH(v[a>>2]);return a|0}function tM(a){a=a|0;return C(z[a+4208>>2])}function oK(a,b){a=a|0;b=b|0;return oc(b)|0}function nK(a,b){a=a|0;b=b|0;return Nb(b)|0}function ml(a){a=a|0;Rx(v[a>>2]);return a|0}function hu(a){RO(a);v[a>>2]=77380;return a}function gL(a){t[a+4|0]=0;t[a|0]=0;return a}function g6(a,b){a=a|0;b=b|0;return Qh(a)|0}function dg(a){return v[wb(a)>>2]-v[a>>2]|0}function dda(a,b,c){a=a|0;b=b|0;c=c|0;Td(a)}function bp(a,b){return v[a>>2]<v[b>>2]?b:a}function au(a,b,c){b=b-a|0;if(b){yh(c,a,b)}}function ar(a){return jr(v[a>>2],v[a+4>>2])}function YR(a,b){u[a+22>>1]=b&7;$A(a);aB(a)}function Vf(a){return v[a+4>>2]-v[a>>2]>>11}function U_(a,b){a=a|0;b=b|0;OF(Qb(b,0,36))}function ML(a){return Xh(C(OL(a)*C(32768)))}function Ki(a,b){a=a|0;b=b|0;return C(C(0))}function Fda(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function EH(a){RO(a);v[a>>2]=77452;return a}function $6(a){a=a|0;OJ(a);return v[a+4>>2]}function zx(a){a=a|0;return Nh(a,464300)|0}function zea(a,b){a=a|0;b=b|0;gg(a,b+36|0)}function ze(a){return v[a+4>>2]-v[a>>2]>>5}function w5(a){a=a|0;return Nh(a,464096)|0}function vx(a){a=a|0;return Nh(a,464308)|0}function vf(a){return v[a+4>>2]-v[a>>2]>>4}function tc(a){return v[a+4>>2]-v[a>>2]>>1}function sf(a){return v[a+4>>2]-v[a>>2]>>3}function rp(a,b){return v[a>>2]-v[b>>2]>>1}function ov(a,b){return v[a>>2]-v[b>>2]>>2}function nH(){return(v[v[22614]>>2]?4:1)|0}function n7(a,b){a=a|0;b=b|0;SQ(v[a>>2],b)}function fl(a,b){kb[v[v[b>>2]+44>>2]](a,b)}function el(a,b){kb[v[v[b>>2]+32>>2]](a,b)}function ek(a){return v[a+8>>2]&2147483647}function dh(a){return v[a+4>>2]-v[a>>2]>>8}function _q(a,b){a=a|0;b=b|0;return b-a>>1}function ZD(a){return w[a+1|0]==2&w[a|0]<3}function XR(a,b){t[a+21|0]=b&3;$A(a);aB(a)}function WK(a){a=a|0;return+OO(v[a+24>>2])}function SL(a){return C(C(a*C(96))+C(-96))}function Qfa(a,b){a=a|0;b=b|0;gk(a+40|0,b)}function Px(a){a=a|0;return Nh(a,464260)|0}function Nb(a){return v[a+4>>2]-v[a>>2]>>2}function NT(a,b){return v[a>>2]+B(b,872)|0}function Mx(a){a=a|0;return Nh(a,464268)|0}function Lw(a){ps(a+32|0);xb(a+12|0);vb(a)}function L5(a){a=a|0;return Nh(a,464080)|0}function Km(a){vb(a+36|0);Lc(a+24|0);jn(a)}function Ix(a){a=a|0;return Nh(a,464276)|0}function Hs(a,b){kb[v[v[b>>2]+40>>2]](a,b)}function $u(a){Ye(a+24|0);gc(a+12|0);gc(a)}function $_(a){a=a|0;return v[a+4>>2]!=0|0}function zD(a){a=a|0;return Nh(a,466e3)|0}function yW(a,b){return v[a>>2]+B(b,33)|0}function w6(a,b){a=a|0;b=b|0;tJ(a-88|0,b)}function vm(a){a=a|0;return XH(v[a>>2])|0}function ty(a){a=a|0;Ft(a+8|0);return a|0}function so(a){return v[v[a+48>>2]+12>>2]}function po(a,b,c){Nj(a,b,b+c|0);return a}function of(a){v[a>>2]=v[a>>2]+2;return a}function oc(a){return v[a+4>>2]-v[a>>2]|0}function my(a){a=a|0;if(a){iJ(a);he(a,a)}}function jF(a){return(w[a+24|0]&16)>>>4|0}function ika(a){a=a|0;return ds(a+20|0)|0}function hS(a){v[a>>2]=v[a>>2]-2;return a}function fi(a){return x[a+480190>>1]<3999}function bn(a,b){return v[a>>2]+B(b,56)|0}function bf(a,b){return v[a>>2]+B(b,52)|0}function at(a){a=a|0;oh(a+8|0);return a|0}function ak(a,b){return v[a>>2]-v[b>>2]|0}function _t(a,b){return v[a>>2]+B(b,28)|0}function _s(a){a=a|0;oh(a+4|0);return a|0}function ZN(a,b){Vm(a,A[b>>3],-A[b+8>>3])}function YY(a,b){a=a|0;b=b|0;gk(a+12|0,b)}function Wl(a,b){return v[a>>2]+B(b,24)|0}function VP(a,b){if(z[a>>2]>b){z[a>>2]=b}}function Rca(a){a=a|0;t[a+4202|0]=1;zM(a)}function RL(a){a=a|0;Qb(a+4296|0,0,81928)}function Qf(a){a=a|0;Jh(a+8|0);return a|0}function Oj(a,b){return v[a>>2]+B(b,36)|0}function OG(a,b){return Bp(a,Jb(b),Ab(b))}function O0(a,b){a=a|0;b=b|0;gg(a,b+16|0)}function M6(a,b){a=a|0;b=b|0;JJ(a-88|0,b)}function L6(a,b){a=a|0;b=b|0;IJ(a-88|0,b)}function Kg(a,b){return v[a>>2]+B(b,20)|0}function Kba(a){a=a|0;return v[a+4260>>2]}function Hn(a,b){return v[a>>2]+(b<<11)|0}function HK(a,b){a=a|0;b=b|0;gg(a,b+12|0)}function Gd(a,b){v[a>>2]=v[b>>2];return a}function GI(a,b){t[a|0]=b+48;return a+1|0}function Fc(a,b){a=a|0;b=b|0;Yp(a,b+28|0)}function Ad(a,b){return v[a>>2]+B(b,12)|0}function ye(a,b){return v[a>>2]+(b<<3)|0}function una(a,b){a=a|0;b=b|0;Rk(a,b,17)}function sc(a,b){return v[a>>2]+(b<<1)|0}function rg(a,b){v[a+8>>2]=b|-2147483648}function pL(a){return(Jb(a)+Ab(a)|0)-1|0}function oba(a){a=a|0;return(a|0)==277|0}function kj(a){return B(jj(a),fd(a))&255}function eqa(a,b){a=a|0;b=b|0;Rk(a,b,44)}function cd(a){return v[a>>2]==v[a+4>>2]}function cX(a,b){v[a>>2]=b;v[a+4>>2]=b+4}function ad(a,b){return v[a>>2]+B(b,6)|0}function _f(a){a=a|0;return!v[a+16>>2]|0}function _F(a,b){xc(a,b);xc(a+4|0,b+4|0)}function Zs(a,b){v[a+24>>2]=v[a+24>>2]+b}function Xl(a){a=a|0;return v[a>>2]+14|0}function WF(a){v[a+4>>2]=0;v[a>>2]=78964}function Tl(a,b){return v[a>>2]+(b<<8)|0}function Tc(a,b){return v[a>>2]+(b<<4)|0}function Qj(a,b){return v[a>>2]==v[b>>2]}function Q6(a){a=a|0;return ty(a-88|0)|0}function Mb(a,b){return v[a>>2]+(b<<2)|0}function M0(a,b){a=a|0;b=b|0;lx(a,83848)}function K6(a,b){a=a|0;b=+b;GJ(a-88|0,b)}function K0(a,b){a=a|0;b=b|0;lx(a,83868)}function I6(a,b){a=a|0;b=+b;EJ(a-88|0,b)}function HE(a,b){return v[a>>2]+(b<<5)|0}function Gj(a){u[a+4>>1]=65535;v[a>>2]=0}function Fla(a,b){a=a|0;b=b|0;Rk(a,b,10)}function F6(a,b){a=a|0;b=+b;CJ(a-88|0,b)}function Eda(a){a=a|0;return w[a+4201|0]}function EM(a){return(w[a+24|0]&8)>>>3|0}function Dda(a){a=a|0;return w[a+4202|0]}function Bg(a){a=a|0;return GP(w[a|0])|0}function Ana(a,b){a=a|0;b=b|0;Vt(a,b,17)}function Am(a){return(a|0)==32|a-9>>>0<5}function $b(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function zn(a,b){return y[a>>2]<y[b>>2]}function xZ(a,b){a=a|0;b=b|0;Vt(a,b,11)}function ww(a,b){a=a|0;b=b|0;rw(a,b,32)}function vba(a){a=a|0;return-2013527448}function uv(a,b){return z[a>>2]<z[b>>2]}function ula(a,b){a=a|0;b=b|0;Rk(a,b,5)}function tW(a,b){a=a|0;b=b|0;return b|0}function ot(a,b){return v[a>>2]<v[b>>2]}function jS(a,b){v[a>>2]=v[a>>2]+(b<<1)}function he(a,b){if(!v[a+80>>2]){Yb(b)}}function gZ(a,b){a=a|0;b=b|0;Rk(a,b,11)}function eT(a,b){return A[a>>3]<A[b>>3]}function _N(a){v[a+4>>2]=v[a+4>>2]|8192}function WG(a,b){a=a|0;b=b|0;Ge(a,1,45)}function VG(a,b){a=a|0;b=b|0;lI(a,1,45)}function UV(a,b){v[a>>2]=v[a>>2]+(b<<2)}function Sq(a){a=a|0;if(a){Yb(a+-64|0)}}function N0(a,b){a=a|0;b=b|0;Tb(a,8570)}function Mj(a,b){return u[a>>1]<u[b>>1]}function L0(a,b){a=a|0;b=b|0;Tb(a,8687)}function Ib(a){return(a<<8|a>>>8)&65535}function Hr(a,b,c){if(b){Qb(a,Lg(c),b)}}function Hna(a,b){a=a|0;b=b|0;MD(a,b,8)}function Go(a,b,c){return a<b?b:a>c?c:a}function Gn(a,b){return x[a>>1]<x[b>>1]}function Di(a,b,c){Dc(a,b);Dc(a+12|0,c)}function DP(a,b){return(Nl(a,b)|0)!=255}function CX(a,b){v[a>>2]=v[a>>2]+B(b,6)}function CA(a,b,c){return a<b?b:a>c?c:a}function BF(a,b){bc(a,v[b>>2],sf(b)<<3)}function $E(a,b){a=a|0;b=b|0;Rk(a,b,32)}function xk(a,b){return Jb(a)+(b<<2)|0}function xca(a){a=a|0;return-285139079}function vu(a,b){a=a|0;b=b|0;qI(a,b,0)}function tn(a,b){a=a|0;b=b|0;bc(a,b,7)}function rs(a){al(a);cG(a);_k(a);al(a)}function q8(a){a=a|0;return+A[a+16>>3]}function pca(a){a=a|0;return-284078960}function pS(a,b){v[a+4>>2]=b;v[a>>2]=b}function mba(a,b){a=a|0;b=b|0;return 3}function lba(a,b){a=a|0;b=b|0;return 2}function jda(a){a=a|0;return 542066252}function jZ(a){a=a|0;return v[a+12>>2]}function ica(a){a=a|0;return-281111764}function iT(a,b){a=a|0;b=b|0;yk(a,0,b)}function fd(a){return w[a+34|0]&64?2:1}function eH(a,b,c){Fe(a,b);Fe(a+4|0,c)}function dca(a){a=a|0;return-271958638}function bj(a){return B(v[a>>2],kj(a))}function aG(a,b){vH(a,b);v[a>>2]=89404}function _c(a){v[v[a+8>>2]>>2]=v[a>>2]}function Zy(a,b){a=a|0;b=b|0;mN(a,3,b)}function ZY(a){a=a|0;return v[a+24>>2]}function Vja(a){a=a|0;US(a);return a|0}function Uba(a){a=a|0;return-620920304}function RE(a){wb(a);return 2147483647}function Lba(a){a=a|0;return-275227023}function J6(a){a=a|0;return+FJ(a-88|0)}function Hca(a){a=a|0;return-270114148}function H6(a){a=a|0;return+DJ(a-88|0)}function F_(a){a=a|0;return v[a+16>>2]}function E6(a){a=a|0;return+BJ(a-88|0)}function Cba(a){a=a|0;return 302837129}function Ah(a){a=+a;return gr(ee(a))|0}function AK(a){return a?(a|0)==2?3:2:1}function $r(a){a=a|0;return 2147483647}function vw(a){return w[a+21|0]>>>7|0}function uy(a){a=a|0;return v[a+8>>2]}function tv(a){a=a|0;return Pb(a,1)^1}function op(a,b){u[a+8>>1]=b;return a}function oh(a){a=a|0;Lx(a);return a|0}function jj(a){return t[a+34|0]&1?2:1}function jL(a,b){return w[a|0]<w[b|0]}function hs(a,b){a=a|0;b=b|0;return 1}function cI(a,b){return MH(a)^MH(b)^1}function bt(a,b){a=a|0;b=b|0;return-1}function YH(a,b){return LH(a)^LH(b)^1}function XE(a){return w[a+22|0]>>>7|0}function W6(a){a=a|0;return w[a+40|0]}function Ue(a,b){v[a+4>>2]=b;return a}function T4(a){a=a|0;return CH(a,0)|0}function Sl(a,b){return t[a|0]<t[b|0]}function Sb(a){return HE(a,w[a+16|0])}function SK(a){return x[a+1074448>>1]}function S4(a){a=a|0;return CH(a,1)|0}function PQ(a){a=a|0;vr(a);return a|0}function P4(a){a=a|0;return AH(a,0)|0}function N4(a){a=a|0;return AH(a,1)|0}function LJ(a){v[a>>2]=60068;return a}function KL(a,b){a=a|0;b=b|0;return 0}function KH(a){a=a|0;Gx(a);return a|0}function Jk(a){return v[a+1298364>>2]}function Jh(a){a=a|0;NF(a);return a|0}function Gx(a){a=a|0;Cs(a);return a|0}function El(a){return(w[a+16|0]&5)!=0}function Dx(a){a=a|0;if(qH(a)){Yb(a)}}function De(a){return w[a+11|0]>>>7|0}function Bt(a){a=a|0;return v[a+4>>2]}function $ca(a,b){a=a|0;b=b|0;Gu(a,b)}function ypa(a){a=a|0;return VX(a)|0}function yn(a,b){tc(a);fF(a,b);CE(a)}function od(a,b){return Hn(a+12|0,b)}function mj(a){return v[a+4>>2]-36|0}function mG(a,b){a=a|0;b=b|0;Qq(a,b)}function lS(a,b){ze(a);fS(a,b);eS(a)}function ij(a,b){Nb(a);wU(a,b);qw(a)}function ih(a,b){a=a|0;b=b|0;SY(a,b)}function h7(a){a=a|0;return w[a+8|0]}function goa(a){a=a|0;return Jk(a)|0}function e_(a,b){a=a|0;b=b|0;No(a,b)}function XK(a){return v[a+4>>2]-48|0}function Ur(a,b){a=a|0;b=b|0;Fw(a,b)}function Tba(a){a=a|0;v[a+4224>>2]=0}function TM(a,b,c){a=a|0;b=b|0;c=c|0}function Rka(a){a=a|0;return PT(a)|0}function RC(a,b){Jg(a);WW(a,b);KW(a)}function Q0(a){a=a|0;return t[a+8|0]}function PL(a){v[a>>2]=0;v[a+4>>2]=0}function P0(a){a=a|0;return t[a+9|0]}function OU(a){return v[a+4>>2]-56|0}function Nr(a,b){a=a|0;b=b|0;Vv(a,b)}function Mu(a){return v[wb(a)>>2]<<5}function Kn(a){v[a+4>>2]=v[a+4>>2]+1}function JU(a){return v[a+4>>2]-28|0}function Iga(a){a=a|0;return lm(a)|0}function IO(a){return v[a+4>>2]-32|0}function HR(a,b){a=a|0;b=b|0;$f(a,b)}function GP(a){return(a+5&255)>>>0<2}function GK(a){return v[a+4>>2]-12|0}function Em(a,b){oc(a);qK(a,b);mK(a)}function Afa(a){a=a|0;return Mi(a)|0}function AV(a,b){if(!oV(a,b)){ZB(b)}}function AN(a,b){Sf(a);BO(a,b);xN(a)}function $f(a,b){a=a|0;b=b|0;gg(a,b)}function yc(a,b){v[a>>2]=b;return a}function xf(a){return v[a+24620>>2]}function wz(a){a=a|0;return El(a)|0}function vo(a){return v[a+4>>2]-4|0}function sha(a,b){a=a|0;b=b|0;zR(b)}function pu(a){return zo(a)<<24>>24}function n_(a){a=a|0;return tf(a)|0}function n2(){Zd(465520,Vd(464064))}function mha(a,b){a=a|0;b=b|0;Ye(b)}function lc(a,b){return v[a>>2]+b|0}function l2(){Zd(465528,Vd(464072))}function j2(){Zd(465552,Vd(464260))}function j$(a){a=a|0;return sg(a)|0}function iy(a){return!sd(a,90132,6)}function iF(a){a=a|0;return Ng(a)|0}function i2(){Zd(465560,Vd(464268))}function hka(a,b){a=a|0;b=b|0;ed(b)}function gc(a){ut(a);km(a);return a}function g2(){Zd(465568,Vd(464276))}function f2(){Zd(465584,Vd(464284))}function f$(a){a=a|0;return v[a>>2]}function em(a,b,c){if(c){yh(a,b,c)}}function e2(){Zd(465592,Vd(464292))}function d2(){Zd(465600,Vd(464300))}function c2(){Zd(465624,Vd(464308))}function b2(){Zd(465656,Vd(464080))}function a2(){Zd(465664,Vd(464088))}function _1(){Zd(465680,Vd(464104))}function Zb(a){return Gg(v[a+4>>2])}function ZE(a){return w[a+21|0]&127}function Z1(){Zd(465688,Vd(464144))}function YE(a){return w[a+22|0]&127}function YC(a,b){return DX(a,0-b|0)}function YA(a,b){return B(b,12)+a|0}function Y1(){Zd(465696,Vd(464152))}function X1(){Zd(465704,Vd(464160))}function Wr(a){t[a+2|0]=0;u[a>>1]=0}function WZ(a){a=a|0;return uE(a)|0}function WY(a){a=a|0;return ds(a)|0}function W8(a){a=a|0;return ue(a)|0}function W1(){Zd(465712,Vd(464168))}function V1(){Zd(465720,Vd(464176))}function U1(){Zd(465728,Vd(464184))}function T1(){Zd(465736,Vd(464192))}function SY(a,b){JH(a,v[a+16>>2]|b)}function S1(){Zd(465744,Vd(464200))}function Rg(a,b,c){return Ln(a,b,c)}function R1(){Zd(465752,Vd(464112))}function Qr(a){a=a|0;return Ae(a)|0}function Qna(a,b){a=a|0;b=b|0;_j(b)}function Qg(a,b,c){if(c){hc(a,b,c)}}function Q1(){Zd(465768,Vd(464120))}function O1(){Zd(465784,Vd(464128))}function NV(a,b){return we(a,0-b|0)}function M1(){Zd(465800,Vd(464136))}function Lfa(a,b){a=a|0;b=b|0;Km(b)}function L1(){Zd(465816,Vd(464208))}function Kfa(a,b){a=a|0;b=b|0;Ig(b)}function K1(){Zd(465824,Vd(464216))}function J7(a){a=a|0;return rK(a)|0}function Gha(a,b){a=a|0;b=b|0;Zm(b)}function Aea(a){a=a|0;Vt(a,18726,1)}function Ada(a,b){a=a|0;b=b|0;cz(b)}function $1(){Zd(465672,Vd(464096))}function uh(a,b){v[a>>2]=v[a>>2]|b}function ue(a){return v[a>>2]+16|0}function u6(a,b){a=a|0;b=b|0;Yb(b)}function tS(a,b){t[v[a>>2]]=w[b|0]}function st(a){a=a|0;t[a+6152|0]=0}function pK(a){return(Yg(a)|0)==-1}function nm(a){Fm(a);v[a>>2]=89032}function nG(a,b){a=a|0;b=b|0;vb(b)}function mo(a,b){v[a+1298424>>2]=b}function mk(a,b,c){wd(a,v[b>>2],c)}function lw(a,b){v[a>>2]=v[a>>2]+b}function lK(a,b){a=a|0;b=b|0;Dy(b)}function kK(a,b){a=a|0;b=b|0;Gl(b)}function k2(){Zd(465536,Vd(466e3))}function jf(a,b){Yo(a);yc(a+4|0,b)}function h_(a,b){a=a|0;b=b|0;Wr(b)}function gN(a,b){a=a|0;b=b|0;Yo(b)}function dU(a){td(a,0,-1);return a}function Y2(a){a=a|0;lo(a,1,10784)}function Xs(a){return He(a,-1)?0:a}function Wd(a){WF(a);v[a>>2]=84104}function V_(a,b){a=a|0;b=b|0;Lw(b)}function Ul(a,b){yp(a,b,v[b+4>>2])}function UG(a){return Nh(a,464152)}function TG(a){return Nh(a,464144)}function RG(a){return Nh(a,464168)}function QG(a){return Nh(a,464160)}function Ok(a){t[a|0]=0;t[a+1|0]=0}function Lh(a,b){a=a|0;b=b|0;Kb(a)}function KZ(a,b){a=a|0;b=b|0;fw(b)}function Ii(a){a=a|0;t[a+4202|0]=0}function IZ(a,b){a=a|0;b=b|0;Ok(b)}function Hj(a,b){return(b<<13)+a|0}function HZ(a,b){a=a|0;b=b|0;Jh(b)}function GZ(a,b){a=a|0;b=b|0;xb(b)}function Dg(a,b){td(a,Jb(b),Ab(b))}function Cy(a,b){a=a|0;b=b|0;If(b)}function Bj(a){return cd(a+36|0)^1}function Bh(a,b){Yo(a);df(a+4|0,b)}function zu(a,b,c){return LA(b,c)}function wr(a,b){return qe(a,b)^1}function vd(a,b){return(b<<1)+a|0}function sV(a,b){return(b<<4)+a|0}function rr(a){v[a>>2]=v[a>>2]+12}function rT(a,b){yB(a,b);return a}function pp(a){v[a>>2]=2;return a}function pn(a){v[a>>2]=v[a>>2]+28}function pc(a,b){return Jb(a)+b|0}function nS(a){v[a>>2]=v[a>>2]+32}function kc(a,b){Rw(a,b);return a}function fN(a,b,c){return Mj(b,c)}function ex(a,b){return v[a+b>>2]}function aE(a){return w[a+1|0]==1}function Zo(a){v[a>>2]=v[a>>2]+16}function Xfa(a){a=a|0;Bf(a,Ti(a))}function Xd(a){return v[fc(a)>>2]}function Wi(a){v[a>>2]=0;return a}function W$(a){a=a|0;return 10368}function Vb(a){return Gg(v[a>>2])}function VO(a){v[a>>2]=v[a>>2]+52}function Te(a){return Sf(a)&65535}function Rm(a){u[a>>1]=0;return a}function RT(a){return v[wb(a)>>2]}function Qh(a){return a-48>>>0<10}function Pe(a,b){return(b<<2)+a|0}function Ny(a,b){return Hz(a,b)^1}function NC(a,b,c){return Gn(b,c)}function Jy(a){return a+1298368|0}function Hy(a){return Yg(a+120|0)}function Fh(a){v[a>>2]=1;return a}function Eh(a){v[a>>2]=v[a>>2]+20}function Cla(a){a=a|0;fW(a,65535)}function Bw(a){return t[a+24|0]&1}function Bo(a){return a+1074328|0}function BM(a){return w[a+4232|0]}function B4(a){a=a|0;return 10482}function Aq(a){gc(a+4|0);return a}function $K(a){v[a>>2]=v[a>>2]+24}function z4(a){a=a|0;return 7556}function yL(a){a=a|0;Py(a);Yb(a)}function xr(a){oc(a);HF(a);mK(a)}function ut(a){dg(a);oc(a);dg(a)}function u4(a){a=a|0;return 3923}function sD(a){Xj(a);tY(a);sY(a)}function sB(a,b,c){$S(ne(a,b),c)}function qR(a){tg(a);sf(a);tg(a)}function qE(a){dm(a);Ie(a);dm(a)}function pU(a){return w[a|0]<129}function o9(a){a=a|0;Oy(a);Yb(a)}function i7(a){a=a|0;SJ(a);Yb(a)}function hY(a){mn(a);Xj(a);mn(a)}function gW(a,b){hc(a,b+4|0,256)}function gT(a){aj(a);$i(a);aj(a)}function g5(a){a=a|0;return 7676}function ev(a){bi(a);ze(a);bi(a)}function cM(a){a=a|0;Yy(a);Yb(a)}function bm(a){tc(a);Aw(a);CE(a)}function a7(a){a=a|0;PJ(a);Yb(a)}function _M(a){Vf(a);SM(a);RM(a)}function Zp(a){ug(a);Ec(a);ug(a)}function Z$(a,b){a=a|0;b=b|0;L()}function X$(a){a=a|0;return 6987}function Tx(a){xi(a);vf(a);xi(a)}function TP(a,b,c,d){XP(a,b,c,d)}function So(a,b){u[a>>1]=x[b>>1]}function S$(a){a=a|0;return 2812}function Qv(a){v[a>>2]=v[a>>2]+2}function Qe(a){v[a>>2]=v[a>>2]+4}function QC(a){Wj(a);Jg(a);Wj(a)}function Pw(a){a=a|0;Cs(a);Yb(a)}function Oe(a){v[a>>2]=v[a>>2]+1}function OM(a){Cl(a);Vf(a);Cl(a)}function Np(a){a=a|0;hx(a);Yb(a)}function KP(a,b,c,d){wA(a,b,c,d)}function KN(a){Jg(a);XW(a);KW(a)}function JF(a){_k(a);al(a);_k(a)}function GH(a){v[a+72>>2]=463096}function GA(a){t[a|0]=0;return a}function Fg(a){Nb(a);br(a);qw(a)}function Fe(a,b){v[a>>2]=v[b>>2]}function FH(a){v[a+72>>2]=463180}function Ep(a){Og(a);tc(a);Og(a)}function Ek(a){pe(a);Nb(a);pe(a)}function Dd(a){return v[a>>2]!=0}function DO(a){ok(a);Sf(a);ok(a)}function DH(a){a=a|0;ym(a);Yb(a)}function Cu(a){v[a>>2]=v[a>>2]+8}function Cr(a){return Qb(a,0,48)}function Bl(a){a=a|0;kf(a);Yb(a)}function BH(a){a=a|0;$p(a);Yb(a)}function $j(a){v[a>>2]=v[a>>2]+6}function xb(a){Kd(a+12|0);Kd(a)}function vq(a){u[a+480214>>1]=0}function pk(a){return!v[a+4>>2]}function p0(a){a=a|0;vb(464364)}function ow(a,b){return OE(a,b)}function nO(a,b){return lO(a,b)}function n0(a){a=a|0;Ic(464380)}function li(a,b,c){pf(a,c,13,b)}function lf(a,b){return Mg(a,b)}function l0(a){a=a|0;vb(464396)}function jx(a){return wb(a+8|0)}function jr(a,b){return VV(a,b)}function i0(a){a=a|0;Ic(464412)}function hg(a){return Wh(Lg(a))}function g0(a){a=a|0;vb(464428)}function eN(a,b){return Mj(a,b)}function e0(a){a=a|0;Ic(464444)}function c0(a){a=a|0;vb(464460)}function af(a){a=a|0;return a|0}function a0(a){a=a|0;Ic(464476)}function _b(a,b){return bf(a,b)}function Zm(a){vb(a+12|0);Ze(a)}function Wh(a){return a<<24>>24}function Uy(a,b){return ah(a,b)}function Sm(a){vb(a+12|0);vb(a)}function Rj(a,b){return HE(a,b)}function Ri(a){return ze(a)&255}function Rh(a,b){return Pe(a,b)}function Qo(a){return _m(ee(a))}function QE(a,b){return NE(a,b)}function P6(a){a=a|0;KJ(a-88|0)}function OW(a,b){td(a,b,b+16|0)}function Nd(a,b){return Hn(a,b)}function MC(a,b){return Gn(a,b)}function Jba(a){a=a|0;return 13}function Is(a){a=a|0;return 127}function Ica(a){a=a|0;Yb(Yy(a))}function Ff(a){vb(a+20|0);vb(a)}function Ej(a,b){return a>>>b&1}function Dq(a){sR(a+12|0);xR(a)}function BU(a,b){return Pj(b,a)}function Al(a,b,c){td(a,b,1<<c)}function $l(a){return Nv(tc(a))}function yH(){return(db()|0)>0}function xM(a){a=a|0;Yb(yM(a))}function wca(a){a=a|0;return 6}function v4(a){a=a|0;Yb(Gx(a))}function qu(a,b){return a<<8|b}function o5(a){a=a|0;Yb(cu(a))}function o1(a){a=a|0;Yb(IG(a))}function mM(a){a=a|0;Yb(nM(a))}function m9(a){a=a|0;Yb(Py(a))}function kI(a){a=a|0;Yb(oh(a))}function k7(a){a=a|0;Yb(TJ(a))}function f1(a){a=a|0;Yb(GG(a))}function ec(a,b){v[a+100>>2]=b}function dM(a){a=a|0;Yb(eM(a))}function d5(a){a=a|0;Yb(KH(a))}function c7(a){a=a|0;Yb(QJ(a))}function b$(a){a=a|0;Yb(VF(a))}function av(a){return a>>>27^a}function XL(a){a=a|0;Yb(YL(a))}function Vka(a){a=a|0;return 9}function VV(a,b){return b-a>>2}function VM(a){a=a|0;Yb(WM(a))}function V5(a){a=a|0;Yb(ym(a))}function V$(a){a=a|0;Yb(hx(a))}function U$(a){a=a|0;Yb(Cs(a))}function TS(a){return a+4896|0}function Sx(a){a=a|0;Yb(at(a))}function S_(a){a=a|0;Yb(KF(a))}function S0(a){a=a|0;Yb(DG(a))}function R5(a){a=a|0;Yb($p(a))}function R0(a){a=a|0;Yb(CG(a))}function Ox(a){a=a|0;Yb(_s(a))}function OH(a){a=a|0;Yb(Bq(a))}function O7(a){a=a|0;Yb(Ht(a))}function NH(a){a=a|0;Yb(wf(a))}function M_(a){a=a|0;Yb(xF(a))}function K_(a){a=a|0;Yb(wF(a))}function KJ(a){a=a|0;Yb(ty(a))}function Iy(a,b){return b-a>>3}function HM(a){a=a|0;Yb(IM(a))}function G1(a){a=a|0;Yb(KG(a))}function FT(a){JB(Qb(a,0,872))}function Bd(a,b){t[a|0]=w[b|0]}function BG(a){a=a|0;Yb(kx(a))}function $4(a){a=a|0;Yb(Lx(a))}function vr(a){Wi(a);return a}function vk(a){return Dd(a)^1}function up(a){return a>>>0<5}function uM(a){a=a|0;return 7}function te(a){a=a|0;return 1}function tR(a){Sj(a);return a}function sl(a){return a+120|0}function re(a){a=a|0;return 2}function oS(a,b){return b-a|0}function oA(a){tF(a);return a}function mc(a){Hg(a);return a}function lC(){return Nc(20,4)}function jc(a){a=a|0;return 0}function jG(a){a=a|0;return 3}function j9(){return 19923026}function ii(a){return cd(a)^1}function ic(a,b){return a+b|0}function hh(a){dd(a);return a}function hM(a){a=a|0;return 5}function hI(a){a=a|0;return-1}function dd(a){vh(a);return a}function cf(a,b){u[a+28>>1]=b}function cR(){return Nc(36,4)}function ax(){return lb()<<16}function aF(a){return a>>>0>8}function _v(a){return!v[a>>2]}function ZU(a,b){bc(a,b,1108)}function QW(a){Cr(Qb(a,0,48))}function Pv(a){a=a|0;return 4}function NU(a,b){pf(a,b,33,1)}function Lu(a){return a+256|0}function Lo(a,b){v[a+36>>2]=b}function It(a,b){v[a+32>>2]=b}function Ho(a){mc(a);return a}function FD(a,b){bc(a,b,1954)}function F1(){Yp(464244,MG())}function $g(a){return D(a)==N}function $W(){return Nc(32,4)}function $B(a,b){bc(a,b,1024)}function zt(a){v[a>>2]=56276}function zX(a,b){bc(a,b,157)}function zS(a,b,c){Xq(a,c,b)}function yS(a,b,c){Wq(a,c,b)}function x5(a){a=a|0;SY(a,1)}function vU(a,b){bc(a,b,608)}function uX(a,b){bc(a,b,576)}function uN(a,b){ok(a);ok(a)}function tt(a,b){dg(a);dg(a)}function tq(a,b){z[a+8>>2]=b}function tY(a){lY(a,v[a>>2])}function rq(a,b){z[a+4>>2]=b}function rn(a,b){le(a,b+8|0)}function rU(a){return a+48|0}function qq(a,b){t[a+33|0]=b}function nV(a,b){bc(a,b,130)}function mX(a){return a+36|0}function mR(a){lR(a,v[a>>2])}function lV(a,b){bc(a,b,600)}function kp(a,b){wb(b);wb(a)}function j7(a){a=a|0;UJ(a,1)}function iL(a){v[a>>2]=55204}function iK(a,b,c){tK(a,b,c)}function gS(a){fS(a,v[a>>2])}function fp(a,b){v[a+8>>2]=b}function fX(a){II(a,v[a>>2])}function fV(a,b){bc(a,b,126)}function eE(a,b){dm(a);dm(a)}function eB(a,b){bi(a);bi(a)}function dn(a,b){pe(a);pe(a)}function de(a,b){v[a+4>>2]=b}function dc(a){return a+12|0}function dI(a,b){xi(a);xi(a)}function br(a){wU(a,v[a>>2])}function bU(a,b){bc(a,b,204)}function b7(a){a=a|0;Zu(a,1)}function _r(a,b){Og(a);Og(a)}function _e(a,b){t[a+11|0]=b}function _S(a,b){bc(a,b,263)}function Zw(a,b){ug(a);ug(a)}function ZC(a,b){pf(a,b,8,2)}function Ys(a,b){Yp(a,b+4|0)}function XW(a){WW(a,v[a>>2])}function Wp(a){return a+20|0}function Vw(a,b){bG(a,be(b))}function VW(a,b){bc(a,b,674)}function VC(a,b){oX(a,be(b))}function Sv(a,b){bc(a,b,512)}function SM(a){PM(a,v[a>>2])}function RO(a){v[a>>2]=78428}function Pr(a,b){bc(a,b,192)}function Od(a){de(a,v[a>>2])}function MJ(a){v[a>>2]=60044}function Lz(a,b){t[a+34|0]=b}function Kz(a,b){t[a+32|0]=b}function Jz(a,b){t[a+35|0]=b}function Hp(a){v[a>>2]=27764}function HF(a){qK(a,v[a>>2])}function Fm(a){v[a>>2]=89052}function FE(a,b){bc(a,b,497)}function FC(a,b){Wj(a);Wj(a)}function DW(a,b){bc(a,b,128)}function CO(a){BO(a,v[a>>2])}function BX(a,b){bc(a,b,218)}function Aw(a){fF(a,v[a>>2])}function AY(a,b){bc(a,b,610)}function AU(a,b){bc(a,b,146)}function AR(a){return D(a)<N}function AM(a,b,c){Ln(a,b,c)}function $c(a,b){a=a|0;b=b|0}function zq(a){Qb(a,0,8192)}function wb(a){return a+8|0}function tka(a){a=a|0;FT(a)}function tD(a,b){bc(a,b,64)}function rQ(a){return 0-a|0}function qd(a){return a+1|0}function qC(a,b){bc(a,b,40)}function pV(a,b){bc(a,b,30)}function oE(a,b){bc(a,b,38)}function mE(a,b){bc(a,b,41)}function k9(){return 393216}function gw(a,b){bc(a,b,16)}function gd(a){return!Ab(a)}function fj(a){return a+3|0}function fc(a){return a+4|0}function f6(){return 460756}function ew(a,b){bc(a,b,65)}function ega(a){a=a|0;mA(a)}function dV(a,b){bc(a,b,32)}function cz(a){Qb(a,0,2048)}function cs(a,b){bc(a,b,36)}function cW(a,b){bc(a,b,52)}function ZO(a){Qb(a,0,1024)}function Xo(a){Qb(a,0,4096)}function Wba(){return 65535}function Ve(a){return a+2|0}function VE(a,b){rw(a,b,22)}function Uja(a){a=a|0;Xo(a)}function TF(a,b){bc(a,b,24)}function SD(a,b){bc(a,b,11)}function SB(a){v[a+12>>2]=0}function RU(a,b){bc(a,b,96)}function PD(a,b){bc(a,b,17)}function NR(a,b){bc(a,b,27)}function Lg(a){return a&255}function JX(a,b){bc(a,b,98)}function Iv(a,b){bc(a,b,66)}function GX(a,b){bc(a,b,48)}function GU(a){if(a){Yb(a)}}function ED(a){Qb(a,0,1954)}function Dv(a,b){bc(a,b,22)}function Dla(){return 65534}function Cf(a,b){t[a+3|0]=b}function BC(a,b){bc(a,b,33)}function Ap(a,b){t[a+1|0]=b}function $X(a,b){bc(a,b,12)}function $V(a,b){bc(a,b,80)}function zk(a,b){yp(a,b,0)}function zY(a){Qb(a,0,610)}function zU(a){Qb(a,0,146)}function yd(a){Zp(a);sF(a)}function yX(a){Qb(a,0,157)}function xN(a){ok(a);Sf(a)}function vc(a){v[a+8>>2]=0}function uU(a){Qb(a,0,608)}function tX(a){Qb(a,0,576)}function sq(a,b){z[a>>2]=b}function sY(a){mn(a);Xj(a)}function sR(a){Jq(a,Xd(a))}function qw(a){pe(a);Nb(a)}function qB(a){Qb(a,0,512)}function o4(){return 79528}function nv(a){oC(a,Xd(a))}function nC(a,b){bc(a,b,4)}function n4(){return 80304}function mr(a){pC(a,Xd(a))}function mK(a){dg(a);oc(a)}function m4(){return 81856}function kV(a){Qb(a,0,600)}function kE(a,b){oi(a,2,b)}function jn(a){QC(a);wv(a)}function jd(a){qE(a);rE(a)}function iR(a){ug(a);Ec(a)}function iP(a){lu(a,Xd(a))}function gX(a){t[a+31|0]=0}function fY(a,b){bc(a,b,3)}function es(a,b){bc(a,b,8)}function eV(a){Qb(a,0,126)}function eS(a){bi(a);ze(a)}function df(a,b){v[a>>2]=b}function dX(a){KC(a,Xd(a))}function cO(a){Fz(a,Xd(a))}function bg(){rd(8267);L()}function aU(a){Qb(a,0,204)}function _x(){io(4782);L()}function Zn(){io(8267);L()}function Ze(a){Ep(a);bs(a)}function Zc(a){a=a|0;Yb(a)}function ZB(a){Qb(a,0,130)}function YW(a){LC(a,Xd(a))}function Xv(a,b){bc(a,b,5)}function Wb(a){Mn(v[a>>2])}function Uka(a){a=a|0;gb=a}function UW(a){Qb(a,0,192)}function Sc(){rd(4782);L()}function RM(a){Cl(a);Vf(a)}function QV(a,b){bc(a,b,2)}function Pi(a){return a!=a}function OX(a,b){bc(a,b,6)}function Mq(a){Tx(a);BR(a)}function Lc(a){Ek(a);sv(a)}function Kl(a){JA(a,Xd(a))}function KW(a){Wj(a);Jg(a)}function Ila(){return gb|0}function IT(a){zB(a,Xd(a))}function HT(a){AB(a,Xd(a))}function Fs(a){a=a|0;Ls(a)}function EE(a){Qb(a,0,497)}function CE(a){Og(a);tc(a)}function BB(a){Qb(a,0,256)}function tC(a){Qb(a,0,80)}function nE(a){Qb(a,0,38)}function lE(a){Qb(a,0,41)}function lD(a){Qb(a,0,66)}function iD(a){Qb(a,0,64)}function bW(a){Qb(a,0,52)}function Zi(a,b){t[a|0]=b}function SU(a){Qb(a,0,96)}function O8(){return 2048}function IX(a){Qb(a,0,98)}function HX(a){Qb(a,0,48)}function Dw(a){Qb(a,0,36)}function CC(a){Qb(a,0,33)}function zc(a){gc(a+8|0)}function zR(a){Vm(a,0,0)}function yB(a,b){yc(a,b)}function xO(a,b){lw(a,b)}function wq(a,b){Fe(a,b)}function wO(a,b){vO(a,b)}function wD(a,b){Zj(a,b)}function no(a,b){JH(a,b)}function mh(a){a=a|0;L()}function lp(a,b){Bd(a,b)}function js(a,b){Rw(a,b)}function jR(a){Kq(a+8|0)}function fz(a,b){qi(a,b)}function fw(a){u[a>>1]=0}function ed(a){xb(a+8|0)}function bB(a,b){ag(a,b)}function Zk(a,b){de(a,b)}function ZW(a,b){df(a,b)}function Yo(a){v[a>>2]=0}function YV(a,b){UV(a,b)}function XU(a,b){le(a,b)}function Vh(a,b){Uh(a,b)}function Kpa(){ua();L()}
function Fk(a){vb(a+4|0)}function DN(a,b){nW(a,b)}function AC(a,b){oW(a,b)}function If(a){t[a|0]=0}function sO(a){bO(a,0)}function qD(a){RX(a,0)}function ps(a){bG(a,0)}function ln(a){oX(a,0)}function ju(a){YO(a,0)}function iu(a){XO(a,0)}function hq(a){rL(a,0)}function Ig(a){eX(a,0)}function Hc(a){Ee(a,0)}function Fi(a){sL(a,0)}function Ei(a){qL(a,0)}function mf(a){a=a|0}function gR(a){xB(a)}function _H(a){JL(a)}function WT(a){dd(a)}function Hb(a){vb(a)}function Y$(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var kb=c([null,Wm,Tb,Ot,gg,EL,lo,n6,Y5,kT,k5,h4,d3,tT,Wm,N5,tZ,vn,ih,_4,$,zD,qn,p_,hx,Oc,He,ZY,un,af,Zc,GF,hs,Ifa,Ypa,Vpa,Qpa,Kpa,Hpa,wpa,aD,Uoa,Qoa,dqa,Bpa,RB,c6,Tna,Sna,FW,Pf,dp,ir,Fb,$c,FW,b6,ska,nT,NS,Qq,No,_5,X5,Wm,Qq,No,pi,Dha,gg,Tb,EL,HR,xu,yf,qI,vu,$f,lga,MG,kga,Gg,mP,u5,iga,HR,Mfa,tA,tA,jha,cha,Hfa,Dfa,Tga,Qga,bga,_fa,a5,jga,$f,qfa,J5,wz,H5,HN,F5,Vea,Qea,t5,Wm,D5,B5,vea,Ut,oea,fea,bN,Bp,Wm,Pf,Xy,ql,QI,Fy,ko,Zh,f8,Cy,$c,Zh,Hf,ko,Zh,$c,j5,c5,Y4,V4,F4,q4,Ns,$f,a4,M3,Kh,ri,n$,s3,dH,cH,Y2,Ns,P2,Pn,qx,Fs,gk,Xc,Ef,u0,Pn,us,A1,r1,j0,G2,$$,yG,T$,yG,m2,EG,N$,G$,D$,Kh,sG,Pf,On,Nn,nj,nG,mG,lG,Ut,m$,ia,Op,Np,Bt,Wc,Pb,j$,Uw,i$,lm,h$,dG,g$,Kp,bl,dG,Ud,os,Zh,e$,Cs,Sw,U_,T_,ef,f$,d$,c$,V_,Jh,ef,MF,ef,Jw,ko,P_,O_,N_,ko,Pw,Bt,VF,b$,Gp,KL,a$,af,Zc,$_,te,te,Bt,uy,__,Z_,Y_,mh,Y$,X_,W_,KF,S_,Gp,R_,Zc,jc,te,te,jc,jc,Q_,xF,M_,Gp,L_,wF,K_,J_,I_,H_,G_,F_,E_,D_,C_,Qy,Bfa,wfa,tfa,ds,OF,x_,IF,nG,$c,uF,u_,t_,Pw,Pf,Pf,iF,Sd,r_,q_,Pf,$c,$c,$c,Fy,Xy,Cy,ql,i_,ir,o_,Fb,j_,Tk,h_,$c,iF,ki,g_,f_,e_,a_,DE,xn,$c,XZ,wE,Rb,VZ,UZ,TZ,SZ,Je,Bc,RZ,QZ,PZ,OZ,Cg,zg,wh,NZ,iw,tE,MZ,sE,Pf,LZ,dp,Pf,Pf,HZ,KZ,$c,JZ,DE,IZ,GZ,DZ,CZ,BZ,_D,AZ,We,zZ,yZ,xZ,wZ,Vz,JT,RS,vZ,me,uZ,hw,XD,Hd,gk,xh,qZ,pZ,aw,Ke,Qr,qf,FO,oZ,nZ,mZ,ac,WD,lZ,VD,pd,cw,Pl,Or,My,Cn,Dn,Rd,Xe,iZ,Pf,Fy,Xy,Cy,$c,hZ,gZ,Zr,Yc,jw,bZ,Mr,aZ,Ag,Pc,Ob,Rf,Ef,$Y,Rv,_Y,Xc,Lr,Qha,YY,XY,Si,WY,CD,Kr,ud,VY,Jr,UY,Kea,Tf,Be,Jm,to,rz,kqa,QY,CM,BD,Ov,Ir,Nk,Ef,jqa,iqa,$E,hqa,kh,gqa,fqa,am,eqa,EY,nj,cqa,lj,Qf,mG,lG,Ut,Op,$pa,_pa,Zpa,vY,Upa,am,rD,nf,Tpa,Spa,Rpa,Ppa,Oo,oB,Opa,Npa,Mpa,Lpa,Hf,ce,kt,pD,Kv,oD,Gpa,Fpa,Ipa,nY,Cn,Dn,oY,nn,ql,$c,Of,bY,Cpa,Mk,xpa,vpa,upa,Ud,Bf,BY,ypa,XX,tpa,WX,spa,pB,rpa,TX,qpa,ppa,opa,Sw,npa,Cn,fq,kpa,Mr,jp,jpa,ipa,CD,hpa,Qk,gpa,fpa,epa,dpa,wn,fr,cpa,bpa,apa,$oa,am,bD,lj,Qf,Cv,Bv,NX,kz,Tha,Yj,Av,uz,oq,Zt,$5,XC,Roa,vX,Gh,Noa,Moa,Ofa,Joa,cga,zv,Cp,Ioa,Hoa,Goa,Br,TE,Foa,Ku,Wo,Eoa,Doa,Poa,qX,k_,Coa,Ro,UE,yv,Boa,Ef,Aoa,Mc,zoa,yoa,pX,xoa,d_,woa,voa,uoa,toa,nX,soa,Xu,roa,Ef,qoa,poa,uw,uY,Ooa,Ef,ooa,noa,fq,xp,moa,loa,koa,EO,UC,joa,UC,UC,TC,jX,SC,Hm,ioa,gba,hoa,goa,foa,eoa,doa,coa,boa,bea,iX,Pf,RW,kd,hp,Xna,Af,GC,Pna,Nr,aoa,Pf,EC,Ona,$na,_na,Zna,ag,cea,Rfa,Uda,Yna,Ot,Wna,Vna,Una,ef,$f,af,$c,$c,$c,Rna,ir,Qna,qr,Kna,Jna,Ina,Hna,Gna,Fna,Ena,Dna,Cna,AW,zW,Bna,Ana,zna,yna,xna,wna,vna,una,wW,hn,pW,Qf,hW,zC,rna,yC,qna,or,BS,Br,pna,ona,nna,mna,$C,ES,Gb,Xl,xC,lna,WZ,kna,jna,fW,eW,ww,Yr,wC,ina,Ge,hna,Ot,Br,gna,Br,fna,Ur,ena,Ef,vY,lv,SV,bna,ana,Ud,$ma,_ma,Zma,kC,Yma,iv,Xma,Wma,Vma,Uma,Tma,Sma,xE,Rma,Qma,Xha,Pma,Oma,Nma,Mma,Tja,iha,gha,Lma,p6,OC,q6,Kma,Jma,ly,my,Nfa,Ima,Ef,lX,kX,HS,Hma,Gma,aw,Sw,KV,lr,Fma,Ema,Kh,ri,Dma,Mv,gv,Nj,Ih,aC,uma,tma,Bma,tv,$c,qma,pma,TD,oma,GO,nma,mma,yN,hp,lma,hV,kma,jma,hm,gm,dv,BA,ima,hma,Po,gma,cm,ema,dma,XB,tp,Jw,_la,VB,Zla,Yla,Xla,Ol,Wla,am,lj,Qf,Ih,Tla,Sla,Rla,Qla,Iu,yC,Nla,Lk,wk,dv,Mc,Mla,Nea,KV,lr,lv,Jla,Hla,rD,YU,VB,cw,Gla,Fla,Ela,Wba,Dla,Cla,Bla,bv,Ala,bv,zla,qs,l_,tla,am,vla,sla,aC,wla,ula,lj,Qf,FU,EU,pla,zC,ola,lla,kla,US,hV,qX,kha,ZQ,hla,aw,cla,bla,WD,hU,ala,$ka,_ka,Zka,gn,gU,Yka,Xka,Wka,ZT,Rka,Qka,Pka,Oka,Nka,Mka,Lka,an,Sja,TT,Kka,Jka,Ika,Hka,Gka,Fka,Eka,ch,Uha,eu,Zga,fha,dha,Dka,Oea,Ud,Cka,yC,Bka,Aka,zka,tv,NB,yka,MT,Ah,xka,wka,wT,vka,uka,_q,tka,CT,lv,yT,pka,oka,mka,nka,ef,lka,kka,CU,ef,Xr,jka,hka,Vha,dka,cka,hfa,bka,aka,$ja,RN,_ja,gfa,SN,Zja,Yja,Xja,O4,QH,Wha,fv,Ef,Vfa,Ufa,bT,aT,Pf,$c,rB,Rja,Qja,Pja,Oja,Nja,Mja,Lja,Kja,Jja,Ija,Hja,Gja,Fja,Eja,Dja,Cja,Bja,Aja,zja,yja,xja,wja,vja,uja,tja,sja,rja,qja,pja,nja,mja,lja,kja,jja,ija,hja,gja,fja,eja,dja,cja,bja,aja,$ia,_ia,Zia,Yia,Xia,Wia,Via,Uia,Tia,Sia,Ria,Qia,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Fia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,jia,iia,hia,gia,fia,eia,dia,cia,bia,aia,$ha,Zha,Tq,_ha,iS,gj,jE,mS,Rha,Fha,Pha,Oha,Nha,Mha,Lha,kS,Kha,Jha,Iha,Hha,Gu,Eha,Gha,TR,Bha,Aha,Vv,LR,Cfa,yha,xha,pq,Dz,Bz,Az,UA,wha,DR,vha,uha,Pf,sha,$c,Jo,nq,vR,pha,oha,Li,nha,Tf,lha,mha,af,$c,st,r6,ej,hha,Sfa,Xi,Yha,_h,YQ,ika,$h,nfa,eha,Mr,bha,Ih,Uw,aha,$ga,_ga,Mr,Yga,Uw,Oga,Nga,PQ,ef,Lga,am,sG,On,Nn,Ut,Kh,Kga,am,Mga,Qf,yu,RQ,Pf,af,NQ,lj,Qf,Pf,lj,Qf,gp,Jga,s_,Re,kZ,KQ,Iga,Jpa,JQ,IQ,HQ,GQ,FQ,EQ,DQ,CQ,BQ,AQ,zQ,yQ,xQ,wQ,vQ,uQ,tQ,sQ,qQ,pQ,oQ,nQ,mQ,lQ,kQ,jQ,iQ,hQ,gQ,fQ,eQ,dQ,cQ,bQ,aQ,$P,_P,ZP,YP,Hga,Gga,Fga,Ega,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,sga,rga,rha,SP,Sz,Bu,oR,qga,pga,Rz,Bg,Fo,Gq,oga,RP,To,yA,xA,Qm,Uz,HO,Tz,Eo,ru,LP,nga,vA,Om,lB,kB,JP,_A,Eu,Qi,mga,Zl,bP,Sha,Vja,dY,gga,iO,fga,Uja,ega,tf,dga,aga,l$,B_,w_,z_,Zfa,v_,A_,k$,y_,$m,Yfa,CS,UO,xq,Xfa,sfa,cda,Wfa,TO,jA,Cha,Tfa,pea,tea,Qfa,rea,nea,ef,ef,Gs,Pfa,GS,Lfa,Kfa,Jfa,AO,fka,eka,Loa,Koa,nla,mla,gla,fla,tna,sna,cma,bma,Mna,Lna,dZ,cZ,_oa,Zoa,FZ,EZ,sZ,rZ,Vla,Ula,rla,qla,rka,qka,Xpa,Wpa,Epa,Dpa,$Z,_Z,ZZ,YZ,Lla,Kla,yla,xla,sma,rma,Nna,CW,Woa,Voa,Toa,Soa,bqa,aqa,mpa,lpa,Pla,Ola,ffa,efa,Tea,Sea,wma,vma,Tka,Ska,ama,$la,Yoa,Xoa,jla,ila,ela,dla,Apa,zpa,Cma,yma,xma,c_,b_,fZ,eZ,dna,cna,Ama,zma,mh,Ffa,Efa,cP,$c,$f,rB,Afa,ws,yfa,zfa,SQ,vfa,xfa,ufa,$t,rfa,Vga,Tm,Xga,Wga,pfa,ofa,Sr,Rga,Sga,mfa,gka,m_,lfa,nF,Yw,yz,XD,kfa,UB,jfa,Uga,ifa,dfa,cfa,rD,bfa,Fr,VB,afa,$ea,_ea,aC,Zea,Ih,Yea,Xea,Wea,Uea,Rea,am,sJ,t6,s6,lj,Qf,Pea,Sq,Mea,Jea,vv,Hea,Gea,Fea,Eea,_f,Uh,xm,Dea,GN,Cea,xea,Bea,Lea,Aea,uea,yea,Iea,wea,nz,oz,rN,Pf,dea,ir,hN,qea,ZS,kq,lea,kea,jea,iea,hea,pN,sea,mq,ag,oN,eea,yl,Uh,gN,aea,$da,_da,Zda,Yda,Xda,Zf,Wda,Vda,gea,mea,Sda,Rda,Th,Qda,Pda,QM,Cda,fn,ir,nN,Bda,hN,Ada,$c,gN,$c,WM,VM,VM,UM,jc,mf,jc,jc,jc,$c,Pv,Kda,Lda,Nda,Mda,Oda,Ki,hs,hs,ez,TM,ez,ez,fma,mf,CW,Gda,Fda,Eda,Dda,Jda,Ii,XM,hda,jc,jc,te,dz,re,re,te,Ida,Hda,$c,mf,$c,mf,yda,kda,IM,HM,HM,jda,jc,mf,jc,jc,jc,$c,Vka,MM,wda,mda,lda,xda,Ki,uda,tda,sda,rda,qda,pda,oda,nda,vda,Ii,LM,jc,jc,te,re,re,te,KM,JM,ida,eda,DM,Zg,kf,mh,fda,$y,gda,jc,dda,TM,bda,$f,OS,ada,$ca,_ca,Zca,Gu,Oca,Dca,vca,oca,hca,$ba,Rba,Iba,Bba,fca,Tda,zda,Yca,Xca,tn,yO,yM,xM,xM,UM,jc,mf,jc,jc,jc,$c,jG,Sca,Tca,Vca,Uca,Wca,Ki,Rca,Ii,zM,jc,jc,te,re,re,te,Qca,Pca,wM,Zy,Yy,Ica,vM,Hca,jc,mf,jc,jc,jc,$c,uM,Lca,Mca,Nca,Ki,Kca,Ii,Jca,jc,jc,te,re,re,$c,mf,tM,Gca,Fca,sM,Eca,rM,qM,Cca,nM,mM,mM,xca,jc,mf,jc,jc,jc,$c,wca,zca,Aca,Bca,Ki,yca,Ii,oM,jc,jc,te,re,re,uca,Bl,Bl,pca,jc,mf,jc,jc,jc,$c,hM,rca,sca,tca,Ki,qca,Ii,iM,jc,jc,te,re,re,nca,eM,dM,dM,ica,jc,mf,jc,jc,jc,$c,hM,kca,lca,mca,Ki,jca,Ii,fM,jc,jc,te,re,re,gca,cM,cM,dca,uM,eca,tM,cca,bca,sM,aca,rM,qM,_ba,Bl,Bl,Uba,jc,mf,jc,jc,jc,$c,re,Xba,Yba,Zba,Ki,Vba,Ii,Tba,jc,jc,te,re,re,Qba,Sba,YL,XL,XL,Lba,jc,mf,jc,jc,Kba,$c,Jba,Nba,Oba,Pba,Ki,Mba,Ii,Vy,jc,jc,te,re,re,$c,mf,Hba,Bl,Bl,Cba,jc,mf,jc,jc,jc,$c,jG,Eba,Fba,Gba,Ki,Dba,Ii,UL,jc,jc,te,re,re,Aba,Bl,Bl,vba,jc,mf,jc,jc,jc,$c,Pv,xba,yba,zba,Ki,wba,Ii,RL,jc,jc,te,re,re,k9,tba,q9,b9,j9,i9,R8,qx,dL,Kt,GL,N8,jba,FL,O8,cL,J8,I8,af,fba,eba,GL,H8,F8,BL,bba,Py,_K,uy,ZK,YK,t8,p8,q8,r8,Ty,E8,Naa,wL,D8,C8,B8,A8,z8,y8,x8,w8,v8,u8,o8,Ty,i8,WK,VK,UK,TK,RK,QK,PK,OK,NK,MK,LK,KK,h8,ho,JK,IK,vl,gq,g8,vH,e8,c8,b8,a8,$7,FK,EK,Dt,_7,Z7,X7,W7,V7,U7,T7,S7,R7,Q7,V8,nL,mL,lL,kL,T6,R6,BL,Ty,I9,H9,G9,F9,E9,D9,C9,B9,A9,z9,y9,x9,w9,v9,u9,t9,s9,r9,ua,p9,Oy,o9,n9,yL,l9,yL,m9,Lq,h9,Pga,xl,xs,iT,Ql,f9,e9,L7,c9,yk,nT,tu,Z8,hga,U8,mI,T8,M5,zha,P7,Ot,tha,qha,$fa,Y8,g9,a9,xz,og,W8,Gfa,Q8,uL,tL,cL,M8,P8,bL,L8,K8,ef,X8,S8,_8,bc,G8,s8,NO,n8,m8,l8,U6,dA,eA,$8,JO,k8,j8,oo,HK,zea,d8,Ti,Y7,Yc,KO,tz,Wja,sz,K7,J7,I7,sK,H7,jK,At,jK,At,aa,n7,m7,d7,l7,mh,Ht,O7,d9,af,mh,af,Zc,N7,M7,mh,oK,nK,oK,nK,$c,Ct,$c,Ct,lK,kK,lK,kK,Zc,G7,af,Zc,F7,E7,Zc,hK,gK,mh,D7,fK,C7,fK,B7,eK,A7,eK,Zc,z7,y7,Zc,cK,bK,wt,wt,wt,wt,x7,Ay,Ay,Ay,Zc,w7,v7,Zc,aK,$J,u7,_J,t7,_J,s7,ZJ,r7,ZJ,Zc,q7,p7,Zc,YJ,XJ,vt,vt,vt,vt,o7,xy,xy,xy,TJ,k7,Gp,j7,SJ,i7,te,te,h7,g7,Bt,f7,e7,mh,QJ,c7,Gp,b7,PJ,a7,te,jc,te,$6,_6,Z6,Y6,X6,W6,V6,mh,$c,Ct,$c,Ct,ty,KJ,O6,N6,JJ,IJ,GJ,FJ,EJ,DJ,CJ,BJ,AJ,zJ,yJ,xJ,wJ,vJ,uJ,tJ,Q6,P6,M6,L6,K6,J6,I6,H6,F6,E6,D6,C6,B6,A6,z6,y6,x6,w6,af,mh,af,mh,v6,u6,o6,m6,h6,l6,k6,j6,i6,e6,d6,Rs,a6,FI,EI,DI,Ui,bN,Bp,xo,Fc,L5,K5,I5,G5,E5,C5,A5,Rx,z5,S6,G6,HJ,y5,xo,x5,w5,v5,TH,af,ym,V5,$c,Wm,jI,iI,jc,jc,U5,hI,T5,bt,S5,bt,$p,R5,$c,Wm,jI,iI,jc,jc,Q5,hI,P5,bt,O5,bt,at,Sx,fI,eI,at,Sx,fI,eI,_s,Ox,VH,UH,_s,Ox,VH,UH,cu,o5,p5,n5,s5,r5,q5,oh,kI,oh,kI,Bq,OH,m5,l5,wf,NH,i5,h5,mf,b5,e5,KH,af,Zc,g5,E4,D4,C4,f5,d5,Lx,$4,W5,jc,Z4,X4,W4,du,du,Mx,Ix,$s,$H,DH,U4,T4,S4,R4,BH,Q4,P4,N4,M4,DH,L4,zH,K4,J4,BH,I4,zH,H4,G4,af,mh,mh,n_,w4,s4,wH,Gx,Zc,B4,A4,Zc,z4,x4,y4,v4,Zc,u4,t4,r4,jc,jc,jc,zx,Ph,Oh,Os,Yb,Ss,lk,kk,nl,yx,ml,b4,rj,Ug,_3,Y3,iH,iH,U3,S3,hH,sj,Q3,O3,xe,L3,p4,Cx,Px,vx,Ph,Oh,Ms,wm,il,vm,qn,um,rj,Ug,fH,sj,x3,r3,q3,l4,Fx,g6,SH,l3,Vs,un,g3,Sn,Bx,mf,N2,Js,M2,L2,K2,J2,H2,E2,D2,jl,C2,B2,z2,Z5,x2,w2,t2,s2,o2,n2,l2,k2,j2,i2,h2,g2,f2,e2,d2,c2,b2,a2,$1,_1,Z1,Y1,X1,W1,V1,U1,T1,S1,R1,Q1,P1,O1,N1,M1,L1,K1,J1,D1,H1,_$,I1,F1,E1,C1,o4,m4,n4,Dx,pH,pl,oH,_p,a1,$0,uI,nH,mH,I0,H0,F0,E0,C0,B0,z0,y0,w0,v0,s0,r0,p0,lx,n0,l0,i0,g0,e0,c0,a0,KG,G1,vM,IG,o1,n1,m1,l1,k1,tW,j1,i1,h1,GG,f1,e1,d1,c1,b1,jc,_0,Z0,DG,S0,Q0,P0,HK,N0,L0,CG,R0,uy,jZ,O0,M0,K0,af,Zc,Zc,B1,z1,y1,x1,w1,v1,u1,t1,tW,s1,q1,p1,Zc,HG,HG,nx,te,te,g1,te,Zc,Y0,X0,nx,jc,jc,W0,Pv,Zc,V0,U0,nx,jc,jc,T0,Pv,af,Zc,k4,j4,i4,af,Zc,g4,f4,e4,Zc,d4,c4,$3,Z3,X3,W3,V3,T3,R3,P3,N3,Zc,K3,J3,I3,H3,G3,F3,E3,D3,C3,B3,A3,Zc,z3,y3,w3,v3,u3,t3,p3,o3,Zc,n3,m3,k3,j3,i3,h3,f3,e3,af,Zc,re,c3,b3,a3,$2,_2,Z2,J0,D0,x0,h0,d0,q0,m0,af,Zc,re,X2,W2,V2,U2,T2,S2,G0,A0,t0,f0,b0,o0,k0,kx,BG,R2,kx,BG,Q2,Zc,Is,Is,Lh,Lh,Lh,WG,jc,gl,gl,Zc,Is,Is,Lh,Lh,Lh,WG,jc,gl,gl,Zc,$r,$r,Lh,Lh,Lh,VG,jc,gl,gl,Zc,$r,$r,Lh,Lh,Lh,VG,jc,gl,gl,Zc,O2,I2,Zc,F2,A2,Zc,y2,v2,Zc,u2,r2,Zc,PG,q2,$c,Zc,PG,p2,$c,Da,Z$,Zc,W$,Zc,X$,V$,U$,Np,Np,Np,Np,Pw,Zc,S$,af,Zc,mf,mf,R$,H$,K$,Q$,Zc,I$,L$,P$,Zc,J$,M$,O$]);function lb(){return s.byteLength/65536|0}function qb(rb){rb=rb|0;var mb=lb()|0;var nb=mb+rb|0;if(mb<nb&&nb<65536){var ob=new ArrayBuffer(B(nb,65536));var pb=new Int8Array(ob);pb.set(t);t=new Int8Array(ob);u=new Int16Array(ob);v=new Int32Array(ob);w=new Uint8Array(ob);x=new Uint16Array(ob);y=new Uint32Array(ob);z=new Float32Array(ob);A=new Float64Array(ob);s=ob;r.buffer=s;e=w}return mb}return{"va":TY,"wa":uba,"xa":sba,"ya":Zc,"za":Yb,"Aa":rba,"Ba":qba,"Ca":pba,"Da":Kt,"Ea":$c,"Fa":oba,"Ga":nba,"Ha":mba,"Ia":hs,"Ja":lba,"Ka":KL,"La":kba,"Ma":af,"Na":IL,"Oa":HL,"Pa":IL,"Qa":iba,"Ra":C$,"Sa":B$,"Ta":A$,"Ua":hba,"Va":DL,"Wa":dba,"Xa":CL,"Ya":cba,"Za":aba,"_a":$aa,"$a":_aa,"ab":Zaa,"bb":Yaa,"cb":Xaa,"db":Waa,"eb":Vaa,"fb":Uaa,"gb":Taa,"hb":Saa,"ib":Raa,"jb":Qaa,"kb":Paa,"lb":Oaa,"mb":Maa,"nb":Laa,"ob":Kaa,"pb":Jaa,"qb":Iaa,"rb":Haa,"sb":Gaa,"tb":Faa,"ub":Eaa,"vb":Daa,"wb":Caa,"xb":Baa,"yb":Aaa,"zb":zaa,"Ab":yaa,"Bb":xaa,"Cb":waa,"Db":vaa,"Eb":uaa,"Fb":taa,"Gb":saa,"Hb":raa,"Ib":qaa,"Jb":paa,"Kb":oaa,"Lb":naa,"Mb":maa,"Nb":laa,"Ob":kaa,"Pb":jaa,"Qb":iaa,"Rb":haa,"Sb":gaa,"Tb":faa,"Ub":eaa,"Vb":daa,"Wb":caa,"Xb":baa,"Yb":aaa,"Zb":$9,"_b":_9,"$b":Z9,"ac":Y9,"bc":X9,"cc":W9,"dc":V9,"ec":U9,"fc":z$,"gc":T9,"hc":S9,"ic":R9,"jc":Q9,"kc":y$,"lc":P9,"mc":O9,"nc":N9,"oc":M9,"pc":L9,"qc":K9,"rc":J9,"sc":Cd,"tc":f6,"uc":Ila,"vc":Uka,"wc":oja,"xc":F$,"yc":E$,"zc":kb,"Ac":r$,"Bc":x$,"Cc":w$,"Dc":v$,"Ec":u$,"Fc":t$,"Gc":s$,"Hc":r$,"Ic":q$,"Jc":p$,"Kc":o$}}return sb(ub)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


